@@ -37,8 +37,6 @@
 
 #include "base/logging.h"
 #include "base/singleton.h"
-#include "base/status.h"
-#include "base/statusor.h"
 #include "base/system_util.h"
 #include "base/util.h"
 #include "data_manager/data_manager.h"
@@ -48,6 +46,7 @@
 #include "protocol/commands.pb.h"
 #include "session/session_handler.h"
 #include "session/session_usage_observer.h"
+#include "absl/status/statusor.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
 
@@ -85,40 +84,36 @@ jbyteArray JNICALL evalCommand(JNIEnv *env, jclass clazz,
   return out_bytes_array;
 }
 
-string JstringToCcString(JNIEnv *env, jstring j_string) {
+std::string JstringToCcString(JNIEnv *env, jstring j_string) {
   const char *cstr = env->GetStringUTFChars(j_string, nullptr);
-  const string cc_string(cstr);
+  const std::string cc_string(cstr);
   env->ReleaseStringUTFChars(j_string, cstr);
   return cc_string;
 }
 
-mozc::StatusOr<std::unique_ptr<DataManager>> CreateDataManager(
-    const std::string &data_file_path) {
-  auto data_manager = absl::make_unique<DataManager>();
-  const auto status = data_manager->InitFromFile(data_file_path);
-  if (status != DataManager::Status::OK) {
-    return mozc::FailedPreconditionError(
-        DataManager::StatusCodeToString(status));
-  }
-  return data_manager;
-}
-
 std::unique_ptr<EngineInterface> CreateMobileEngine(
     const std::string &data_file_path) {
-  auto data_manager = CreateDataManager(data_file_path);
+  absl::StatusOr<std::unique_ptr<DataManager>> data_manager =
+      DataManager::CreateFromFile(data_file_path);
   if (!data_manager.ok()) {
-    LOG(ERROR) << "Failed to create a data manager from " << data_file_path
-               << ": " << data_manager.status()
-               << ": Fallback to minimal engine";
-    return absl::make_unique<MinimalEngine>();
+    LOG(ERROR)
+        << "Fallback to minimal engine due to data manager creation failure: "
+        << data_manager.status();
+    return std::make_unique<MinimalEngine>();
   }
-  const absl::string_view data_version = (*data_manager)->GetDataVersion();
+  // NOTE: we need to copy the data version to our local string before calling
+  // `Engine::CreateMobileEngine` because, if the engine creation below fails,
+  // it deletes `data_manager` and all the references to its data get
+  // invalidated. We want to log the data version on failure, so its copy is
+  // necessary.
+  const std::string data_version =
+      std::string((*data_manager)->GetDataVersion());
   auto engine = Engine::CreateMobileEngine(*std::move(data_manager));
   if (!engine.ok()) {
     LOG(ERROR) << "Failed to create a mobile engine: file " << data_file_path
                << ", data version: " << data_version << ": " << engine.status()
                << ": Fallback to minimal engine";
-    return absl::make_unique<MinimalEngine>();
+    return std::make_unique<MinimalEngine>();
   }
   LOG(INFO) << "Successfully created a mobile engine from " << data_file_path
             << ", data version=" << data_version;
@@ -134,14 +129,15 @@ std::unique_ptr<SessionHandlerInterface> CreateSessionHandler(
   std::unique_ptr<EngineInterface> engine;
   if (j_data_file_path == nullptr) {
     LOG(ERROR) << "j_data_file_path is null.  Fallback to minimal engine.";
-    engine = absl::make_unique<MinimalEngine>();
+    engine = std::make_unique<MinimalEngine>();
   } else {
-    const string &data_file_path = JstringToCcString(env, j_data_file_path);
+    const std::string &data_file_path =
+        JstringToCcString(env, j_data_file_path);
     engine = CreateMobileEngine(data_file_path);
   }
   DCHECK(engine);
-  auto result = absl::make_unique<SessionHandler>(
-      std::move(engine), absl::make_unique<EngineBuilder>());
+  auto result = std::make_unique<SessionHandler>(
+      std::move(engine), std::make_unique<EngineBuilder>());
   result->AddObserver(Singleton<session::SessionUsageObserver>::get());
   return result;
 }
@@ -157,7 +153,7 @@ jboolean JNICALL onPostLoad(JNIEnv *env, jclass clazz,
   }
 
   // First of all, set the user profile directory.
-  const string &original_dir = SystemUtil::GetUserProfileDirectory();
+  const std::string &original_dir = SystemUtil::GetUserProfileDirectory();
   SystemUtil::SetUserProfileDirectory(
       JstringToCcString(env, user_profile_directory_path));
 
@@ -173,7 +169,7 @@ jboolean JNICALL onPostLoad(JNIEnv *env, jclass clazz,
 }
 
 jstring JNICALL getDataVersion(JNIEnv *env) {
-  string version = "";
+  std::string version = "";
   if (g_session_handler) {
     const absl::string_view version_sp = g_session_handler->GetDataVersion();
     version.assign(version_sp.begin(), version_sp.end());
@@ -202,7 +198,7 @@ Java_com_google_android_inputmethod_japanese_session_MozcJNI_initialize(
       {"getDataVersion", "()Ljava/lang/String;",
        reinterpret_cast<void *>(&mozc::jni::getDataVersion)},
   };
-  if (env->RegisterNatives(clazz, methods, arraysize(methods))) {
+  if (env->RegisterNatives(clazz, methods, std::size(methods))) {
     // Fatal error. No way to recover.
     return false;
   }
