@@ -60,8 +60,8 @@ class AndroidUtil {
   //     AndroidUtil::GetSystemProperty(kAndroidSystemPropertyModel));
   // Note : Using ::popen("getprop [property name]", "r") is better solution
   // but currently popen seems to be unstable.
-  static string GetSystemProperty(const string &key,
-                                  const string &default_value);
+  static std::string GetSystemProperty(const std::string &key,
+                                       const std::string &default_value);
 
  private:
   FRIEND_TEST(AndroidUtilTest, ParseLine_valid);
@@ -72,17 +72,18 @@ class AndroidUtil {
   // returns true.
   // If something goes wrong (e.g. file system error, non-existent property
   // name), returns false. |output| is undefined.
-  static bool GetPropertyFromFile(const string &key, string *output);
+  static bool GetPropertyFromFile(const std::string &key, std::string *output);
 
   // Parses the line.
   // If the returned value is ture, the property's key and value string are
   // returned as |lhs| and |rhs| respectively.
   // If false, |line| is malformed.
   // In this case |lhs| and |rhs| are not modified.
-  static bool ParseLine(const string &line, string *lhs, string *rhs);
+  static bool ParseLine(const std::string &line, std::string *lhs,
+                        std::string *rhs);
 
-  static std::map<string, string> property_cache;
-  static std::set<string> undefined_keys;
+  static std::map<std::string, std::string> property_cache;
+  static std::set<std::string> undefined_keys;
 
   DISALLOW_IMPLICIT_CONSTRUCTORS(AndroidUtil);
 };
