@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,6 +30,8 @@
 #ifndef MOZC_BASE_CONFIG_FILE_STREAM_H_
 #define MOZC_BASE_CONFIG_FILE_STREAM_H_
 
+#include <string>
+
 #include "base/file_stream.h"
 
 namespace mozc {
@@ -74,7 +76,7 @@ class ConfigFileStream {
   //     return Open(filename, ios_base::in);
   //   }
   // As of Mozc 1.3, a number of files had had depended on this method.
-  // However, we did not programatically replaced all of them with
+  // However, we did not programmatically replaced all of them with
   // |OpenReadText| because these existing code do not have enough unit
   // tests to check the treatment of line-end character, especially on Windows.
   // Perhaps |OpenReadBinary| might be more appropriate in some cases.
