@@ -33,9 +33,11 @@
 #include <ios>
 #include <istream>
 #include <memory>
+#include <string>
 
 #include "base/file_util.h"
 #include "base/system_util.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
@@ -115,45 +117,39 @@ TEST_F(ConfigFileStreamTest, AtomicUpdate) {
   const std::string filename = ConfigFileStream::GetFileName(prefixed_filename);
   const std::string tmp_filename = filename + ".tmp";
 
-  EXPECT_FALSE(FileUtil::FileExists(filename));
-  EXPECT_FALSE(FileUtil::FileExists(tmp_filename));
+  EXPECT_FALSE(FileUtil::FileExists(filename).ok());
+  EXPECT_FALSE(FileUtil::FileExists(tmp_filename).ok());
 
   const std::string contents = "123\n2\n3";
   ConfigFileStream::AtomicUpdate(prefixed_filename, contents);
-  EXPECT_TRUE(FileUtil::FileExists(filename));
-  EXPECT_FALSE(FileUtil::FileExists(tmp_filename));
+  EXPECT_OK(FileUtil::FileExists(filename));
+  EXPECT_FALSE(FileUtil::FileExists(tmp_filename).ok());
   EXPECT_EQ(contents, GetFileData(filename));
 
   const std::string new_contents = "246\n4\n6";
   ConfigFileStream::AtomicUpdate(prefixed_filename, new_contents);
-  EXPECT_TRUE(FileUtil::FileExists(filename));
-  EXPECT_FALSE(FileUtil::FileExists(tmp_filename));
+  EXPECT_OK(FileUtil::FileExists(filename));
+  EXPECT_FALSE(FileUtil::FileExists(tmp_filename).ok());
   EXPECT_EQ(new_contents, GetFileData(filename));
 
-  if (FileUtil::FileExists(filename)) {
-    FileUtil::Unlink(filename);
-  }
+  EXPECT_OK(FileUtil::UnlinkIfExists(filename));
 }
 
 TEST_F(ConfigFileStreamTest, OpenReadBinary) {
   // At first, generate a binary data file in (temporary) user directory
   // so that we can load it as "user://my_binary_file.dat"
-  const char kTestFileName[] = "my_binary_file.dat";
+  constexpr char kTestFileName[] = "my_binary_file.dat";
   const std::string &test_file_path =
       FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(), kTestFileName);
 
-  const char kBinaryData[] = {
+  constexpr char kBinaryData[] = {
       ' ', ' ', '\r', ' ', '\n', ' ', '\r', '\n', ' ', '\0', ' ',
   };
-  const size_t kBinaryDataSize = sizeof(kBinaryData);
-  {
-    OutputFileStream ofs(test_file_path.c_str(),
-                         std::ios::out | std::ios::binary);
-    ofs.write(kBinaryData, kBinaryDataSize);
-  }
-
-  ASSERT_TRUE(FileUtil::FileExists(test_file_path));
-
+  constexpr size_t kBinaryDataSize = sizeof(kBinaryData);
+  ASSERT_OK(FileUtil::SetContents(
+      test_file_path, absl::string_view(kBinaryData, kBinaryDataSize)));
+  ASSERT_OK(FileUtil::FileExists(test_file_path));
+  FileUnlinker unlinker(test_file_path);
   {
     std::unique_ptr<std::istream> ifs(ConfigFileStream::OpenReadBinary(
         "user://" + std::string(kTestFileName)));
@@ -166,36 +162,29 @@ TEST_F(ConfigFileStreamTest, OpenReadBinary) {
     }
     EXPECT_TRUE(IsEof(ifs.get()));
   }
-
-  // Remove test file just in case.
-  EXPECT_TRUE(FileUtil::Unlink(test_file_path));
-  EXPECT_FALSE(FileUtil::FileExists(test_file_path));
 }
 
 TEST_F(ConfigFileStreamTest, OpenReadText) {
   // At first, generate a binary data file in (temporary) user directory
   // so that we can load it as "user://my_binary_file.dat"
-  const char kTestFileName[] = "my_text_file.dat";
+  constexpr char kTestFileName[] = "my_text_file.dat";
   const std::string &test_file_path =
       FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(), kTestFileName);
 
-  const char kSourceTextData[] = {
+  constexpr char kSourceTextData[] = {
       'a', 'b', '\r', 'c', '\n', 'd', '\r', '\n', 'e',
   };
-  {
-    // Use |ios::binary| to preserve the line-end character.
-    OutputFileStream ofs(test_file_path.c_str(),
-                         std::ios::out | std::ios::binary);
-    ofs.write(kSourceTextData, sizeof(kSourceTextData));
-  }
-
-  ASSERT_TRUE(FileUtil::FileExists(test_file_path));
+  ASSERT_OK(FileUtil::SetContents(
+      test_file_path,
+      absl::string_view(kSourceTextData, sizeof(kSourceTextData))));
+  ASSERT_OK(FileUtil::FileExists(test_file_path));
+  FileUnlinker unlinker(test_file_path);
 
 #ifdef OS_WIN
 #define TRAILING_CARRIAGE_RETURN ""
-#else
+#else  // OS_WIN
 #define TRAILING_CARRIAGE_RETURN "\r"
-#endif
+#endif  // OS_WIN
   const char *kExpectedLines[] = {
       "ab\rc",
       "d" TRAILING_CARRIAGE_RETURN,
@@ -211,15 +200,11 @@ TEST_F(ConfigFileStreamTest, OpenReadText) {
     int line_number = 0;  // note that this is 1-origin.
     while (!std::getline(*ifs, line).fail()) {
       ++line_number;
-      ASSERT_LE(line_number, arraysize(kExpectedLines));
+      ASSERT_LE(line_number, std::size(kExpectedLines));
       EXPECT_EQ(line, kExpectedLines[line_number - 1])
           << "failed at line: " << line_number;
     }
   }
-
-  // Remove test file just in case.
-  EXPECT_TRUE(FileUtil::Unlink(test_file_path));
-  EXPECT_FALSE(FileUtil::FileExists(test_file_path));
 }
 
 }  // namespace mozc
