@@ -27,14 +27,15 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include <cstdint>
 #include <iostream>
 #include <string>
 
 #include "base/encryptor.h"
-#include "base/file_stream.h"
+#include "base/file_util.h"
 #include "base/init_mozc.h"
 #include "base/logging.h"
-#include "base/mmap.h"
+#include "base/status.h"
 #include "base/util.h"
 #include "absl/flags/flag.h"
 
@@ -69,18 +70,18 @@ int main(int argc, char **argv) {
   }
 
   const std::string iv_str = absl::GetFlag(FLAGS_iv);
-  const uint8 *iv =
-      iv_str.empty() ? nullptr : reinterpret_cast<const uint8 *>(iv_str.data());
+  const uint8_t *iv = iv_str.empty()
+                          ? nullptr
+                          : reinterpret_cast<const uint8_t *>(iv_str.data());
 
   if (!absl::GetFlag(FLAGS_input_file).empty() &&
       !absl::GetFlag(FLAGS_output_file).empty()) {
     mozc::Encryptor::Key key;
     CHECK(key.DeriveFromPassword(absl::GetFlag(FLAGS_password),
                                  absl::GetFlag(FLAGS_salt), iv));
-
-    mozc::Mmap mmap;
-    CHECK(mmap.Open(absl::GetFlag(FLAGS_input_file).c_str(), "r"));
-    std::string buf(mmap.begin(), mmap.size());
+    std::string buf;
+    CHECK_OK(
+        mozc::FileUtil::GetContents(absl::GetFlag(FLAGS_input_file), &buf));
     if (absl::GetFlag(FLAGS_encrypt)) {
       CHECK(mozc::Encryptor::EncryptString(key, &buf));
     } else if (absl::GetFlag(FLAGS_decrypt)) {
@@ -88,10 +89,8 @@ int main(int argc, char **argv) {
     } else {
       LOG(FATAL) << "unknown mode. set --encrypt or --decrypt";
     }
-    mozc::OutputFileStream ofs(absl::GetFlag(FLAGS_output_file).c_str(),
-                               std::ios::binary);
-    CHECK(ofs);
-    ofs.write(buf.data(), buf.size());
+    CHECK_OK(
+        mozc::FileUtil::SetContents(absl::GetFlag(FLAGS_output_file), buf));
   } else if (!absl::GetFlag(FLAGS_test_input).empty()) {
     mozc::Encryptor::Key key1, key2;
     CHECK(key1.DeriveFromPassword(absl::GetFlag(FLAGS_password),
