@@ -29,7 +29,9 @@
 
 #include "base/encryptor.h"
 
+#include <cstdint>
 #include <memory>
+#include <string>
 
 #include "base/password_manager.h"
 #include "base/system_util.h"
@@ -80,10 +82,10 @@ TEST(EncryptorTest, VerificationTest) {
     const std::string salt(kTestData[0].salt, kTestData[0].salt_size);
     Encryptor::Key key1, key2;
     EXPECT_TRUE(key1.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[0].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[0].iv)));
     EXPECT_TRUE(key1.IsAvailable());
     EXPECT_TRUE(key2.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[0].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[0].iv)));
     EXPECT_TRUE(key2.IsAvailable());
     std::string input(kTestData[0].input, kTestData[0].input_size);
     const std::string encrypted(kTestData[0].encrypted,
@@ -101,10 +103,10 @@ TEST(EncryptorTest, VerificationTest) {
     const std::string salt(kTestData[1].salt, kTestData[1].salt_size);
     Encryptor::Key key1, key2;
     EXPECT_TRUE(key1.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[1].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[1].iv)));
     EXPECT_TRUE(key1.IsAvailable());
     EXPECT_TRUE(key2.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[1].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[1].iv)));
     EXPECT_TRUE(key2.IsAvailable());
     std::string input(kTestData[1].input, kTestData[1].input_size);
     const std::string encrypted(kTestData[1].encrypted,
@@ -122,10 +124,10 @@ TEST(EncryptorTest, VerificationTest) {
     const std::string salt(kTestData[2].salt, kTestData[2].salt_size);
     Encryptor::Key key1, key2;
     EXPECT_TRUE(key1.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[2].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[2].iv)));
     EXPECT_TRUE(key1.IsAvailable());
     EXPECT_TRUE(key2.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[2].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[2].iv)));
     EXPECT_TRUE(key2.IsAvailable());
     std::string input(kTestData[2].input, kTestData[2].input_size);
     const std::string encrypted(kTestData[2].encrypted,
@@ -143,10 +145,10 @@ TEST(EncryptorTest, VerificationTest) {
     const std::string salt(kTestData[3].salt, kTestData[3].salt_size);
     Encryptor::Key key1, key2;
     EXPECT_TRUE(key1.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[3].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[3].iv)));
     EXPECT_TRUE(key1.IsAvailable());
     EXPECT_TRUE(key2.DeriveFromPassword(
-        password, salt, reinterpret_cast<const uint8 *>(kTestData[3].iv)));
+        password, salt, reinterpret_cast<const uint8_t *>(kTestData[3].iv)));
     EXPECT_TRUE(key2.IsAvailable());
     std::string input(kTestData[3].input, kTestData[3].input_size);
     const std::string encrypted(kTestData[3].encrypted,
@@ -172,10 +174,10 @@ TEST(EncryptorTest, BasicTest) {
 }
 
 TEST(EncryptorTest, EncryptBatch) {
-  const size_t kSizeTable[] = {1,    10,   16,    32,    100,
-                               1000, 1600, 10000, 16000, 100000};
+  constexpr size_t kSizeTable[] = {1,    10,   16,    32,    100,
+                                   1000, 1600, 10000, 16000, 100000};
 
-  for (size_t i = 0; i < arraysize(kSizeTable); ++i) {
+  for (size_t i = 0; i < std::size(kSizeTable); ++i) {
     std::unique_ptr<char[]> buf(new char[kSizeTable[i]]);
     Util::GetRandomSequence(buf.get(), kSizeTable[i]);
 
@@ -227,9 +229,9 @@ TEST(EncryptorTest, EncryptBatch) {
 
 TEST(EncryptorTest, ProtectData) {
   SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
-  const size_t kSizeTable[] = {1, 10, 100, 1000, 10000, 100000};
+  constexpr size_t kSizeTable[] = {1, 10, 100, 1000, 10000, 100000};
 
-  for (size_t i = 0; i < arraysize(kSizeTable); ++i) {
+  for (size_t i = 0; i < std::size(kSizeTable); ++i) {
     std::unique_ptr<char[]> buf(new char[kSizeTable[i]]);
     Util::GetRandomSequence(buf.get(), kSizeTable[i]);
     std::string input(buf.get(), kSizeTable[i]);
