@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -43,7 +43,7 @@ namespace {
 std::wstring ToPlatformString(const char* filename) {
   // Since Windows uses UTF-16 for internationalized file names, we should
   // convert the encoding of the given |filename| from UTF-8 to UTF-16.
-  // NOTE: To avoid circular dependency, |Util::UTF8ToWide| shouldn't be used
+  // NOTE: To avoid circular dependency, |Util::Utf8ToWide| shouldn't be used
   // here.
   std::wstring_convert<std::codecvt_utf8_utf16<wchar_t>, wchar_t> utf8_to_wide;
   return utf8_to_wide.from_bytes(filename);
@@ -81,20 +81,6 @@ void OutputFileStream::open(const char* filename,
 
 // Common implementations.
 
-void InputFileStream::ReadToString(std::string* s) {
-  seekg(0, end);
-  const size_t size = tellg();
-  seekg(0, beg);
-  s->resize(size);
-  read(&(*s)[0], size);
-}
-
-std::string InputFileStream::Read() {
-  std::string s;
-  ReadToString(&s);
-  return s;
-}
-
 void InputFileStream::UnusedKeyMethod() {}   // go/definekeymethod
 void OutputFileStream::UnusedKeyMethod() {}  // go/definekeymethod
 
