@@ -34,12 +34,14 @@
 #include <windows.h>
 #else  // OS_WIN
 #include <sys/types.h>
-#endif
+#endif  // OS_WIN
 
 #include <string>
 #include <vector>
 
 #include "base/port.h"
+#include "absl/status/status.h"
+#include "absl/status/statusor.h"
 #include "absl/strings/string_view.h"
 
 // Ad-hoc workaround against macro problem on Windows.
@@ -61,7 +63,7 @@ namespace mozc {
 
 #if defined(OS_WIN)
 using FileTimeStamp = uint64;
-#else
+#else   // OS_WIN
 using FileTimeStamp = time_t;
 #endif  // OS_WIN
 
@@ -69,19 +71,23 @@ class FileUtilInterface {
  public:
   virtual ~FileUtilInterface() = default;
 
-  virtual bool CreateDirectory(const std::string &path) const = 0;
-  virtual bool RemoveDirectory(const std::string &dirname) const = 0;
-  virtual bool Unlink(const std::string &filename) const = 0;
-  virtual bool FileExists(const std::string &filename) const = 0;
-  virtual bool DirectoryExists(const std::string &dirname) const = 0;
-  virtual bool CopyFile(const std::string &from,
-                        const std::string &to) const = 0;
-  virtual bool IsEqualFile(const std::string &filename1,
-                          const std::string &filename2) const = 0;
-  virtual bool AtomicRename(const std::string &from,
-                            const std::string &to) const = 0;
-  virtual bool GetModificationTime(const std::string &filename,
-                                  FileTimeStamp *modified_at) const = 0;
+  virtual absl::Status CreateDirectory(const std::string &path) const = 0;
+  virtual absl::Status RemoveDirectory(const std::string &dirname) const = 0;
+  virtual absl::Status Unlink(const std::string &filename) const = 0;
+  virtual absl::Status FileExists(const std::string &filename) const = 0;
+  virtual absl::Status DirectoryExists(const std::string &dirname) const = 0;
+  virtual absl::Status CopyFile(const std::string &from,
+                                const std::string &to) const = 0;
+  virtual absl::StatusOr<bool> IsEqualFile(
+      const std::string &filename1, const std::string &filename2) const = 0;
+  virtual absl::StatusOr<bool> IsEquivalent(
+      const std::string &filename1, const std::string &filename2) const = 0;
+  virtual absl::Status AtomicRename(const std::string &from,
+                                    const std::string &to) const = 0;
+  virtual absl::Status CreateHardLink(const std::string &from,
+                                      const std::string &to) = 0;
+  virtual absl::StatusOr<FileTimeStamp> GetModificationTime(
+      const std::string &filename) const = 0;
 
  protected:
   FileUtilInterface() = default;
@@ -89,43 +95,65 @@ class FileUtilInterface {
 
 class FileUtil {
  public:
+  FileUtil() = delete;
+  ~FileUtil() = delete;
+
   // Creates a directory. Does not create directories in the way to the path.
-  static bool CreateDirectory(const std::string &path);
+  static absl::Status CreateDirectory(const std::string &path);
 
   // Removes an empty directory.
-  static bool RemoveDirectory(const std::string &dirname);
+  static absl::Status RemoveDirectory(const std::string &dirname);
+  static absl::Status RemoveDirectoryIfExists(const std::string &dirname);
 
-  // Removes a file.
-  static bool Unlink(const std::string &filename);
+  // Removes a file. The second version returns OK when `filename` doesn't
+  // exist. The third version logs error message on failure (i.e., it ignores
+  // any error and is not recommended).
+  static absl::Status Unlink(const std::string &filename);
+  static absl::Status UnlinkIfExists(const std::string &filename);
+  static void UnlinkOrLogError(const std::string &filename);
 
   // Returns true if a file or a directory with the name exists.
-  static bool FileExists(const std::string &filename);
+  static absl::Status FileExists(const std::string &filename);
 
   // Returns true if the directory exists.
-  static bool DirectoryExists(const std::string &dirname);
+  static absl::Status DirectoryExists(const std::string &dirname);
 
 #ifdef OS_WIN
   // Adds file attributes to the file to hide it.
   // FILE_ATTRIBUTE_NORMAL will be removed.
-  static bool HideFile(const string &filename);
-  static bool HideFileWithExtraAttributes(const string &filename,
+  static bool HideFile(const std::string &filename);
+  static bool HideFileWithExtraAttributes(const std::string &filename,
                                           DWORD extra_attributes);
 #endif  // OS_WIN
 
   // Copies a file to another file, using mmap internally.
   // The destination file will be overwritten if exists.
   // Returns true if the file is copied successfully.
-  static bool CopyFile(const std::string &from, const std::string &to);
+  static absl::Status CopyFile(const std::string &from, const std::string &to);
 
   // Compares the contents of two given files. Ignores the difference between
   // their path strings.
   // Returns true if both files have same contents.
-  static bool IsEqualFile(const std::string &filename1,
-                          const std::string &filename2);
+  static absl::StatusOr<bool> IsEqualFile(const std::string &filename1,
+                                          const std::string &filename2);
+
+  // Compares the two filenames point to the same file. Symbolic/hard links are
+  // considered. This is a wrapper of std::filesystem::equivalent.
+  // IsEqualFile reads the contents of the files, but IsEquivalent does not.
+  // Returns an error, if either of files doesn't exist.
+  static absl::StatusOr<bool> IsEquivalent(const std::string &filename1,
+                                           const std::string &filename2);
 
   // Moves/Renames a file atomically.
-  // Returns true if the file is renamed successfully.
-  static bool AtomicRename(const std::string &from, const std::string &to);
+  // Returns OK if the file is renamed successfully.
+  static absl::Status AtomicRename(const std::string &from,
+                                   const std::string &to);
+
+  // Creates a hard link. This returns false if the filesystem does not support
+  // hard link or the target file already exists.
+  // This is a wrapper of std::filesystem::create_hard_link.
+  static absl::Status CreateHardLink(const std::string &from,
+                                     const std::string &to);
 
   // Joins the give path components using the OS-specific path delimiter.
   static std::string JoinPath(const std::vector<absl::string_view> &components);
@@ -151,14 +179,46 @@ class FileUtil {
 
   // Returns the modification time in `modified_at`.
   // Returns false if something went wrong.
-  static bool GetModificationTime(const std::string &filename,
-                                  FileTimeStamp *modified_at);
+  static absl::StatusOr<FileTimeStamp> GetModificationTime(
+      const std::string &filename);
+
+  // Reads the contents of the file `filename` into `output`.
+  static absl::Status GetContents(
+      const std::string &filename, std::string *output,
+      std::ios_base::openmode mode = std::ios::binary);
+
+  // Reads the contents of the file `filename` and returns it.
+  static absl::StatusOr<std::string> GetContents(
+      const std::string &filename,
+      std::ios_base::openmode mode = std::ios::binary);
+
+  // Writes the data provided in `content` to the file `filename`, overwriting
+  // any existing content.
+  static absl::Status SetContents(
+      const std::string &filename, absl::string_view content,
+      std::ios_base::openmode mode = std::ios::binary);
 
   // Sets a mock for unittest.
   static void SetMockForUnitTest(FileUtilInterface *mock);
 
+  // Make a hard-link or copy of `src_file`.
+  static absl::Status LinkOrCopyFile(const std::string &src_path,
+                                     const std::string &dst_path);
+};
+
+// RAII wrapper for a file. Unlinks the file when this instance goes out of
+// scope.
+class FileUnlinker final {
+ public:
+  explicit FileUnlinker(const std::string &filename) : filename_(filename) {}
+
+  FileUnlinker(const FileUnlinker &) = delete;
+  FileUnlinker &operator=(const FileUnlinker &) = delete;
+
+  ~FileUnlinker() { FileUtil::UnlinkOrLogError(filename_); }
+
  private:
-  DISALLOW_IMPLICIT_CONSTRUCTORS(FileUtil);
+  const std::string filename_;
 };
 
 }  // namespace mozc
