@@ -30,6 +30,7 @@
 #ifndef MOZC_BASE_HASH_H_
 #define MOZC_BASE_HASH_H_
 
+#include <cstdint>
 #include <type_traits>
 
 #include "base/port.h"
@@ -40,25 +41,25 @@ namespace mozc {
 class Hash {
  public:
   // Calculates 64-bit fingerprint.
-  static uint64 Fingerprint(absl::string_view str);
-  static uint64 FingerprintWithSeed(absl::string_view str, uint32 seed);
+  static uint64_t Fingerprint(absl::string_view str);
+  static uint64_t FingerprintWithSeed(absl::string_view str, uint32_t seed);
 
   // Calculates 32-bit fingerprint.
-  static uint32 Fingerprint32(absl::string_view str);
-  static uint32 Fingerprint32WithSeed(absl::string_view str, uint32 seed);
+  static uint32_t Fingerprint32(absl::string_view str);
+  static uint32_t Fingerprint32WithSeed(absl::string_view str, uint32_t seed);
 
   // Calculates 64-bit fingerprint for integral types.
   // Note: This function depends on endian.
   template <typename T>
-  static typename std::enable_if<std::is_integral<T>::value, uint64>::type
+  static typename std::enable_if<std::is_integral<T>::value, uint64_t>::type
   Fingerprint(T num) {
     return Fingerprint(
         absl::string_view(reinterpret_cast<const char*>(&num), sizeof(num)));
   }
 
   template <typename T>
-  static typename std::enable_if<std::is_integral<T>::value, uint64>::type
-  FingerprintWithSeed(T num, uint32 seed) {
+  static typename std::enable_if<std::is_integral<T>::value, uint64_t>::type
+  FingerprintWithSeed(T num, uint32_t seed) {
     return FingerprintWithSeed(
         absl::string_view(reinterpret_cast<const char*>(&num), sizeof(num)),
         seed);
@@ -67,15 +68,15 @@ class Hash {
   // Calculates 32-bit fingerprint for integral types.
   // Note: This function depends on endian.
   template <typename T>
-  static typename std::enable_if<std::is_integral<T>::value, uint32>::type
+  static typename std::enable_if<std::is_integral<T>::value, uint32_t>::type
   Fingerprint32(T num) {
     return Fingerprint32(
         absl::string_view(reinterpret_cast<const char*>(&num), sizeof(num)));
   }
 
   template <typename T>
-  static typename std::enable_if<std::is_integral<T>::value, uint32>::type
-  Fingerprint32WithSeed(T num, uint32 seed) {
+  static typename std::enable_if<std::is_integral<T>::value, uint32_t>::type
+  Fingerprint32WithSeed(T num, uint32_t seed) {
     return Fingerprint32WithSeed(
         absl::string_view(reinterpret_cast<const char*>(&num), sizeof(num)),
         seed);
