@@ -41,20 +41,20 @@ namespace {
 const char kFileSchema[] = "file://";
 }  // namespace
 
-bool MacProcess::OpenBrowserForMac(const string &url) {
+bool MacProcess::OpenBrowserForMac(const std::string &url) {
   bool success = false;
   NSURL *nsURL = nil;
   if (url.find(kFileSchema) == 0) {
     // for making URL from "file://...", use fileURLWithPath
-    const string filepath = url.substr(strlen(kFileSchema));
+    const std::string filepath = url.substr(strlen(kFileSchema));
     NSString *nsStr = [[NSString alloc] initWithBytes:filepath.data()
-                                        length:filepath.size()
-                                        encoding:NSUTF8StringEncoding];
+                                               length:filepath.size()
+                                             encoding:NSUTF8StringEncoding];
     nsURL = [NSURL fileURLWithPath:nsStr];
   } else {
     NSString *nsStr = [[NSString alloc] initWithBytes:url.data()
-                                        length:url.size()
-                                        encoding:NSUTF8StringEncoding];
+                                               length:url.size()
+                                             encoding:NSUTF8StringEncoding];
     nsURL = [NSURL URLWithString:nsStr];
   }
   if (nsURL) {
@@ -65,16 +65,16 @@ bool MacProcess::OpenBrowserForMac(const string &url) {
   return success;
 }
 
-bool MacProcess::OpenApplication(const string &path) {
+bool MacProcess::OpenApplication(const std::string &path) {
   NSString *nsStr = [[NSString alloc] initWithBytes:path.data()
-                                      length:path.size()
-                                      encoding:NSUTF8StringEncoding];
+                                             length:path.size()
+                                           encoding:NSUTF8StringEncoding];
   [[NSWorkspace sharedWorkspace] launchApplication:nsStr];
   return true;
 }
 
 namespace {
-bool LaunchMozcToolInternal(const string &tool_name, const string &error_type) {
+bool LaunchMozcToolInternal(const std::string &tool_name, const std::string &error_type) {
   // FLAGS_error_type is used where FLAGS_mode is "error_message_dialog".
   setenv("FLAGS_error_type", error_type.c_str(), 1);
 
@@ -97,8 +97,7 @@ bool LaunchMozcToolInternal(const string &tool_name, const string &error_type) {
   }
 
   // The Mozc Tool apps reside in the same directory where the mozc server does.
-  NSString *toolAppPath =
-      [NSString stringWithUTF8String:MacUtil::GetServerDirectory().c_str()];
+  NSString *toolAppPath = [NSString stringWithUTF8String:MacUtil::GetServerDirectory().c_str()];
 
   if (appName != nil) {
     toolAppPath = [toolAppPath stringByAppendingPathComponent:appName];
@@ -106,21 +105,19 @@ bool LaunchMozcToolInternal(const string &tool_name, const string &error_type) {
     // Otherwise, we tries to invoke the application by settings FLAGS_mode.
     // use --fromenv option to specify tool name
     setenv("FLAGS_mode", tool_name.c_str(), 1);
-    toolAppPath = [toolAppPath
-                    stringByAppendingPathComponent:@ kProductPrefix "Tool.app"];
+    toolAppPath = [toolAppPath stringByAppendingPathComponent:@kProductPrefix "Tool.app"];
   }
 
-  bool succeeded =
-      [[NSWorkspace sharedWorkspace] launchApplication:toolAppPath];
+  bool succeeded = [[NSWorkspace sharedWorkspace] launchApplication:toolAppPath];
   return succeeded;
 }
 }  // namespace
 
-bool MacProcess::LaunchMozcTool(const string &tool_name) {
+bool MacProcess::LaunchMozcTool(const std::string &tool_name) {
   return LaunchMozcToolInternal(tool_name, "");
 }
 
-bool MacProcess::LaunchErrorMessageDialog(const string &error_type) {
+bool MacProcess::LaunchErrorMessageDialog(const std::string &error_type) {
   return LaunchMozcToolInternal("error_message_dialog", error_type);
 }
 
