@@ -33,11 +33,12 @@
 
 #ifdef OS_IOS
 #import <UIKit/UIKit.h>
-#else
-#include <launch.h>
+#else  // OS_IOS
 #include <CoreFoundation/CoreFoundation.h>
+#include <CoreGraphics/CoreGraphics.h>
 #include <IOKit/IOKitLib.h>
-#endif
+#include <launch.h>
+#endif  // OS_IOS
 
 #include "base/const.h"
 #include "base/logging.h"
@@ -47,23 +48,20 @@
 
 namespace mozc {
 namespace {
-const char kServerDirectory[] =
-    "/Library/Input Methods/" kProductPrefix ".app/Contents/Resources";
+const char kServerDirectory[] = "/Library/Input Methods/" kProductPrefix ".app/Contents/Resources";
 #ifndef OS_IOS
 const unsigned char kPrelauncherPath[] =
-    "/Library/Input Methods/" kProductPrefix ".app/Contents/Resources/"
-    kProductPrefix "Prelauncher.app";
+    "/Library/Input Methods/" kProductPrefix ".app/Contents/Resources/" kProductPrefix
+    "Prelauncher.app";
 #endif  // OS_IOS
 
 #ifdef GOOGLE_JAPANESE_INPUT_BUILD
-const char kProjectPrefix[] =
-    "com.google.inputmethod.Japanese.";
+const char kProjectPrefix[] = "com.google.inputmethod.Japanese.";
 #elif defined(MOZC_BUILD)
-const char kProjectPrefix[] =
-    "org.mozc.inputmethod.Japanese.";
-#else
+const char kProjectPrefix[] = "org.mozc.inputmethod.Japanese.";
+#else  // GOOGLE_JAPANESE_INPUT_BUILD, MOZC_BUILD
 #error Unknown branding
-#endif
+#endif  // GOOGLE_JAPANESE_INPUT_BUILD, MOZC_BUILD
 
 #ifndef OS_IOS
 // Returns the reference of prelauncher login item.
@@ -71,19 +69,15 @@ const char kProjectPrefix[] =
 // Otherwise you must release the reference.
 LSSharedFileListItemRef GetPrelauncherLoginItem() {
   LSSharedFileListItemRef prelauncher_item = nullptr;
-  scoped_cftyperef<CFURLRef> url(
-    CFURLCreateFromFileSystemRepresentation(
-        kCFAllocatorDefault, kPrelauncherPath,
-        strlen((const char *)kPrelauncherPath), true));
+  scoped_cftyperef<CFURLRef> url(CFURLCreateFromFileSystemRepresentation(
+      kCFAllocatorDefault, kPrelauncherPath, strlen((const char *)kPrelauncherPath), true));
   if (!url.get()) {
-    LOG(ERROR) << "CFURLCreateFromFileSystemRepresentation error:"
-               << " Cannot create CFURL object.";
+    LOG(ERROR) << "CFURLCreateFromFileSystemRepresentation error: Cannot create CFURL object.";
     return nullptr;
   }
 
   scoped_cftyperef<LSSharedFileListRef> login_items(
-      LSSharedFileListCreate(
-          kCFAllocatorDefault, kLSSharedFileListSessionLoginItems, nullptr));
+      LSSharedFileListCreate(kCFAllocatorDefault, kLSSharedFileListSessionLoginItems, nullptr));
   if (!login_items.get()) {
     LOG(ERROR) << "LSSharedFileListCreate error: Cannot get the login items.";
     return nullptr;
@@ -92,26 +86,22 @@ LSSharedFileListItemRef GetPrelauncherLoginItem() {
   scoped_cftyperef<CFArrayRef> login_items_array(
       LSSharedFileListCopySnapshot(login_items.get(), nullptr));
   if (!login_items_array.get()) {
-    LOG(ERROR) << "LSSharedFileListCopySnapshot error:"
-               << " Cannot get the login items.";
+    LOG(ERROR) << "LSSharedFileListCopySnapshot error: Cannot get the login items.";
     return nullptr;
   }
 
-  for(CFIndex i = 0; i < CFArrayGetCount(login_items_array.get()); ++i) {
-    LSSharedFileListItemRef item =
-        reinterpret_cast<LSSharedFileListItemRef>(const_cast<void *>(
-            CFArrayGetValueAtIndex(login_items_array.get(), i)));
+  for (CFIndex i = 0; i < CFArrayGetCount(login_items_array.get()); ++i) {
+    LSSharedFileListItemRef item = reinterpret_cast<LSSharedFileListItemRef>(
+        const_cast<void *>(CFArrayGetValueAtIndex(login_items_array.get(), i)));
     if (!item) {
-      LOG(ERROR) << "CFArrayGetValueAtIndex error:"
-                 << " Cannot get the login item.";
+      LOG(ERROR) << "CFArrayGetValueAtIndex error: Cannot get the login item.";
       return nullptr;
     }
 
     CFURLRef item_url_ref = nullptr;
     if (LSSharedFileListItemResolve(item, 0, &item_url_ref, nullptr) == noErr) {
       if (!item_url_ref) {
-        LOG(ERROR) << "LSSharedFileListItemResolve error:"
-                   << " Cannot get the login item url.";
+        LOG(ERROR) << "LSSharedFileListItemResolve error: Cannot get the login item url.";
         return nullptr;
       }
       if (CFEqual(item_url_ref, url.get())) {
@@ -125,11 +115,10 @@ LSSharedFileListItemRef GetPrelauncherLoginItem() {
 }
 #endif  // OS_IOS
 
-string GetSearchPathForDirectoriesInDomains(NSSearchPathDirectory directory) {
-  string dir;
+std::string GetSearchPathForDirectoriesInDomains(NSSearchPathDirectory directory) {
+  std::string dir;
   @autoreleasepool {
-    NSArray *paths = NSSearchPathForDirectoriesInDomains(
-        directory, NSUserDomainMask, YES);
+    NSArray *paths = NSSearchPathForDirectoriesInDomains(directory, NSUserDomainMask, YES);
     if ([paths count] > 0) {
       dir.assign([[paths objectAtIndex:0] fileSystemRepresentation]);
     }
@@ -139,48 +128,43 @@ string GetSearchPathForDirectoriesInDomains(NSSearchPathDirectory directory) {
 
 }  // namespace
 
-string MacUtil::GetLabelForSuffix(const string &suffix) {
-  return string(kProjectPrefix) + suffix;
+std::string MacUtil::GetLabelForSuffix(const std::string &suffix) {
+  return std::string(kProjectPrefix) + suffix;
 }
 
-string MacUtil::GetApplicationSupportDirectory() {
+std::string MacUtil::GetApplicationSupportDirectory() {
   return GetSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory);
 }
 
-string MacUtil::GetCachesDirectory() {
+std::string MacUtil::GetCachesDirectory() {
   return GetSearchPathForDirectoriesInDomains(NSCachesDirectory);
 }
 
-string MacUtil::GetLoggingDirectory() {
-  string dir;
+std::string MacUtil::GetLoggingDirectory() {
+  std::string dir;
   @autoreleasepool {
-    NSArray *paths = NSSearchPathForDirectoriesInDomains(
-        NSLibraryDirectory, NSUserDomainMask, YES);
+    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSUserDomainMask, YES);
     if ([paths count] > 0) {
-      dir.assign(
-          [[[[paths objectAtIndex:0] stringByAppendingPathComponent:@"Logs"]
-             stringByAppendingPathComponent:@kProductPrefix]
-            fileSystemRepresentation]);
+      dir.assign([[[[paths objectAtIndex:0] stringByAppendingPathComponent:@"Logs"]
+          stringByAppendingPathComponent:@kProductPrefix] fileSystemRepresentation]);
     }
   }
   return dir;
 }
 
-string MacUtil::GetOSVersionString() {
-  string version;
+std::string MacUtil::GetOSVersionString() {
+  std::string version;
   @autoreleasepool {
     version.assign([[[NSProcessInfo processInfo] operatingSystemVersionString]
-                    cStringUsingEncoding:NSUTF8StringEncoding]);
+        cStringUsingEncoding:NSUTF8StringEncoding]);
   }
   return version;
 }
 
-string MacUtil::GetServerDirectory() {
-  return kServerDirectory;
-}
+std::string MacUtil::GetServerDirectory() { return kServerDirectory; }
 
-string MacUtil::GetResourcesDirectory() {
-  string result;
+std::string MacUtil::GetResourcesDirectory() {
+  std::string result;
   @autoreleasepool {
     NSBundle *mainBundle = [NSBundle mainBundle];
     if (mainBundle) {
@@ -194,30 +178,27 @@ string MacUtil::GetResourcesDirectory() {
 }
 
 #ifdef OS_IOS
-string MacUtil::GetSerialNumber() {
-  string result;
-  NSString *const kSerialNumberNSString =
-      [[UIDevice currentDevice].identifierForVendor UUIDString];
+std::string MacUtil::GetSerialNumber() {
+  std::string result;
+  NSString *const kSerialNumberNSString = [[UIDevice currentDevice].identifierForVendor UUIDString];
   if (kSerialNumberNSString != nil) {
     result.assign([kSerialNumberNSString UTF8String]);
   }
   return result;
 }
-#else
-string MacUtil::GetSerialNumber() {
+#else   // OS_IOS
+std::string MacUtil::GetSerialNumber() {
   // Please refer to TN1103 for the details
   // http://developer.apple.com/library/mac/#technotes/tn/tn1103.html
-  string result;
+  std::string result;
   io_service_t platformExpert = IOServiceGetMatchingService(
       kIOMasterPortDefault, IOServiceMatching("IOPlatformExpertDevice"));
 
   if (platformExpert) {
-    CFTypeRef serialNumberAsCFString =
-        IORegistryEntryCreateCFProperty(
-            platformExpert, CFSTR(kIOPlatformSerialNumberKey),
-            kCFAllocatorDefault, 0);
+    CFTypeRef serialNumberAsCFString = IORegistryEntryCreateCFProperty(
+        platformExpert, CFSTR(kIOPlatformSerialNumberKey), kCFAllocatorDefault, 0);
     if (serialNumberAsCFString) {
-      NSString *serialNumberNSString = (__bridge NSString*)serialNumberAsCFString;
+      NSString *serialNumberNSString = (__bridge NSString *)serialNumberAsCFString;
       result.assign([serialNumberNSString UTF8String]);
     }
 
@@ -228,18 +209,15 @@ string MacUtil::GetSerialNumber() {
   return result;
 }
 
-bool MacUtil::StartLaunchdService(const string &service_name,
-                                  pid_t *pid) {
+bool MacUtil::StartLaunchdService(const std::string &service_name, pid_t *pid) {
   int dummy_pid = 0;
   if (pid == nullptr) {
     pid = &dummy_pid;
   }
-  const string label = GetLabelForSuffix(service_name);
+  const std::string label = GetLabelForSuffix(service_name);
 
-  launch_data_t start_renderer_command =
-      launch_data_alloc(LAUNCH_DATA_DICTIONARY);
-  launch_data_dict_insert(start_renderer_command,
-                          launch_data_new_string(label.c_str()),
+  launch_data_t start_renderer_command = launch_data_alloc(LAUNCH_DATA_DICTIONARY);
+  launch_data_dict_insert(start_renderer_command, launch_data_new_string(label.c_str()),
                           LAUNCH_KEY_STARTJOB);
   launch_data_t result_data = launch_msg(start_renderer_command);
   launch_data_free(start_renderer_command);
@@ -250,24 +228,19 @@ bool MacUtil::StartLaunchdService(const string &service_name,
   launch_data_free(result_data);
 
   // Getting PID by using launch_msg API.
-  launch_data_t get_renderer_info =
-      launch_data_alloc(LAUNCH_DATA_DICTIONARY);
-  launch_data_dict_insert(get_renderer_info,
-                          launch_data_new_string(label.c_str()),
+  launch_data_t get_renderer_info = launch_data_alloc(LAUNCH_DATA_DICTIONARY);
+  launch_data_dict_insert(get_renderer_info, launch_data_new_string(label.c_str()),
                           LAUNCH_KEY_GETJOB);
   launch_data_t renderer_info = launch_msg(get_renderer_info);
   launch_data_free(get_renderer_info);
   if (renderer_info == nullptr) {
-    LOG(ERROR) << "Unexpected error: launchd doesn't return the data "
-               << "for the service.";
+    LOG(ERROR) << "Unexpected error: launchd doesn't return the data for the service.";
     return false;
   }
 
-  launch_data_t pid_data = launch_data_dict_lookup(
-      renderer_info, LAUNCH_JOBKEY_PID);
+  launch_data_t pid_data = launch_data_dict_lookup(renderer_info, LAUNCH_JOBKEY_PID);
   if (pid_data == nullptr) {
-    LOG(ERROR) <<
-        "Unexpected error: launchd response doesn't have PID";
+    LOG(ERROR) << "Unexpected error: launchd response doesn't have PID";
     launch_data_free(renderer_info);
     return false;
   }
@@ -277,22 +250,19 @@ bool MacUtil::StartLaunchdService(const string &service_name,
 }
 
 bool MacUtil::CheckPrelauncherLoginItemStatus() {
-  scoped_cftyperef<LSSharedFileListItemRef> prelauncher_item(
-      GetPrelauncherLoginItem());
+  scoped_cftyperef<LSSharedFileListItemRef> prelauncher_item(GetPrelauncherLoginItem());
   return (prelauncher_item.get() != nullptr);
 }
 
 void MacUtil::RemovePrelauncherLoginItem() {
-  scoped_cftyperef<LSSharedFileListItemRef> prelauncher_item(
-      GetPrelauncherLoginItem());
+  scoped_cftyperef<LSSharedFileListItemRef> prelauncher_item(GetPrelauncherLoginItem());
 
   if (!prelauncher_item.get()) {
     DLOG(INFO) << "prelauncher_item not found.  Probably not registered yet.";
     return;
   }
   scoped_cftyperef<LSSharedFileListRef> login_items(
-      LSSharedFileListCreate(
-          kCFAllocatorDefault, kLSSharedFileListSessionLoginItems, nullptr));
+      LSSharedFileListCreate(kCFAllocatorDefault, kLSSharedFileListSessionLoginItems, nullptr));
   if (!login_items.get()) {
     LOG(ERROR) << "LSSharedFileListCreate error: Cannot get the login items.";
     return;
@@ -305,26 +275,21 @@ void MacUtil::AddPrelauncherLoginItem() {
     return;
   }
   scoped_cftyperef<LSSharedFileListRef> login_items(
-      LSSharedFileListCreate(
-          kCFAllocatorDefault, kLSSharedFileListSessionLoginItems, nullptr));
+      LSSharedFileListCreate(kCFAllocatorDefault, kLSSharedFileListSessionLoginItems, nullptr));
   if (!login_items.get()) {
     LOG(ERROR) << "LSSharedFileListCreate error: Cannot get the login items.";
     return;
   }
-  scoped_cftyperef<CFURLRef> url(
-    CFURLCreateFromFileSystemRepresentation(
-        kCFAllocatorDefault, kPrelauncherPath,
-        strlen((const char *)kPrelauncherPath), true));
+  scoped_cftyperef<CFURLRef> url(CFURLCreateFromFileSystemRepresentation(
+      kCFAllocatorDefault, kPrelauncherPath, strlen((const char *)kPrelauncherPath), true));
 
   if (!url.get()) {
     LOG(ERROR) << "CFURLCreateFromFileSystemRepresentation error:"
                << " Cannot create CFURL object.";
     return;
   }
-  scoped_cftyperef<LSSharedFileListItemRef> new_item(
-      LSSharedFileListInsertItemURL(
-          login_items.get(), kLSSharedFileListItemLast, nullptr, nullptr, url.get(),
-          nullptr, nullptr));
+  scoped_cftyperef<LSSharedFileListItemRef> new_item(LSSharedFileListInsertItemURL(
+      login_items.get(), kLSSharedFileListItemLast, nullptr, nullptr, url.get(), nullptr, nullptr));
   if (!new_item.get()) {
     LOG(ERROR) << "LSSharedFileListInsertItemURL error:"
                << " Cannot insert the prelauncher to the login items.";
@@ -332,25 +297,21 @@ void MacUtil::AddPrelauncherLoginItem() {
   }
 }
 
-bool MacUtil::GetFrontmostWindowNameAndOwner(string *name, string *owner) {
+bool MacUtil::GetFrontmostWindowNameAndOwner(std::string *name, std::string *owner) {
   DCHECK(name);
   DCHECK(owner);
-  scoped_cftyperef<CFArrayRef> window_list(
-      ::CGWindowListCopyWindowInfo(
-          kCGWindowListOptionOnScreenOnly | kCGWindowListExcludeDesktopElements,
-          kCGNullWindowID));
+  scoped_cftyperef<CFArrayRef> window_list(::CGWindowListCopyWindowInfo(
+      kCGWindowListOptionOnScreenOnly | kCGWindowListExcludeDesktopElements, kCGNullWindowID));
   const CFIndex window_count = CFArrayGetCount(window_list.get());
   for (CFIndex i = 0; i < window_count; ++i) {
-    const NSDictionary *window_data = static_cast<const NSDictionary *>(
-        CFArrayGetValueAtIndex(window_list.get(), i));
-    if ([[window_data objectForKey:(id)kCGWindowSharingState] intValue] ==
-        kCGWindowSharingNone) {
+    const NSDictionary *window_data =
+        static_cast<const NSDictionary *>(CFArrayGetValueAtIndex(window_list.get(), i));
+    if ([[window_data objectForKey:(id)kCGWindowSharingState] intValue] == kCGWindowSharingNone) {
       // Skips not shared window.
       continue;
     }
     NSString *window_name = [window_data objectForKey:(id)kCGWindowName];
-    NSString *owner_name =
-      [window_data objectForKey:(id)kCGWindowOwnerName];
+    NSString *owner_name = [window_data objectForKey:(id)kCGWindowOwnerName];
     NSNumber *window_layer = [window_data objectForKey:(id)kCGWindowLayer];
 
     if ((window_name == nil) || (owner_name == nil) || (window_layer == nil)) {
@@ -364,8 +325,7 @@ bool MacUtil::GetFrontmostWindowNameAndOwner(string *name, string *owner) {
     // Hack to ignore the window (name == "" and owner == "Google Chrome")
     // Chrome browser seems to create a window which has no name in front of the
     // actual frontmost Chrome window.
-    if ([window_name isEqualToString:@""] &&
-        [owner_name isEqualToString:@"Google Chrome"]) {
+    if ([window_name isEqualToString:@""] && [owner_name isEqualToString:@"Google Chrome"]) {
       continue;
     }
     name->assign([window_name UTF8String]);
@@ -375,19 +335,14 @@ bool MacUtil::GetFrontmostWindowNameAndOwner(string *name, string *owner) {
   return false;
 }
 
-bool MacUtil::IsSuppressSuggestionWindow(const string &name,
-                                         const string &owner) {
+bool MacUtil::IsSuppressSuggestionWindow(const std::string &name, const std::string &owner) {
   // TODO(horo): Make a function to check the name, then share it with the
   //             Windows client.
   // Currently we don't support "Firefox", because in Firefox "activateServer:"
   // of IMKStateSetting Protocol is not called when the user changes the
   // browsing tab.
-  return (("Google Chrome" == owner) ||
-          ("Safari" == owner)) &&
-         (("Google" == name) ||
-          absl::EndsWith(
-              name,
-              " - Google \xE6\xA4\x9C\xE7\xB4\xA2") ||  // " - Google 検索"
+  return (("Google Chrome" == owner) || ("Safari" == owner)) &&
+         (("Google" == name) || absl::EndsWith(name, " - Google 検索") ||
           absl::EndsWith(name, " - Google Search"));
 }
 #endif  // OS_IOS
