@@ -34,8 +34,8 @@
 namespace mozc {
 
 TEST(MacUtil, GetSerialNumber) {
-  const string serial1 = MacUtil::GetSerialNumber();
-  const string serial2 = MacUtil::GetSerialNumber();
+  const std::string serial1 = MacUtil::GetSerialNumber();
+  const std::string serial2 = MacUtil::GetSerialNumber();
   // In this scenario, serial numbers should not be empty.
   EXPECT_FALSE(serial1.empty());
   EXPECT_EQ(serial1, serial2);
@@ -43,34 +43,20 @@ TEST(MacUtil, GetSerialNumber) {
 
 #ifndef OS_IOS
 TEST(MacUtil, IsSuppressSuggestionWindow) {
-  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow(
-      "", ""));
-  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow(
-      "", "Test"));
-  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow(
-      "Test", ""));
-  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow(
-      "Test", "Test"));
+  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow("", ""));
+  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow("", "Test"));
+  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow("Test", ""));
+  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow("Test", "Test"));
 
-  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow(
-      "Google", "Google Chrome"));
-  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow(
-      "Google", "Safari"));
-  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow(
-      "Google", "Firefox"));
-  // "ABC - Google 検索"
-  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow(
-      "ABC - Google \xE6\xA4\x9C\xE7\xB4\xA2", "Google Chrome"));
-  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow(
-      "ABC - Google \xE6\xA4\x9C\xE7\xB4\xA2", "Safari"));
-  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow(
-      "ABC - Google \xE6\xA4\x9C\xE7\xB4\xA2", "Firefox"));
-  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow(
-      "ABC - Google Search", "Google Chrome"));
-  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow(
-      "ABC - Google Search", "Safari"));
-  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow(
-      "ABC - Google Search", "Firefox"));
+  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow("Google", "Google Chrome"));
+  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow("Google", "Safari"));
+  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow("Google", "Firefox"));
+  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow("ABC - Google 検索", "Google Chrome"));
+  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow("ABC - Google 検索", "Safari"));
+  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow("ABC - Google 検索", "Firefox"));
+  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow("ABC - Google Search", "Google Chrome"));
+  EXPECT_TRUE(MacUtil::IsSuppressSuggestionWindow("ABC - Google Search", "Safari"));
+  EXPECT_FALSE(MacUtil::IsSuppressSuggestionWindow("ABC - Google Search", "Firefox"));
 }
 #endif  // OS_IOS
 
