@@ -33,12 +33,14 @@
 #include <cctype>
 #include <cerrno>
 #include <cmath>
+#include <cstdint>
 #include <cstdio>
 #include <cstring>
 #include <limits>
 #include <string>
 #include <vector>
 
+#include "base/japanese_util.h"
 #include "base/japanese_util_rule.h"
 #include "base/logging.h"
 #include "base/port.h"
@@ -83,10 +85,10 @@ const char *const kCircledNumbers[] = {
 // Structure to store character set variations.
 struct NumberStringVariation {
   const char *const *const digits;
-  const int numbers_size;
   const char *description;
   const char *separator;
   const char *point;
+  const int numbers_size;
   const NumberUtil::NumberString::Style style;
 };
 
@@ -109,9 +111,9 @@ bool IsDecimalNumber(absl::string_view str) {
   return true;
 }
 
-const char kAsciiZero = '0';
-const char kAsciiOne = '1';
-const char kAsciiNine = '9';
+constexpr char kAsciiZero = '0';
+constexpr char kAsciiOne = '1';
+constexpr char kAsciiNine = '9';
 
 }  // namespace
 
@@ -174,19 +176,19 @@ namespace {
 // To know what "大字" means, please refer
 // http://ja.wikipedia.org/wiki/%E5%A4%A7%E5%AD%97_(%E6%95%B0%E5%AD%97)
 const NumberStringVariation kKanjiVariations[] = {
-    {kNumHalfWidthDigits, 10, "数字", nullptr, nullptr,
+    {kNumHalfWidthDigits, "数字", nullptr, nullptr, 10,
      NumberUtil::NumberString::NUMBER_ARABIC_AND_KANJI_HALFWIDTH},
-    {kNumFullWidthDigits, 10, "数字", nullptr, nullptr,
+    {kNumFullWidthDigits, "数字", nullptr, nullptr, 10,
      NumberUtil::NumberString::NUMBER_ARABIC_AND_KANJI_FULLWIDTH},
-    {kNumKanjiDigits, 10, "漢数字", nullptr, nullptr,
+    {kNumKanjiDigits, "漢数字", nullptr, nullptr, 10,
      NumberUtil::NumberString::NUMBER_KANJI},
-    {kNumKanjiOldDigits, 10, "大字", nullptr, nullptr,
+    {kNumKanjiOldDigits, "大字", nullptr, nullptr, 10,
      NumberUtil::NumberString::NUMBER_OLD_KANJI},
 };
 
-const char kOldTwoTen[] = "弐拾";
-const size_t kOldTwoTenLength = arraysize(kOldTwoTen) - 1;
-const char kOldTwenty[] = "廿";
+constexpr char kOldTwoTen[] = "弐拾";
+constexpr size_t kOldTwoTenLength = std::size(kOldTwoTen) - 1;
+constexpr char kOldTwenty[] = "廿";
 
 }  // namespace
 
@@ -194,7 +196,7 @@ bool NumberUtil::ArabicToKanji(absl::string_view input_num,
                                std::vector<NumberString> *output) {
   DCHECK(output);
   const char *const kNumZero = "零";
-  const int kDigitsInBigRank = 4;
+  constexpr int kDigitsInBigRank = 4;
 
   if (!IsDecimalInteger(input_num)) {
     return false;
@@ -214,7 +216,7 @@ bool NumberUtil::ArabicToKanji(absl::string_view input_num,
 
   // If given number needs higher ranks than our expectations,
   // we don't convert it.
-  if (arraysize(kNumKanjiBiggerRanks) * kDigitsInBigRank < input_num.size()) {
+  if (std::size(kNumKanjiBiggerRanks) * kDigitsInBigRank < input_num.size()) {
     return false;
   }
 
@@ -235,7 +237,7 @@ bool NumberUtil::ArabicToKanji(absl::string_view input_num,
   const size_t rank_size = ranked_numbers.size();
 
   for (size_t variation_index = 0;
-       variation_index < arraysize(kKanjiVariations); ++variation_index) {
+       variation_index < std::size(kKanjiVariations); ++variation_index) {
     const NumberStringVariation &variation = kKanjiVariations[variation_index];
     const char *const *const digits = variation.digits;
     const NumberString::Style style = variation.style;
@@ -322,9 +324,9 @@ bool NumberUtil::ArabicToKanji(absl::string_view input_num,
 namespace {
 
 const NumberStringVariation kNumDigitsVariations[] = {
-    {kNumHalfWidthDigits, 10, "数字", ",", ".",
+    {kNumHalfWidthDigits, "数字", ",", ".", 10,
      NumberUtil::NumberString::NUMBER_SEPARATED_ARABIC_HALFWIDTH},
-    {kNumFullWidthDigits, 10, "数字", "，", "．",
+    {kNumFullWidthDigits, "数字", "，", "．", 10,
      NumberUtil::NumberString::NUMBER_SEPARATED_ARABIC_FULLWIDTH},
 };
 
@@ -353,7 +355,7 @@ bool NumberUtil::ArabicToSeparatedArabic(absl::string_view input_num,
     return false;
   }
 
-  for (size_t i = 0; i < arraysize(kNumDigitsVariations); ++i) {
+  for (size_t i = 0; i < std::size(kNumDigitsVariations); ++i) {
     const NumberStringVariation &variation = kNumDigitsVariations[i];
     const char *const *const digits = variation.digits;
     // TODO(peria): Bring |result| out if it improves the performance.
@@ -365,7 +367,7 @@ bool NumberUtil::ArabicToSeparatedArabic(absl::string_view input_num,
       if (j != 0 && (integer.size() - j) % 3 == 0) {
         result.append(variation.separator);
       }
-      const uint32 d = static_cast<uint32>(integer[j] - kAsciiZero);
+      const uint32_t d = static_cast<uint32_t>(integer[j] - kAsciiZero);
       if (d <= 9 && digits[d]) {
         result.append(digits[d]);
       }
@@ -391,9 +393,9 @@ namespace {
 // use default for wide Arabic, because half/full width for
 // normal number is learned by character form manager.
 const NumberStringVariation kSingleDigitsVariations[] = {
-    {kNumKanjiDigits, 10, "漢数字", nullptr, nullptr,
+    {kNumKanjiDigits, "漢数字", nullptr, nullptr, 10,
      NumberUtil::NumberString::NUMBER_KANJI_ARABIC},
-    {kNumFullWidthDigits, 10, "数字", nullptr, nullptr,
+    {kNumFullWidthDigits, "数字", nullptr, nullptr, 10,
      NumberUtil::NumberString::DEFAULT_STYLE},
 };
 
@@ -407,7 +409,7 @@ bool NumberUtil::ArabicToWideArabic(absl::string_view input_num,
     return false;
   }
 
-  for (size_t i = 0; i < arraysize(kSingleDigitsVariations); ++i) {
+  for (size_t i = 0; i < std::size(kSingleDigitsVariations); ++i) {
     const NumberStringVariation &variation = kSingleDigitsVariations[i];
     // TODO(peria): Bring |result| out if it improves the performance.
     std::string result;
@@ -426,12 +428,13 @@ bool NumberUtil::ArabicToWideArabic(absl::string_view input_num,
 namespace {
 
 const NumberStringVariation kSpecialNumericVariations[] = {
-    {kRomanNumbersCapital, arraysize(kRomanNumbersCapital),
-     "ローマ数字(大文字)", nullptr, nullptr,
+    {kRomanNumbersCapital, "ローマ数字(大文字)", nullptr, nullptr,
+     std::size(kRomanNumbersCapital),
      NumberUtil::NumberString::NUMBER_ROMAN_CAPITAL},
-    {kRomanNumbersSmall, arraysize(kRomanNumbersSmall), "ローマ数字(小文字)",
-     nullptr, nullptr, NumberUtil::NumberString::NUMBER_ROMAN_SMALL},
-    {kCircledNumbers, arraysize(kCircledNumbers), "丸数字", nullptr, nullptr,
+    {kRomanNumbersSmall, "ローマ数字(小文字)", nullptr, nullptr,
+     std::size(kRomanNumbersSmall),
+     NumberUtil::NumberString::NUMBER_ROMAN_SMALL},
+    {kCircledNumbers, "丸数字", nullptr, nullptr, std::size(kCircledNumbers),
      NumberUtil::NumberString::NUMBER_CIRCLED},
 };
 
@@ -462,13 +465,13 @@ bool NumberUtil::ArabicToOtherForms(absl::string_view input_num,
   }
 
   // Following conversions require uint64 number.
-  uint64 n;
+  uint64_t n;
   if (!SafeStrToUInt64(input_num, &n)) {
     return converted;
   }
 
   // Special forms
-  for (size_t i = 0; i < arraysize(kSpecialNumericVariations); ++i) {
+  for (size_t i = 0; i < std::size(kSpecialNumericVariations); ++i) {
     const NumberStringVariation &variation = kSpecialNumericVariations[i];
     if (n < variation.numbers_size && variation.digits[n]) {
       output->push_back(NumberString(variation.digits[n], variation.description,
@@ -488,27 +491,27 @@ bool NumberUtil::ArabicToOtherRadixes(absl::string_view input_num,
     return false;
   }
 
-  uint64 n;
+  uint64_t n;
   if (!SafeStrToUInt64(input_num, &n)) {
     return false;
   }
 
   // Hexadecimal
   if (n > 9) {
-    const std::string hex = absl::StrFormat("0x%x", static_cast<uint64>(n));
+    const std::string hex = absl::StrFormat("0x%x", static_cast<uint64_t>(n));
     output->push_back(NumberString(hex, "16進数", NumberString::NUMBER_HEX));
   }
 
   // Octal
   if (n > 7) {
-    const std::string oct = absl::StrFormat("0%o", static_cast<uint64>(n));
+    const std::string oct = absl::StrFormat("0%o", static_cast<uint64_t>(n));
     output->push_back(NumberString(oct, "8進数", NumberString::NUMBER_OCT));
   }
 
   // Binary
   if (n > 1) {
     std::string binary;
-    for (uint64 num = n; num; num >>= 1) {
+    for (uint64_t num = n; num; num >>= 1) {
       binary.push_back(kAsciiZero + static_cast<char>(num & 0x1));
     }
     // "b0" will be "0b" in head of |binary|
@@ -536,9 +539,9 @@ const absl::string_view SkipWhiteSpace(absl::string_view str) {
 
 // *output = arg1 + arg2
 // return false when an integer overflow happens.
-bool AddAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
+bool AddAndCheckOverflow(uint64_t arg1, uint64_t arg2, uint64_t *output) {
   *output = arg1 + arg2;
-  if (arg2 > (std::numeric_limits<uint64>::max() - arg1)) {
+  if (arg2 > (std::numeric_limits<uint64_t>::max() - arg1)) {
     // overflow happens
     return false;
   }
@@ -547,9 +550,9 @@ bool AddAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
 
 // *output = arg1 * arg2
 // return false when an integer overflow happens.
-bool MultiplyAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
+bool MultiplyAndCheckOverflow(uint64_t arg1, uint64_t arg2, uint64_t *output) {
   *output = arg1 * arg2;
-  if (arg1 != 0 && arg2 > (std::numeric_limits<uint64>::max() / arg1)) {
+  if (arg1 != 0 && arg2 > (std::numeric_limits<uint64_t>::max() / arg1)) {
     // overflow happens
     return false;
   }
@@ -557,7 +560,7 @@ bool MultiplyAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
 }
 
 // A simple wrapper of strtoull function. |c_str| must be terminated by '\0'.
-inline uint64 StrToUint64(const char *c_str, char **end_ptr, int base) {
+inline uint64_t StrToUint64(const char *c_str, char **end_ptr, int base) {
 #ifdef OS_WIN
   return _strtoui64(c_str, end_ptr, base);
 #else   // OS_WIN
@@ -568,13 +571,13 @@ inline uint64 StrToUint64(const char *c_str, char **end_ptr, int base) {
 // Converts a string which describes a number into an uint64 value in |base|
 // radix.  Does not convert octal or hexadecimal strings with "0" or "0x"
 // suffixes.
-bool SafeStrToUInt64WithBase(absl::string_view str, int base, uint64 *value) {
+bool SafeStrToUInt64WithBase(absl::string_view str, int base, uint64_t *value) {
   DCHECK(value);
 
   // Maximum possible length of number string, including terminating '\0'. Note
   // that the maximum possible length is achieved when str="111...11" (64
   // unities) and base=2.
-  const size_t kMaxPossibleLength = 65;
+  constexpr size_t kMaxPossibleLength = 65;
 
   // Leading white spaces are allowed.
   const absl::string_view stripped_str = SkipWhiteSpace(str);
@@ -618,49 +621,49 @@ bool SafeCast(SrcType src, DestType *dest) {
 }
 
 template <>
-bool SafeCast(int64 src, int16 *dest) {
-  if (src < static_cast<int64>(std::numeric_limits<int16>::min()) ||
-      static_cast<int64>(std::numeric_limits<int16>::max()) < src) {
+bool SafeCast(int64_t src, int16_t *dest) {
+  if (src < static_cast<int64_t>(std::numeric_limits<int16_t>::min()) ||
+      static_cast<int64_t>(std::numeric_limits<int16_t>::max()) < src) {
     return false;
   }
-  *dest = static_cast<int16>(src);
+  *dest = static_cast<int16_t>(src);
   return true;
 }
 
 template <>
-bool SafeCast(int64 src, int32 *dest) {
-  if (src < static_cast<int64>(std::numeric_limits<int32>::min()) ||
-      static_cast<int64>(std::numeric_limits<int32>::max()) < src) {
+bool SafeCast(int64_t src, int32_t *dest) {
+  if (src < static_cast<int64_t>(std::numeric_limits<int32_t>::min()) ||
+      static_cast<int64_t>(std::numeric_limits<int32_t>::max()) < src) {
     return false;
   }
-  *dest = static_cast<int32>(src);
+  *dest = static_cast<int32_t>(src);
   return true;
 }
 
 template <>
-bool SafeCast(uint64 src, int64 *dest) {
-  if (src > static_cast<uint64>(std::numeric_limits<int64>::max())) {
+bool SafeCast(uint64_t src, int64_t *dest) {
+  if (src > static_cast<uint64_t>(std::numeric_limits<int64_t>::max())) {
     return false;
   }
-  *dest = static_cast<int64>(src);
+  *dest = static_cast<int64_t>(src);
   return true;
 }
 
 template <>
-bool SafeCast(uint64 src, uint16 *dest) {
-  if (src > static_cast<uint64>(std::numeric_limits<uint16>::max())) {
+bool SafeCast(uint64_t src, uint16_t *dest) {
+  if (src > static_cast<uint64_t>(std::numeric_limits<uint16_t>::max())) {
     return false;
   }
-  *dest = static_cast<uint16>(src);
+  *dest = static_cast<uint16_t>(src);
   return true;
 }
 
 template <>
-bool SafeCast(uint64 src, uint32 *dest) {
-  if (src > static_cast<uint64>(std::numeric_limits<uint32>::max())) {
+bool SafeCast(uint64_t src, uint32_t *dest) {
+  if (src > static_cast<uint64_t>(std::numeric_limits<uint32_t>::max())) {
     return false;
   }
-  *dest = static_cast<uint32>(src);
+  *dest = static_cast<uint32_t>(src);
   return true;
 }
 
@@ -672,13 +675,13 @@ bool SafeUnaryNegation(SrcType src, DestType *dest) {
 }
 
 template <>
-bool SafeUnaryNegation(uint64 src, int64 *dest) {
-  int64 tmp = 0;
+bool SafeUnaryNegation(uint64_t src, int64_t *dest) {
+  int64_t tmp = 0;
   if (!SafeCast(src, &tmp)) {
     if (src == 0x8000000000000000ul) {
       // This is an exceptional case. |src| isn't in the range of int64,
       // but |-src| is in the range.
-      *dest = std::numeric_limits<int64>::min();
+      *dest = std::numeric_limits<int64_t>::min();
       return true;
     }
     return false;
@@ -689,28 +692,28 @@ bool SafeUnaryNegation(uint64 src, int64 *dest) {
 
 }  // namespace
 
-bool NumberUtil::SafeStrToInt16(absl::string_view str, int16 *value) {
-  int64 tmp;
+bool NumberUtil::SafeStrToInt16(absl::string_view str, int16_t *value) {
+  int64_t tmp;
   if (!SafeStrToInt64(str, &tmp)) {
     return false;
   }
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToInt32(absl::string_view str, int32 *value) {
-  int64 tmp;
+bool NumberUtil::SafeStrToInt32(absl::string_view str, int32_t *value) {
+  int64_t tmp;
   if (!SafeStrToInt64(str, &tmp)) {
     return false;
   }
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToInt64(absl::string_view str, int64 *value) {
+bool NumberUtil::SafeStrToInt64(absl::string_view str, int64_t *value) {
   const absl::string_view stripped_str = SkipWhiteSpace(str);
   if (stripped_str.empty()) {
     return false;
   }
-  uint64 tmp;
+  uint64_t tmp;
   if (stripped_str[0] == '-') {
     absl::string_view opposite_str =
         stripped_str.substr(1, stripped_str.size() - 1);
@@ -725,39 +728,39 @@ bool NumberUtil::SafeStrToInt64(absl::string_view str, int64 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToUInt16(absl::string_view str, uint16 *value) {
-  uint64 tmp;
+bool NumberUtil::SafeStrToUInt16(absl::string_view str, uint16_t *value) {
+  uint64_t tmp;
   if (!SafeStrToUInt64WithBase(str, 10, &tmp)) {
     return false;
   }
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToUInt32(absl::string_view str, uint32 *value) {
-  uint64 tmp;
+bool NumberUtil::SafeStrToUInt32(absl::string_view str, uint32_t *value) {
+  uint64_t tmp;
   if (!SafeStrToUInt64WithBase(str, 10, &tmp)) {
     return false;
   }
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeHexStrToUInt32(absl::string_view str, uint32 *value) {
-  uint64 tmp;
+bool NumberUtil::SafeHexStrToUInt32(absl::string_view str, uint32_t *value) {
+  uint64_t tmp;
   if (!SafeStrToUInt64WithBase(str, 16, &tmp)) {
     return false;
   }
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeOctStrToUInt32(absl::string_view str, uint32 *value) {
-  uint64 tmp;
+bool NumberUtil::SafeOctStrToUInt32(absl::string_view str, uint32_t *value) {
+  uint64_t tmp;
   if (!SafeStrToUInt64WithBase(str, 8, &tmp)) {
     return false;
   }
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToUInt64(absl::string_view str, uint64 *value) {
+bool NumberUtil::SafeStrToUInt64(absl::string_view str, uint64_t *value) {
   return SafeStrToUInt64WithBase(str, 10, value);
 }
 
@@ -794,8 +797,8 @@ namespace {
 //   [1, 2, 3, 10, 100] => begin points to [10, 100], output = 123
 // Returns false when overflow happened.
 bool ReduceLeadingNumbersAsBase10System(
-    std::vector<uint64>::const_iterator *begin,
-    const std::vector<uint64>::const_iterator &end, uint64 *output) {
+    std::vector<uint64_t>::const_iterator *begin,
+    const std::vector<uint64_t>::const_iterator &end, uint64_t *output) {
   *output = 0;
   for (; *begin < end; ++*begin) {
     if (**begin >= 10) {
@@ -814,8 +817,8 @@ bool ReduceLeadingNumbersAsBase10System(
 //   [1, 2, 3] => 123
 //   [1, 2, 3, 10] => false
 // Returns false if a number greater than 10 was found or overflow happened.
-bool InterpretNumbersAsBase10System(const std::vector<uint64> &numbers,
-                                    uint64 *output) {
+bool InterpretNumbersAsBase10System(const std::vector<uint64_t> &numbers,
+                                    uint64_t *output) {
   auto begin = numbers.begin();
   const bool success =
       ReduceLeadingNumbersAsBase10System(&begin, numbers.end(), output);
@@ -825,9 +828,9 @@ bool InterpretNumbersAsBase10System(const std::vector<uint64> &numbers,
 
 // Reads a leading number in a sequence and advances the iterator. Returns false
 // if the range is empty or the leading number is not less than 10.
-bool ReduceOnesDigit(std::vector<uint64>::const_iterator *begin,
-                     const std::vector<uint64>::const_iterator &end,
-                     uint64 *num) {
+bool ReduceOnesDigit(std::vector<uint64_t>::const_iterator *begin,
+                     const std::vector<uint64_t>::const_iterator &end,
+                     uint64_t *num) {
   if (*begin == end || **begin >= 10) {
     return false;
   }
@@ -854,9 +857,9 @@ bool ReduceOnesDigit(std::vector<uint64>::const_iterator *begin,
 //     [2, 1000, ...] => 2000
 //     [1, 1000, ...] => 1000
 //     [1, 2, 3, 4, ...] => 1234
-bool ReduceDigitsHelper(std::vector<uint64>::const_iterator *begin,
-                        const std::vector<uint64>::const_iterator &end,
-                        uint64 *num, const uint64 expected_base) {
+bool ReduceDigitsHelper(std::vector<uint64_t>::const_iterator *begin,
+                        const std::vector<uint64_t>::const_iterator &end,
+                        uint64_t *num, const uint64_t expected_base) {
   // Skip leading zero(s).
   while (*begin != end && **begin == 0) {
     ++*begin;
@@ -864,7 +867,7 @@ bool ReduceDigitsHelper(std::vector<uint64>::const_iterator *begin,
   if (*begin == end) {
     return false;
   }
-  const uint64 leading_number = **begin;
+  const uint64_t leading_number = **begin;
 
   // If the leading number is less than 10, e.g., patterns like [2, 10], we need
   // to check the next number.
@@ -872,7 +875,7 @@ bool ReduceDigitsHelper(std::vector<uint64>::const_iterator *begin,
     if (end - *begin < 2) {
       return false;
     }
-    const uint64 next_number = *(*begin + 1);
+    const uint64_t next_number = *(*begin + 1);
 
     // If the next number is also less than 10, this pattern is like
     // [1, 2, ...] => 12. In this case, the result must be less than
@@ -907,21 +910,21 @@ bool ReduceDigitsHelper(std::vector<uint64>::const_iterator *begin,
   return false;
 }
 
-inline bool ReduceTensDigit(std::vector<uint64>::const_iterator *begin,
-                            const std::vector<uint64>::const_iterator &end,
-                            uint64 *num) {
+inline bool ReduceTensDigit(std::vector<uint64_t>::const_iterator *begin,
+                            const std::vector<uint64_t>::const_iterator &end,
+                            uint64_t *num) {
   return ReduceDigitsHelper(begin, end, num, 10);
 }
 
-inline bool ReduceHundredsDigit(std::vector<uint64>::const_iterator *begin,
-                                const std::vector<uint64>::const_iterator &end,
-                                uint64 *num) {
+inline bool ReduceHundredsDigit(
+    std::vector<uint64_t>::const_iterator *begin,
+    const std::vector<uint64_t>::const_iterator &end, uint64_t *num) {
   return ReduceDigitsHelper(begin, end, num, 100);
 }
 
-inline bool ReduceThousandsDigit(std::vector<uint64>::const_iterator *begin,
-                                 const std::vector<uint64>::const_iterator &end,
-                                 uint64 *num) {
+inline bool ReduceThousandsDigit(
+    std::vector<uint64_t>::const_iterator *begin,
+    const std::vector<uint64_t>::const_iterator &end, uint64_t *num) {
   return ReduceDigitsHelper(begin, end, num, 1000);
 }
 
@@ -931,12 +934,12 @@ inline bool ReduceThousandsDigit(std::vector<uint64>::const_iterator *begin,
 //        => begin points to [10000, ...], num = 1234
 //   [3, 100, 4, 100]
 //        => error because same base number appears twice
-bool ReduceNumberLessThan10000(std::vector<uint64>::const_iterator *begin,
-                               const std::vector<uint64>::const_iterator &end,
-                               uint64 *num) {
+bool ReduceNumberLessThan10000(std::vector<uint64_t>::const_iterator *begin,
+                               const std::vector<uint64_t>::const_iterator &end,
+                               uint64_t *num) {
   *num = 0;
   bool success = false;
-  uint64 n = 0;
+  uint64_t n = 0;
   // Note: the following additions never overflow.
   if (ReduceThousandsDigit(begin, end, &n)) {
     *num += n;
@@ -964,13 +967,13 @@ bool ReduceNumberLessThan10000(std::vector<uint64>::const_iterator *begin,
 //   "一万二千三百四十五" = [1, 10000, 2, 1000, 3, 100, 4, 10, 5] => 12345
 // Base-10 numbers must be decreasing, i.e.,
 //   "一十二百" = [1, 10, 2, 100] => error
-bool InterpretNumbersInJapaneseWay(const std::vector<uint64> &numbers,
-                                   uint64 *output) {
-  uint64 last_base = std::numeric_limits<uint64>::max();
+bool InterpretNumbersInJapaneseWay(const std::vector<uint64_t> &numbers,
+                                   uint64_t *output) {
+  uint64_t last_base = std::numeric_limits<uint64_t>::max();
   auto begin = numbers.begin();
   *output = 0;
   do {
-    uint64 coef = 0;
+    uint64_t coef = 0;
     if (!ReduceNumberLessThan10000(&begin, numbers.end(), &coef)) {
       return false;
     }
@@ -981,7 +984,7 @@ bool InterpretNumbersInJapaneseWay(const std::vector<uint64> &numbers,
       return false;  // Increasing order of base-10 numbers.
     }
     // Safely performs *output += coef * *begin.
-    uint64 delta = 0;
+    uint64_t delta = 0;
     if (!MultiplyAndCheckOverflow(coef, *begin, &delta) ||
         !AddAndCheckOverflow(*output, delta, output)) {
       return false;
@@ -994,8 +997,8 @@ bool InterpretNumbersInJapaneseWay(const std::vector<uint64> &numbers,
 
 // Interprets a sequence of numbers directly or in a Japanese reading way
 // depending on the maximum number in the sequence.
-bool NormalizeNumbersHelper(const std::vector<uint64> &numbers,
-                            uint64 *number_output) {
+bool NormalizeNumbersHelper(const std::vector<uint64_t> &numbers,
+                            uint64_t *number_output) {
   const auto itr_max = std::max_element(numbers.begin(), numbers.end());
   if (itr_max == numbers.end()) {
     return false;  // numbers is empty
@@ -1017,7 +1020,7 @@ bool NormalizeNumbersInternal(absl::string_view input, bool trim_leading_zeros,
   DCHECK(arabic_output);
   const char *begin = input.data();
   const char *end = input.data() + input.size();
-  std::vector<uint64> numbers;
+  std::vector<uint64_t> numbers;
   numbers.reserve(input.size());
 
   // Map Kanji number string to digits, e.g., "二百十一" -> [2, 100, 10, 1].
@@ -1028,13 +1031,13 @@ bool NormalizeNumbersInternal(absl::string_view input, bool trim_leading_zeros,
 
   while (begin < end) {
     size_t mblen = 0;
-    const char32 wchar = Util::UTF8ToUCS4(begin, end, &mblen);
+    const char32 wchar = Util::Utf8ToUcs4(begin, end, &mblen);
     kanji_char.assign(begin, mblen);
 
     std::string tmp;
     NumberUtil::KanjiNumberToArabicNumber(kanji_char, &tmp);
 
-    uint64 n = 0;
+    uint64_t n = 0;
     if (!NumberUtil::SafeStrToUInt64(tmp, &n)) {
       break;
     }
@@ -1061,7 +1064,7 @@ bool NormalizeNumbersInternal(absl::string_view input, bool trim_leading_zeros,
   }
 
   // Try interpreting the sequence of digits.
-  uint64 n = 0;
+  uint64_t n = 0;
   if (!NormalizeNumbersHelper(numbers, &n)) {
     return false;
   }
@@ -1081,7 +1084,7 @@ bool NormalizeNumbersInternal(absl::string_view input, bool trim_leading_zeros,
     arabic_output->append(num_zeros, kAsciiZero);
   }
 
-  arabic_output->append(absl::StrFormat("%u", static_cast<uint64>(n)));
+  arabic_output->append(absl::StrFormat("%u", static_cast<uint64_t>(n)));
   return true;
 }
 
@@ -1110,7 +1113,7 @@ bool NumberUtil::NormalizeNumbersWithSuffix(absl::string_view input,
 
 void NumberUtil::KanjiNumberToArabicNumber(absl::string_view input,
                                            std::string *output) {
-  Util::ConvertUsingDoubleArray(
+  japanese_util::ConvertUsingDoubleArray(
       japanese_util_rule::kanjinumber_to_arabicnumber_da,
       japanese_util_rule::kanjinumber_to_arabicnumber_table, input, output);
 }
