@@ -31,7 +31,7 @@
 
 #ifdef OS_WIN
 #include <Windows.h>
-#else
+#else  // OS_WIN
 #include <string.h>
 #include <sys/stat.h>
 
@@ -55,6 +55,7 @@
 
 #include <cstdlib>
 #include <memory>
+#include <string>
 #include <vector>
 
 #include "base/const.h"
@@ -63,6 +64,7 @@
 #include "base/system_util.h"
 #include "base/util.h"
 #include "absl/strings/match.h"
+#include "absl/strings/str_split.h"
 
 #ifdef OS_WIN
 #include "base/scoped_handle.h"
@@ -81,7 +83,7 @@ static char **environ = *_NSGetEnviron();
 // posix_spawn() since Qt applications use (at least) DISPLAY and QT_IM_MODULE
 // environment variables.
 extern char **environ;
-#endif
+#endif  // __APPLE__
 
 namespace mozc {
 
@@ -94,15 +96,19 @@ bool Process::OpenBrowser(const std::string &url) {
 
 #ifdef OS_WIN
   std::wstring wurl;
-  Util::UTF8ToWide(url, &wurl);
+  Util::Utf8ToWide(url, &wurl);
   return WinUtil::ShellExecuteInSystemDir(L"open", wurl.c_str(), nullptr);
-#endif
+#endif  // OS_WIN
 
 #if defined(OS_LINUX) || defined(OS_ANDROID)
-  static const char kBrowserCommand[] = "/usr/bin/xdg-open";
+
+#ifndef MOZC_BROWSER_COMMAND
   // xdg-open which uses kfmclient or gnome-open internally works both on KDE
   // and GNOME environments.
-  return SpawnProcess(kBrowserCommand, url);
+#define MOZC_BROWSER_COMMAND "/usr/bin/xdg-open"
+#endif  // MOZC_BROWSER_COMMAND
+
+  return SpawnProcess(MOZC_BROWSER_COMMAND, url);
 #endif  // OS_LINUX || OS_ANDROID
 
 #ifdef __APPLE__
@@ -115,11 +121,11 @@ bool Process::SpawnProcess(const std::string &path, const std::string &arg,
                            size_t *pid) {
 #ifdef OS_WIN
   std::wstring wpath;
-  Util::UTF8ToWide(path, &wpath);
+  Util::Utf8ToWide(path, &wpath);
   wpath = L"\"" + wpath + L"\"";
   if (!arg.empty()) {
     std::wstring warg;
-    Util::UTF8ToWide(arg, &warg);
+    Util::Utf8ToWide(arg, &warg);
     wpath += L" ";
     wpath += warg;
   }
@@ -159,11 +165,11 @@ bool Process::SpawnProcess(const std::string &path, const std::string &arg,
 #elif defined(OS_WASM)
   // Spawning processes is not supported in WASM.
   return false;
-#else
+#else  // OS_WASM
 
-  std::vector<std::string> arg_tmp;
-  Util::SplitStringUsing(arg, " ", &arg_tmp);
-  std::unique_ptr<const char *[]> argv(new const char *[arg_tmp.size() + 2]);
+  const std::vector<std::string> arg_tmp =
+      absl::StrSplit(arg, ' ', absl::SkipEmpty());
+  auto argv = std::make_unique<const char *[]>(arg_tmp.size() + 2);
   argv[0] = path.c_str();
   for (size_t i = 0; i < arg_tmp.size(); ++i) {
     argv[i + 1] = arg_tmp[i].c_str();
@@ -183,7 +189,7 @@ bool Process::SpawnProcess(const std::string &path, const std::string &arg,
     // In mac launchApplication cannot accept any arguments.
     return MacProcess::OpenApplication(path);
   }
-#endif
+#endif  // __APPLE__
 
 #if defined(OS_LINUX) || defined(OS_ANDROID)
   // Do not call posix_spawn() for obviously bad path.
@@ -206,7 +212,7 @@ bool Process::SpawnProcess(const std::string &path, const std::string &arg,
   // not affect current process behavior since Glibc never check the variable
   // after main().
   // (www.gnu.org/software/libc/manual/html_node/Heap-Consistency-Checking.html)
-  const int kOverwrite = 0;  // Do not overwrite.
+  constexpr int kOverwrite = 0;  // Do not overwrite.
   ::setenv("MALLOC_CHECK_", "2", kOverwrite);
 #endif  // OS_LINUX || OS_ANDROID
   pid_t tmp_pid = 0;
@@ -271,9 +277,9 @@ bool Process::WaitProcess(size_t pid, int timeout) {
 #elif defined(OS_WASM)
   // Process handling is not supported in WASM.
   return false;
-#else
+#else   // OS_WASM
   pid_t processe_id = static_cast<pid_t>(pid);
-  const int kPollingDuration = 250;
+  constexpr int kPollingDuration = 250;
   int left_time = timeout < 0 ? 1 : timeout;
   while (left_time > 0) {
     Util::Sleep(kPollingDuration);
@@ -290,7 +296,7 @@ bool Process::WaitProcess(size_t pid, int timeout) {
 
   LOG(ERROR) << pid << " didn't terminate within " << timeout << " msec";
   return false;
-#endif
+#endif  // OS_WASM
 }
 
 bool Process::IsProcessAlive(size_t pid, bool default_result) {
@@ -321,7 +327,7 @@ bool Process::IsProcessAlive(size_t pid, bool default_result) {
   // Process handling is not supported in WASM.
   return false;
 #else   // OS_WIN
-  const int kSig = 0;
+  constexpr int kSig = 0;
   if (::kill(static_cast<pid_t>(pid), kSig) == -1) {
     if (errno == EPERM || errno == EINVAL) {
       // permission denied or invalid signal.
@@ -375,7 +381,8 @@ bool Process::LaunchErrorMessageDialog(const std::string &error_type) {
 #endif  // __APPLE__
 
 #ifdef OS_WIN
-  const string arg = "--mode=error_message_dialog --error_type=" + error_type;
+  const std::string arg =
+      "--mode=error_message_dialog --error_type=" + error_type;
   size_t pid = 0;
   if (!Process::SpawnProcess(SystemUtil::GetToolPath(), arg, &pid)) {
     LOG(ERROR) << "cannot launch " << kMozcTool;
@@ -384,7 +391,7 @@ bool Process::LaunchErrorMessageDialog(const std::string &error_type) {
 #endif  // OS_WIN
 
 #if defined(OS_LINUX) || defined(OS_ANDROID)
-  const char kMozcTool[] = "mozc_tool";
+  constexpr char kMozcTool[] = "mozc_tool";
   const std::string arg =
       "--mode=error_message_dialog --error_type=" + error_type;
   size_t pid = 0;
