@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,24 +29,24 @@
 
 #include <string>
 
-#include "base/flags.h"
 #include "base/init_mozc.h"
 #include "base/logging.h"
 #include "base/process.h"
+#include "absl/flags/flag.h"
 
-DEFINE_string(open_browser, "", "URL");
-DEFINE_string(spawn_process, "", "path");
+ABSL_FLAG(std::string, open_browser, "", "URL");
+ABSL_FLAG(std::string, spawn_process, "", "path");
 
 int main(int argc, char **argv) {
   mozc::InitMozc(argv[0], &argc, &argv);
-  if (!FLAGS_open_browser.empty()) {
-    if (!mozc::Process::OpenBrowser(FLAGS_open_browser)) {
-      LOG(INFO) << "Failed to open: " << FLAGS_open_browser;
+  if (!absl::GetFlag(FLAGS_open_browser).empty()) {
+    if (!mozc::Process::OpenBrowser(absl::GetFlag(FLAGS_open_browser))) {
+      LOG(INFO) << "Failed to open: " << absl::GetFlag(FLAGS_open_browser);
     }
   }
-  if (!FLAGS_spawn_process.empty()) {
-    if (!mozc::Process::SpawnProcess(FLAGS_spawn_process, "")) {
-      LOG(INFO) << "Failed to spawn: " << FLAGS_spawn_process;
+  if (!absl::GetFlag(FLAGS_spawn_process).empty()) {
+    if (!mozc::Process::SpawnProcess(absl::GetFlag(FLAGS_spawn_process), "")) {
+      LOG(INFO) << "Failed to spawn: " << absl::GetFlag(FLAGS_spawn_process);
     }
   }
   return 0;
