@@ -91,8 +91,8 @@ bool IsDifferentUser(const HANDLE hToken) {
   // Sacrifice the last character. That is practically ok for our purpose.
   src.SourceName[TOKEN_SOURCE_LENGTH - 1] = '\0';
 
-  const char kSeclogo[] = "seclogo";
-  const char kCredPro[] = "CredPro";
+  constexpr char kSeclogo[] = "seclogo";
+  constexpr char kCredPro[] = "CredPro";
 
   return (AreEqualArray(kSeclogo, src.SourceName) ||
           AreEqualArray(kCredPro, src.SourceName));
@@ -210,14 +210,16 @@ RunLevel::RunLevelType RunLevel::GetRunLevel(RunLevel::RequestType type) {
     // Get the server path before the process is sandboxed.
     // SHGetFolderPath may fail in a sandboxed process.
     // See http://b/2301066 for details.
-    const volatile string sys_dir = SystemUtil::GetServerDirectory();
+    // 'volatile' is used here to make sure calling GetServerDirectory.
+    // It internally initializes caches of file paths.
+    const volatile std::string sys_dir = SystemUtil::GetServerDirectory();
 
     // Get the user profile path here because of the same reason.
     // See http://b/2301066 for details.
-    const string user_dir = SystemUtil::GetUserProfileDirectory();
+    const std::string user_dir = SystemUtil::GetUserProfileDirectory();
 
     std::wstring dir;
-    Util::UTF8ToWide(user_dir, &dir);
+    Util::Utf8ToWide(user_dir, &dir);
     ScopedHandle dir_handle(::CreateFile(dir.c_str(), READ_CONTROL | WRITE_DAC,
                                          0, nullptr, OPEN_EXISTING,
                                          FILE_FLAG_BACKUP_SEMANTICS, 0));
