@@ -30,6 +30,7 @@
 #include "base/serialized_string_array.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <cstring>
 #include <memory>
 #include <string>
@@ -48,14 +49,14 @@ class SerializedStringArrayTest : public ::testing::Test {
   }
 
   absl::string_view AlignString(const std::string &s) {
-    buf_.reset(new uint32[(s.size() + 3) / 4]);
+    buf_.reset(new uint32_t[(s.size() + 3) / 4]);
     return absl::string_view(
         static_cast<const char *>(memcpy(buf_.get(), s.data(), s.size())),
         s.size());
   }
 
  private:
-  std::unique_ptr<uint32[]> buf_;
+  std::unique_ptr<uint32_t[]> buf_;
 };
 
 TEST_F(SerializedStringArrayTest, DefaultConstructor) {
@@ -74,7 +75,7 @@ TEST_F(SerializedStringArrayTest, EmptyArray) {
   EXPECT_EQ(0, a.size());
 }
 
-const char kTestData[] =
+constexpr char kTestData[] =
     "\x03\x00\x00\x00"                  // Array size = 3
     "\x1c\x00\x00\x00\x05\x00\x00\x00"  // (28, 5)
     "\x22\x00\x00\x00\x04\x00\x00\x00"  // (34, 4)
@@ -84,16 +85,16 @@ const char kTestData[] =
     "google\0";                         // offset = 39, len = 6
 
 TEST_F(SerializedStringArrayTest, SerializeToBuffer) {
-  std::unique_ptr<uint32[]> buf;
+  std::unique_ptr<uint32_t[]> buf;
   const absl::string_view actual = SerializedStringArray::SerializeToBuffer(
       {"Hello", "Mozc", "google"}, &buf);
-  const absl::string_view expected(kTestData, arraysize(kTestData) - 1);
+  const absl::string_view expected(kTestData, std::size(kTestData) - 1);
   EXPECT_EQ(expected, actual);
 }
 
 TEST_F(SerializedStringArrayTest, Basic) {
   const absl::string_view data =
-      AlignString(std::string(kTestData, arraysize(kTestData) - 1));
+      AlignString(std::string(kTestData, std::size(kTestData) - 1));
 
   ASSERT_TRUE(SerializedStringArray::VerifyData(data));
 
@@ -118,7 +119,7 @@ TEST_F(SerializedStringArrayTest, Basic) {
 
 TEST_F(SerializedStringArrayTest, Iterator) {
   const absl::string_view data =
-      AlignString(std::string(kTestData, arraysize(kTestData) - 1));
+      AlignString(std::string(kTestData, std::size(kTestData) - 1));
 
   ASSERT_TRUE(SerializedStringArray::VerifyData(data));
 
