@@ -27,6 +27,7 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include <cstdint>
 #include <iostream>
 #include <string>
 
@@ -35,7 +36,7 @@
 #include "base/util.h"
 #include "absl/flags/flag.h"
 
-ABSL_FLAG(int32, sleep_time, 1000, "sleep time");
+ABSL_FLAG(int32_t, sleep_time, 1000, "sleep time");
 
 int main(int argc, char **argv) {
   mozc::InitMozc(argv[0], &argc, &argv);
