@@ -29,6 +29,10 @@
 
 #include "base/system_util.h"
 
+#include <cstdint>
+
+#include "absl/status/status.h"
+
 #ifdef OS_WIN
 // clang-format off
 #include <Windows.h>
@@ -46,6 +50,7 @@
 #ifdef __APPLE__
 #include <sys/stat.h>
 #include <sys/sysctl.h>
+
 #include <cerrno>
 #endif  // __APPLE__
 
@@ -78,31 +83,38 @@
 #ifdef OS_WIN
 #include "base/win_util.h"
 #endif  // OS_WIN
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
-
 namespace {
-class UserProfileDirectoryImpl {
+
+class UserProfileDirectoryImpl final {
  public:
   UserProfileDirectoryImpl() = default;
-  virtual ~UserProfileDirectoryImpl() = default;
+  ~UserProfileDirectoryImpl() = default;
 
   std::string GetDir();
   void SetDir(const std::string &dir);
 
  private:
   std::string GetUserProfileDirectory() const;
+
   std::string dir_;
+  absl::Mutex mutex_;
 };
 
 std::string UserProfileDirectoryImpl::GetDir() {
+  absl::MutexLock l(&mutex_);
   if (!dir_.empty()) {
     return dir_;
   }
   const std::string dir = GetUserProfileDirectory();
-  FileUtil::CreateDirectory(dir);
-  if (!FileUtil::DirectoryExists(dir)) {
-    LOG(ERROR) << "Failed to create directory: " << dir;
+  if (absl::Status s = FileUtil::CreateDirectory(dir);
+      !s.ok() && !absl::IsAlreadyExists(s)) {
+    LOG(ERROR) << "Failed to create directory: " << dir << ": " << s;
+  }
+  if (absl::Status s = FileUtil::DirectoryExists(dir); !s.ok()) {
+    LOG(ERROR) << "User profile directory doesn't exist: " << dir << ": " << s;
   }
 
   dir_ = dir;
@@ -110,6 +122,7 @@ std::string UserProfileDirectoryImpl::GetDir() {
 }
 
 void UserProfileDirectoryImpl::SetDir(const std::string &dir) {
+  absl::MutexLock l(&mutex_);
   dir_ = dir;
 }
 
@@ -122,12 +135,12 @@ class LocalAppDataDirectoryCache {
   }
   HRESULT result() const { return result_; }
   const bool succeeded() const { return SUCCEEDED(result_); }
-  const string &path() const { return path_; }
+  const std::string &path() const { return path_; }
 
  private:
   // b/5707813 implies that TryGetLocalAppData causes an exception and makes
   // Singleton<LocalAppDataDirectoryCache> invalid state which results in an
-  // infinite spin loop in CallOnce. To prevent this, the constructor of
+  // infinite spin loop in call_once. To prevent this, the constructor of
   // LocalAppDataDirectoryCache must be exception free.
   // Note that __try and __except does not guarantees that any destruction
   // of internal C++ objects when a non-C++ exception occurs except that
@@ -135,7 +148,7 @@ class LocalAppDataDirectoryCache {
   // Since Mozc uses /EHs option in common.gypi, we must admit potential
   // memory leakes when any non-C++ exception occues in TryGetLocalAppData.
   // See http://msdn.microsoft.com/en-us/library/1deeycx5.aspx
-  static HRESULT __declspec(nothrow) SafeTryGetLocalAppData(string *dir) {
+  static HRESULT __declspec(nothrow) SafeTryGetLocalAppData(std::string *dir) {
     __try {
       return TryGetLocalAppData(dir);
     } __except (EXCEPTION_EXECUTE_HANDLER) {
@@ -143,7 +156,7 @@ class LocalAppDataDirectoryCache {
     }
   }
 
-  static HRESULT TryGetLocalAppData(string *dir) {
+  static HRESULT TryGetLocalAppData(std::string *dir) {
     if (dir == nullptr) {
       return E_FAIL;
     }
@@ -160,7 +173,7 @@ class LocalAppDataDirectoryCache {
     return TryGetLocalAppDataLow(dir);
   }
 
-  static HRESULT TryGetLocalAppDataForAppContainer(string *dir) {
+  static HRESULT TryGetLocalAppDataForAppContainer(std::string *dir) {
     // User profiles for processes running under AppContainer seem to be as
     // follows, while the scheme is not officially documented.
     //   "%LOCALAPPDATA%\Packages\<package sid>\..."
@@ -181,13 +194,13 @@ class LocalAppDataDirectoryCache {
     }
     path.erase(local_pos);
     path += L"Low";
-    if (Util::WideToUTF8(path, dir) == 0) {
+    if (Util::WideToUtf8(path, dir) == 0) {
       return E_FAIL;
     }
     return S_OK;
   }
 
-  static HRESULT TryGetLocalAppDataLow(string *dir) {
+  static HRESULT TryGetLocalAppDataLow(std::string *dir) {
     if (dir == nullptr) {
       return E_FAIL;
     }
@@ -210,8 +223,8 @@ class LocalAppDataDirectoryCache {
     std::wstring wpath = task_mem_buffer;
     ::CoTaskMemFree(task_mem_buffer);
 
-    string path;
-    if (Util::WideToUTF8(wpath, &path) == 0) {
+    std::string path;
+    if (Util::WideToUtf8(wpath, &path) == 0) {
       return E_UNEXPECTED;
     }
 
@@ -220,7 +233,7 @@ class LocalAppDataDirectoryCache {
   }
 
   HRESULT result_;
-  string path_;
+  std::string path_;
 };
 #endif  // OS_WIN
 
@@ -255,25 +268,25 @@ std::string UserProfileDirectoryImpl::GetUserProfileDirectory() const {
   DCHECK(SUCCEEDED(Singleton<LocalAppDataDirectoryCache>::get()->result()));
   std::string dir = Singleton<LocalAppDataDirectoryCache>::get()->path();
 
-# ifdef GOOGLE_JAPANESE_INPUT_BUILD
+#ifdef GOOGLE_JAPANESE_INPUT_BUILD
   dir = FileUtil::JoinPath(dir, kCompanyNameInEnglish);
-  FileUtil::CreateDirectory(dir);
-# endif  // GOOGLE_JAPANESE_INPUT_BUILD
+  if (absl::Status s = FileUtil::CreateDirectory(dir); !s.ok()) {
+    LOG(ERROR) << s;
+  }
+#endif  // GOOGLE_JAPANESE_INPUT_BUILD
   return FileUtil::JoinPath(dir, kProductNameInEnglish);
 
-
 #elif defined(__APPLE__)
   std::string dir = MacUtil::GetApplicationSupportDirectory();
-# ifdef GOOGLE_JAPANESE_INPUT_BUILD
+#ifdef GOOGLE_JAPANESE_INPUT_BUILD
   dir = FileUtil::JoinPath(dir, "Google");
   // The permission of ~/Library/Application Support/Google seems to be 0755.
   // TODO(komatsu): nice to make a wrapper function.
   ::mkdir(dir.c_str(), 0755);
   return FileUtil::JoinPath(dir, "JapaneseInput");
-# else   //  GOOGLE_JAPANESE_INPUT_BUILD
+#else   //  GOOGLE_JAPANESE_INPUT_BUILD
   return FileUtil::JoinPath(dir, "Mozc");
-# endif  //  GOOGLE_JAPANESE_INPUT_BUILD
-
+#endif  //  GOOGLE_JAPANESE_INPUT_BUILD
 
 #elif defined(OS_LINUX)
   // 1. If "$HOME/.mozc" already exists,
@@ -296,7 +309,7 @@ std::string UserProfileDirectoryImpl::GetUserProfileDirectory() const {
   }
 
   const std::string old_dir = FileUtil::JoinPath(home, ".mozc");
-  if (FileUtil::DirectoryExists(old_dir)) {
+  if (FileUtil::DirectoryExists(old_dir).ok()) {
     return old_dir;
   }
 
@@ -306,10 +319,10 @@ std::string UserProfileDirectoryImpl::GetUserProfileDirectory() const {
   }
   return FileUtil::JoinPath(home, ".config/mozc");
 
-#else
+#else  // Supported platforms
 #error Undefined target platform.
 
-#endif
+#endif  // Platforms
 }
 
 }  // namespace
@@ -320,8 +333,10 @@ std::string SystemUtil::GetUserProfileDirectory() {
 
 std::string SystemUtil::GetLoggingDirectory() {
 #ifdef __APPLE__
-  string dir = MacUtil::GetLoggingDirectory();
-  FileUtil::CreateDirectory(dir);
+  std::string dir = MacUtil::GetLoggingDirectory();
+  if (absl::Status s = FileUtil::CreateDirectory(dir); !s.ok()) {
+    LOG(ERROR) << s;
+  }
   return dir;
 #else   // __APPLE__
   return GetUserProfileDirectory();
@@ -342,19 +357,20 @@ class ProgramFilesX86Cache {
   }
   const bool succeeded() const { return SUCCEEDED(result_); }
   const HRESULT result() const { return result_; }
-  const string &path() const { return path_; }
+  const std::string &path() const { return path_; }
 
  private:
   // b/5707813 implies that the Shell API causes an exception in some cases.
-  // In order to avoid potential infinite loops in CallOnce. the constructor of
-  // ProgramFilesX86Cache must be exception free.
+  // In order to avoid potential infinite loops in call_once. the constructor
+  // of ProgramFilesX86Cache must be exception free.
   // Note that __try and __except does not guarantees that any destruction
   // of internal C++ objects when a non-C++ exception occurs except that
   // /EHa compiler option is specified.
   // Since Mozc uses /EHs option in common.gypi, we must admit potential
   // memory leakes when any non-C++ exception occues in TryProgramFilesPath.
   // See http://msdn.microsoft.com/en-us/library/1deeycx5.aspx
-  static HRESULT __declspec(nothrow) SafeTryProgramFilesPath(string *path) {
+  static HRESULT __declspec(nothrow)
+      SafeTryProgramFilesPath(std::string *path) {
     __try {
       return TryProgramFilesPath(path);
     } __except (EXCEPTION_EXECUTE_HANDLER) {
@@ -362,7 +378,7 @@ class ProgramFilesX86Cache {
     }
   }
 
-  static HRESULT TryProgramFilesPath(string *path) {
+  static HRESULT TryProgramFilesPath(std::string *path) {
     if (path == nullptr) {
       return E_FAIL;
     }
@@ -391,15 +407,15 @@ class ProgramFilesX86Cache {
       return result;
     }
 
-    string program_files;
-    if (Util::WideToUTF8(program_files_path_buffer, &program_files) == 0) {
+    std::string program_files;
+    if (Util::WideToUtf8(program_files_path_buffer, &program_files) == 0) {
       return E_FAIL;
     }
     *path = program_files;
     return S_OK;
   }
   HRESULT result_;
-  string path_;
+  std::string path_;
 };
 }  // namespace
 #endif  // OS_WIN
@@ -407,15 +423,15 @@ class ProgramFilesX86Cache {
 std::string SystemUtil::GetServerDirectory() {
 #ifdef OS_WIN
   DCHECK(SUCCEEDED(Singleton<ProgramFilesX86Cache>::get()->result()));
-# if defined(GOOGLE_JAPANESE_INPUT_BUILD)
+#if defined(GOOGLE_JAPANESE_INPUT_BUILD)
   return FileUtil::JoinPath(
       FileUtil::JoinPath(Singleton<ProgramFilesX86Cache>::get()->path(),
                          kCompanyNameInEnglish),
       kProductNameInEnglish);
-# else   // GOOGLE_JAPANESE_INPUT_BUILD
+#else   // GOOGLE_JAPANESE_INPUT_BUILD
   return FileUtil::JoinPath(Singleton<ProgramFilesX86Cache>::get()->path(),
                             kProductNameInEnglish);
-# endif  // GOOGLE_JAPANESE_INPUT_BUILD
+#endif  // GOOGLE_JAPANESE_INPUT_BUILD
 #endif  // OS_WIN
 
 #if defined(__APPLE__)
@@ -423,12 +439,11 @@ std::string SystemUtil::GetServerDirectory() {
 #endif  // __APPLE__
 
 #if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_WASM)
-# if defined(MOZC_SERVER_DIRECTORY)
-  return MOZC_SERVER_DIRECTORY;
-# else
-  return "/usr/lib/mozc";
-# endif  // MOZC_SERVER_DIRECTORY
-#endif   // OS_LINUX || OS_ANDROID || OS_WASM
+#ifndef MOZC_SERVER_DIR
+#define MOZC_SERVER_DIR "/usr/lib/mozc"
+#endif  // MOZC_SERVER_DIR
+  return MOZC_SERVER_DIR;
+#endif  // OS_LINUX || OS_ANDROID || OS_WASM
 
   // If none of the above platforms is specified, the compiler raises an error
   // because of no return value.
@@ -462,17 +477,22 @@ std::string SystemUtil::GetToolPath() {
 }
 
 std::string SystemUtil::GetDocumentDirectory() {
-#if defined(__APPLE__)
+#if defined(OS_LINUX)
+
+#ifndef MOZC_DOCUMENT_DIR
+#define MOZC_DOCUMENT_DIR "/usr/lib/mozc/documents"
+#endif  // MOZC_DOCUMENT_DIR
+  return MOZC_DOCUMENT_DIR;
+
+#elif defined(__APPLE__)
   return GetServerDirectory();
-#elif defined(MOZC_DOCUMENT_DIRECTORY)
-  return MOZC_DOCUMENT_DIRECTORY;
-#else
+#else   // OS_LINUX, __APPLE__
   return FileUtil::JoinPath(GetServerDirectory(), "documents");
-#endif  // __APPLE__
+#endif  // OS_LINUX, __APPLE__
 }
 
 std::string SystemUtil::GetCrashReportDirectory() {
-  const char kCrashReportDirectory[] = "CrashReports";
+  constexpr char kCrashReportDirectory[] = "CrashReports";
   return FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(),
                             kCrashReportDirectory);
 }
@@ -487,8 +507,8 @@ std::string SystemUtil::GetUserNameAsString() {
   //   or will be impersonated.
   const BOOL result = ::GetUserName(wusername, &name_size);
   DCHECK_NE(FALSE, result);
-  string username;
-  Util::WideToUTF8(&wusername[0], &username);
+  std::string username;
+  Util::WideToUtf8(&wusername[0], &username);
   return username;
 #endif  // OS_WIN
 
@@ -516,10 +536,10 @@ namespace {
 class UserSidImpl {
  public:
   UserSidImpl();
-  const string &get() { return sid_; }
+  const std::string &get() { return sid_; }
 
  private:
-  string sid_;
+  std::string sid_;
 };
 
 UserSidImpl::UserSidImpl() {
@@ -551,7 +571,7 @@ UserSidImpl::UserSidImpl() {
     return;
   }
 
-  Util::WideToUTF8(p_sid_user_name, &sid_);
+  Util::WideToUtf8(p_sid_user_name, &sid_);
 
   ::LocalFree(p_sid_user_name);
   ::CloseHandle(htoken);
@@ -571,7 +591,7 @@ std::string SystemUtil::GetUserSidAsString() {
 #ifdef OS_WIN
 namespace {
 
-string GetObjectNameAsString(HANDLE handle) {
+std::string GetObjectNameAsString(HANDLE handle) {
   if (handle == nullptr) {
     LOG(ERROR) << "Unknown handle";
     return "";
@@ -628,18 +648,18 @@ bool GetCurrentSessionId(uint32 *session_id) {
 // desktop is most appropriate and important desktop for our use case.
 // See
 // http://blogs.adobe.com/asset/2012/10/new-security-capabilities-in-adobe-reader-and-acrobat-xi-now-available.html
-string GetInputDesktopName() {
+std::string GetInputDesktopName() {
   const HDESK desktop_handle =
       ::OpenInputDesktop(0, FALSE, DESKTOP_READOBJECTS);
   if (desktop_handle == nullptr) {
     return "";
   }
-  const string desktop_name = GetObjectNameAsString(desktop_handle);
+  const std::string desktop_name = GetObjectNameAsString(desktop_handle);
   ::CloseDesktop(desktop_handle);
   return desktop_name;
 }
 
-string GetProcessWindowStationName() {
+std::string GetProcessWindowStationName() {
   // We must not close the returned value of GetProcessWindowStation().
   // http://msdn.microsoft.com/en-us/library/windows/desktop/ms683225.aspx
   const HWINSTA window_station = ::GetProcessWindowStation();
@@ -650,7 +670,7 @@ string GetProcessWindowStationName() {
   return GetObjectNameAsString(window_station);
 }
 
-string GetSessionIdString() {
+std::string GetSessionIdString() {
   uint32 session_id = 0;
   if (!GetCurrentSessionId(&session_id)) {
     return "";
@@ -675,19 +695,19 @@ std::string SystemUtil::GetDesktopNameAsString() {
 #endif  // __APPLE__
 
 #if defined(OS_WIN)
-  const string &session_id = GetSessionIdString();
+  const std::string &session_id = GetSessionIdString();
   if (session_id.empty()) {
     DLOG(ERROR) << "Failed to retrieve session id";
     return "";
   }
 
-  const string &window_station_name = GetProcessWindowStationName();
+  const std::string &window_station_name = GetProcessWindowStationName();
   if (window_station_name.empty()) {
     DLOG(ERROR) << "Failed to retrieve window station name";
     return "";
   }
 
-  const string &desktop_name = GetInputDesktopName();
+  const std::string &desktop_name = GetInputDesktopName();
   if (desktop_name.empty()) {
     DLOG(ERROR) << "Failed to retrieve desktop name";
     return "";
@@ -705,8 +725,8 @@ class SystemDirectoryCache {
  public:
   SystemDirectoryCache() : system_dir_(nullptr) {
     const UINT copied_len_wo_null_if_success =
-        ::GetSystemDirectory(path_buffer_, arraysize(path_buffer_));
-    if (copied_len_wo_null_if_success >= arraysize(path_buffer_)) {
+        ::GetSystemDirectory(path_buffer_, std::size(path_buffer_));
+    if (copied_len_wo_null_if_success >= std::size(path_buffer_)) {
       // Function failed.
       return;
     }
@@ -742,7 +762,7 @@ bool SystemUtil::IsWindows7OrLater() {
 #ifdef OS_WIN
   static const bool result = ::IsWindows7OrGreater();
   return result;
-#else
+#else   // OS_WIN
   return false;
 #endif  // OS_WIN
 }
@@ -751,7 +771,7 @@ bool SystemUtil::IsWindows8OrLater() {
 #ifdef OS_WIN
   static const bool result = ::IsWindows8OrGreater();
   return result;
-#else
+#else   // OS_WIN
   return false;
 #endif  // OS_WIN
 }
@@ -760,7 +780,7 @@ bool SystemUtil::IsWindows8_1OrLater() {
 #ifdef OS_WIN
   static const bool result = ::IsWindows8Point1OrGreater();
   return result;
-#else
+#else   // OS_WIN
   return false;
 #endif  // OS_WIN
 }
@@ -792,7 +812,7 @@ bool SystemUtil::IsWindowsX64() {
   // This function never fails.
   ::GetNativeSystemInfo(&system_info);
   return (system_info.wProcessorArchitecture == PROCESSOR_ARCHITECTURE_AMD64);
-#else
+#else   // OS_WIN
   return false;
 #endif  // OS_WIN
 }
@@ -818,14 +838,14 @@ const wchar_t *SystemUtil::GetSystemDir() {
   return Singleton<SystemDirectoryCache>::get()->system_dir();
 }
 
-string SystemUtil::GetMSCTFAsmCacheReadyEventName() {
-  const string &session_id = GetSessionIdString();
+std::string SystemUtil::GetMSCTFAsmCacheReadyEventName() {
+  const std::string &session_id = GetSessionIdString();
   if (session_id.empty()) {
     DLOG(ERROR) << "Failed to retrieve session id";
     return "";
   }
 
-  const string &desktop_name = GetInputDesktopName();
+  const std::string &desktop_name = GetInputDesktopName();
 
   if (desktop_name.empty()) {
     DLOG(ERROR) << "Failed to retrieve desktop name";
@@ -841,7 +861,7 @@ string SystemUtil::GetMSCTFAsmCacheReadyEventName() {
 // version only when initializing.
 std::string SystemUtil::GetOSVersionString() {
 #ifdef OS_WIN
-  string ret = "Windows";
+  std::string ret = "Windows";
   OSVERSIONINFOEX osvi = {0};
   osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
   if (GetVersionEx(reinterpret_cast<OSVERSIONINFO *>(&osvi))) {
@@ -856,14 +876,14 @@ std::string SystemUtil::GetOSVersionString() {
   }
   return ret;
 #elif defined(__APPLE__)
-  const string ret = "MacOSX " + MacUtil::GetOSVersionString();
+  const std::string ret = "MacOSX " + MacUtil::GetOSVersionString();
   // TODO(toshiyuki): get more specific info
   return ret;
 #elif defined(OS_LINUX)
   const std::string ret = "Linux";
   return ret;
 #else   // !OS_WIN && !__APPLE__ && !OS_LINUX
-  const string ret = "Unknown";
+  const std::string ret = "Unknown";
   return ret;
 #endif  // OS_WIN, __APPLE__, OS_LINUX
 }
@@ -877,7 +897,7 @@ void SystemUtil::DisableIME() {
 #endif  // OS_WIN
 }
 
-uint64 SystemUtil::GetTotalPhysicalMemory() {
+uint64_t SystemUtil::GetTotalPhysicalMemory() {
 #if defined(OS_WIN)
   MEMORYSTATUSEX memory_status = {sizeof(MEMORYSTATUSEX)};
   if (!::GlobalMemoryStatusEx(&memory_status)) {
@@ -891,7 +911,7 @@ uint64 SystemUtil::GetTotalPhysicalMemory() {
   uint64 total_memory = 0;
   size_t size = sizeof(total_memory);
   const int error =
-      sysctl(mib, arraysize(mib), &total_memory, &size, nullptr, 0);
+      sysctl(mib, std::size(mib), &total_memory, &size, nullptr, 0);
   if (error == -1) {
     const int error = errno;
     LOG(ERROR) << "sysctl with hw.memsize failed. "
@@ -902,19 +922,19 @@ uint64 SystemUtil::GetTotalPhysicalMemory() {
 #endif  // __APPLE__
 
 #if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_WASM)
-# if defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
-  const int32 page_size = sysconf(_SC_PAGESIZE);
-  const int32 number_of_phyisical_pages = sysconf(_SC_PHYS_PAGES);
+#if defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
+  const int32_t page_size = sysconf(_SC_PAGESIZE);
+  const int32_t number_of_phyisical_pages = sysconf(_SC_PHYS_PAGES);
   if (number_of_phyisical_pages < 0) {
     // likely to be overflowed.
     LOG(FATAL) << number_of_phyisical_pages << ", " << page_size;
     return 0;
   }
-  return static_cast<uint64>(number_of_phyisical_pages) * page_size;
-# else   // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
+  return static_cast<uint64_t>(number_of_phyisical_pages) * page_size;
+#else   // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
   return 0;
-# endif  // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
-#endif   // OS_LINUX || OS_ANDROID || OS_WASM
+#endif  // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
+#endif  // OS_LINUX || OS_ANDROID || OS_WASM
 
   // If none of the above platforms is specified, the compiler raises an error
   // because of no return value.
