@@ -29,6 +29,8 @@
 
 #include "base/trie.h"
 
+#include <string>
+
 #include "testing/base/public/gunit.h"
 
 namespace mozc {
@@ -42,7 +44,7 @@ TEST(TrieTest, Trie) {
     ADD,
     REMOVE,
   };
-  static const struct TestCase {
+  const struct TestCase {
     const int type;
     const std::string key;
     const std::string value;
@@ -68,7 +70,7 @@ TEST(TrieTest, Trie) {
       {LOOKUP, "abcd", "", true, "data_abcd"},
       {REMOVE, "xyz", "", false, ""},
   };
-  const int size = arraysize(test_cases);
+  const int size = std::size(test_cases);
   for (int i = 0; i < size; ++i) {
     const TestCase &test = test_cases[i];
     switch (test.type) {
