@@ -29,6 +29,8 @@
 
 #include "base/unverified_aes256.h"
 
+#include <cstdint>
+
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
@@ -60,14 +62,14 @@ class TestableUnverifiedAES256 : public UnverifiedAES256 {
 template <size_t kArraySize>
 AssertionResult AssertEqualDataWithFormat(const char* expected_expression,
                                           const char* actual_expression,
-                                          const uint8 (&expected)[kArraySize],
-                                          const uint8 (&actual)[kArraySize]) {
+                                          const uint8_t (&expected)[kArraySize],
+                                          const uint8_t (&actual)[kArraySize]) {
   for (size_t i = 0; i < kArraySize; ++i) {
     if (expected[i] != actual[i]) {
       return AssertionFailure()
              << "Data mismatsh at " << i << " byte."
-             << " expected: " << static_cast<uint32>(expected[i])
-             << ", actual: " << static_cast<uint32>(actual[i]);
+             << " expected: " << static_cast<uint32_t>(expected[i])
+             << ", actual: " << static_cast<uint32_t>(actual[i]);
     }
   }
   return AssertionSuccess();
@@ -79,12 +81,12 @@ AssertionResult AssertEqualDataWithFormat(const char* expected_expression,
 TEST(UnverifiedAES256Test, MakeKeySchedule) {
   // A.3 Expansion of a 256-bit Cipher Key
   // http://csrc.nist.gov/publications/fips/fips197/fips-197.pdf
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x60, 0x3d, 0xeb, 0x10, 0x15, 0xca, 0x71, 0xbe, 0x2b, 0x73, 0xae,
       0xf0, 0x85, 0x7d, 0x77, 0x81, 0x1f, 0x35, 0x2c, 0x07, 0x3b, 0x61,
       0x08, 0xd7, 0x2d, 0x98, 0x10, 0xa3, 0x09, 0x14, 0xdf, 0xf4,
   };
-  const uint8 kExpected[UnverifiedAES256::kKeyScheduleBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kKeyScheduleBytes] = {
       0x60, 0x3d, 0xeb, 0x10, 0x15, 0xca, 0x71, 0xbe, 0x2b, 0x73, 0xae, 0xf0,
       0x85, 0x7d, 0x77, 0x81, 0x1f, 0x35, 0x2c, 0x07, 0x3b, 0x61, 0x08, 0xd7,
       0x2d, 0x98, 0x10, 0xa3, 0x09, 0x14, 0xdf, 0xf4, 0x9b, 0xa3, 0x54, 0x11,
@@ -106,18 +108,18 @@ TEST(UnverifiedAES256Test, MakeKeySchedule) {
       0x9a, 0xdf, 0x6a, 0xce, 0xbd, 0x10, 0x19, 0x0d, 0xfe, 0x48, 0x90, 0xd1,
       0xe6, 0x18, 0x8d, 0x0b, 0x04, 0x6d, 0xf3, 0x44, 0x70, 0x6c, 0x63, 0x1e,
   };
-  uint8 key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
+  uint8_t key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
 
   TestableUnverifiedAES256::MakeKeySchedule(kKey, key_schedule);
   EXPECT_EQ_ARRAY(kExpected, key_schedule);
 }
 
 TEST(UnverifiedAES256Test, SubBytes) {
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
       0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   };
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x63, 0x7c, 0x77, 0x7b, 0xf2, 0x6b, 0x6f, 0xc5,
       0x30, 0x01, 0x67, 0x2b, 0xfe, 0xd7, 0xab, 0x76,
   };
@@ -126,11 +128,11 @@ TEST(UnverifiedAES256Test, SubBytes) {
 }
 
 TEST(UnverifiedAES256Test, InvSubBytes) {
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
       0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   };
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x52, 0x09, 0x6a, 0xd5, 0x30, 0x36, 0xa5, 0x38,
       0xbf, 0x40, 0xa3, 0x9e, 0x81, 0xf3, 0xd7, 0xfb,
   };
@@ -139,11 +141,11 @@ TEST(UnverifiedAES256Test, InvSubBytes) {
 }
 
 TEST(UnverifiedAES256Test, MixColumns) {
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
       0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   };
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x02, 0x07, 0x00, 0x05, 0x06, 0x03, 0x04, 0x01,
       0x0a, 0x0f, 0x08, 0x0d, 0x0e, 0x0b, 0x0c, 0x09,
   };
@@ -152,11 +154,11 @@ TEST(UnverifiedAES256Test, MixColumns) {
 }
 
 TEST(UnverifiedAES256Test, InvMixColumns) {
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
       0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   };
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x0a, 0x0f, 0x08, 0x0d, 0x0e, 0x0b, 0x0c, 0x09,
       0x02, 0x07, 0x00, 0x05, 0x06, 0x03, 0x04, 0x01,
   };
@@ -165,11 +167,11 @@ TEST(UnverifiedAES256Test, InvMixColumns) {
 }
 
 TEST(UnverifiedAES256Test, ShiftRows) {
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
       0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   };
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x05, 0x0a, 0x0f, 0x04, 0x09, 0x0e, 0x03,
       0x08, 0x0d, 0x02, 0x07, 0x0c, 0x01, 0x06, 0x0b,
   };
@@ -178,15 +180,15 @@ TEST(UnverifiedAES256Test, ShiftRows) {
 }
 
 TEST(UnverifiedAES256Test, TransformECB_Zero) {
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
-  uint8 key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
+  uint8_t key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
   TestableUnverifiedAES256::MakeKeySchedule(kKey, key_schedule);
 
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
@@ -195,7 +197,7 @@ TEST(UnverifiedAES256Test, TransformECB_Zero) {
   // $ openssl enc -e -nopad -aes-256-ecb -K
   // 0000000000000000000000000000000000000000000000000000000000000000 -in <(echo
   // "0000: 00000000000000000000000000000000" | xxd -r) -out >(xxd -g 1 -i -c 8)
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0xdc, 0x95, 0xc0, 0x78, 0xa2, 0x40, 0x89, 0x89,
       0xad, 0x48, 0xa2, 0x14, 0x92, 0x84, 0x20, 0x87,
   };
@@ -205,15 +207,15 @@ TEST(UnverifiedAES256Test, TransformECB_Zero) {
 }
 
 TEST(UnverifiedAES256Test, InverseTransformECB_Zero) {
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
-  uint8 key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
+  uint8_t key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
   TestableUnverifiedAES256::MakeKeySchedule(kKey, key_schedule);
 
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
@@ -222,7 +224,7 @@ TEST(UnverifiedAES256Test, InverseTransformECB_Zero) {
   // $ openssl enc -d -nopad -aes-256-ecb -K
   // 0000000000000000000000000000000000000000000000000000000000000000 -in <(echo
   // "0000: 00000000000000000000000000000000" | xxd -r) -out >(xxd -g 1 -i -c 8)
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x67, 0x67, 0x1c, 0xe1, 0xfa, 0x91, 0xdd, 0xeb,
       0x0f, 0x8f, 0xbb, 0xb3, 0x66, 0xb5, 0x31, 0xb4,
   };
@@ -233,18 +235,18 @@ TEST(UnverifiedAES256Test, InverseTransformECB_Zero) {
 TEST(UnverifiedAES256Test, TransformECB) {
   // http://csrc.nist.gov/publications/fips/fips197/fips-197.pdf
   // C.3 AES-256 (Nk=8, Nr=14)
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a,
       0x0b, 0x0c, 0x0d, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13, 0x14, 0x15,
       0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
   };
-  uint8 key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
+  uint8_t key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
   TestableUnverifiedAES256::MakeKeySchedule(kKey, key_schedule);
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77,
       0x88, 0x99, 0xaa, 0xbb, 0xcc, 0xdd, 0xee, 0xff,
   };
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x8e, 0xa2, 0xb7, 0xca, 0x51, 0x67, 0x45, 0xbf,
       0xea, 0xfc, 0x49, 0x90, 0x4b, 0x49, 0x60, 0x89,
   };
@@ -255,18 +257,18 @@ TEST(UnverifiedAES256Test, TransformECB) {
 TEST(UnverifiedAES256Test, InverseTransformECB) {
   // http://csrc.nist.gov/publications/fips/fips197/fips-197.pdf
   // C.3 AES-256 (Nk=8, Nr=14)
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a,
       0x0b, 0x0c, 0x0d, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13, 0x14, 0x15,
       0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
   };
-  uint8 key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
+  uint8_t key_schedule[UnverifiedAES256::kKeyScheduleBytes] = {};
   TestableUnverifiedAES256::MakeKeySchedule(kKey, key_schedule);
-  uint8 block[UnverifiedAES256::kBlockBytes] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes] = {
       0x8e, 0xa2, 0xb7, 0xca, 0x51, 0x67, 0x45, 0xbf,
       0xea, 0xfc, 0x49, 0x90, 0x4b, 0x49, 0x60, 0x89,
   };
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77,
       0x88, 0x99, 0xaa, 0xbb, 0xcc, 0xdd, 0xee, 0xff,
   };
@@ -275,18 +277,18 @@ TEST(UnverifiedAES256Test, InverseTransformECB) {
 }
 
 TEST(UnverifiedAES256Test, TransformCBC_Zero) {
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
-  const uint8 kIV[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kIV[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
-  const size_t kNumBlocks = 4;
+  constexpr size_t kNumBlocks = 4;
 
-  uint8 block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
@@ -302,7 +304,7 @@ TEST(UnverifiedAES256Test, TransformCBC_Zero) {
   // 00000000000000000000000000000000 \n0010: 00000000000000000000000000000000
   // \n0020: 00000000000000000000000000000000 \n0030:
   // 00000000000000000000000000000000" | xxd -r) -out >(xxd -g 1 -i -c 8)
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0xdc, 0x95, 0xc0, 0x78, 0xa2, 0x40, 0x89, 0x89, 0xad, 0x48, 0xa2,
       0x14, 0x92, 0x84, 0x20, 0x87, 0x08, 0xc3, 0x74, 0x84, 0x8c, 0x22,
       0x82, 0x33, 0xc2, 0xb3, 0x4f, 0x33, 0x2b, 0xd2, 0xe9, 0xd3, 0x8b,
@@ -316,17 +318,17 @@ TEST(UnverifiedAES256Test, TransformCBC_Zero) {
 }
 
 TEST(UnverifiedAES256Test, InverseTransformCBC_Zero) {
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
-  const uint8 kIV[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kIV[UnverifiedAES256::kBlockBytes] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   };
-  const size_t kNumBlocks = 4;
-  uint8 block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  constexpr size_t kNumBlocks = 4;
+  uint8_t block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
@@ -342,7 +344,7 @@ TEST(UnverifiedAES256Test, InverseTransformCBC_Zero) {
   // 00000000000000000000000000000000 \n0010: 00000000000000000000000000000000
   // \n0020: 00000000000000000000000000000000 \n0030:
   // 00000000000000000000000000000000" | xxd -r) -out >(xxd -g 1 -i -c 8)
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0x67, 0x67, 0x1c, 0xe1, 0xfa, 0x91, 0xdd, 0xeb, 0x0f, 0x8f, 0xbb,
       0xb3, 0x66, 0xb5, 0x31, 0xb4, 0x67, 0x67, 0x1c, 0xe1, 0xfa, 0x91,
       0xdd, 0xeb, 0x0f, 0x8f, 0xbb, 0xb3, 0x66, 0xb5, 0x31, 0xb4, 0x67,
@@ -355,17 +357,17 @@ TEST(UnverifiedAES256Test, InverseTransformCBC_Zero) {
 }
 
 TEST(UnverifiedAES256Test, TransformCBC_NonZero) {
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0xfe, 0x02, 0xfc, 0x04, 0xfa, 0x06, 0xf8, 0xf7, 0x09, 0xf5,
       0x0b, 0xf3, 0x0d, 0xf1, 0x0f, 0xff, 0x01, 0xfd, 0x03, 0xfb, 0x05,
       0xf9, 0x07, 0x08, 0xf6, 0x0a, 0xf4, 0x0c, 0xf2, 0x0e, 0xf0,
   };
-  const uint8 kIV[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kIV[UnverifiedAES256::kBlockBytes] = {
       0xf0, 0xe1, 0xd2, 0xc3, 0xb4, 0xa5, 0x96, 0x87,
       0x78, 0x69, 0x5a, 0x4b, 0x3c, 0x2d, 0x1e, 0x0f,
   };
-  const size_t kNumBlocks = 5;
-  uint8 block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  constexpr size_t kNumBlocks = 5;
+  uint8_t block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0x6f, 0x72, 0x67, 0x61, 0x6e, 0x69, 0x7a, 0x65, 0x20, 0x74, 0x68, 0x65,
       0x20, 0x77, 0x6f, 0x72, 0x6c, 0x64, 0x27, 0x73, 0x20, 0x69, 0x6e, 0x66,
       0x6f, 0x72, 0x6d, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x20, 0x61, 0x6e, 0x64,
@@ -383,7 +385,7 @@ TEST(UnverifiedAES256Test, TransformCBC_NonZero) {
   // \n0020: 20616e64206d616b6520697420756e69 \n0030:
   // 76657273616c6c792061636365737369 \n0040: 626c6520616e642075736566756c0000"
   // | xxd -r) -out >(xxd -g 1 -i -c 8)
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0xcd, 0xba, 0x6b, 0xc8, 0xec, 0x35, 0x36, 0x8c, 0x2f, 0x1a, 0x99, 0x57,
       0x44, 0xdd, 0x3a, 0x51, 0x63, 0xd0, 0x02, 0xd8, 0xab, 0x72, 0x5f, 0xb7,
       0x5a, 0x83, 0x0c, 0xf9, 0x37, 0x9d, 0x80, 0xeb, 0x6d, 0x1a, 0xb2, 0xdd,
@@ -397,18 +399,18 @@ TEST(UnverifiedAES256Test, TransformCBC_NonZero) {
 }
 
 TEST(UnverifiedAES256Test, InverseTransformCBC_NonZero) {
-  const uint8 kKey[UnverifiedAES256::kKeyBytes] = {
+  constexpr uint8_t kKey[UnverifiedAES256::kKeyBytes] = {
       0x00, 0xfe, 0x02, 0xfc, 0x04, 0xfa, 0x06, 0xf8, 0xf7, 0x09, 0xf5,
       0x0b, 0xf3, 0x0d, 0xf1, 0x0f, 0xff, 0x01, 0xfd, 0x03, 0xfb, 0x05,
       0xf9, 0x07, 0x08, 0xf6, 0x0a, 0xf4, 0x0c, 0xf2, 0x0e, 0xf0,
   };
-  const uint8 kIV[UnverifiedAES256::kBlockBytes] = {
+  constexpr uint8_t kIV[UnverifiedAES256::kBlockBytes] = {
       0xf0, 0xe1, 0xd2, 0xc3, 0xb4, 0xa5, 0x96, 0x87,
       0x78, 0x69, 0x5a, 0x4b, 0x3c, 0x2d, 0x1e, 0x0f,
   };
-  const size_t kNumBlocks = 5;
+  constexpr size_t kNumBlocks = 5;
 
-  uint8 block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  uint8_t block[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0xcd, 0xba, 0x6b, 0xc8, 0xec, 0x35, 0x36, 0x8c, 0x2f, 0x1a, 0x99, 0x57,
       0x44, 0xdd, 0x3a, 0x51, 0x63, 0xd0, 0x02, 0xd8, 0xab, 0x72, 0x5f, 0xb7,
       0x5a, 0x83, 0x0c, 0xf9, 0x37, 0x9d, 0x80, 0xeb, 0x6d, 0x1a, 0xb2, 0xdd,
@@ -426,7 +428,7 @@ TEST(UnverifiedAES256Test, InverseTransformCBC_NonZero) {
   // \n0020: 6d1ab2ddca9aee32ea91c5abc285b2a5 \n0030:
   // 304ee51ac9a236a06442217ef6ae5c7e \n0040: 84ff637f783a4eab0a5eb24974cd0f85"
   // | xxd -r) -out >(xxd -g 1 -i -c 8)
-  const uint8 kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
+  constexpr uint8_t kExpected[UnverifiedAES256::kBlockBytes * kNumBlocks] = {
       0x6f, 0x72, 0x67, 0x61, 0x6e, 0x69, 0x7a, 0x65, 0x20, 0x74, 0x68, 0x65,
       0x20, 0x77, 0x6f, 0x72, 0x6c, 0x64, 0x27, 0x73, 0x20, 0x69, 0x6e, 0x66,
       0x6f, 0x72, 0x6d, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x20, 0x61, 0x6e, 0x64,
