@@ -36,17 +36,17 @@
 
 namespace mozc {
 
-class URL {
+class Url {
  public:
   // Composes a URL for an uninstallation survey.  Note that we should set
   // version because, in Mac OS, we can not get mozc version from uninstaller
   // binary.
-  static bool GetUninstallationSurveyURL(const std::string &version,
+  static bool GetUninstallationSurveyUrl(const std::string &version,
                                          std::string *url);
 
   // should never be allocated.
  private:
-  DISALLOW_IMPLICIT_CONSTRUCTORS(URL);
+  DISALLOW_IMPLICIT_CONSTRUCTORS(Url);
 };
 
 }  // namespace mozc
