@@ -29,22 +29,25 @@
 
 #include "base/url.h"
 
+#include <optional>
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "base/util.h"
 #include "testing/base/public/gunit.h"
+#include "absl/strings/str_split.h"
 
 namespace mozc {
 namespace {
 
-const char kSurveyBaseURL[] =
+constexpr char kSurveyBaseUrl[] =
     "http://www.google.com/support/ime/japanese/bin/request.py";
 
 bool FindEncodedParam(const std::vector<std::string> &params,
                       const std::string &key, const std::string &value) {
   std::string encoded;
-  Util::EncodeURI(value, &encoded);
+  Util::EncodeUri(value, &encoded);
   const std::string param = key + "=" + encoded;
   for (size_t i = 0; i < params.size(); ++i) {
     if (params[i] == param) {
@@ -54,35 +57,43 @@ bool FindEncodedParam(const std::vector<std::string> &params,
   return false;
 }
 
-TEST(URLTest, UninstallationSurveyURL) {
-  std::string url;
-  URL::GetUninstallationSurveyURL("0.1.2.3", &url);
-  std::vector<std::string> url_and_params;
-  Util::SplitStringUsing(url, "?", &url_and_params);
-  EXPECT_EQ(2, url_and_params.size());
-  EXPECT_EQ(kSurveyBaseURL, url_and_params[0]);
+struct ParsedUrl {
+  std::string base_url;
   std::vector<std::string> params;
-  Util::SplitStringUsing(url_and_params[1], "&", &params);
-  EXPECT_EQ(4, params.size());
-  EXPECT_TRUE(FindEncodedParam(params, "contact_type", "surveyime"));
-  EXPECT_TRUE(FindEncodedParam(params, "hl", "jp"));
-  EXPECT_TRUE(FindEncodedParam(params, "format", "inproduct"));
-  EXPECT_TRUE(FindEncodedParam(params, "version", "0.1.2.3"));
+};
+
+std::optional<ParsedUrl> ParseUrl(absl::string_view url) {
+  std::vector<std::string> url_and_params = absl::StrSplit(url, '?');
+  if (url_and_params.size() != 2) {
+    return std::nullopt;
+  }
+  return ParsedUrl{std::move(url_and_params[0]),
+                   absl::StrSplit(url_and_params[1], '&')};
 }
 
-TEST(URLTest, UninstallationSurveyURLWithNoVersion) {
+TEST(UrlTest, UninstallationSurveyUrl) {
   std::string url;
-  URL::GetUninstallationSurveyURL("", &url);
-  std::vector<std::string> url_and_params;
-  Util::SplitStringUsing(url, "?", &url_and_params);
-  EXPECT_EQ(2, url_and_params.size());
-  EXPECT_EQ(kSurveyBaseURL, url_and_params[0]);
-  std::vector<std::string> params;
-  Util::SplitStringUsing(url_and_params[1], "&", &params);
-  EXPECT_EQ(3, params.size());
-  EXPECT_TRUE(FindEncodedParam(params, "contact_type", "surveyime"));
-  EXPECT_TRUE(FindEncodedParam(params, "hl", "jp"));
-  EXPECT_TRUE(FindEncodedParam(params, "format", "inproduct"));
+  Url::GetUninstallationSurveyUrl("0.1.2.3", &url);
+  const std::optional<ParsedUrl> parsed = ParseUrl(url);
+  ASSERT_TRUE(parsed.has_value()) << "Unexpected URL format: " << url;
+  EXPECT_EQ(kSurveyBaseUrl, parsed->base_url);
+  EXPECT_EQ(4, parsed->params.size());
+  EXPECT_TRUE(FindEncodedParam(parsed->params, "contact_type", "surveyime"));
+  EXPECT_TRUE(FindEncodedParam(parsed->params, "hl", "jp"));
+  EXPECT_TRUE(FindEncodedParam(parsed->params, "format", "inproduct"));
+  EXPECT_TRUE(FindEncodedParam(parsed->params, "version", "0.1.2.3"));
+}
+
+TEST(UrlTest, UninstallationSurveyUrlWithNoVersion) {
+  std::string url;
+  Url::GetUninstallationSurveyUrl("", &url);
+  const std::optional<ParsedUrl> parsed = ParseUrl(url);
+  ASSERT_TRUE(parsed.has_value()) << "Unexpected URL format: " << url;
+  EXPECT_EQ(kSurveyBaseUrl, parsed->base_url);
+  EXPECT_EQ(3, parsed->params.size());
+  EXPECT_TRUE(FindEncodedParam(parsed->params, "contact_type", "surveyime"));
+  EXPECT_TRUE(FindEncodedParam(parsed->params, "hl", "jp"));
+  EXPECT_TRUE(FindEncodedParam(parsed->params, "format", "inproduct"));
 }
 
 }  // namespace
