@@ -29,6 +29,9 @@
 
 #include "base/util.h"
 
+#include <cerrno>
+#include <cstdint>
+
 #ifdef OS_WIN
 // clang-format off
 #include <Windows.h>
@@ -50,7 +53,6 @@
 #endif  // !OS_WIN
 
 #include <algorithm>
-#include <cctype>
 #include <cstdarg>
 #include <cstdlib>
 #include <cstring>
@@ -64,17 +66,16 @@
 #include <vector>
 
 #include "base/double_array.h"
-#include "base/japanese_util_rule.h"
 #include "base/logging.h"
 #include "base/port.h"
-#include "absl/strings/string_view.h"
-
+#include "absl/numeric/bits.h"
 #include "absl/strings/ascii.h"
 #include "absl/strings/escaping.h"
 #include "absl/strings/match.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/str_format.h"
 #include "absl/strings/str_split.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 
@@ -155,9 +156,9 @@ template <typename Delimiter>
 SplitIterator<Delimiter, AllowEmpty>::SplitIterator(absl::string_view s,
                                                     const char *delim)
     : end_(s.data() + s.size()),
-      delim_(delim),
       sp_begin_(s.data()),
       sp_len_(0),
+      delim_(delim),
       done_(sp_begin_ == end_) {
   const char *p = sp_begin_;
   for (; p != end_ && !delim_.Contains(*p); ++p) {
@@ -185,42 +186,6 @@ template class SplitIterator<MultiDelimiter, SkipEmpty>;
 template class SplitIterator<SingleDelimiter, AllowEmpty>;
 template class SplitIterator<MultiDelimiter, AllowEmpty>;
 
-void Util::SplitStringUsing(absl::string_view str, const char *delim,
-                            std::vector<std::string> *output) {
-  if (delim[0] == '\0') {
-    // absl::StrSplit decomposes all characters if delim is empty.
-    // e.g. absl::StrSplit("abc", "") -> ["a", "b", "c"].
-    // This block can be deleted if the above spec is practically no problem.
-    output->emplace_back(str.data(), str.size());
-    return;
-  }
-  *output = absl::StrSplit(str, absl::ByAnyChar(delim), absl::SkipEmpty());
-}
-
-void Util::SplitStringUsing(absl::string_view str, const char *delim,
-                            std::vector<absl::string_view> *output) {
-  if (delim[0] == '\0') {
-    // absl::StrSplit decomposes all characters if delim is empty.
-    // e.g. absl::StrSplit("abc", "") -> ["a", "b", "c"].
-    // This block can be deleted if the above spec is practically no problem.
-    output->push_back(str);
-    return;
-  }
-  *output = absl::StrSplit(str, absl::ByAnyChar(delim), absl::SkipEmpty());
-}
-
-void Util::SplitStringAllowEmpty(absl::string_view str, const char *delim,
-                                 std::vector<std::string> *output) {
-  if (delim[0] == '\0') {
-    // absl::StrSplit decomposes all characters if delim is empty.
-    // e.g. absl::StrSplit("abc", "") -> ["a", "b", "c"].
-    // This block can be deleted if the above spec is practically no problem.
-    output->emplace_back(str.data(), str.size());
-    return;
-  }
-  *output = absl::StrSplit(str, absl::ByAnyChar(delim), absl::AllowEmpty());
-}
-
 void Util::SplitStringToUtf8Chars(absl::string_view str,
                                   std::vector<std::string> *output) {
   const char *begin = str.data();
@@ -280,12 +245,6 @@ void Util::SplitCSV(const std::string &input,
   }
 }
 
-void Util::ConcatStrings(absl::string_view s1, absl::string_view s2,
-                         std::string *output) {
-  output->clear();
-  absl::StrAppend(output, s1, s2);
-}
-
 void Util::AppendStringWithDelimiter(absl::string_view delimiter,
                                      absl::string_view append_string,
                                      std::string *output) {
@@ -322,7 +281,7 @@ void Util::StringReplace(absl::string_view s, absl::string_view oldsub,
 // case.  The value comes from both of (0x0061 "a" - 0x0041 "A") and
 // (0xFF41 "ａ" - 0xFF21 "Ａ").
 namespace {
-const size_t kOffsetFromUpperToLower = 0x0020;
+constexpr size_t kOffsetFromUpperToLower = 0x0020;
 }
 
 void Util::LowerString(std::string *str) {
@@ -332,7 +291,7 @@ void Util::LowerString(std::string *str) {
   std::string utf8;
   size_t pos = 0;
   while (pos < str->size()) {
-    char32 ucs4 = UTF8ToUCS4(begin + pos, begin + str->size(), &mblen);
+    char32 ucs4 = Utf8ToUcs4(begin + pos, begin + str->size(), &mblen);
     if (mblen == 0) {
       break;
     }
@@ -340,7 +299,7 @@ void Util::LowerString(std::string *str) {
     if ((0x0041 <= ucs4 && ucs4 <= 0x005A) ||
         (0xFF21 <= ucs4 && ucs4 <= 0xFF3A)) {
       ucs4 += kOffsetFromUpperToLower;
-      UCS4ToUTF8(ucs4, &utf8);
+      Ucs4ToUtf8(ucs4, &utf8);
       // The size of upper case character must be equal to the source
       // lower case character.  The following check asserts it.
       if (utf8.size() != mblen) {
@@ -360,12 +319,12 @@ void Util::UpperString(std::string *str) {
   std::string utf8;
   size_t pos = 0;
   while (pos < str->size()) {
-    char32 ucs4 = UTF8ToUCS4(begin + pos, begin + str->size(), &mblen);
+    char32 ucs4 = Utf8ToUcs4(begin + pos, begin + str->size(), &mblen);
     // ('a' <= ucs4 && ucs4 <= 'z') || ('ａ' <= ucs4 && ucs4 <= 'ｚ')
     if ((0x0061 <= ucs4 && ucs4 <= 0x007A) ||
         (0xFF41 <= ucs4 && ucs4 <= 0xFF5A)) {
       ucs4 -= kOffsetFromUpperToLower;
-      UCS4ToUTF8(ucs4, &utf8);
+      Ucs4ToUtf8(ucs4, &utf8);
       // The size of upper case character must be equal to the source
       // lower case character.  The following check asserts it.
       if (utf8.size() != mblen) {
@@ -461,13 +420,13 @@ const unsigned char kUTF8LenTbl[256] = {
     2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
     4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4};
 
-bool IsUTF8TrailingByte(uint8 c) { return (c & 0xc0) == 0x80; }
+bool IsUTF8TrailingByte(uint8_t c) { return (c & 0xc0) == 0x80; }
 
 }  // namespace
 
 // Return length of a single UTF-8 source character
 size_t Util::OneCharLen(const char *src) {
-  return kUTF8LenTbl[*reinterpret_cast<const uint8 *>(src)];
+  return kUTF8LenTbl[*reinterpret_cast<const uint8_t *>(src)];
 }
 
 size_t Util::CharsLen(const char *src, size_t size) {
@@ -481,7 +440,7 @@ size_t Util::CharsLen(const char *src, size_t size) {
   return length;
 }
 
-char32 Util::UTF8ToUCS4(const char *begin, const char *end, size_t *mblen) {
+char32 Util::Utf8ToUcs4(const char *begin, const char *end, size_t *mblen) {
   absl::string_view s(begin, end - begin);
   absl::string_view rest;
   char32 c = 0;
@@ -489,7 +448,7 @@ char32 Util::UTF8ToUCS4(const char *begin, const char *end, size_t *mblen) {
     *mblen = 0;
     return 0;
   }
-  *mblen = rest.begin() - s.begin();
+  *mblen = rest.data() - s.data();
   return c;
 }
 
@@ -517,7 +476,7 @@ bool Util::SplitFirstChar32(absl::string_view s, char32 *first_char32,
     char32 min_value = 0;
     char32 max_value = 0xffffffff;
     {
-      const uint8 leading_byte = static_cast<uint8>(s[0]);
+      const uint8_t leading_byte = static_cast<uint8_t>(s[0]);
       if (leading_byte < 0x80) {
         *first_char32 = leading_byte;
         *rest = absl::ClippedSubstr(s, 1);
@@ -567,7 +526,7 @@ bool Util::SplitFirstChar32(absl::string_view s, char32 *first_char32,
     }
 
     for (size_t i = 1; i < len; ++i) {
-      const uint8 c = static_cast<uint8>(s[i]);
+      const uint8_t c = static_cast<uint8_t>(s[i]);
       if (!IsUTF8TrailingByte(c)) {
         // Trailing bytes not found.
         return false;
@@ -635,19 +594,19 @@ bool Util::IsValidUtf8(absl::string_view s) {
   return true;
 }
 
-void Util::UCS4ToUTF8(char32 c, std::string *output) {
+void Util::Ucs4ToUtf8(char32 c, std::string *output) {
   output->clear();
-  UCS4ToUTF8Append(c, output);
+  Ucs4ToUtf8Append(c, output);
 }
 
-void Util::UCS4ToUTF8Append(char32 c, std::string *output) {
+void Util::Ucs4ToUtf8Append(char32 c, std::string *output) {
   char buf[7];
-  output->append(buf, UCS4ToUTF8(c, buf));
+  output->append(buf, Ucs4ToUtf8(c, buf));
 }
 
-size_t Util::UCS4ToUTF8(char32 c, char *output) {
+size_t Util::Ucs4ToUtf8(char32 c, char *output) {
   if (c == 0) {
-    // Do nothing if |c| is NUL. Previous implementation of UCS4ToUTF8Append
+    // Do nothing if |c| is NUL. Previous implementation of Ucs4ToUtf8Append
     // worked like this.
     output[0] = '\0';
     return 0;
@@ -701,14 +660,14 @@ size_t Util::UCS4ToUTF8(char32 c, char *output) {
 #ifdef OS_WIN
 size_t Util::WideCharsLen(absl::string_view src) {
   const int num_chars =
-      ::MultiByteToWideChar(CP_UTF8, 0, src.begin(), src.size(), nullptr, 0);
+      ::MultiByteToWideChar(CP_UTF8, 0, src.data(), src.size(), nullptr, 0);
   if (num_chars <= 0) {
     return 0;
   }
   return num_chars;
 }
 
-int Util::UTF8ToWide(absl::string_view input, std::wstring *output) {
+int Util::Utf8ToWide(absl::string_view input, std::wstring *output) {
   const size_t output_length = WideCharsLen(input);
   if (output_length == 0) {
     return 0;
@@ -717,14 +676,14 @@ int Util::UTF8ToWide(absl::string_view input, std::wstring *output) {
   const size_t buffer_len = output_length + 1;
   std::unique_ptr<wchar_t[]> input_wide(new wchar_t[buffer_len]);
   const int copied_num_chars = ::MultiByteToWideChar(
-      CP_UTF8, 0, input.begin(), input.size(), input_wide.get(), buffer_len);
+      CP_UTF8, 0, input.data(), input.size(), input_wide.get(), buffer_len);
   if (0 <= copied_num_chars && copied_num_chars < buffer_len) {
     output->assign(input_wide.get(), copied_num_chars);
   }
   return copied_num_chars;
 }
 
-int Util::WideToUTF8(const wchar_t *input, string *output) {
+int Util::WideToUtf8(const wchar_t *input, std::string *output) {
   const int output_length =
       WideCharToMultiByte(CP_UTF8, 0, input, -1, nullptr, 0, nullptr, nullptr);
   if (output_length == 0) {
@@ -741,8 +700,8 @@ int Util::WideToUTF8(const wchar_t *input, string *output) {
   return result;
 }
 
-int Util::WideToUTF8(const std::wstring &input, string *output) {
-  return WideToUTF8(input.c_str(), output);
+int Util::WideToUtf8(const std::wstring &input, std::string *output) {
+  return WideToUtf8(input.c_str(), output);
 }
 #endif  // OS_WIN
 
@@ -776,22 +735,14 @@ void Util::Utf8SubString(absl::string_view src, size_t start, size_t length,
   result->assign(substr.data(), substr.size());
 }
 
-bool Util::StartsWith(absl::string_view str, absl::string_view prefix) {
-  return absl::StartsWith(str, prefix);
-}
-
-bool Util::EndsWith(absl::string_view str, absl::string_view suffix) {
-  return absl::EndsWith(str, suffix);
-}
-
-void Util::StripUTF8BOM(std::string *line) {
+void Util::StripUtf8Bom(std::string *line) {
   static constexpr char kUTF8BOM[] = "\xef\xbb\xbf";
   *line = std::string(absl::StripPrefix(*line, kUTF8BOM));
 }
 
-bool Util::IsUTF16BOM(const std::string &line) {
-  static const char kUTF16LEBOM[] = "\xff\xfe";
-  static const char kUTF16BEBOM[] = "\xfe\xff";
+bool Util::IsUtf16Bom(const std::string &line) {
+  static constexpr char kUTF16LEBOM[] = "\xff\xfe";
+  static constexpr char kUTF16BEBOM[] = "\xfe\xff";
   if (line.size() >= 2 &&
       (line.substr(0, 2) == kUTF16LEBOM || line.substr(0, 2) == kUTF16BEBOM)) {
     return true;
@@ -801,10 +752,10 @@ bool Util::IsUTF16BOM(const std::string &line) {
 
 namespace {
 // http://unicode.org/~scherer/emoji4unicode/snapshot/full.html
-static const char kUtf8MinGooglePuaEmoji[] = "\xf3\xbe\x80\x80";
-static const char kUtf8MaxGooglePuaEmoji[] = "\xf3\xbe\xba\xa0";
-static const char32 kUcs4MinGooglePuaEmoji = 0xFE000;
-static const char32 kUcs4MaxGooglePuaEmoji = 0xFEEA0;
+static constexpr char kUtf8MinGooglePuaEmoji[] = "\xf3\xbe\x80\x80";
+static constexpr char kUtf8MaxGooglePuaEmoji[] = "\xf3\xbe\xba\xa0";
+static constexpr char32 kUcs4MinGooglePuaEmoji = 0xFE000;
+static constexpr char32 kUcs4MaxGooglePuaEmoji = 0xFEEA0;
 }  // namespace
 
 bool Util::IsAndroidPuaEmoji(absl::string_view s) {
@@ -873,7 +824,7 @@ void Util::GetRandomAsciiSequence(char *buf, size_t buf_size) {
   // Its size happens to be 64, which is just one fourth of the number of
   // values that can be represented by a single byte value. This accidental
   // coincidence makes implementation of the method quite simple.
-  const char kCharMap[] =
+  constexpr char kCharMap[] =
       "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ-_";
   GetRandomSequence(buf, buf_size);
   for (size_t i = 0; i < buf_size; ++i) {
@@ -891,9 +842,9 @@ int Util::Random(int size) {
   return static_cast<int>(1.0 * size * rand() / (RAND_MAX + 1.0));
 }
 
-void Util::SetRandomSeed(uint32 seed) { ::srand(seed); }
+void Util::SetRandomSeed(uint32_t seed) { ::srand(seed); }
 
-void Util::Sleep(uint32 msec) {
+void Util::Sleep(uint32_t msec) {
 #ifdef OS_WIN
   ::Sleep(msec);
 #else   // OS_WIN
@@ -911,172 +862,6 @@ void EscapeInternal(char input, absl::string_view prefix, std::string *output) {
   *output += static_cast<char>(lo >= 10 ? lo - 10 + 'A' : lo + '0');
 }
 
-int LookupDoubleArray(const japanese_util_rule::DoubleArray *array,
-                      const char *key, int len, int *result) {
-  int seekto = 0;
-  int n = 0;
-  int b = array[0].base;
-  uint32 p = 0;
-  *result = -1;
-  uint32 num = 0;
-
-  for (int i = 0; i < len; ++i) {
-    p = b;
-    n = array[p].base;
-    if (static_cast<uint32>(b) == array[p].check && n < 0) {
-      seekto = i;
-      *result = -n - 1;
-      ++num;
-    }
-    p = b + static_cast<uint8>(key[i]) + 1;
-    if (static_cast<uint32>(b) == array[p].check) {
-      b = array[p].base;
-    } else {
-      return seekto;
-    }
-  }
-  p = b;
-  n = array[p].base;
-  if (static_cast<uint32>(b) == array[p].check && n < 0) {
-    seekto = len;
-    *result = -n - 1;
-  }
-
-  return seekto;
-}
-
-}  // namespace
-
-void Util::ConvertUsingDoubleArray(const japanese_util_rule::DoubleArray *da,
-                                   const char *ctable, absl::string_view input,
-                                   std::string *output) {
-  output->clear();
-  const char *begin = input.data();
-  const char *const end = input.data() + input.size();
-  while (begin < end) {
-    int result = 0;
-    int mblen =
-        LookupDoubleArray(da, begin, static_cast<int>(end - begin), &result);
-    if (mblen > 0) {
-      const char *p = &ctable[result];
-      const size_t len = strlen(p);
-      output->append(p, len);
-      mblen -= static_cast<int32>(p[len + 1]);
-      begin += mblen;
-    } else {
-      mblen = OneCharLen(begin);
-      output->append(begin, mblen);
-      begin += mblen;
-    }
-  }
-}
-
-void Util::HiraganaToKatakana(absl::string_view input, std::string *output) {
-  ConvertUsingDoubleArray(japanese_util_rule::hiragana_to_katakana_da,
-                          japanese_util_rule::hiragana_to_katakana_table, input,
-                          output);
-}
-
-void Util::HiraganaToHalfwidthKatakana(absl::string_view input,
-                                       std::string *output) {
-  // combine two rules
-  std::string tmp;
-  ConvertUsingDoubleArray(japanese_util_rule::hiragana_to_katakana_da,
-                          japanese_util_rule::hiragana_to_katakana_table, input,
-                          &tmp);
-  ConvertUsingDoubleArray(
-      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_da,
-      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_table, tmp,
-      output);
-}
-
-void Util::HiraganaToRomanji(absl::string_view input, std::string *output) {
-  ConvertUsingDoubleArray(japanese_util_rule::hiragana_to_romanji_da,
-                          japanese_util_rule::hiragana_to_romanji_table, input,
-                          output);
-}
-
-void Util::HalfWidthAsciiToFullWidthAscii(absl::string_view input,
-                                          std::string *output) {
-  ConvertUsingDoubleArray(
-      japanese_util_rule::halfwidthascii_to_fullwidthascii_da,
-      japanese_util_rule::halfwidthascii_to_fullwidthascii_table, input,
-      output);
-}
-
-void Util::FullWidthAsciiToHalfWidthAscii(absl::string_view input,
-                                          std::string *output) {
-  ConvertUsingDoubleArray(
-      japanese_util_rule::fullwidthascii_to_halfwidthascii_da,
-      japanese_util_rule::fullwidthascii_to_halfwidthascii_table, input,
-      output);
-}
-
-void Util::HiraganaToFullwidthRomanji(absl::string_view input,
-                                      std::string *output) {
-  std::string tmp;
-  ConvertUsingDoubleArray(japanese_util_rule::hiragana_to_romanji_da,
-                          japanese_util_rule::hiragana_to_romanji_table, input,
-                          &tmp);
-  ConvertUsingDoubleArray(
-      japanese_util_rule::halfwidthascii_to_fullwidthascii_da,
-      japanese_util_rule::halfwidthascii_to_fullwidthascii_table, tmp, output);
-}
-
-void Util::RomanjiToHiragana(absl::string_view input, std::string *output) {
-  ConvertUsingDoubleArray(japanese_util_rule::romanji_to_hiragana_da,
-                          japanese_util_rule::romanji_to_hiragana_table, input,
-                          output);
-}
-
-void Util::KatakanaToHiragana(absl::string_view input, std::string *output) {
-  ConvertUsingDoubleArray(japanese_util_rule::katakana_to_hiragana_da,
-                          japanese_util_rule::katakana_to_hiragana_table, input,
-                          output);
-}
-
-void Util::HalfWidthKatakanaToFullWidthKatakana(absl::string_view input,
-                                                std::string *output) {
-  ConvertUsingDoubleArray(
-      japanese_util_rule::halfwidthkatakana_to_fullwidthkatakana_da,
-      japanese_util_rule::halfwidthkatakana_to_fullwidthkatakana_table, input,
-      output);
-}
-
-void Util::FullWidthKatakanaToHalfWidthKatakana(absl::string_view input,
-                                                std::string *output) {
-  ConvertUsingDoubleArray(
-      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_da,
-      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_table, input,
-      output);
-}
-
-void Util::FullWidthToHalfWidth(absl::string_view input, std::string *output) {
-  std::string tmp;
-  FullWidthAsciiToHalfWidthAscii(input, &tmp);
-  output->clear();
-  FullWidthKatakanaToHalfWidthKatakana(tmp, output);
-}
-
-void Util::HalfWidthToFullWidth(absl::string_view input, std::string *output) {
-  std::string tmp;
-  HalfWidthAsciiToFullWidthAscii(input, &tmp);
-  output->clear();
-  HalfWidthKatakanaToFullWidthKatakana(tmp, output);
-}
-
-// TODO(tabata): Add another function to split voice mark
-// of some UNICODE only characters (required to display
-// and commit for old clients)
-void Util::NormalizeVoicedSoundMark(absl::string_view input,
-                                    std::string *output) {
-  ConvertUsingDoubleArray(japanese_util_rule::normalize_voiced_sound_da,
-                          japanese_util_rule::normalize_voiced_sound_table,
-                          input, output);
-}
-
-namespace {
-
 struct BracketPair {
   absl::string_view GetOpenBracket() const {
     return absl::string_view(open, open_len);
@@ -1216,13 +1001,13 @@ bool Util::IsEnglishTransliteration(const std::string &value) {
 }
 
 // URL
-void Util::EncodeURI(const std::string &input, std::string *output) {
-  const char kDigits[] = "0123456789ABCDEF";
+void Util::EncodeUri(const std::string &input, std::string *output) {
+  constexpr char kDigits[] = "0123456789ABCDEF";
   const char *begin = input.data();
   const char *end = input.data() + input.size();
   output->clear();
   while (begin < end) {
-    if (isascii(*begin) && (isdigit(*begin) || isalpha(*begin))) {
+    if (absl::ascii_isascii(*begin) && absl::ascii_isalnum(*begin)) {
       *output += *begin;
     } else {
       *output += '%';
@@ -1233,7 +1018,7 @@ void Util::EncodeURI(const std::string &input, std::string *output) {
   }
 }
 
-void Util::DecodeURI(const std::string &input, std::string *output) {
+void Util::DecodeUri(const std::string &input, std::string *output) {
   output->clear();
   const char *p = input.data();
   const char *end = input.data() + input.size();
@@ -1254,7 +1039,7 @@ void Util::DecodeURI(const std::string &input, std::string *output) {
   }
 }
 
-void Util::AppendCGIParams(
+void Util::AppendCgiParams(
     const std::vector<std::pair<std::string, std::string> > &params,
     std::string *base) {
   if (params.empty() || base == nullptr) {
@@ -1268,7 +1053,7 @@ void Util::AppendCGIParams(
     // Append "<first>=<encoded second>&"
     base->append(it->first);
     base->append("=");
-    EncodeURI(it->second, &encoded);
+    EncodeUri(it->second, &encoded);
     base->append(encoded);
     base->append("&");
   }
@@ -1407,7 +1192,7 @@ Util::FormType Util::GetFormType(char32 w) {
 // return script type of first character in str
 Util::ScriptType Util::GetScriptType(const char *begin, const char *end,
                                      size_t *mblen) {
-  const char32 w = UTF8ToUCS4(begin, end, mblen);
+  const char32 w = Utf8ToUcs4(begin, end, mblen);
   return GetScriptType(w);
 }
 
@@ -1463,9 +1248,9 @@ Util::ScriptType Util::GetScriptType(absl::string_view str) {
   return GetScriptTypeInternal(str, false);
 }
 
-Util::ScriptType Util::GetFirstScriptType(const std::string &str) {
+Util::ScriptType Util::GetFirstScriptType(absl::string_view str) {
   size_t mblen = 0;
-  return GetScriptType(str.c_str(), str.c_str() + str.size(), &mblen);
+  return GetScriptType(str.data(), str.data() + str.size(), &mblen);
 }
 
 Util::ScriptType Util::GetScriptTypeWithoutSymbols(const std::string &str) {
@@ -1510,21 +1295,61 @@ Util::FormType Util::GetFormType(const std::string &str) {
   return result;
 }
 
-// Util::CharcterSet Util::GetCharacterSet(char32 ucs4);
+bool Util::IsAscii(absl::string_view str) {
+  for (const char c : str) {
+    if (!absl::ascii_isascii(c)) {
+      return false;
+    }
+  }
+  return true;
+}
+
+namespace {
+// const uint32_t* kJisX0208Bitmap[]
+// constexpr uint64_t kJisX0208BitmapIndex
 #include "base/character_set.inc"
 
-Util::CharacterSet Util::GetCharacterSet(absl::string_view str) {
-  CharacterSet result = ASCII;
-  for (ConstChar32Iterator iter(str); !iter.Done(); iter.Next()) {
-    result = std::max(result, GetCharacterSet(iter.Get()));
+bool IsJisX0208Char(char32 ucs4) {
+  if (ucs4 <= 0x7F) {
+    return true;  // ASCII
   }
-  return result;
+
+  if ((65377 <= ucs4 && ucs4 <= 65439)) {
+    return true;  // JISX0201
+  }
+
+  if (ucs4 < 65536) {
+    const int index = ucs4 / 1024;
+    if ((kJisX0208BitmapIndex & (static_cast<uint64_t>(1) << index)) == 0) {
+      return false;
+    }
+    // Note, the return value of 1 << 64 is not zero. It's undefined.
+    const int bitmap_index =
+        absl::popcount(kJisX0208BitmapIndex << (63 - index)) - 1;
+    const uint32_t *bitmap = kJisX0208Bitmap[bitmap_index];
+    if ((bitmap[(ucs4 % 1024) / 32] >> (ucs4 % 32)) & 0b1) {
+      return true;  // JISX0208
+    }
+    return false;
+  }
+
+  return false;
+}
+}  // namespace
+
+bool Util::IsJisX0208(absl::string_view str) {
+  for (ConstChar32Iterator iter(str); !iter.Done(); iter.Next()) {
+    if (!IsJisX0208Char(iter.Get())) {
+      return false;
+    }
+  }
+  return true;
 }
 
 // CAUTION: Be careful to change the implementation of serialization.  Some
 // files use this format, so compatibility can be lost.  See, e.g.,
 // data_manager/dataset_writer.cc.
-std::string Util::SerializeUint64(uint64 x) {
+std::string Util::SerializeUint64(uint64_t x) {
   const char s[8] = {
       static_cast<char>(x >> 56),          static_cast<char>((x >> 48) & 0xFF),
       static_cast<char>((x >> 40) & 0xFF), static_cast<char>((x >> 32) & 0xFF),
@@ -1534,17 +1359,17 @@ std::string Util::SerializeUint64(uint64 x) {
   return std::string(s, 8);
 }
 
-bool Util::DeserializeUint64(absl::string_view s, uint64 *x) {
+bool Util::DeserializeUint64(absl::string_view s, uint64_t *x) {
   if (s.size() != 8) {
     return false;
   }
   // The following operations assume `char` is unsigned (i.e. -funsigned-char).
   static_assert(std::is_unsigned_v<char>,
                 "`char` is not unsigned. Use -funsigned-char.");
-  *x = static_cast<uint64>(s[0]) << 56 | static_cast<uint64>(s[1]) << 48 |
-       static_cast<uint64>(s[2]) << 40 | static_cast<uint64>(s[3]) << 32 |
-       static_cast<uint64>(s[4]) << 24 | static_cast<uint64>(s[5]) << 16 |
-       static_cast<uint64>(s[6]) << 8 | static_cast<uint64>(s[7]);
+  *x = static_cast<uint64_t>(s[0]) << 56 | static_cast<uint64_t>(s[1]) << 48 |
+       static_cast<uint64_t>(s[2]) << 40 | static_cast<uint64_t>(s[3]) << 32 |
+       static_cast<uint64_t>(s[4]) << 24 | static_cast<uint64_t>(s[5]) << 16 |
+       static_cast<uint64_t>(s[6]) << 8 | static_cast<uint64_t>(s[7]);
   return true;
 }
 
@@ -1564,4 +1389,24 @@ bool Util::IsLittleEndian() {
   return u.c[0] == 0x78U;
 }
 
+absl::StatusCode Util::ErrnoToCanonicalCode(int error_number) {
+  switch (error_number) {
+    case 0:
+      return absl::StatusCode::kOk;
+    case EACCES:
+      return absl::StatusCode::kPermissionDenied;
+    case ENOENT:
+      return absl::StatusCode::kNotFound;
+    case EEXIST:
+      return absl::StatusCode::kAlreadyExists;
+    default:
+      return absl::StatusCode::kUnknown;
+  }
+}
+
+absl::Status Util::ErrnoToCanonicalStatus(int error_number,
+                                          absl::string_view message) {
+  return absl::Status(ErrnoToCanonicalCode(error_number),
+                      absl::StrCat(message, ": errno=", error_number));
+}
 }  // namespace mozc
