@@ -31,14 +31,15 @@
 #define MOZC_BASE_UTIL_H_
 
 #include <climits>
+#include <cstdint>
 #include <ctime>
-#include <initializer_list>
 #include <string>
 #include <utility>
 #include <vector>
 
 #include "base/double_array.h"
 #include "base/port.h"
+#include "absl/status/status.h"
 #include "absl/strings/str_format.h"
 #include "absl/strings/str_join.h"
 #include "absl/strings/string_view.h"
@@ -108,43 +109,16 @@ class SplitIterator {
 
 class Util {
  public:
+  Util() = delete;
+  ~Util() = delete;
+
   // String utils
-  static void SplitStringUsing(absl::string_view str, const char *delim,
-                               std::vector<std::string> *output);
-  static void SplitStringUsing(absl::string_view str, const char *delim,
-                               std::vector<absl::string_view> *output);
-
-  static void SplitStringAllowEmpty(absl::string_view str, const char *delim,
-                                    std::vector<std::string> *output);
-
   static void SplitStringToUtf8Chars(absl::string_view str,
                                      std::vector<std::string> *output);
 
   static void SplitCSV(const std::string &input,
                        std::vector<std::string> *output);
 
-  template <typename Range>
-  static std::string JoinStrings(const Range &range, absl::string_view delim) {
-    return absl::StrJoin(range, delim);
-  }
-
-  template <typename Range>
-  static void JoinStrings(const Range &range, absl::string_view delim,
-                          std::string *output) {
-    output->assign(absl::StrJoin(range, delim));
-  }
-
-  template <typename T>
-  static std::string JoinStrings(std::initializer_list<T> il,
-                                 absl::string_view delim) {
-    return absl::StrJoin(il, delim);
-  }
-
-  // Concatenate s1 and s2 then store it to output.
-  // s1 or s2 should not be a reference into output.
-  static void ConcatStrings(absl::string_view s1, absl::string_view s2,
-                            std::string *output);
-
   static void AppendStringWithDelimiter(absl::string_view delimiter,
                                         absl::string_view append_string,
                                         std::string *output);
@@ -196,23 +170,23 @@ class Util {
 
   // Converts the first character of UTF8 string starting at |begin| to UCS4.
   // The read byte length is stored to |mblen|.
-  static char32 UTF8ToUCS4(const char *begin, const char *end, size_t *mblen);
-  static char32 UTF8ToUCS4(absl::string_view s) {
+  static char32 Utf8ToUcs4(const char *begin, const char *end, size_t *mblen);
+  static char32 Utf8ToUcs4(absl::string_view s) {
     size_t mblen = 0;
-    return UTF8ToUCS4(s.data(), s.data() + s.size(), &mblen);
+    return Utf8ToUcs4(s.data(), s.data() + s.size(), &mblen);
   }
 
   // Converts a UCS4 code point to UTF8 string.
-  static void UCS4ToUTF8(char32 c, std::string *output);
+  static void Ucs4ToUtf8(char32 c, std::string *output);
 
   // Converts a UCS4 code point to UTF8 string and appends it to |output|, i.e.,
   // |output| is not cleared.
-  static void UCS4ToUTF8Append(char32 c, std::string *output);
+  static void Ucs4ToUtf8Append(char32 c, std::string *output);
 
   // Converts a UCS4 code point to UTF8 and stores it to char array.  The result
   // is terminated by '\0'.  Returns the byte length of converted UTF8 string.
   // REQUIRES: The output buffer must be longer than 7 bytes.
-  static size_t UCS4ToUTF8(char32 c, char *output);
+  static size_t Ucs4ToUtf8(char32 c, char *output);
 
   // Returns true if |s| is split into |first_char32| + |rest|.
   // You can pass nullptr to |first_char32| and/or |rest| to ignore the matched
@@ -241,9 +215,9 @@ class Util {
   static size_t WideCharsLen(absl::string_view src);
   // Converts the encoding of the specified string from UTF-8 to UTF-16, and
   // vice versa.
-  static int UTF8ToWide(absl::string_view input, std::wstring *output);
-  static int WideToUTF8(const wchar_t *input, string *output);
-  static int WideToUTF8(const std::wstring &input, string *output);
+  static int Utf8ToWide(absl::string_view input, std::wstring *output);
+  static int WideToUtf8(const wchar_t *input, std::string *output);
+  static int WideToUtf8(const std::wstring &input, std::string *output);
 #endif  // OS_WIN
 
   // Extracts a substring range, where both start and length are in terms of
@@ -259,28 +233,16 @@ class Util {
   static void Utf8SubString(absl::string_view src, size_t start, size_t length,
                             std::string *result);
 
-  // Determines whether the beginning of |str| matches |prefix|.
-  static bool StartsWith(absl::string_view str, absl::string_view prefix);
-
-  // Determines whether the end of |str| matches |suffix|.
-  static bool EndsWith(absl::string_view str, absl::string_view suffix);
-
   // Strip a heading UTF-8 BOM (binary order mark) sequence (= \xef\xbb\xbf).
-  static void StripUTF8BOM(std::string *line);
+  static void StripUtf8Bom(std::string *line);
 
   // return true the line starts with UTF16-LE/UTF16-BE BOM.
-  static bool IsUTF16BOM(const std::string &line);
+  static bool IsUtf16Bom(const std::string &line);
 
   // Returns true if the given |s| has only one ucs4 character, and it is
   // in the range of Android Emoji PUA.
   static bool IsAndroidPuaEmoji(absl::string_view s);
 
-  template <typename... Args>
-  static std::string StringPrintf(const absl::FormatSpec<Args...> &format,
-                                  const Args &... args) {
-    return absl::StrFormat(format, args...);
-  }
-
   // Chop the return characters (i.e. '\n' and '\r') at the end of the
   // given line.
   static bool ChopReturns(std::string *line);
@@ -300,37 +262,11 @@ class Util {
   static int Random(int size);
 
   // Set the seed of Util::Random().
-  static void SetRandomSeed(uint32 seed);
+  static void SetRandomSeed(uint32_t seed);
 
   // Suspends the execution of the current thread until
   // the time-out interval elapses.
-  static void Sleep(uint32 msec);
-
-  // Japanese utilities for character form transliteration.
-  static void ConvertUsingDoubleArray(const japanese_util_rule::DoubleArray *da,
-                                      const char *table,
-                                      absl::string_view input,
-                                      std::string *output);
-  static void HiraganaToKatakana(absl::string_view input, std::string *output);
-  static void HiraganaToHalfwidthKatakana(absl::string_view input,
-                                          std::string *output);
-  static void HiraganaToRomanji(absl::string_view input, std::string *output);
-  static void HalfWidthAsciiToFullWidthAscii(absl::string_view input,
-                                             std::string *output);
-  static void FullWidthAsciiToHalfWidthAscii(absl::string_view input,
-                                             std::string *output);
-  static void HiraganaToFullwidthRomanji(absl::string_view input,
-                                         std::string *output);
-  static void RomanjiToHiragana(absl::string_view input, std::string *output);
-  static void KatakanaToHiragana(absl::string_view input, std::string *output);
-  static void HalfWidthKatakanaToFullWidthKatakana(absl::string_view input,
-                                                   std::string *output);
-  static void FullWidthKatakanaToHalfWidthKatakana(absl::string_view input,
-                                                   std::string *output);
-  static void FullWidthToHalfWidth(absl::string_view input,
-                                   std::string *output);
-  static void HalfWidthToFullWidth(absl::string_view input,
-                                   std::string *output);
+  static void Sleep(uint32_t msec);
 
   // Returns true if all chars in input are both defined
   // in full width and half-width-katakana area
@@ -345,9 +281,6 @@ class Util {
   // Returns true if |input| looks like a pure English word.
   static bool IsEnglishTransliteration(const std::string &value);
 
-  static void NormalizeVoicedSoundMark(absl::string_view input,
-                                       std::string *output);
-
   // Returns true if key is an open bracket.  If key is an open bracket,
   // corresponding close bracket is assigned.
   static bool IsOpenBracket(absl::string_view key, std::string *close_bracket);
@@ -356,14 +289,14 @@ class Util {
   // corresponding open bracket is assigned.
   static bool IsCloseBracket(absl::string_view key, std::string *open_bracket);
 
-  static void EncodeURI(const std::string &input, std::string *output);
-  static void DecodeURI(const std::string &input, std::string *output);
+  static void EncodeUri(const std::string &input, std::string *output);
+  static void DecodeUri(const std::string &input, std::string *output);
 
   // Make a string for CGI parameters from params and append it to
   // base.  The result looks like:
   //   <base><key1>=<encoded val1>&<key2>=<encoded val2>
   // The base is supposed to end "?" or "&".
-  static void AppendCGIParams(
+  static void AppendCgiParams(
       const std::vector<std::pair<std::string, std::string> > &params,
       std::string *base);
 
@@ -395,7 +328,7 @@ class Util {
                                   size_t *mblen);
 
   // return script type of first character in str
-  static ScriptType GetFirstScriptType(const std::string &str);
+  static ScriptType GetFirstScriptType(absl::string_view str);
 
   // return script type of string. all chars in str must be
   // KATAKANA/HIRAGANA/KANJI/NUMBER or ALPHABET.
@@ -430,38 +363,28 @@ class Util {
   // return UNKNOWN_FORM if |str| contains both HALF_WIDTH and FULL_WIDTH.
   static FormType GetFormType(const std::string &str);
 
-  // Basically, if charset >= JIX0212, the char is platform dependent char.
-  enum CharacterSet {
-    ASCII,         // ASCII (simply ucs4 <= 0x007F)
-    JISX0201,      // defined at least in 0201 (can be in 0208/0212/0213/CP9232)
-    JISX0208,      // defined at least in 0208 (can be in 0212/0213/CP932)
-    JISX0212,      // defined at least in 0212 (can be in 0213/CP932)
-    JISX0213,      // defined at least in 0213 (can be in CP932)
-    CP932,         // defined only in CP932, not in JISX02*
-    UNICODE_ONLY,  // defined only in UNICODE, not in JISX* nor CP932
-    CHARACTER_SET_SIZE,
-  };
+  // Returns true if all characters of `str` are ASCII (U+00 - U+7F).
+  static bool IsAscii(absl::string_view str);
 
-  // Returns CharacterSet.
-  static CharacterSet GetCharacterSet(char32 ucs4);
-
-  // Returns CharacterSet of string.
-  // if the given string contains multiple charasets, return
-  // the maximum character set.
-  static CharacterSet GetCharacterSet(absl::string_view str);
+  // Returns true if all characters of `str` are JIS X 0208.
+  static bool IsJisX0208(absl::string_view str);
 
   // Serializes uint64 into a string of eight byte.
-  static std::string SerializeUint64(uint64 x);
+  static std::string SerializeUint64(uint64_t x);
 
   // Deserializes a string serialized by SerializeUint64.  Returns false if the
   // length of s is not eight or s is in an invalid format.
-  static bool DeserializeUint64(absl::string_view s, uint64 *x);
+  static bool DeserializeUint64(absl::string_view s, uint64_t *x);
 
   // Checks endian-ness at runtime.
   static bool IsLittleEndian();
 
- private:
-  DISALLOW_IMPLICIT_CONSTRUCTORS(Util);
+  // Converts `errno` to absl::StatusCode.
+  static absl::StatusCode ErrnoToCanonicalCode(int error_number);
+
+  // Converts `errno` to absl::Status.
+  static absl::Status ErrnoToCanonicalStatus(int error_number,
+                                             absl::string_view message);
 };
 
 // Const iterator implementation to traverse on a (utf8) string as a char32
@@ -575,14 +498,15 @@ class SplitIterator<Delimiter, AllowEmpty> {
 
  private:
   const char *const end_;
-  const Delimiter delim_;
   const char *sp_begin_;
   absl::string_view::size_type sp_len_;
+  const Delimiter delim_;
   bool done_;
 
   DISALLOW_COPY_AND_ASSIGN(SplitIterator);
 };
 
+
 }  // namespace mozc
 
 #endif  // MOZC_BASE_UTIL_H_
