@@ -30,6 +30,7 @@
 #include "base/util.h"
 
 #include <climits>
+#include <cstdint>
 #include <cstdlib>
 #include <cstring>
 #include <limits>
@@ -44,103 +45,14 @@
 #include "base/port.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
+#include "absl/strings/match.h"
 
 namespace mozc {
-namespace {
-
-void FillTestCharacterSetMap(std::map<char32, Util::CharacterSet> *test_map) {
-  CHECK(test_map);
-  const std::string &path = testing::GetSourceFileOrDie(
-      {"data", "test", "character_set", "character_set.tsv"});
-  std::map<std::string, Util::CharacterSet> character_set_type_map;
-  character_set_type_map["ASCII"] = Util::ASCII;
-  character_set_type_map["JISX0201"] = Util::JISX0201;
-  character_set_type_map["JISX0208"] = Util::JISX0208;
-  character_set_type_map["JISX0212"] = Util::JISX0212;
-  character_set_type_map["JISX0213"] = Util::JISX0213;
-  character_set_type_map["CP932"] = Util::CP932;
-  // UNICODE_ONLY should not appear in the tsv file though.
-  character_set_type_map["UNICODE_ONLY"] = Util::UNICODE_ONLY;
-
-  InputFileStream finput(path.c_str());
-
-  // Read tsv file.
-  std::string line;
-  while (!std::getline(finput, line).fail()) {
-    if (Util::StartsWith(line, "#")) {
-      // Skip comment line.
-      continue;
-    }
-
-    std::vector<std::string> col;
-    mozc::Util::SplitStringUsing(line, "\t", &col);
-    CHECK_GE(col.size(), 2) << "format error: " << line;
-    const char32 ucs4 = NumberUtil::SimpleAtoi(col[0]);
-    std::map<std::string, Util::CharacterSet>::const_iterator itr =
-        character_set_type_map.find(col[1]);
-    // We cannot use CHECK_NE here because of overload resolution.
-    CHECK(character_set_type_map.end() != itr)
-        << "Unknown character set type: " << col[1];
-    test_map->insert(std::make_pair(ucs4, itr->second));
-  }
-}
-
-Util::CharacterSet GetExpectedCharacterSet(
-    const std::map<char32, Util::CharacterSet> &test_map, char32 ucs4) {
-  std::map<char32, Util::CharacterSet>::const_iterator itr =
-      test_map.find(ucs4);
-  if (test_map.find(ucs4) == test_map.end()) {
-    // If the test data does not have an entry, it should be
-    // interpreted as |Util::UNICODE_ONLY|.
-    return Util::UNICODE_ONLY;
-  }
-  return itr->second;
-}
-
-}  // namespace
-
-TEST(UtilTest, JoinStrings) {
-  std::vector<std::string> input = {"ab", "cdef", "ghr"};
-  std::string output;
-  Util::JoinStrings(input, ":", &output);
-  EXPECT_EQ("ab:cdef:ghr", output);
-}
-
-TEST(UtilTest, JoinStrings2) {
-  {
-    const std::vector<absl::string_view> input = {"ab"};
-    EXPECT_EQ("ab", Util::JoinStrings(input, ":"));
-  }
-  {
-    const std::vector<absl::string_view> input = {"ab", "cdef", "ghr"};
-    EXPECT_EQ("ab:cdef:ghr", Util::JoinStrings(input, ":"));
-  }
-  {
-    const std::vector<absl::string_view> input = {"ab", "cdef", "ghr"};
-    EXPECT_EQ("ab::cdef::ghr", Util::JoinStrings(input, "::"));
-  }
-}
-
-TEST(UtilTest, ConcatStrings) {
-  std::string s;
-
-  Util::ConcatStrings("", "", &s);
-  EXPECT_TRUE(s.empty());
-
-  Util::ConcatStrings("ABC", "", &s);
-  EXPECT_EQ("ABC", s);
-
-  Util::ConcatStrings("", "DEF", &s);
-  EXPECT_EQ("DEF", s);
-
-  Util::ConcatStrings("ABC", "DEF", &s);
-  EXPECT_EQ("ABCDEF", s);
-}
 
 TEST(UtilTest, AppendStringWithDelimiter) {
   std::string result;
   std::string input;
-  const char kDelemiter[] = ":";
+  constexpr char kDelemiter[] = ":";
 
   {
     result.clear();
@@ -380,107 +292,6 @@ TEST(UtilTest, SplitIterator_MultiDelimiter_AllowEmpty) {
   }
 }
 
-TEST(UtilTest, SplitStringUsing) {
-  {
-    const std::string input = "a b  c def";
-    std::vector<std::string> output;
-    Util::SplitStringUsing(input, " ", &output);
-    EXPECT_EQ(output.size(), 4);
-    EXPECT_EQ("a", output[0]);
-    EXPECT_EQ("b", output[1]);
-    EXPECT_EQ("c", output[2]);
-    EXPECT_EQ("def", output[3]);
-  }
-  {
-    const std::string input = " a b  c";
-    std::vector<std::string> output;
-    Util::SplitStringUsing(input, " ", &output);
-    EXPECT_EQ(output.size(), 3);
-    EXPECT_EQ("a", output[0]);
-    EXPECT_EQ("b", output[1]);
-    EXPECT_EQ("c", output[2]);
-  }
-  {
-    const std::string input = "a b  c ";
-    std::vector<std::string> output;
-    Util::SplitStringUsing(input, " ", &output);
-    EXPECT_EQ(output.size(), 3);
-    EXPECT_EQ("a", output[0]);
-    EXPECT_EQ("b", output[1]);
-    EXPECT_EQ("c", output[2]);
-  }
-  {
-    const std::string input = "a:b  cd ";
-    std::vector<std::string> output;
-    Util::SplitStringUsing(input, ": ", &output);
-    EXPECT_EQ(output.size(), 3);
-    EXPECT_EQ("a", output[0]);
-    EXPECT_EQ("b", output[1]);
-    EXPECT_EQ("cd", output[2]);
-  }
-  {
-    const std::string input = "Empty delimiter";
-    std::vector<std::string> output;
-    Util::SplitStringUsing(input, "", &output);
-    EXPECT_EQ(output.size(), 1);
-    EXPECT_EQ(input, output[0]);
-  }
-}
-
-TEST(UtilTest, SplitStringAllowEmpty) {
-  {
-    const std::string input = "a b  c def";
-    std::vector<std::string> output;
-    Util::SplitStringAllowEmpty(input, " ", &output);
-    EXPECT_EQ(output.size(), 5);
-    EXPECT_EQ("a", output[0]);
-    EXPECT_EQ("b", output[1]);
-    EXPECT_EQ("", output[2]);
-    EXPECT_EQ("c", output[3]);
-    EXPECT_EQ("def", output[4]);
-  }
-  {
-    const std::string input = " a b  c";
-    std::vector<std::string> output;
-    Util::SplitStringAllowEmpty(input, " ", &output);
-    EXPECT_EQ(output.size(), 5);
-    EXPECT_EQ("", output[0]);
-    EXPECT_EQ("a", output[1]);
-    EXPECT_EQ("b", output[2]);
-    EXPECT_EQ("", output[3]);
-    EXPECT_EQ("c", output[4]);
-  }
-  {
-    const std::string input = "a b  c ";
-    std::vector<std::string> output;
-    Util::SplitStringAllowEmpty(input, " ", &output);
-    EXPECT_EQ(output.size(), 5);
-    EXPECT_EQ("a", output[0]);
-    EXPECT_EQ("b", output[1]);
-    EXPECT_EQ("", output[2]);
-    EXPECT_EQ("c", output[3]);
-    EXPECT_EQ("", output[4]);
-  }
-  {
-    const std::string input = "a:b  c ";
-    std::vector<std::string> output;
-    Util::SplitStringAllowEmpty(input, ": ", &output);
-    EXPECT_EQ(output.size(), 5);
-    EXPECT_EQ("a", output[0]);
-    EXPECT_EQ("b", output[1]);
-    EXPECT_EQ("", output[2]);
-    EXPECT_EQ("c", output[3]);
-    EXPECT_EQ("", output[4]);
-  }
-  {
-    const std::string input = "Empty delimiter";
-    std::vector<std::string> output;
-    Util::SplitStringAllowEmpty(input, "", &output);
-    EXPECT_EQ(output.size(), 1);
-    EXPECT_EQ(input, output[0]);
-  }
-}
-
 TEST(UtilTest, StripWhiteSpaces) {
   // basic scenario.
   {
@@ -551,13 +362,13 @@ TEST(UtilTest, SplitStringToUtf8Chars) {
         "a", "あ", "亜", "\n", "a",
     };
     std::string joined_string;
-    for (int i = 0; i < arraysize(kInputs); ++i) {
+    for (int i = 0; i < std::size(kInputs); ++i) {
       joined_string += kInputs[i];
     }
 
     std::vector<std::string> output;
     Util::SplitStringToUtf8Chars(joined_string, &output);
-    EXPECT_EQ(arraysize(kInputs), output.size());
+    EXPECT_EQ(std::size(kInputs), output.size());
 
     for (size_t i = 0; i < output.size(); ++i) {
       EXPECT_EQ(kInputs[i], output[i]);
@@ -709,77 +520,77 @@ TEST(UtilTest, IsUpperOrCapitalizedAscii) {
   EXPECT_FALSE(Util::IsUpperOrCapitalizedAscii("Ｈｅｌｌｏ"));
 }
 
-void VerifyUTF8ToUCS4(const std::string &text, char32 expected_ucs4,
+void VerifyUtf8ToUcs4(const std::string &text, char32 expected_ucs4,
                       size_t expected_len) {
   const char *begin = text.data();
   const char *end = begin + text.size();
   size_t mblen = 0;
-  char32 result = Util::UTF8ToUCS4(begin, end, &mblen);
+  char32 result = Util::Utf8ToUcs4(begin, end, &mblen);
   EXPECT_EQ(expected_ucs4, result) << text << " " << expected_ucs4;
   EXPECT_EQ(expected_len, mblen) << text << " " << expected_len;
 }
 
-TEST(UtilTest, UTF8ToUCS4) {
-  VerifyUTF8ToUCS4("", 0, 0);
-  VerifyUTF8ToUCS4("\x01", 1, 1);
-  VerifyUTF8ToUCS4("\x7F", 0x7F, 1);
-  VerifyUTF8ToUCS4("\xC2\x80", 0x80, 2);
-  VerifyUTF8ToUCS4("\xDF\xBF", 0x7FF, 2);
-  VerifyUTF8ToUCS4("\xE0\xA0\x80", 0x800, 3);
-  VerifyUTF8ToUCS4("\xEF\xBF\xBF", 0xFFFF, 3);
-  VerifyUTF8ToUCS4("\xF0\x90\x80\x80", 0x10000, 4);
-  VerifyUTF8ToUCS4("\xF7\xBF\xBF\xBF", 0x1FFFFF, 4);
+TEST(UtilTest, Utf8ToUcs4) {
+  VerifyUtf8ToUcs4("", 0, 0);
+  VerifyUtf8ToUcs4("\x01", 1, 1);
+  VerifyUtf8ToUcs4("\x7F", 0x7F, 1);
+  VerifyUtf8ToUcs4("\xC2\x80", 0x80, 2);
+  VerifyUtf8ToUcs4("\xDF\xBF", 0x7FF, 2);
+  VerifyUtf8ToUcs4("\xE0\xA0\x80", 0x800, 3);
+  VerifyUtf8ToUcs4("\xEF\xBF\xBF", 0xFFFF, 3);
+  VerifyUtf8ToUcs4("\xF0\x90\x80\x80", 0x10000, 4);
+  VerifyUtf8ToUcs4("\xF7\xBF\xBF\xBF", 0x1FFFFF, 4);
   // do not test 5-6 bytes because it's out of spec of UTF8.
 }
 
-TEST(UtilTest, UCS4ToUTF8) {
+TEST(UtilTest, Ucs4ToUtf8) {
   std::string output;
 
-  // Do nothing if |c| is NUL. Previous implementation of UCS4ToUTF8 worked like
+  // Do nothing if |c| is NUL. Previous implementation of Ucs4ToUtf8 worked like
   // this even though the reason is unclear.
-  Util::UCS4ToUTF8(0, &output);
+  Util::Ucs4ToUtf8(0, &output);
   EXPECT_TRUE(output.empty());
 
-  Util::UCS4ToUTF8(0x7F, &output);
+  Util::Ucs4ToUtf8(0x7F, &output);
   EXPECT_EQ("\x7F", output);
-  Util::UCS4ToUTF8(0x80, &output);
+  Util::Ucs4ToUtf8(0x80, &output);
   EXPECT_EQ("\xC2\x80", output);
-  Util::UCS4ToUTF8(0x7FF, &output);
+  Util::Ucs4ToUtf8(0x7FF, &output);
   EXPECT_EQ("\xDF\xBF", output);
-  Util::UCS4ToUTF8(0x800, &output);
+  Util::Ucs4ToUtf8(0x800, &output);
   EXPECT_EQ("\xE0\xA0\x80", output);
-  Util::UCS4ToUTF8(0xFFFF, &output);
+  Util::Ucs4ToUtf8(0xFFFF, &output);
   EXPECT_EQ("\xEF\xBF\xBF", output);
-  Util::UCS4ToUTF8(0x10000, &output);
+  Util::Ucs4ToUtf8(0x10000, &output);
   EXPECT_EQ("\xF0\x90\x80\x80", output);
-  Util::UCS4ToUTF8(0x1FFFFF, &output);
+  Util::Ucs4ToUtf8(0x1FFFFF, &output);
   EXPECT_EQ("\xF7\xBF\xBF\xBF", output);
 
   // Buffer version.
   char buf[7];
 
-  EXPECT_EQ(0, Util::UCS4ToUTF8(0, buf));
+  EXPECT_EQ(0, Util::Ucs4ToUtf8(0, buf));
   EXPECT_EQ(0, strcmp(buf, ""));
 
-  EXPECT_EQ(1, Util::UCS4ToUTF8(0x7F, buf));
+  EXPECT_EQ(1, Util::Ucs4ToUtf8(0x7F, buf));
   EXPECT_EQ(0, strcmp("\x7F", buf));
 
-  EXPECT_EQ(2, Util::UCS4ToUTF8(0x80, buf));
+  EXPECT_EQ(2, Util::Ucs4ToUtf8(0x80, buf));
   EXPECT_EQ(0, strcmp("\xC2\x80", buf));
 
-  EXPECT_EQ(2, Util::UCS4ToUTF8(0x7FF, buf));
+  EXPECT_EQ(2, Util::Ucs4ToUtf8(0x7FF, buf));
   EXPECT_EQ(0, strcmp("\xDF\xBF", buf));
 
-  EXPECT_EQ(3, Util::UCS4ToUTF8(0x800, buf));
+  EXPECT_EQ(3, Util::Ucs4ToUtf8(0x800, buf));
   EXPECT_EQ(0, strcmp("\xE0\xA0\x80", buf));
 
-  EXPECT_EQ(3, Util::UCS4ToUTF8(0xFFFF, buf));
+  EXPECT_EQ(3, Util::Ucs4ToUtf8(0xFFFF, buf));
   EXPECT_EQ(0, strcmp("\xEF\xBF\xBF", buf));
 
-  EXPECT_EQ(4, Util::UCS4ToUTF8(0x10000, buf));
+  EXPECT_EQ(4, Util::Ucs4ToUtf8(0x10000, buf));
   EXPECT_EQ(0, strcmp("\xF0\x90\x80\x80", buf));
 
-  EXPECT_EQ(4, Util::UCS4ToUTF8(0x1FFFFF, buf));
+  EXPECT_EQ(4, Util::Ucs4ToUtf8(0x1FFFFF, buf));
   EXPECT_EQ(0, strcmp("\xF7\xBF\xBF\xBF", buf));
 }
 
@@ -877,40 +688,19 @@ TEST(UtilTest, Utf8SubString3) {
   EXPECT_EQ(result, "中野です");
 }
 
-TEST(UtilTest, StartsWith) {
-  const std::string str = "abcdefg";
-  EXPECT_TRUE(Util::StartsWith(str, ""));
-  EXPECT_TRUE(Util::StartsWith(str, "a"));
-  EXPECT_TRUE(Util::StartsWith(str, "abc"));
-  EXPECT_TRUE(Util::StartsWith(str, "abcdefg"));
-  EXPECT_FALSE(Util::StartsWith(str, "abcdefghi"));
-  EXPECT_FALSE(Util::StartsWith(str, "foobar"));
-}
-
-TEST(UtilTest, EndsWith) {
-  const std::string str = "abcdefg";
-  EXPECT_TRUE(Util::EndsWith(str, ""));
-  EXPECT_TRUE(Util::EndsWith(str, "g"));
-  EXPECT_TRUE(Util::EndsWith(str, "fg"));
-  EXPECT_TRUE(Util::EndsWith(str, "abcdefg"));
-  EXPECT_FALSE(Util::EndsWith(str, "aaabcdefg"));
-  EXPECT_FALSE(Util::EndsWith(str, "foobar"));
-  EXPECT_FALSE(Util::EndsWith(str, "foobarbuzbuz"));
-}
-
-TEST(UtilTest, StripUTF8BOM) {
+TEST(UtilTest, StripUtf8Bom) {
   std::string line;
 
   // Should be stripped.
   line =
       "\xef\xbb\xbf"
       "abc";
-  Util::StripUTF8BOM(&line);
+  Util::StripUtf8Bom(&line);
   EXPECT_EQ("abc", line);
 
   // Should be stripped.
   line = "\xef\xbb\xbf";
-  Util::StripUTF8BOM(&line);
+  Util::StripUtf8Bom(&line);
   EXPECT_EQ("", line);
 
   // BOM in the middle of text. Shouldn't be stripped.
@@ -918,7 +708,7 @@ TEST(UtilTest, StripUTF8BOM) {
       "a"
       "\xef\xbb\xbf"
       "bc";
-  Util::StripUTF8BOM(&line);
+  Util::StripUtf8Bom(&line);
   EXPECT_EQ(
       "a"
       "\xef\xbb\xbf"
@@ -929,7 +719,7 @@ TEST(UtilTest, StripUTF8BOM) {
   line =
       "\xef\xbb"
       "abc";
-  Util::StripUTF8BOM(&line);
+  Util::StripUtf8Bom(&line);
   EXPECT_EQ(
       "\xef\xbb"
       "abc",
@@ -937,25 +727,25 @@ TEST(UtilTest, StripUTF8BOM) {
 
   // String shorter than the BOM. Do nothing.
   line = "a";
-  Util::StripUTF8BOM(&line);
+  Util::StripUtf8Bom(&line);
   EXPECT_EQ("a", line);
 
   // Empty string. Do nothing.
   line = "";
-  Util::StripUTF8BOM(&line);
+  Util::StripUtf8Bom(&line);
   EXPECT_EQ("", line);
 }
 
-TEST(UtilTest, IsUTF16BOM) {
-  EXPECT_FALSE(Util::IsUTF16BOM(""));
-  EXPECT_FALSE(Util::IsUTF16BOM("abc"));
-  EXPECT_TRUE(Util::IsUTF16BOM("\xfe\xff"));
-  EXPECT_TRUE(Util::IsUTF16BOM("\xff\xfe"));
-  EXPECT_TRUE(Util::IsUTF16BOM("\xfe\xff "));
-  EXPECT_TRUE(Util::IsUTF16BOM("\xff\xfe "));
-  EXPECT_FALSE(Util::IsUTF16BOM(" \xfe\xff"));
-  EXPECT_FALSE(Util::IsUTF16BOM(" \xff\xfe"));
-  EXPECT_FALSE(Util::IsUTF16BOM("\xff\xff"));
+TEST(UtilTest, IsUtf16Bom) {
+  EXPECT_FALSE(Util::IsUtf16Bom(""));
+  EXPECT_FALSE(Util::IsUtf16Bom("abc"));
+  EXPECT_TRUE(Util::IsUtf16Bom("\xfe\xff"));
+  EXPECT_TRUE(Util::IsUtf16Bom("\xff\xfe"));
+  EXPECT_TRUE(Util::IsUtf16Bom("\xfe\xff "));
+  EXPECT_TRUE(Util::IsUtf16Bom("\xff\xfe "));
+  EXPECT_FALSE(Util::IsUtf16Bom(" \xfe\xff"));
+  EXPECT_FALSE(Util::IsUtf16Bom(" \xff\xfe"));
+  EXPECT_FALSE(Util::IsUtf16Bom("\xff\xff"));
 }
 
 TEST(UtilTest, IsAndroidPuaEmoji) {
@@ -964,173 +754,23 @@ TEST(UtilTest, IsAndroidPuaEmoji) {
   EXPECT_FALSE(Util::IsAndroidPuaEmoji("a"));
 
   std::string str;
-  Util::UCS4ToUTF8(0xFDFFF, &str);
+  Util::Ucs4ToUtf8(0xFDFFF, &str);
   EXPECT_FALSE(Util::IsAndroidPuaEmoji(str));
-  Util::UCS4ToUTF8(0xFE000, &str);
+  Util::Ucs4ToUtf8(0xFE000, &str);
   EXPECT_TRUE(Util::IsAndroidPuaEmoji(str));
-  Util::UCS4ToUTF8(0xFE800, &str);
+  Util::Ucs4ToUtf8(0xFE800, &str);
   EXPECT_TRUE(Util::IsAndroidPuaEmoji(str));
-  Util::UCS4ToUTF8(0xFEEA0, &str);
+  Util::Ucs4ToUtf8(0xFEEA0, &str);
   EXPECT_TRUE(Util::IsAndroidPuaEmoji(str));
-  Util::UCS4ToUTF8(0xFEEA1, &str);
+  Util::Ucs4ToUtf8(0xFEEA1, &str);
   EXPECT_FALSE(Util::IsAndroidPuaEmoji(str));
 
   // If it has two ucs4 chars (or more), just expect false.
-  Util::UCS4ToUTF8(0xFE000, &str);
-  Util::UCS4ToUTF8Append(0xFE000, &str);
+  Util::Ucs4ToUtf8(0xFE000, &str);
+  Util::Ucs4ToUtf8Append(0xFE000, &str);
   EXPECT_FALSE(Util::IsAndroidPuaEmoji(str));
 }
 
-TEST(UtilTest, HiraganaToKatakana) {
-  {
-    const std::string input =
-        "あいうえおぁぃぅぇぉかきくけこがぎぐげごさしすせそざじずぜぞたちつてと"
-        "だぢづでどっなにぬねのはひふへほばびぶべぼぱぴぷぺぽまみむめもやゆよゃ"
-        "ゅょらりるれろわゎをんゔ";
-    std::string output;
-    Util::HiraganaToKatakana(input, &output);
-    EXPECT_EQ(
-        "アイウエオァィゥェォカキクケコガギグゲゴサシスセソザジズゼゾタチツテト"
-        "ダヂヅデドッナニヌネノハヒフヘホバビブベボパピプペポマミムメモヤユヨャ"
-        "ュョラリルレロワヮヲンヴ",
-        output);
-  }
-  {
-    const std::string input = "わたしのなまえはなかのですうまーよろしゅう";
-    std::string output;
-    Util::HiraganaToKatakana(input, &output);
-    EXPECT_EQ("ワタシノナマエハナカノデスウマーヨロシュウ", output);
-  }
-  {
-    const std::string input = "グーグル工藤よろしくabc";
-    std::string output;
-    Util::HiraganaToKatakana(input, &output);
-    EXPECT_EQ("グーグル工藤ヨロシクabc", output);
-  }
-}
-
-TEST(UtilTest, KatakanaToHiragana) {
-  {
-    const std::string input =
-        "アイウエオァィゥェォカキクケコガギグゲゴサシスセソザジズゼゾタチツテト"
-        "ダヂヅデドッナニヌネノハヒフヘホバビブベボパピプペポマミムメモヤユヨャ"
-        "ュョラリルレロワヮヲンヰヱヴ";
-    std::string output;
-    Util::KatakanaToHiragana(input, &output);
-    EXPECT_EQ(
-        "あいうえおぁぃぅぇぉかきくけこがぎぐげごさしすせそざじずぜぞたちつてと"
-        "だぢづでどっなにぬねのはひふへほばびぶべぼぱぴぷぺぽまみむめもやゆよゃ"
-        "ゅょらりるれろわゎをんゐゑゔ",
-        output);
-  }
-  {
-    const std::string input = "ワタシノナマエハナカノデスウマーヨロシュウ";
-    std::string output;
-    Util::KatakanaToHiragana(input, &output);
-    EXPECT_EQ("わたしのなまえはなかのですうまーよろしゅう", output);
-  }
-  {
-    const std::string input = "グーグル工藤ヨロシクabc";
-    std::string output;
-    Util::KatakanaToHiragana(input, &output);
-    EXPECT_EQ("ぐーぐる工藤よろしくabc", output);
-  }
-}
-
-TEST(UtilTest, RomanjiToHiragana) {
-  struct {
-    const char *input;
-    const char *expected;
-  } kTestCases[] = {
-      {"watasinonamaehatakahashinoriyukidesu",
-       "わたしのなまえはたかはしのりゆきです"},
-      {"majissukamajiyabexe", "まじっすかまじやべぇ"},
-      {"kk", "っk"},
-      {"xyz", "xyz"},
-  };
-  for (size_t i = 0; i < arraysize(kTestCases); ++i) {
-    std::string actual;
-    Util::RomanjiToHiragana(kTestCases[i].input, &actual);
-    EXPECT_EQ(kTestCases[i].expected, actual);
-  }
-}
-
-TEST(UtilTest, NormalizeVoicedSoundMark) {
-  const std::string input = "僕のう゛ぁいおりん";
-  std::string output;
-  Util::NormalizeVoicedSoundMark(input, &output);
-  EXPECT_EQ("僕のゔぁいおりん", output);
-}
-
-TEST(UtilTest, IsFullWidthSymbolInHalfWidthKatakana) {
-  EXPECT_FALSE(Util::IsFullWidthSymbolInHalfWidthKatakana("グーグル"));
-  EXPECT_TRUE(Util::IsFullWidthSymbolInHalfWidthKatakana("ー"));
-  EXPECT_TRUE(Util::IsFullWidthSymbolInHalfWidthKatakana("。"));
-  EXPECT_FALSE(Util::IsFullWidthSymbolInHalfWidthKatakana("グーグル。"));
-  EXPECT_TRUE(Util::IsFullWidthSymbolInHalfWidthKatakana("ー。"));
-  EXPECT_FALSE(Util::IsFullWidthSymbolInHalfWidthKatakana("ーグ。"));
-}
-
-TEST(UtilTest, IsHalfWidthKatakanaSymbol) {
-  EXPECT_FALSE(Util::IsHalfWidthKatakanaSymbol("ｸﾞｰｸﾞﾙ"));
-  EXPECT_TRUE(Util::IsHalfWidthKatakanaSymbol("ｰ"));
-  EXPECT_TRUE(Util::IsHalfWidthKatakanaSymbol("｡"));  // Half-width
-  EXPECT_TRUE(Util::IsHalfWidthKatakanaSymbol("､"));  // Half-width
-  EXPECT_FALSE(Util::IsHalfWidthKatakanaSymbol("グーグル｡"));
-  EXPECT_TRUE(Util::IsHalfWidthKatakanaSymbol("､｡"));  // Half-width
-}
-
-TEST(UtilTest, FullWidthAndHalfWidth) {
-  std::string output;
-
-  Util::FullWidthToHalfWidth("", &output);
-  EXPECT_EQ("", output);
-
-  Util::HalfWidthToFullWidth("", &output);
-  EXPECT_EQ("", output);
-
-  Util::HalfWidthToFullWidth("abc[]?.", &output);
-  EXPECT_EQ("ａｂｃ［］？．", output);
-
-  Util::HalfWidthToFullWidth("ｲﾝﾀｰﾈｯﾄ｢」", &output);
-  EXPECT_EQ("インターネット「」", output);
-
-  Util::HalfWidthToFullWidth("ｲﾝﾀｰﾈｯﾄグーグル", &output);
-  EXPECT_EQ("インターネットグーグル", output);
-
-  Util::FullWidthToHalfWidth("ａｂｃ［］？．", &output);
-  EXPECT_EQ("abc[]?.", output);
-
-  Util::FullWidthToHalfWidth("インターネット", &output);
-  EXPECT_EQ("ｲﾝﾀｰﾈｯﾄ", output);
-
-  Util::FullWidthToHalfWidth("ｲﾝﾀｰﾈｯﾄグーグル", &output);
-  EXPECT_EQ("ｲﾝﾀｰﾈｯﾄｸﾞｰｸﾞﾙ", output);
-
-  // spaces
-  Util::FullWidthToHalfWidth(" 　", &output);  // Half- and full-width spaces
-  EXPECT_EQ("  ", output);                     // 2 half-width spaces
-
-  Util::HalfWidthToFullWidth(" 　", &output);  // Half- and full-width spaces
-  EXPECT_EQ("　　", output);                   // 2 full-width spaces
-
-  // Spaces are treated as Ascii here
-  // Half- and full-width spaces
-  Util::FullWidthAsciiToHalfWidthAscii(" 　", &output);
-  EXPECT_EQ("  ", output);  // 2 half-width spaces
-
-  Util::HalfWidthAsciiToFullWidthAscii("  ", &output);
-  EXPECT_EQ("　　", output);  // 2 full-width spaces
-
-  // Half- and full-width spaces
-  Util::FullWidthKatakanaToHalfWidthKatakana(" 　", &output);
-  EXPECT_EQ(" 　", output);  // Not changed
-
-  // Half- and full-width spaces
-  Util::HalfWidthKatakanaToFullWidthKatakana(" 　", &output);
-  EXPECT_EQ(" 　", output);  // Not changed
-}
-
 TEST(UtilTest, BracketTest) {
   static const struct BracketType {
     const char *open_bracket;
@@ -1195,48 +835,48 @@ TEST(UtilTest, ChopReturns) {
   EXPECT_EQ("line", line);
 }
 
-TEST(UtilTest, EncodeURI) {
+TEST(UtilTest, EncodeUri) {
   std::string encoded;
-  Util::EncodeURI("もずく", &encoded);
+  Util::EncodeUri("もずく", &encoded);
   EXPECT_EQ("%E3%82%82%E3%81%9A%E3%81%8F", encoded);
 
   encoded.clear();
-  Util::EncodeURI("mozc", &encoded);
+  Util::EncodeUri("mozc", &encoded);
   EXPECT_EQ("mozc", encoded);
 
   encoded.clear();
-  Util::EncodeURI("http://mozc/?q=Hello World", &encoded);
+  Util::EncodeUri("http://mozc/?q=Hello World", &encoded);
   EXPECT_EQ("http%3A%2F%2Fmozc%2F%3Fq%3DHello%20World", encoded);
 }
 
-TEST(UtilTest, DecodeURI) {
+TEST(UtilTest, DecodeUri) {
   std::string decoded;
-  Util::DecodeURI("%E3%82%82%E3%81%9A%E3%81%8F", &decoded);
+  Util::DecodeUri("%E3%82%82%E3%81%9A%E3%81%8F", &decoded);
   EXPECT_EQ("もずく", decoded);
 
   decoded.clear();
-  Util::DecodeURI("mozc", &decoded);
+  Util::DecodeUri("mozc", &decoded);
   EXPECT_EQ("mozc", decoded);
 
   decoded.clear();
-  Util::DecodeURI("http%3A%2F%2Fmozc%2F%3Fq%3DHello+World", &decoded);
+  Util::DecodeUri("http%3A%2F%2Fmozc%2F%3Fq%3DHello+World", &decoded);
   EXPECT_EQ("http://mozc/?q=Hello World", decoded);
 }
 
-TEST(UtilTest, AppendCGIParams) {
+TEST(UtilTest, AppendCgiParams) {
   std::vector<std::pair<std::string, std::string> > params;
   std::string url;
-  Util::AppendCGIParams(params, &url);
+  Util::AppendCgiParams(params, &url);
   EXPECT_TRUE(url.empty());
 
   params.push_back(std::make_pair("foo", "b a+r"));
   url = "http://mozc.com?";
-  Util::AppendCGIParams(params, &url);
+  Util::AppendCgiParams(params, &url);
   EXPECT_EQ("http://mozc.com?foo=b%20a%2Br", url);
 
   params.push_back(std::make_pair("buzz", "mozc"));
   url.clear();
-  Util::AppendCGIParams(params, &url);
+  Util::AppendCgiParams(params, &url);
   EXPECT_EQ("foo=b%20a%2Br&buzz=mozc", url);
 }
 
@@ -1471,86 +1111,55 @@ TEST(UtilTest, FormType) {
   EXPECT_EQ(Util::HALF_WIDTH, Util::GetFormType("@!#"));
 }
 
-// We have a snapshot of the result of |Util::GetCharacterSet(ucs4)| in
-// data/test/character_set/character_set.tsv.
-// Compare the result for each character just in case.
-TEST(UtilTest, CharacterSetFullTest) {
-  std::map<char32, Util::CharacterSet> test_set;
-  FillTestCharacterSetMap(&test_set);
-  EXPECT_FALSE(test_set.empty());
-
-  // Unicode characters consist of [U+0000, U+10FFFF].
-  for (char32 ucs4 = 0; ucs4 <= 0x10ffff; ++ucs4) {
-    EXPECT_EQ(GetExpectedCharacterSet(test_set, ucs4),
-              Util::GetCharacterSet(ucs4))
-        << "Character set changed at " << ucs4;
-  }
+TEST(UtilTest, IsAscii) {
+  EXPECT_FALSE(Util::IsAscii("あいうえお"));
+  EXPECT_TRUE(Util::IsAscii("abc"));
+  EXPECT_FALSE(Util::IsAscii("abcあいう"));
+  EXPECT_TRUE(Util::IsAscii(""));
+  EXPECT_TRUE(Util::IsAscii("\x7F"));
+  EXPECT_FALSE(Util::IsAscii("\x80"));
 }
 
-TEST(UtilTest, CharacterSet_gen_character_set) {
-  // [0x00, 0x7f] are ASCII
-  for (size_t i = 0; i <= 0x7f; ++i) {
-    EXPECT_EQ(Util::ASCII, Util::GetCharacterSet(i));
-  }
-  // [0x80, 0xff] are not ASCII
-  for (size_t i = 0x80; i <= 0xff; ++i) {
-    EXPECT_NE(Util::ASCII, Util::GetCharacterSet(i));
-  }
+TEST(UtilTest, IsJisX0208) {
+  EXPECT_TRUE(Util::IsJisX0208(u8"\u007F"));
+  EXPECT_FALSE(Util::IsJisX0208(u8"\u0080"));
 
-  // 0213
-  // "Ⅰ"
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet(0x2160));
-  // "①"
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet(0x2460));
-  // "㊤"
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet(0x32A4));
-  // "ð ®" from UCS4 range (b/4176888)
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet(0x20B9F));
-  // "ðª²" from UCS4 range (b/4176888)
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet(0x2A6B2));
-
-  // only in CP932
-  // "凬"
-  EXPECT_EQ(Util::CP932, Util::GetCharacterSet(0x51EC));
-
-  // only in Unicode
-  // "￦"
-  EXPECT_EQ(Util::UNICODE_ONLY, Util::GetCharacterSet(0xFFE6));
-  // "ð ®·" from UCS4 range (b/4176888)
-  EXPECT_EQ(Util::UNICODE_ONLY, Util::GetCharacterSet(0x20BB7));
-}
-
-TEST(UtilTest, CharacterSet) {
-  EXPECT_EQ(Util::JISX0208, Util::GetCharacterSet("あいうえお"));
-  EXPECT_EQ(Util::ASCII, Util::GetCharacterSet("abc"));
-  EXPECT_EQ(Util::JISX0208, Util::GetCharacterSet("abcあいう"));
+  EXPECT_TRUE(Util::IsJisX0208("あいうえお"));
+  EXPECT_TRUE(Util::IsJisX0208("abc"));
+  EXPECT_TRUE(Util::IsJisX0208("abcあいう"));
 
   // half width katakana
-  EXPECT_EQ(Util::JISX0201, Util::GetCharacterSet("ｶﾀｶﾅ"));
-  EXPECT_EQ(Util::JISX0208, Util::GetCharacterSet("ｶﾀｶﾅカタカナ"));
+  EXPECT_TRUE(Util::IsJisX0208("ｶﾀｶﾅ"));
+  EXPECT_TRUE(Util::IsJisX0208("ｶﾀｶﾅカタカナ"));
 
-  // 0213
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet("Ⅰ"));
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet("①"));
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet("㊤"));
-  // "ð ® " from UCS4 range (b/4176888)
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet("𠮟"));
-  // "ðª ²" from UCS4 range (b/4176888)
-  EXPECT_EQ(Util::JISX0213, Util::GetCharacterSet("𪚲"));
+  // boundary edges
+  EXPECT_TRUE(Util::IsJisX0208("ﾟ"));  // U+FF9F, the last char of JIS X 0208
+  EXPECT_TRUE(Util::IsJisX0208(u8"\uFF9F"));   // U+FF9F
+  EXPECT_FALSE(Util::IsJisX0208(u8"\uFFA0"));  // U+FF9F + 1
+  EXPECT_FALSE(Util::IsJisX0208(u8"\uFFFF"));
+  EXPECT_FALSE(Util::IsJisX0208(u8"\U00010000"));
+
+  // JIS X 0213
+  EXPECT_FALSE(Util::IsJisX0208("Ⅰ"));
+  EXPECT_FALSE(Util::IsJisX0208("①"));
+  EXPECT_FALSE(Util::IsJisX0208("㊤"));
 
   // only in CP932
-  EXPECT_EQ(Util::CP932, Util::GetCharacterSet("凬"));
+  EXPECT_FALSE(Util::IsJisX0208("凬"));
 
   // only in Unicode
-  EXPECT_EQ(Util::UNICODE_ONLY, Util::GetCharacterSet("￦"));
-  // "ð ®·" from UCS4 range (b/4176888)
-  EXPECT_EQ(Util::UNICODE_ONLY, Util::GetCharacterSet("\xF0\xA0\xAE\xB7"));
+  EXPECT_FALSE(Util::IsJisX0208("￦"));
+
+  // SIP range (U+20000 - U+2FFFF)
+  EXPECT_FALSE(Util::IsJisX0208("𠮟"));  // U+20B9F
+  EXPECT_FALSE(Util::IsJisX0208("𪚲"));  // U+2A6B2
+  EXPECT_FALSE(Util::IsJisX0208("𠮷"));  // U+20BB7
 }
 
 #ifdef OS_WIN
 TEST(UtilTest, WideCharsLen) {
   // "að ®b"
-  const string input_utf8 = "a\360\240\256\237b";
+  const std::string input_utf8 = "a\360\240\256\237b";
   EXPECT_EQ(4, Util::WideCharsLen(input_utf8));
   EXPECT_EQ(0, Util::WideCharsLen(Util::Utf8SubString(input_utf8, 0, 0)));
   EXPECT_EQ(1, Util::WideCharsLen(Util::Utf8SubString(input_utf8, 0, 1)));
@@ -1558,26 +1167,26 @@ TEST(UtilTest, WideCharsLen) {
   EXPECT_EQ(4, Util::WideCharsLen(Util::Utf8SubString(input_utf8, 0, 3)));
 }
 
-TEST(UtilTest, UTF8ToWide) {
-  const string input_utf8 = "abc";
+TEST(UtilTest, Utf8ToWide) {
+  const std::string input_utf8 = "abc";
   std::wstring output_wide;
-  Util::UTF8ToWide(input_utf8, &output_wide);
+  Util::Utf8ToWide(input_utf8, &output_wide);
 
-  string output_utf8;
-  Util::WideToUTF8(output_wide, &output_utf8);
+  std::string output_utf8;
+  Util::WideToUtf8(output_wide, &output_utf8);
   EXPECT_EQ("abc", output_utf8);
 }
 
-TEST(UtilTest, WideToUTF8_SurrogatePairSupport) {
+TEST(UtilTest, WideToUtf8_SurrogatePairSupport) {
   // Visual C++ 2008 does not support embedding surrogate pair in string
   // literals like L"\uD842\uDF9F". This is why we use wchar_t array instead.
   // "ð ®"
   const wchar_t input_wide[] = {0xD842, 0xDF9F, 0};
-  string output_utf8;
-  Util::WideToUTF8(input_wide, &output_utf8);
+  std::string output_utf8;
+  Util::WideToUtf8(input_wide, &output_utf8);
 
   std::wstring output_wide;
-  Util::UTF8ToWide(output_utf8, &output_wide);
+  Util::Utf8ToWide(output_utf8, &output_wide);
 
   EXPECT_EQ("\360\240\256\237", output_utf8);
   EXPECT_EQ(input_wide, output_wide);
@@ -1925,22 +1534,25 @@ TEST(UtilTest, IsValidUtf8) {
 TEST(UtilTest, SerializeAndDeserializeUint64) {
   struct {
     const char *str;
-    uint64 value;
+    uint64_t value;
   } kCorrectPairs[] = {
       {"\x00\x00\x00\x00\x00\x00\x00\x00", 0},
-      {"\x00\x00\x00\x00\x00\x00\x00\xFF", std::numeric_limits<uint8>::max()},
-      {"\x00\x00\x00\x00\x00\x00\xFF\xFF", std::numeric_limits<uint16>::max()},
-      {"\x00\x00\x00\x00\xFF\xFF\xFF\xFF", std::numeric_limits<uint32>::max()},
-      {"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF", std::numeric_limits<uint64>::max()},
+      {"\x00\x00\x00\x00\x00\x00\x00\xFF", std::numeric_limits<uint8_t>::max()},
+      {"\x00\x00\x00\x00\x00\x00\xFF\xFF",
+       std::numeric_limits<uint16_t>::max()},
+      {"\x00\x00\x00\x00\xFF\xFF\xFF\xFF",
+       std::numeric_limits<uint32_t>::max()},
+      {"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF",
+       std::numeric_limits<uint64_t>::max()},
       {"\x01\x23\x45\x67\x89\xAB\xCD\xEF", 0x0123456789ABCDEF},
       {"\xFE\xDC\xBA\x98\x76\x54\x32\x10", 0xFEDCBA9876543210},
   };
 
-  for (size_t i = 0; i < arraysize(kCorrectPairs); ++i) {
+  for (size_t i = 0; i < std::size(kCorrectPairs); ++i) {
     const std::string serialized(kCorrectPairs[i].str, 8);
     EXPECT_EQ(serialized, Util::SerializeUint64(kCorrectPairs[i].value));
 
-    uint64 v;
+    uint64_t v;
     EXPECT_TRUE(Util::DeserializeUint64(serialized, &v));
     EXPECT_EQ(kCorrectPairs[i].value, v);
   }
@@ -1951,8 +1563,8 @@ TEST(UtilTest, SerializeAndDeserializeUint64) {
       "abc",
       "helloworld",
   };
-  for (size_t i = 0; i < arraysize(kFalseCases); ++i) {
-    uint64 v;
+  for (size_t i = 0; i < std::size(kFalseCases); ++i) {
+    uint64_t v;
     EXPECT_FALSE(Util::DeserializeUint64(kFalseCases[i], &v));
   }
 }
