@@ -42,7 +42,6 @@
 
 namespace mozc {
 namespace {
-using std::unique_ptr;
 typedef WinAPITestHelper::FunctionPointer FunctionPointer;
 
 void WINAPI dummy_func() {}
@@ -116,21 +115,21 @@ class HookTargetInfo {
         continue;
       }
 
-      string module_name = request.module_name;
+      std::string module_name = request.module_name;
       Util::LowerString(&module_name);
       info_[module_name][original_proc_address] = request.new_proc_address;
     }
   }
 
-  const bool IsTargetModule(const string &module_name) const {
-    string lower_module_name(module_name);
+  const bool IsTargetModule(const std::string &module_name) const {
+    std::string lower_module_name(module_name);
     Util::LowerString(&lower_module_name);
     return info_.find(lower_module_name) != info_.end();
   }
 
-  const FunctionPointer GetNewProc(const string &module_name,
+  const FunctionPointer GetNewProc(const std::string &module_name,
                                    FunctionPointer original_proc) const {
-    string lower_module_name(module_name);
+    std::string lower_module_name(module_name);
     Util::LowerString(&lower_module_name);
     const auto module_iterator = info_.find(lower_module_name);
     if (module_iterator == info_.end()) {
@@ -145,7 +144,7 @@ class HookTargetInfo {
   }
 
  private:
-  std::map<string, std::map<FunctionPointer, FunctionPointer>> info_;
+  std::map<std::string, std::map<FunctionPointer, FunctionPointer>> info_;
 };
 
 class PortableExecutableImage {
@@ -275,8 +274,8 @@ class WinAPITestHelper::RestoreInfo {
   std::vector<ThunkRewriter> rewrites;
 };
 
-WinAPITestHelper::HookRequest::HookRequest(const string &src_module,
-                                           const string &src_proc_name,
+WinAPITestHelper::HookRequest::HookRequest(const std::string &src_module,
+                                           const std::string &src_proc_name,
                                            FunctionPointer new_proc_addr)
     : module_name(src_module),
       proc_name(src_proc_name),
@@ -294,11 +293,11 @@ WinAPITestHelper::RestoreInfoHandle WinAPITestHelper::DoHook(
   PortableExecutableImage image(target_module);
   CHECK(image.IsValid());
 
-  unique_ptr<RestoreInfo> restore_info(new RestoreInfo());
+  std::unique_ptr<RestoreInfo> restore_info(new RestoreInfo());
   for (ImageImportDescriptorIterator descriptor_iterator(image);
        !descriptor_iterator.Done(); descriptor_iterator.Next()) {
     const auto &descriptor = descriptor_iterator.Get();
-    const string module_name(image.At<char>(descriptor.Name));
+    const std::string module_name(image.At<char>(descriptor.Name));
     if (!target_info.IsTargetModule(module_name)) {
       continue;
     }
@@ -324,7 +323,7 @@ WinAPITestHelper::RestoreInfoHandle WinAPITestHelper::DoHook(
 
 void WinAPITestHelper::RestoreHook(
     WinAPITestHelper::RestoreInfoHandle restore_info) {
-  unique_ptr<RestoreInfo> info(restore_info);  // takes ownership
+  std::unique_ptr<RestoreInfo> info(restore_info);  // takes ownership
 
   for (size_t i = 0; i < info->rewrites.size(); ++i) {
     const auto &rewrite = info->rewrites[i];
