@@ -46,17 +46,22 @@
 #include <memory>
 
 #include "base/logging.h"
-#include "base/mutex.h"
 #include "base/scoped_handle.h"
 #include "base/system_util.h"
 #include "base/util.h"
+#include "absl/base/call_once.h"
+#include "absl/status/status.h"
+#include "absl/strings/str_cat.h"
 
-using std::unique_ptr;
+// Disable StrCat macro to use absl::StrCat.
+#ifdef StrCat
+#undef StrCat
+#endif  // StrCat
 
 namespace mozc {
 namespace {
 
-once_t g_aux_lib_initialized = MOZC_ONCE_INIT;
+absl::once_flag g_aux_lib_initialized;
 
 void CallAuxUlibInitialize() { ::AuxUlibInitialize(); }
 
@@ -102,7 +107,7 @@ HMODULE WinUtil::LoadSystemLibrary(const std::wstring &base_filename) {
 
 HMODULE WinUtil::LoadMozcLibrary(const std::wstring &base_filename) {
   std::wstring fullpath;
-  Util::UTF8ToWide(SystemUtil::GetServerDirectory(), &fullpath);
+  Util::Utf8ToWide(SystemUtil::GetServerDirectory(), &fullpath);
   fullpath += L"\\";
   fullpath += base_filename;
 
@@ -150,7 +155,7 @@ HMODULE WinUtil::GetSystemModuleHandleAndIncrementRefCount(
 }
 
 bool WinUtil::IsDLLSynchronizationHeld(bool *lock_status) {
-  mozc::CallOnce(&g_aux_lib_initialized, &CallAuxUlibInitialize);
+  absl::call_once(g_aux_lib_initialized, &CallAuxUlibInitialize);
 
   if (lock_status == nullptr) {
     return false;
@@ -456,8 +461,8 @@ bool WinUtil::GetNtPath(const std::wstring &dos_path, std::wstring *nt_path) {
     return false;
   }
 
-  const size_t kMaxPath = 4096;
-  unique_ptr<wchar_t[]> ntpath_buffer(new wchar_t[kMaxPath]);
+  constexpr size_t kMaxPath = 4096;
+  std::unique_ptr<wchar_t[]> ntpath_buffer(new wchar_t[kMaxPath]);
   const DWORD copied_len_without_null = ::GetFinalPathNameByHandleW(
       file_handle.get(), ntpath_buffer.get(), kMaxPath,
       FILE_NAME_NORMALIZED | VOLUME_NAME_NT);
@@ -485,8 +490,8 @@ bool WinUtil::GetProcessInitialNtPath(DWORD pid, std::wstring *nt_path) {
     return false;
   }
 
-  const size_t kMaxPath = 4096;
-  unique_ptr<wchar_t[]> ntpath_buffer(new wchar_t[kMaxPath]);
+  constexpr size_t kMaxPath = 4096;
+  std::unique_ptr<wchar_t[]> ntpath_buffer(new wchar_t[kMaxPath]);
   const DWORD copied_len_without_null = ::GetProcessImageFileNameW(
       process_handle.get(), ntpath_buffer.get(), kMaxPath);
   if (copied_len_without_null == 0 || copied_len_without_null > kMaxPath) {
@@ -536,6 +541,28 @@ bool WinUtil::ShellExecuteInSystemDir(const wchar_t *verb, const wchar_t *file,
   return result > 32;
 }
 
+absl::StatusCode WinUtil::ErrorToCanonicalCode(DWORD error_code) {
+  switch (error_code) {
+    case ERROR_SUCCESS:
+      return absl::StatusCode::kOk;
+    case ERROR_FILE_NOT_FOUND:
+    case ERROR_PATH_NOT_FOUND:
+      return absl::StatusCode::kNotFound;
+    case ERROR_ACCESS_DENIED:
+      return absl::StatusCode::kPermissionDenied;
+    case ERROR_ALREADY_EXISTS:
+      return absl::StatusCode::kAlreadyExists;
+    default:
+      return absl::StatusCode::kUnknown;
+  }
+}
+
+absl::Status WinUtil::ErrorToCanonicalStatus(DWORD error_code,
+                                             absl::string_view message) {
+  return absl::Status(ErrorToCanonicalCode(error_code),
+                      absl::StrCat(message, ": error_code=", error_code));
+}
+
 ScopedCOMInitializer::ScopedCOMInitializer() : hr_(::CoInitialize(nullptr)) {}
 
 ScopedCOMInitializer::~ScopedCOMInitializer() {
