@@ -62,8 +62,6 @@ from build_tools.util import RemoveFile
 from build_tools.util import RunOrDie
 from build_tools.util import RunOrDieError
 
-import six
-
 SRC_DIR = '.'
 # We need to obtain the absolute path of this script before change directory.
 # Note that if any import above has already changed the current
@@ -228,6 +226,9 @@ def ParseGypOptions(args):
                     'is installed. This option is used only on Linux.')
 
   if IsWindows():
+    parser.add_option('--msvs_version', dest='msvs_version',
+                      default='2017',
+                      help='Version of the Visual Studio.')
     parser.add_option('--wix_dir', dest='wix_dir',
                       default=GetDefaultWixPath(),
                       help='A path to the binary directory of wix.')
@@ -272,10 +273,11 @@ def ExpandMetaTarget(options, meta_target_name):
   elif target_platform == 'Mac':
     targets = [SRC_DIR + '/mac/mac.gyp:codesign_DiskImage']
   elif target_platform == 'Windows':
-    targets = ['out_win/%s:mozc_win32_build32' % config]
-    if version.GetQtVersion():
-      targets.append('out_win/%sDynamic:mozc_win32_build32_dynamic' % config)
-    targets.append('out_win/%s_x64:mozc_win32_build64' % config)
+    targets = [
+        'out_win/%s:mozc_win32_build32' % config,
+        'out_win/%sDynamic:mozc_win32_build32_dynamic' % config,
+        'out_win/%s_x64:mozc_win32_build64' % config,
+    ]
 
   return dependencies + targets
 
@@ -332,15 +334,17 @@ def AddPythonPathToEnvironmentFilesForWindows(out_dir):
   for d in os.listdir(out_dir):
     abs_dir = os.path.abspath(os.path.join(out_dir, d))
     with open(os.path.join(abs_dir, 'environment.x86'), 'rb') as x86_file:
-      x86_content = (x86_file.read()[:-1] +
-                     six.b('PYTHONPATH' + '=' + python_path + nul + nul))
+      x86_content = (
+          x86_file.read()[:-1] +
+          ('PYTHONPATH=' + python_path + nul + nul).encode('utf-8'))
     with open(os.path.join(abs_dir, 'environment.x86'), 'wb') as x86_file:
       x86_file.write(x86_content)
       print('== x86_content ==')
       print(x86_content.decode('utf-8'))
     with open(os.path.join(abs_dir, 'environment.x64'), 'rb') as x64_file:
-      x64_content = (x64_file.read()[:-1] +
-                     six.b('PYTHONPATH' + '=' + python_path + nul + nul))
+      x64_content = (
+          x64_file.read()[:-1] +
+          ('PYTHONPATH=' + python_path + nul + nul).encode('utf-8'))
     with open(os.path.join(abs_dir, 'environment.x64'), 'wb') as x64_file:
       x64_file.write(x64_content)
       print('== x64_content ==')
@@ -353,12 +357,9 @@ def GypMain(options, unused_args):
   logging.info('Generating version definition file...')
   template_path = '%s/%s' % (SRC_DIR, options.version_file)
   version_path = '%s/mozc_version.txt' % SRC_DIR
-  if options.noqt:
-    qt_version = ''
-  else:
-    qt_version = '5'
+  version_override = os.environ.get('MOZC_VERSION', None)
   GenerateVersionFile(template_path, version_path, options.target_platform,
-                      qt_version)
+                      version_override)
   version = GetMozcVersion()
   target_platform = version.GetTargetPlatform()
   logging.info('Version string is %s', version.GetVersionString())
@@ -409,6 +410,8 @@ def GypMain(options, unused_args):
 
   # Set the generator name.
   os.environ['GYP_GENERATORS'] = 'ninja'
+  # Disable path normalization that breaks arguments like --name=../../path
+  os.environ['GYP_MSVS_DISABLE_PATH_NORMALIZATION'] = '1'
 
   # Get and show the list of .gyp file names.
   gyp_file_names = GetGypFileNames(options)
@@ -434,6 +437,9 @@ def GypMain(options, unused_args):
 
   gyp_options.extend(gyp_file_names)
 
+  gyp_options.extend(['-D', 'version=' + version.GetVersionString()])
+  gyp_options.extend(['-D', 'short_version=' + version.GetShortVersionString()])
+
   if options.branding:
     gyp_options.extend(['-D', 'branding=%s' % options.branding])
 
@@ -480,7 +486,7 @@ def GypMain(options, unused_args):
   gyp_options.extend(['-D', 'target_platform=%s' % target_platform_value])
 
   if IsWindows():
-    gyp_options.extend(['-G', 'msvs_version=2017'])
+    gyp_options.extend(['-G', 'msvs_version=%s' % options.msvs_version])
 
   if (target_platform == 'Linux' and
       '%s/unix/ibus/ibus.gyp' % SRC_DIR in gyp_file_names):
@@ -515,6 +521,7 @@ def GypMain(options, unused_args):
     out_dir = os.path.join(MOZC_ROOT, 'out_win')
     AddPythonPathToEnvironmentFilesForWindows(out_dir)
 
+  if IsWindows() and (not options.noqt):
     # When Windows build is configured to use DLL version of Qt, copy Qt's DLLs
     # and debug symbols into Mozc's build directory. This is important because:
     # - We can easily back up all the artifacts if relevant product binaries and
@@ -527,33 +534,32 @@ def GypMain(options, unused_args):
     abs_qtdir = os.path.abspath(options.qtdir)
     abs_qt_bin_dir = os.path.join(abs_qtdir, 'bin')
     abs_qt_lib_dir = os.path.join(abs_qtdir, 'lib')
-    abs_out_win_dir = GetBuildBaseName(target_platform)
-    copy_script = os.path.join(
-        ABS_SCRIPT_DIR, 'build_tools', 'copy_dll_and_symbol.py')
-    copy_params = []
-    if qt_version == '5':
-      copy_params.append({
-          'basenames': 'Qt5Cored;Qt5Guid;Qt5Widgetsd',
-          'dll_paths': abs_qt_bin_dir,
-          'pdb_paths': abs_qt_lib_dir,
-          'target_dir': os.path.join(abs_out_win_dir, 'DebugDynamic')})
-      copy_params.append({
-          'basenames': 'Qt5Core;Qt5Gui;Qt5Widgets',
-          'dll_paths': abs_qt_bin_dir,
-          'pdb_paths': abs_qt_lib_dir,
-          'target_dir': os.path.join(abs_out_win_dir, 'ReleaseDynamic')})
-      copy_params.append({
-          'basenames': 'qwindowsd',
-          'dll_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
-          'pdb_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
-          'target_dir': os.path.join(abs_out_win_dir, 'DebugDynamic',
-                                     'platforms')})
-      copy_params.append({
-          'basenames': 'qwindows',
-          'dll_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
-          'pdb_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
-          'target_dir': os.path.join(abs_out_win_dir, 'ReleaseDynamic',
-                                     'platforms')})
+    abs_out_win = GetBuildBaseName(target_platform)
+    abs_out_win_debug_dynamic = os.path.join(abs_out_win, 'DebugDynamic')
+    abs_out_win_release_dynamic = os.path.join(abs_out_win, 'ReleaseDynamic')
+    copy_script = os.path.join(ABS_SCRIPT_DIR, 'build_tools',
+                               'copy_dll_and_symbol.py')
+    copy_params = [{
+        'basenames': 'Qt5Cored;Qt5Guid;Qt5Widgetsd',
+        'dll_paths': abs_qt_bin_dir,
+        'pdb_paths': abs_qt_lib_dir,
+        'target_dir': abs_out_win_debug_dynamic,
+    }, {
+        'basenames': 'Qt5Core;Qt5Gui;Qt5Widgets',
+        'dll_paths': abs_qt_bin_dir,
+        'pdb_paths': abs_qt_lib_dir,
+        'target_dir': abs_out_win_release_dynamic,
+    }, {
+        'basenames': 'qwindowsd',
+        'dll_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
+        'pdb_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
+        'target_dir': os.path.join(abs_out_win_debug_dynamic, 'platforms'),
+    }, {
+        'basenames': 'qwindows',
+        'dll_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
+        'pdb_paths': os.path.join(abs_qtdir, 'plugins', 'platforms'),
+        'target_dir': os.path.join(abs_out_win_release_dynamic, 'platforms'),
+    }]
     for copy_param in copy_params:
       copy_commands = [
           copy_script,
