@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2010-2018, Google Inc.
+# Copyright 2010-2021, Google Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-"""Fix all version info in the input Info.plist file.
+r"""Fix all version info in the input Info.plist file.
 
   % python tweak_info_plist.py --output=out.txt --input=in.txt \
       --branding=Mozc --version_file=version.txt
@@ -38,15 +38,18 @@ See mozc_version.py for the detailed information for version.txt.
 
 __author__ = "mukai"
 
+import codecs
 import datetime
 import logging
 import optparse
 import sys
-import mozc_version
-import tweak_data
+from build_tools import mozc_version
+from build_tools import tweak_data
+
 
 _COPYRIGHT_YEAR = datetime.date.today().year
 
+
 def ParseOptions():
   """Parse command line options.
 
@@ -54,10 +57,10 @@ def ParseOptions():
     An options data.
   """
   parser = optparse.OptionParser()
-  parser.add_option("--version_file", dest="version_file")
-  parser.add_option("--output", dest="output")
-  parser.add_option("--input", dest="input")
-  parser.add_option("--branding", dest="branding")
+  parser.add_option('--version_file', dest='version_file')
+  parser.add_option('--output', dest='output')
+  parser.add_option('--input', dest='input')
+  parser.add_option('--branding', dest='branding')
 
   (options, unused_args) = parser.parse_args()
   return options
@@ -67,21 +70,21 @@ def main():
   """The main function."""
   options = ParseOptions()
   if options.version_file is None:
-    logging.error("--version_file is not specified.")
+    logging.error('--version_file is not specified.')
     sys.exit(-1)
   if options.output is None:
-    logging.error("--output is not specified.")
+    logging.error('--output is not specified.')
     sys.exit(-1)
   if options.input is None:
-    logging.error("--input is not specified.")
+    logging.error('--input is not specified.')
     sys.exit(-1)
   if options.branding is None:
-    logging.error("--branding is not specified.")
+    logging.error('--branding is not specified.')
     sys.exit(-1)
 
   version = mozc_version.MozcVersion(options.version_file)
 
-  copyright_message = (u'© %d Google Inc.' % _COPYRIGHT_YEAR).encode('utf-8')
+  copyright_message = u'© %d Google Inc.' % _COPYRIGHT_YEAR
   long_version = version.GetVersionString()
   short_version = version.GetVersionInFormat('@MAJOR@.@MINOR@.@BUILD@')
 
@@ -102,15 +105,19 @@ def main():
       'GOOGLE_VERSIONINFO_SHORT': short_version,
       'GOOGLE_VERSIONINFO_ABOUT': copyright_message,
       'GOOGLE_VERSIONINFO_FINDER':
-        '%s %s, %s' % (product_name, long_version, copyright_message),
-      'BRANDING': options.branding,
-      'DOMAIN_PREFIX': domain_prefix,
-      'BREAKPAD_PRODUCT': breakpad_product,
-      'BREAKPAD_URL': breakpad_url,
+          '%s %s, %s' % (product_name, long_version, copyright_message),
+      'BRANDING':
+          options.branding,
+      'DOMAIN_PREFIX':
+          domain_prefix,
+      'BREAKPAD_PRODUCT':
+          breakpad_product,
+      'BREAKPAD_URL':
+          breakpad_url,
   }
 
-  open(options.output, 'w').write(
+  codecs.open(options.output, 'w', encoding='utf-8').write(
       tweak_data.ReplaceVariables(open(options.input).read(), variables))
 
 if __name__ == '__main__':
-    main()
+  main()
