@@ -54,7 +54,6 @@ import logging
 import optparse
 import os
 import shutil
-import six
 
 from build_tools import mozc_version
 
@@ -90,12 +89,8 @@ def _VersioningFile(version_string, is_debug, file_path):
   package = os.path.basename(new_file_path)
   file_size = os.path.getsize(new_file_path)
   sha1_digest = _GetSha1Digest(new_file_path)
-  if six.PY3:
-    sha1_hash = base64.b64encode(sha1_digest).decode('latin1')
-    sha1_hash_hex = sha1_digest.hex()
-  else:
-    sha1_hash = base64.b64encode(sha1_digest)
-    sha1_hash_hex = sha1_digest.encode('hex')
+  sha1_hash = base64.b64encode(sha1_digest).decode('latin1')
+  sha1_hash_hex = sha1_digest.hex()
   with open('%s.info' % new_file_path, 'w') as output:
     output.write('package\t%s\n' % package)
     output.write('build_id\t%s\n' % build_id)
