@@ -31,14 +31,17 @@
 
 #include "client/client.h"
 
+#include <cstdint>
+
 #ifdef OS_WIN
 #include <Windows.h>
-#else
+#else  // OS_WIN
 #include <unistd.h>
 #endif  // OS_WIN
 
 #include <cstddef>
 #include <memory>
+#include <string>
 
 #include "base/const.h"
 #include "base/file_stream.h"
@@ -53,7 +56,6 @@
 #include "ipc/ipc.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
-#include "absl/memory/memory.h"
 
 #ifdef OS_WIN
 #include "base/win_util.h"
@@ -69,14 +71,14 @@ namespace mozc {
 namespace client {
 
 namespace {
-const char kServerAddress[] = "session";  // name for the IPC connection.
-const int kResultBufferSize = 8192 * 32;  // size of IPC buffer
-const size_t kMaxPlayBackSize = 512;      // size of maximum history
+constexpr char kServerAddress[] = "session";  // name for the IPC connection.
+constexpr int kResultBufferSize = 8192 * 32;  // size of IPC buffer
+constexpr size_t kMaxPlayBackSize = 512;  // size of maximum history
 
 #ifdef DEBUG
-const int kDefaultTimeout = 100000;  // 100 sec for dbg
-#else
-const int kDefaultTimeout = 30000;  // 30 sec for opt
+constexpr int kDefaultTimeout = 100000;  // 100 sec for dbg
+#else                                    // DEBUG
+constexpr int kDefaultTimeout = 30000;  // 30 sec for opt
 #endif  // DEBUG
 
 // Delete Session is called inside the Destructor of Client class.
@@ -85,7 +87,7 @@ const int kDefaultTimeout = 30000;  // 30 sec for opt
 // This timeout is only applied in the DeleteSessions command
 // called from Destructor. When an application calls DeleteSession
 // explicitly, the default timeout is used.
-const int kDeleteSessionOnDestructorTimeout = 1000;  // 1 sec
+constexpr int kDeleteSessionOnDestructorTimeout = 1000;  // 1 sec
 }  // namespace
 
 Client::Client()
@@ -190,8 +192,8 @@ bool Client::EnsureSession() {
 
 void Client::DumpQueryOfDeath() {
   LOG(ERROR) << "The playback history looks like a query of death";
-  const char kFilename[] = "query_of_death.log";
-  const char kLabel[] = "Query of Death";
+  constexpr char kFilename[] = "query_of_death.log";
+  constexpr char kLabel[] = "Query of Death";
   DumpHistorySnapshot(kFilename, kLabel);
   ResetHistory();
 }
@@ -276,13 +278,13 @@ void Client::ResetHistory() {
     input.mutable_key()->set_mode(last_mode_);
     history_inputs_.push_back(input);
   }
-#endif
+#endif  // __APPLE__
 }
 
-void Client::GetHistoryInputs(std::vector<commands::Input> *output) const {
-  output->clear();
+void Client::GetHistoryInputs(std::vector<commands::Input> *result) const {
+  result->clear();
   for (size_t i = 0; i < history_inputs_.size(); ++i) {
-    output->push_back(history_inputs_[i]);
+    result->push_back(history_inputs_[i]);
   }
 }
 
@@ -291,10 +293,10 @@ bool Client::SendKeyWithContext(const commands::KeyEvent &key,
                                 commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::SEND_KEY);
-  input.mutable_key()->CopyFrom(key);
+  *input.mutable_key() = key;
   // If the pointer of |context| is not the default_instance, update the data.
   if (&context != &commands::Context::default_instance()) {
-    input.mutable_context()->CopyFrom(context);
+    *input.mutable_context() = context;
   }
   return EnsureCallCommand(&input, output);
 }
@@ -306,9 +308,9 @@ bool Client::TestSendKeyWithContext(const commands::KeyEvent &key,
   input.set_type(commands::Input::TEST_SEND_KEY);
   // If the pointer of |context| is not the default_instance, update the data.
   if (&context != &commands::Context::default_instance()) {
-    input.mutable_context()->CopyFrom(context);
+    *input.mutable_context() = context;
   }
-  input.mutable_key()->CopyFrom(key);
+  *input.mutable_key() = key;
   return EnsureCallCommand(&input, output);
 }
 
@@ -317,10 +319,10 @@ bool Client::SendCommandWithContext(const commands::SessionCommand &command,
                                     commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::SEND_COMMAND);
-  input.mutable_command()->CopyFrom(command);
+  *input.mutable_command() = command;
   // If the pointer of |context| is not the default_instance, update the data.
   if (&context != &commands::Context::default_instance()) {
-    input.mutable_context()->CopyFrom(context);
+    *input.mutable_context() = context;
   }
   return EnsureCallCommand(&input, output);
 }
@@ -398,7 +400,7 @@ bool Client::EnsureCallCommand(commands::Input *input,
 
 void Client::EnableCascadingWindow(const bool enable) {
   if (preferences_ == nullptr) {
-    preferences_ = absl::make_unique<config::Config>();
+    preferences_ = std::make_unique<config::Config>();
   }
   preferences_->set_use_cascading_window(enable);
 }
@@ -418,7 +420,7 @@ void Client::set_suppress_error_dialog(bool suppress) {
 }
 
 void Client::set_client_capability(const commands::Capability &capability) {
-  client_capability_.CopyFrom(capability);
+  client_capability_ = capability;
 }
 
 bool Client::CreateSession() {
@@ -426,7 +428,7 @@ bool Client::CreateSession() {
   commands::Input input;
   input.set_type(commands::Input::CREATE_SESSION);
 
-  input.mutable_capability()->CopyFrom(client_capability_);
+  *input.mutable_capability() = client_capability_;
 
   commands::ApplicationInfo *info = input.mutable_application_info();
   DCHECK(info);
@@ -434,10 +436,10 @@ bool Client::CreateSession() {
 #ifdef OS_WIN
   info->set_process_id(static_cast<uint32>(::GetCurrentProcessId()));
   info->set_thread_id(static_cast<uint32>(::GetCurrentThreadId()));
-#else
-  info->set_process_id(static_cast<uint32>(getpid()));
+#else   // OS_WIN
+  info->set_process_id(static_cast<uint32_t>(getpid()));
   info->set_thread_id(0);
-#endif
+#endif  // OS_WIN
 
   commands::Output output;
   if (!CheckVersionOrRestartServerInternal(input, &output)) {
@@ -489,7 +491,7 @@ bool Client::GetConfig(config::Config *config) {
   }
 
   config->Clear();
-  config->CopyFrom(output.config());
+  *config = output.config();
   return true;
 }
 
@@ -497,7 +499,7 @@ bool Client::SetConfig(const config::Config &config) {
   commands::Input input;
   InitInput(&input);
   input.set_type(commands::Input::SET_CONFIG);
-  input.mutable_config()->CopyFrom(config);
+  *input.mutable_config() = config;
 
   commands::Output output;
   if (!Call(input, &output)) {
@@ -709,7 +711,7 @@ void Client::OnFatal(ServerLauncherInterface::ServerErrorType type) {
 void Client::InitInput(commands::Input *input) const {
   input->set_id(id_);
   if (preferences_ != nullptr) {
-    input->mutable_config()->CopyFrom(*preferences_);
+    *input->mutable_config() = *preferences_;
   }
 }
 
@@ -839,7 +841,7 @@ bool Client::LaunchTool(const std::string &mode, const std::string &extra_arg) {
 
   // Validate |mode|.
   // TODO(taku): better to validate the parameter more carefully.
-  const size_t kModeMaxSize = 32;
+  constexpr size_t kModeMaxSize = 32;
   if (mode.empty() || mode.size() >= kModeMaxSize) {
     LOG(ERROR) << "Invalid mode: " << mode;
     return false;
@@ -847,9 +849,9 @@ bool Client::LaunchTool(const std::string &mode, const std::string &extra_arg) {
 
   if (mode == "administration_dialog") {
 #ifdef OS_WIN
-    const string &path = mozc::SystemUtil::GetToolPath();
+    const std::string &path = mozc::SystemUtil::GetToolPath();
     std::wstring wpath;
-    Util::UTF8ToWide(path, &wpath);
+    Util::Utf8ToWide(path, &wpath);
     wpath = L"\"" + wpath + L"\"";
     // Run administration dialog with UAC.
     // AFAIK, ShellExecute is only the way to launch process with
