@@ -32,9 +32,11 @@
 
 #include <map>
 #include <string>
-#include "base/mutex.h"
+
 #include "client/client_interface.h"
 #include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 namespace client {
@@ -90,7 +92,7 @@ class ClientMock : public client::ClientInterface {
  public:                                                                    \
   arg_type called_##method_name() const { return called_##method_name##_; } \
   void set_output_##method_name(const commands::Output &output) {           \
-    outputs_[#method_name].CopyFrom(output);                                \
+    outputs_[#method_name] = output;                                        \
   }
   TEST_METHODS(SendKeyWithContext, commands::KeyEvent);
   TEST_METHODS(TestSendKeyWithContext, commands::KeyEvent);
@@ -112,7 +114,7 @@ class ClientMock : public client::ClientInterface {
 
   // ClientMock is called from a thread in SessionWatchDog, and
   // SessionWatchDogTest. So a mutex lock is required.
-  mutable Mutex mutex_;
+  mutable absl::Mutex mutex_;
 };
 }  // namespace client
 }  // namespace mozc
