@@ -32,6 +32,7 @@
 // events specified by FLAGS_input file or interactive standard input.  Input
 // file format is same as one of session/session_client_main.
 
+#include <cstdint>
 #include <iostream>
 #include <memory>
 #include <string>
@@ -50,11 +51,11 @@
 #include "protocol/renderer_command.pb.h"
 #include "renderer/renderer_client.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/status/status.h"
 #include "absl/strings/match.h"
 
 ABSL_FLAG(std::string, input, "", "Input file");
-ABSL_FLAG(int32, key_duration, 10, "Key duration (msec)");
+ABSL_FLAG(int32_t, key_duration, 10, "Key duration (msec)");
 ABSL_FLAG(std::string, profile_dir, "", "Profile dir");
 ABSL_FLAG(bool, sentence_mode, false, "Use input as sentences");
 ABSL_FLAG(std::string, server_path, "", "Specify server path");
@@ -113,17 +114,17 @@ int Loop(std::istream *input) {
         ::GetCurrentProcessId());
     renderer_command.mutable_application_info()->set_thread_id(
         ::GetCurrentThreadId());
-#endif
+#endif  // OS_WIN
 #if defined(OS_WIN) || defined(__APPLE__)
     renderer_command.mutable_preedit_rectangle()->set_left(10);
     renderer_command.mutable_preedit_rectangle()->set_top(10);
     renderer_command.mutable_preedit_rectangle()->set_right(200);
     renderer_command.mutable_preedit_rectangle()->set_bottom(30);
-    renderer_client = absl::make_unique<renderer::RendererClient>();
+    renderer_client = std::make_unique<renderer::RendererClient>();
     CHECK(renderer_client->Activate());
-#else
+#else   // defined(OS_WIN) || defined(__APPLE__)
     LOG(FATAL) << "test_renderer is only supported on Windows and Mac";
-#endif
+#endif  // defined(OS_WIN) || defined(__APPLE__)
   }
 
   commands::Command command;
@@ -154,7 +155,7 @@ int Loop(std::istream *input) {
       if (renderer_client != nullptr) {
         renderer_command.set_type(commands::RendererCommand::UPDATE);
         renderer_command.set_visible(output.has_candidates());
-        renderer_command.mutable_output()->CopyFrom(output);
+        *renderer_command.mutable_output() = output;
         VLOG(2) << "Sending to Renderer: " << renderer_command.DebugString();
         renderer_client->ExecCommand(renderer_command);
       }
@@ -175,7 +176,12 @@ int main(int argc, char **argv) {
   mozc::InitMozc(argv[0], &argc, &argv);
 
   if (!absl::GetFlag(FLAGS_profile_dir).empty()) {
-    mozc::FileUtil::CreateDirectory(absl::GetFlag(FLAGS_profile_dir));
+    if (absl::Status s =
+            mozc::FileUtil::CreateDirectory(absl::GetFlag(FLAGS_profile_dir));
+        !s.ok() && !absl::IsAlreadyExists(s)) {
+      LOG(ERROR) << s;
+      return -1;
+    }
     mozc::SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_profile_dir));
   }
 
@@ -184,7 +190,7 @@ int main(int argc, char **argv) {
 
   if (!absl::GetFlag(FLAGS_input).empty()) {
     // Batch mode loading the input file.
-    input_file = absl::make_unique<mozc::InputFileStream>(
+    input_file = std::make_unique<mozc::InputFileStream>(
         absl::GetFlag(FLAGS_input).c_str());
     if (input_file->fail()) {
       LOG(ERROR) << "File not opened: " << absl::GetFlag(FLAGS_input);
