@@ -29,6 +29,7 @@
 
 #include "client/client.h"
 
+#include <cstdint>
 #include <map>
 #include <memory>
 #include <string>
@@ -36,34 +37,34 @@
 #include "base/logging.h"
 #include "base/number_util.h"
 #include "base/port.h"
-#include "base/util.h"
 #include "base/version.h"
 #include "ipc/ipc_mock.h"
 #include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 #include "absl/strings/str_format.h"
+#include "absl/strings/str_join.h"
+#include "absl/strings/str_split.h"
 
 namespace mozc {
 namespace client {
-
 namespace {
-const char kPrecedingText[] = "preceding_text";
-const char kFollowingText[] = "following_text";
-const bool kSuppressSuggestion = true;
+
+constexpr char kPrecedingText[] = "preceding_text";
+constexpr char kFollowingText[] = "following_text";
+constexpr bool kSuppressSuggestion = true;
 
 const std::string UpdateVersion(int diff) {
-  std::vector<std::string> tokens;
-  Util::SplitStringUsing(Version::GetMozcVersion(), ".", &tokens);
+  std::vector<std::string> tokens =
+      absl::StrSplit(Version::GetMozcVersion(), '.', absl::SkipEmpty());
   EXPECT_EQ(tokens.size(), 4);
   char buf[64];
   absl::SNPrintF(buf, sizeof(buf), "%d",
                  NumberUtil::SimpleAtoi(tokens[3]) + diff);
   tokens[3] = buf;
-  std::string output;
-  Util::JoinStrings(tokens, ".", &output);
-  return output;
+  return absl::StrJoin(tokens, ".");
 }
+
 }  // namespace
 
 class TestServerLauncher : public ServerLauncherInterface {
@@ -97,7 +98,7 @@ class TestServerLauncher : public ServerLauncherInterface {
     return force_terminate_server_result_;
   }
 
-  bool WaitServer(uint32 pid) override { return true; }
+  bool WaitServer(uint32_t pid) override { return true; }
 
   void OnFatal(ServerLauncherInterface::ServerErrorType type) override {
     LOG(ERROR) << static_cast<int>(type);
@@ -125,8 +126,7 @@ class TestServerLauncher : public ServerLauncherInterface {
   void set_server_program(const std::string &server_path) override {}
 
   const std::string &server_program() const override {
-    static const std::string path;
-    return path;
+    return placeholder_server_program_path_;
   }
 
   void set_restricted(bool restricted) override {}
@@ -141,7 +141,7 @@ class TestServerLauncher : public ServerLauncherInterface {
     force_terminate_server_result_ = result;
   }
 
-  void set_server_protocol_version(uint32 server_protocol_version) {
+  void set_server_protocol_version(uint32_t server_protocol_version) {
     server_protocol_version_ = server_protocol_version;
   }
 
@@ -154,12 +154,13 @@ class TestServerLauncher : public ServerLauncherInterface {
   }
 
  private:
+  const std::string placeholder_server_program_path_;
   IPCClientFactoryMock *factory_;
   bool start_server_result_;
   bool start_server_called_;
   bool force_terminate_server_result_;
   bool force_terminate_server_called_;
-  uint32 server_protocol_version_;
+  uint32_t server_protocol_version_;
   std::string response_;
   std::string product_version_after_start_server_;
   std::map<int, int> error_map_;
@@ -170,8 +171,8 @@ class ClientTest : public testing::Test {
   ClientTest() : version_diff_(0) {}
 
   void SetUp() override {
-    client_factory_ = absl::make_unique<IPCClientFactoryMock>();
-    client_ = absl::make_unique<Client>();
+    client_factory_ = std::make_unique<IPCClientFactoryMock>();
+    client_ = std::make_unique<Client>();
     client_->SetIPCClientFactory(client_factory_.get());
 
     server_launcher_ = new TestServerLauncher(client_factory_.get());
@@ -689,7 +690,7 @@ class SessionPlaybackTestServerLauncher : public ServerLauncherInterface {
     return force_terminate_server_result_;
   }
 
-  bool WaitServer(uint32 pid) override { return true; }
+  bool WaitServer(uint32_t pid) override { return true; }
 
   void OnFatal(ServerLauncherInterface::ServerErrorType type) override {}
 
@@ -714,7 +715,7 @@ class SessionPlaybackTestServerLauncher : public ServerLauncherInterface {
   bool start_server_called_;
   bool force_terminate_server_result_;
   bool force_terminate_server_called_;
-  uint32 server_protocol_version_;
+  uint32_t server_protocol_version_;
   std::string response_;
   std::string product_version_after_start_server_;
   std::map<int, int> error_map_;
@@ -726,10 +727,10 @@ class SessionPlaybackTest : public testing::Test {
   ~SessionPlaybackTest() override {}
 
   void SetUp() override {
-    ipc_client_factory_ = absl::make_unique<IPCClientFactoryMock>();
+    ipc_client_factory_ = std::make_unique<IPCClientFactoryMock>();
     ipc_client_.reset(
         reinterpret_cast<IPCClientMock *>(ipc_client_factory_->NewClient("")));
-    client_ = absl::make_unique<Client>();
+    client_ = std::make_unique<Client>();
     client_->SetIPCClientFactory(ipc_client_factory_.get());
     server_launcher_ =
         new SessionPlaybackTestServerLauncher(ipc_client_factory_.get());
@@ -856,10 +857,10 @@ TEST_F(SessionPlaybackTest, PushAndResetHistoryWithModeTest) {
   EXPECT_EQ(commands::Input::SEND_KEY, history[0].type());
   EXPECT_EQ(commands::KeyEvent::ON, history[0].key().special_key());
   EXPECT_EQ(commands::HIRAGANA, history[0].key().mode());
-#else
+#else   // __APPLE__
   // history is reset, but initializer is not required.
   EXPECT_EQ(0, history.size());
-#endif
+#endif  // __APPLE__
 }
 
 // b/2797557
@@ -940,11 +941,11 @@ TEST_F(SessionPlaybackTest, PlaybackHistoryTest) {
   // PlaybackHistory and push history
   client_->GetHistoryInputs(&history);
   EXPECT_EQ(3, history.size());
-#else
+#else   // DEBUG
   // PlaybackHistory, dump history(including reset), and add last input
   client_->GetHistoryInputs(&history);
   EXPECT_EQ(1, history.size());
-#endif
+#endif  // DEBUG
 }
 
 // b/2797557
@@ -1001,10 +1002,10 @@ TEST_F(SessionPlaybackTest, SetModeInitializerTest) {
   EXPECT_EQ(commands::Input::SEND_KEY, history[0].type());
   EXPECT_EQ(commands::KeyEvent::ON, history[0].key().special_key());
   EXPECT_EQ(commands::FULL_KATAKANA, history[0].key().mode());
-#else
+#else   // __APPLE__
   // history is reset, but initializer is not required.
   EXPECT_EQ(0, history.size());
-#endif
+#endif  // __APPLE__
 }
 
 TEST_F(SessionPlaybackTest, ConsumedTest) {
