@@ -27,6 +27,7 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include <cstdint>
 #ifdef OS_WIN
 #include <sddl.h>
 #include <shlobj.h>
@@ -63,25 +64,25 @@
 namespace mozc {
 namespace client {
 namespace {
-const char kServerName[] = "session";
+constexpr char kServerName[] = "session";
 
 // Wait at most kServerWaitTimeout msec until server gets ready
-const uint32 kServerWaitTimeout = 20000;  // 20 sec
+constexpr uint32_t kServerWaitTimeout = 20000;  // 20 sec
 
 // for every 1000m sec, check server
-const uint32 kRetryIntervalForServer = 1000;
+constexpr uint32_t kRetryIntervalForServer = 1000;
 
 // Try 20 times to check mozc_server is running
-const uint32 kTrial = 20;
+constexpr uint32_t kTrial = 20;
 
 #ifdef DEBUG
 // Load special flags for server.
 // This should be enabled on debug build
-const string LoadServerFlags() {
-  const char kServerFlagsFile[] = "mozc_server_flags.txt";
-  const string filename = FileUtil::JoinPath(
+const std::string LoadServerFlags() {
+  constexpr char kServerFlagsFile[] = "mozc_server_flags.txt";
+  const std::string filename = FileUtil::JoinPath(
       SystemUtil::GetUserProfileDirectory(), kServerFlagsFile);
-  string flags;
+  std::string flags;
   InputFileStream ifs(filename.c_str());
   if (ifs) {
     getline(ifs, flags);
@@ -234,8 +235,8 @@ bool ServerLauncher::ForceTerminateServer(const std::string &name) {
   return IPCClient::TerminateServer(name);
 }
 
-bool ServerLauncher::WaitServer(uint32 pid) {
-  const int kTimeout = 10000;
+bool ServerLauncher::WaitServer(uint32_t pid) {
+  constexpr int kTimeout = 10000;
   return Process::WaitProcess(static_cast<size_t>(pid), kTimeout);
 }
 
