@@ -31,6 +31,11 @@
 
 #include "composer/composer.h"
 
+#include <cstdint>
+#include <unordered_map>
+
+#include "base/clock.h"
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/util.h"
 #include "composer/internal/composition.h"
@@ -46,20 +51,20 @@
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
 #include "absl/flags/flag.h"
+#include "absl/time/time.h"
 
 // Use flags instead of constant for performance evaluation.
-ABSL_FLAG(uint64, max_typing_correction_query_candidates, 40,
+ABSL_FLAG(uint64_t, max_typing_correction_query_candidates, 40,
           "Maximum # of typing correction query temporary candidates.");
-ABSL_FLAG(uint64, max_typing_correction_query_results, 8,
+ABSL_FLAG(uint64_t, max_typing_correction_query_results, 8,
           "Maximum # of typing correction query results.");
 
 namespace mozc {
 namespace composer {
+namespace {
 
 using ::mozc::config::CharacterFormManager;
 
-namespace {
-
 const Transliterators::Transliterator GetTransliterator(
     transliteration::TransliterationType comp_mode) {
   switch (comp_mode) {
@@ -117,46 +122,46 @@ void Transliterate(const transliteration::TransliterationType mode,
   // transformed.
   if (mode == transliteration::HALF_KATAKANA) {
     std::string tmp_input;
-    Util::HiraganaToKatakana(input, &tmp_input);
-    Util::FullWidthToHalfWidth(tmp_input, output);
+    japanese_util::HiraganaToKatakana(input, &tmp_input);
+    japanese_util::FullWidthToHalfWidth(tmp_input, output);
     return;
   }
 
   switch (mode) {
     case transliteration::HALF_ASCII:
-      Util::FullWidthAsciiToHalfWidthAscii(input, output);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(input, output);
       break;
     case transliteration::HALF_ASCII_UPPER:
-      Util::FullWidthAsciiToHalfWidthAscii(input, output);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(input, output);
       Util::UpperString(output);
       break;
     case transliteration::HALF_ASCII_LOWER:
-      Util::FullWidthAsciiToHalfWidthAscii(input, output);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(input, output);
       Util::LowerString(output);
       break;
     case transliteration::HALF_ASCII_CAPITALIZED:
-      Util::FullWidthAsciiToHalfWidthAscii(input, output);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(input, output);
       Util::CapitalizeString(output);
       break;
 
     case transliteration::FULL_ASCII:
-      Util::HalfWidthAsciiToFullWidthAscii(input, output);
+      japanese_util::HalfWidthAsciiToFullWidthAscii(input, output);
       break;
     case transliteration::FULL_ASCII_UPPER:
-      Util::HalfWidthAsciiToFullWidthAscii(input, output);
+      japanese_util::HalfWidthAsciiToFullWidthAscii(input, output);
       Util::UpperString(output);
       break;
     case transliteration::FULL_ASCII_LOWER:
-      Util::HalfWidthAsciiToFullWidthAscii(input, output);
+      japanese_util::HalfWidthAsciiToFullWidthAscii(input, output);
       Util::LowerString(output);
       break;
     case transliteration::FULL_ASCII_CAPITALIZED:
-      Util::HalfWidthAsciiToFullWidthAscii(input, output);
+      japanese_util::HalfWidthAsciiToFullWidthAscii(input, output);
       Util::CapitalizeString(output);
       break;
 
     case transliteration::FULL_KATAKANA:
-      Util::HiraganaToKatakana(input, output);
+      japanese_util::HiraganaToKatakana(input, output);
       break;
     case transliteration::HIRAGANA:
       *output = input;
@@ -188,7 +193,36 @@ transliteration::TransliterationType GetTransliterationTypeFromCompositionMode(
   }
 }
 
-const size_t kMaxPreeditLength = 256;
+// A map used in `GetQueriesForPrediction()`. The key is a modified Hiragana
+// and the values are its related Hiragana characters that can be cycled by
+// hitting the modifier key. For instance, there's a modification cycle
+// つ -> っ -> づ -> つ. For this cycle, the multimap contains:
+//   っ: [つ, づ]
+//   づ: [つ, っ]
+// If the composition ends with a key in this map, its corresponding values
+// are removed from the expansion produced by `GetQueryForPrediction()`,
+// whereby we can suppress prediction from unmodified key when one modified a
+// character explicitly (e.g., we don't want to suggest words starting with
+// "さ" when one typed "ざ" with modified key).
+using ModifierRemovalMap = std::unordered_multimap<std::string, std::string>;
+
+const ModifierRemovalMap *GetModifierRemovalMap() {
+  static const ModifierRemovalMap *const removal_map = new ModifierRemovalMap{
+      {"ぁ", "あ"}, {"ぃ", "い"}, {"ぅ", "う"}, {"ぅ", "ゔ"}, {"ゔ", "う"},
+      {"ゔ", "ぅ"}, {"ぇ", "え"}, {"ぉ", "お"}, {"が", "か"}, {"ぎ", "き"},
+      {"ぐ", "く"}, {"げ", "け"}, {"ご", "こ"}, {"ざ", "さ"}, {"じ", "し"},
+      {"ず", "す"}, {"ぜ", "せ"}, {"ぞ", "そ"}, {"だ", "た"}, {"ぢ", "ち"},
+      {"づ", "つ"}, {"づ", "っ"}, {"っ", "つ"}, {"っ", "づ"}, {"で", "て"},
+      {"ど", "と"}, {"ば", "は"}, {"ば", "ぱ"}, {"ぱ", "は"}, {"ぱ", "ば"},
+      {"び", "ひ"}, {"び", "ぴ"}, {"ぴ", "ひ"}, {"ぴ", "び"}, {"ぶ", "ふ"},
+      {"ぶ", "ぷ"}, {"ぷ", "ふ"}, {"ぷ", "ぶ"}, {"べ", "へ"}, {"べ", "ぺ"},
+      {"ぺ", "へ"}, {"ぺ", "べ"}, {"ぼ", "ほ"}, {"ぼ", "ぽ"}, {"ぽ", "ほ"},
+      {"ぽ", "ぼ"}, {"ゃ", "や"}, {"ゅ", "ゆ"}, {"ょ", "よ"}, {"ゎ", "わ"},
+  };
+  return removal_map;
+}
+
+constexpr size_t kMaxPreeditLength = 256;
 
 }  // namespace
 
@@ -200,25 +234,31 @@ Composer::Composer()
 Composer::Composer(const Table *table, const commands::Request *request,
                    const config::Config *config)
     : position_(0),
-      is_new_input_(true),
       input_mode_(transliteration::HIRAGANA),
       output_mode_(transliteration::HIRAGANA),
       comeback_input_mode_(transliteration::HIRAGANA),
       input_field_type_(commands::Context::NORMAL),
       shifted_sequence_count_(0),
-      composition_(new Composition(table)),
+      composition_(table),
       typing_corrector_(
           table, absl::GetFlag(FLAGS_max_typing_correction_query_candidates),
           absl::GetFlag(FLAGS_max_typing_correction_query_results)),
       max_length_(kMaxPreeditLength),
       request_(request),
-      config_(config) {
+      config_(config),
+      is_new_input_(true) {
   SetInputMode(transliteration::HIRAGANA);
-  typing_corrector_.SetConfig(config);
+  if (config_ == nullptr) {
+    config_ = &config::ConfigHandler::DefaultConfig();
+  }
+  typing_corrector_.SetConfig(config_);
   Reset();
 }
 
-Composer::~Composer() {}
+Composer::Composer(const Composer &) = default;
+Composer &Composer::operator=(const Composer &) = default;
+
+Composer::~Composer() = default;
 
 void Composer::Reset() {
   EditErase();
@@ -226,6 +266,7 @@ void Composer::Reset() {
   SetOutputMode(transliteration::HIRAGANA);
   source_text_.assign("");
   typing_corrector_.Reset();
+  timeout_threshold_msec_ = config_->composing_timeout_threshold_msec();
 }
 
 void Composer::ResetInputMode() { SetInputMode(comeback_input_mode_); }
@@ -237,7 +278,7 @@ void Composer::ReloadConfig() {
 bool Composer::Empty() const { return (GetLength() == 0); }
 
 void Composer::SetTable(const Table *table) {
-  composition_->SetTable(table);
+  composition_.SetTable(table);
 
   typing_corrector_.SetTable(table);
 }
@@ -256,7 +297,7 @@ void Composer::SetInputMode(transliteration::TransliterationType mode) {
   input_mode_ = mode;
   shifted_sequence_count_ = 0;
   is_new_input_ = true;
-  composition_->SetInputMode(GetTransliterator(mode));
+  composition_.SetInputMode(GetTransliterator(mode));
 }
 
 void Composer::SetTemporaryInputMode(
@@ -266,15 +307,15 @@ void Composer::SetTemporaryInputMode(
   input_mode_ = mode;
   shifted_sequence_count_ = 0;
   is_new_input_ = true;
-  composition_->SetInputMode(GetTransliterator(mode));
+  composition_.SetInputMode(GetTransliterator(mode));
 }
 
 void Composer::UpdateInputMode() {
   if (position_ != 0 && request_->update_input_mode_from_surrounding_text()) {
     const Transliterators::Transliterator current_t12r =
-        composition_->GetTransliterator(position_);
-    if (position_ == composition_->GetLength() ||
-        current_t12r == composition_->GetTransliterator(position_ + 1)) {
+        composition_.GetTransliterator(position_);
+    if (position_ == composition_.GetLength() ||
+        current_t12r == composition_.GetTransliterator(position_ + 1)) {
       // - The cursor is at the tail of composition.
       //   Use last character's transliterator as the input mode.
       // - If the current cursor is between the same character type like
@@ -282,7 +323,7 @@ void Composer::UpdateInputMode() {
       input_mode_ = GetTransliterationType(current_t12r, comeback_input_mode_);
       shifted_sequence_count_ = 0;
       is_new_input_ = true;
-      composition_->SetInputMode(GetTransliterator(input_mode_));
+      composition_.SetInputMode(GetTransliterator(input_mode_));
       return;
     }
   }
@@ -314,9 +355,9 @@ transliteration::TransliterationType Composer::GetOutputMode() const {
 
 void Composer::SetOutputMode(transliteration::TransliterationType mode) {
   output_mode_ = mode;
-  composition_->SetTransliterator(0, composition_->GetLength(),
-                                  GetTransliterator(mode));
-  position_ = composition_->GetLength();
+  composition_.SetTransliterator(0, composition_.GetLength(),
+                                 GetTransliterator(mode));
+  position_ = composition_.GetLength();
 }
 
 void Composer::ApplyTemporaryInputMode(const std::string &input,
@@ -384,32 +425,21 @@ void Composer::ApplyTemporaryInputMode(const std::string &input,
   }
 }
 
-bool Composer::InsertCharacterInternal(const std::string &key) {
+bool Composer::ProcessCompositionInput(const CompositionInput &input) {
   if (!EnableInsert()) {
     return false;
   }
-  CompositionInput input;
-  input.set_raw(key);
-  input.set_is_new_input(is_new_input_);
-  position_ = composition_->InsertInput(position_, input);
+
+  position_ = composition_.InsertInput(position_, input);
   is_new_input_ = false;
+  typing_corrector_.InsertCharacter(input.raw(), input.probable_key_events());
   return true;
 }
 
 void Composer::InsertCharacter(const std::string &key) {
-  if (!InsertCharacterInternal(key)) {
-    return;
-  }
-  const ProbableKeyEvents empty_events;
-  typing_corrector_.InsertCharacter(key, empty_events);
-}
-
-void Composer::InsertCharacterForProbableKeyEvents(
-    const std::string &key, const ProbableKeyEvents &probable_key_events) {
-  if (!InsertCharacterInternal(key)) {
-    return;
-  }
-  typing_corrector_.InsertCharacter(key, probable_key_events);
+  CompositionInput input;
+  input.InitFromRaw(key, is_new_input_);
+  ProcessCompositionInput(input);
 }
 
 void Composer::InsertCommandCharacter(const InternalCommand internal_command) {
@@ -441,7 +471,7 @@ void Composer::InsertCharacterPreedit(const std::string &input) {
 
 // Note: This method is only for test.
 void Composer::SetPreeditTextForTestOnly(const std::string &input) {
-  composition_->SetInputMode(Transliterators::RAW_STRING);
+  composition_.SetInputMode(Transliterators::RAW_STRING);
   size_t begin = 0;
   const size_t end = input.size();
   while (begin < end) {
@@ -450,7 +480,7 @@ void Composer::SetPreeditTextForTestOnly(const std::string &input) {
     CompositionInput input;
     input.set_raw(character);
     input.set_is_new_input(is_new_input_);
-    position_ = composition_->InsertInput(position_, input);
+    position_ = composition_.InsertInput(position_, input);
     is_new_input_ = false;
     begin += mblen;
   }
@@ -465,49 +495,32 @@ void Composer::SetPreeditTextForTestOnly(const std::string &input) {
   }
 }
 
-void Composer::InsertCharacterPreeditForProbableKeyEvents(
-    const std::string &input, const ProbableKeyEvents &probable_key_events) {
-  InsertCharacterKeyAndPreeditForProbableKeyEvents(input, input,
-                                                   probable_key_events);
-}
-
-bool Composer::InsertCharacterKeyAndPreeditInternal(
-    const std::string &key, const std::string &preedit) {
-  if (!EnableInsert()) {
-    return false;
-  }
-  CompositionInput input;
-  input.set_raw(key);
-  input.set_conversion(preedit);
-  input.set_is_new_input(is_new_input_);
-  position_ = composition_->InsertInput(position_, input);
-  is_new_input_ = false;
-  return true;
-}
-
 bool Composer::InsertCharacterKeyAndPreedit(const std::string &key,
                                             const std::string &preedit) {
-  if (!InsertCharacterKeyAndPreeditInternal(key, preedit)) {
-    return false;
-  }
-  const ProbableKeyEvents empty_events;
-  typing_corrector_.InsertCharacter(key, empty_events);
-  return true;
-}
-
-void Composer::InsertCharacterKeyAndPreeditForProbableKeyEvents(
-    const std::string &key, const std::string &preedit,
-    const ProbableKeyEvents &probable_key_events) {
-  if (!InsertCharacterKeyAndPreeditInternal(key, preedit)) {
-    return;
-  }
-  typing_corrector_.InsertCharacter(key, probable_key_events);
+  CompositionInput input;
+  input.InitFromRawAndConv(key, preedit, is_new_input_);
+  return ProcessCompositionInput(input);
 }
 
 bool Composer::InsertCharacterKeyEvent(const commands::KeyEvent &key) {
   if (!EnableInsert()) {
     return false;
   }
+
+  // Check timeout.
+  // If the duration from the previous input is over than the threshold,
+  // A STOP_KEY_TOGGLING command is sent before the key input.
+  if (timeout_threshold_msec_ > 0) {
+    int64_t current_msec = key.has_timestamp_msec()
+                               ? key.timestamp_msec()
+                               : absl::ToUnixMillis(Clock::GetAbslTime());
+    if (timestamp_msec_ > 0 &&
+        current_msec - timestamp_msec_ >= timeout_threshold_msec_) {
+      InsertCommandCharacter(STOP_KEY_TOGGLING);
+    }
+    timestamp_msec_ = current_msec;
+  }
+
   if (key.has_mode()) {
     const transliteration::TransliterationType new_input_mode =
         GetTransliterationTypeFromCompositionMode(key.mode());
@@ -531,50 +544,29 @@ bool Composer::InsertCharacterKeyEvent(const commands::KeyEvent &key) {
     }
   }
 
-  // Fill input representing user's raw input.
-  std::string input;
-  if (key.has_key_code()) {
-    Util::UCS4ToUTF8(key.key_code(), &input);
-  } else if (key.has_key_string()) {
-    input = key.key_string();
-  } else {
-    LOG(WARNING) << "input is empty";
+  CompositionInput input;
+  if (!input.Init(key, config_->use_typing_correction(), is_new_input_)) {
     return false;
   }
 
-  bool is_typing_correction_enabled = config_->use_typing_correction();
   if (key.has_key_string()) {
     if (key.input_style() == commands::KeyEvent::AS_IS ||
         key.input_style() == commands::KeyEvent::DIRECT_INPUT) {
-      composition_->SetInputMode(Transliterators::CONVERSION_STRING);
-      if (is_typing_correction_enabled) {
-        InsertCharacterKeyAndPreeditForProbableKeyEvents(
-            input, key.key_string(), key.probable_key_event());
-      } else {
-        InsertCharacterKeyAndPreedit(input, key.key_string());
-      }
+      composition_.SetInputMode(Transliterators::CONVERSION_STRING);
+      ProcessCompositionInput(input);
       SetInputMode(comeback_input_mode_);
     } else {
       // Kana input usually has key_string.  Note that, the existence of
       // key_string never determine if the input mode is Kana or Romaji.
-      if (is_typing_correction_enabled) {
-        InsertCharacterKeyAndPreeditForProbableKeyEvents(
-            input, key.key_string(), key.probable_key_event());
-      } else {
-        InsertCharacterKeyAndPreedit(input, key.key_string());
-      }
+      ProcessCompositionInput(input);
     }
   } else {
     // Romaji input usually does not has key_string.  Note that, the
     // existence of key_string never determines if the input mode is
     // Kana or Romaji.
-    const uint32 modifiers = KeyEventUtil::GetModifiers(key);
-    ApplyTemporaryInputMode(input, KeyEventUtil::HasCaps(modifiers));
-    if (is_typing_correction_enabled) {
-      InsertCharacterForProbableKeyEvents(input, key.probable_key_event());
-    } else {
-      InsertCharacter(input);
-    }
+    const uint32_t modifiers = KeyEventUtil::GetModifiers(key);
+    ApplyTemporaryInputMode(input.raw(), KeyEventUtil::HasCaps(modifiers));
+    ProcessCompositionInput(input);
   }
 
   if (comeback_input_mode_ == input_mode_) {
@@ -584,7 +576,7 @@ bool Composer::InsertCharacterKeyEvent(const commands::KeyEvent &key) {
 }
 
 void Composer::DeleteAt(size_t pos) {
-  composition_->DeleteAt(pos);
+  composition_.DeleteAt(pos);
   // Adjust cursor position for composition mode.
   if (position_ > pos) {
     position_--;
@@ -596,21 +588,21 @@ void Composer::DeleteAt(size_t pos) {
 }
 
 void Composer::Delete() {
-  position_ = composition_->DeleteAt(position_);
+  position_ = composition_.DeleteAt(position_);
   UpdateInputMode();
 
   typing_corrector_.Invalidate();
 }
 
 void Composer::DeleteRange(size_t pos, size_t length) {
-  for (int i = 0; i < length && pos < composition_->GetLength(); ++i) {
+  for (int i = 0; i < length && pos < composition_.GetLength(); ++i) {
     DeleteAt(pos);
   }
   typing_corrector_.Invalidate();
 }
 
 void Composer::EditErase() {
-  composition_->Erase();
+  composition_.Erase();
   position_ = 0;
   SetInputMode(comeback_input_mode_);
   typing_corrector_.Reset();
@@ -635,7 +627,7 @@ void Composer::Backspace() {
   UpdateInputMode();
 
   // Delete 'character to be deleted'
-  position_ = composition_->DeleteAt(position_);
+  position_ = composition_.DeleteAt(position_);
 
   typing_corrector_.Invalidate();
 }
@@ -650,7 +642,7 @@ void Composer::MoveCursorLeft() {
 }
 
 void Composer::MoveCursorRight() {
-  if (position_ < composition_->GetLength()) {
+  if (position_ < composition_.GetLength()) {
     ++position_;
   }
   UpdateInputMode();
@@ -666,7 +658,7 @@ void Composer::MoveCursorToBeginning() {
 }
 
 void Composer::MoveCursorToEnd() {
-  position_ = composition_->GetLength();
+  position_ = composition_.GetLength();
   // Behavior between MoveCursorToEnd and MoveCursorToRight is different.
   // MoveCursorToEnd always makes current input mode default.
   SetInputMode(comeback_input_mode_);
@@ -674,8 +666,8 @@ void Composer::MoveCursorToEnd() {
   typing_corrector_.Invalidate();
 }
 
-void Composer::MoveCursorTo(uint32 new_position) {
-  if (new_position <= composition_->GetLength()) {
+void Composer::MoveCursorTo(uint32_t new_position) {
+  if (new_position <= composition_.GetLength()) {
     position_ = new_position;
     UpdateInputMode();
   }
@@ -687,7 +679,7 @@ void Composer::GetPreedit(std::string *left, std::string *focused,
   DCHECK(left);
   DCHECK(focused);
   DCHECK(right);
-  composition_->GetPreedit(position_, left, focused, right);
+  composition_.GetPreedit(position_, left, focused, right);
 
   // TODO(komatsu): This function can be obsolete.
   std::string preedit = *left + *focused + *right;
@@ -702,7 +694,7 @@ void Composer::GetPreedit(std::string *left, std::string *focused,
 }
 
 void Composer::GetStringForPreedit(std::string *output) const {
-  composition_->GetString(output);
+  composition_.GetString(output);
   TransformCharactersForNumbers(output);
   // If the input field type needs half ascii characters,
   // perform conversion here.
@@ -724,7 +716,7 @@ void Composer::GetStringForPreedit(std::string *output) const {
       field_type == commands::Context::PASSWORD ||
       field_type == commands::Context::TEL) {
     const std::string tmp = *output;
-    Util::FullWidthAsciiToHalfWidthAscii(tmp, output);
+    japanese_util::FullWidthAsciiToHalfWidthAscii(tmp, output);
   }
 }
 
@@ -736,9 +728,9 @@ void Composer::GetStringForSubmission(std::string *output) const {
 
 void Composer::GetQueryForConversion(std::string *output) const {
   std::string base_output;
-  composition_->GetStringWithTrimMode(FIX, &base_output);
+  composition_.GetStringWithTrimMode(FIX, &base_output);
   TransformCharactersForNumbers(&base_output);
-  Util::FullWidthAsciiToHalfWidthAscii(base_output, output);
+  japanese_util::FullWidthAsciiToHalfWidthAscii(base_output, output);
 }
 
 namespace {
@@ -801,7 +793,7 @@ std::string *GetBaseQueryForPrediction(std::string *asis_query,
 
 void Composer::GetQueryForPrediction(std::string *output) const {
   std::string asis_query;
-  composition_->GetStringWithTrimMode(ASIS, &asis_query);
+  composition_.GetStringWithTrimMode(ASIS, &asis_query);
 
   switch (input_mode_) {
     case transliteration::HALF_ASCII: {
@@ -809,7 +801,7 @@ void Composer::GetQueryForPrediction(std::string *output) const {
       return;
     }
     case transliteration::FULL_ASCII: {
-      Util::FullWidthAsciiToHalfWidthAscii(asis_query, output);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(asis_query, output);
       return;
     }
     default: {
@@ -817,7 +809,7 @@ void Composer::GetQueryForPrediction(std::string *output) const {
   }
 
   std::string trimed_query;
-  composition_->GetStringWithTrimMode(TRIM, &trimed_query);
+  composition_.GetStringWithTrimMode(TRIM, &trimed_query);
 
   // NOTE(komatsu): This is a hack to go around the difference
   // expectation between Romanji-Input and Kana-Input.  "かn" in
@@ -829,14 +821,13 @@ void Composer::GetQueryForPrediction(std::string *output) const {
   std::string *base_query =
       GetBaseQueryForPrediction(&asis_query, &trimed_query);
   TransformCharactersForNumbers(base_query);
-  Util::FullWidthAsciiToHalfWidthAscii(*base_query, output);
+  japanese_util::FullWidthAsciiToHalfWidthAscii(*base_query, output);
 }
 
 void Composer::GetQueriesForPrediction(std::string *base,
                                        std::set<std::string> *expanded) const {
   DCHECK(base);
   DCHECK(expanded);
-  DCHECK(composition_.get());
   // In case of the Latin input modes, we don't perform expansion.
   switch (input_mode_) {
     case transliteration::HALF_ASCII:
@@ -849,8 +840,21 @@ void Composer::GetQueriesForPrediction(std::string *base,
     }
   }
   std::string base_query;
-  composition_->GetExpandedStrings(&base_query, expanded);
-  Util::FullWidthAsciiToHalfWidthAscii(base_query, base);
+  composition_.GetExpandedStrings(&base_query, expanded);
+  // The above `GetExpandedStrings` generates expansion for modifier key as
+  // well, e.g., if the composition is "ざ", `expanded` contains "さ" too.
+  // However, "ざ" is usually composed by explicitly hitting the modifier key.
+  // So we don't want to generate prediction from "さ" in this case. The
+  // following code removes such unnecessary expansion.
+  std::string asis;
+  composition_.GetStringWithTrimMode(ASIS, &asis);
+  const std::string trailing = asis.substr(base_query.size());
+  for (auto [iter, end] = GetModifierRemovalMap()->equal_range(trailing);
+       iter != end; ++iter) {
+    expanded->erase(iter->second);
+  }
+
+  japanese_util::FullWidthAsciiToHalfWidthAscii(base_query, base);
 }
 
 void Composer::GetTypeCorrectedQueriesForPrediction(
@@ -858,7 +862,7 @@ void Composer::GetTypeCorrectedQueriesForPrediction(
   typing_corrector_.GetQueriesForPrediction(queries);
 }
 
-size_t Composer::GetLength() const { return composition_->GetLength(); }
+size_t Composer::GetLength() const { return composition_.GetLength(); }
 
 size_t Composer::GetCursor() const { return position_; }
 
@@ -867,11 +871,11 @@ void Composer::GetTransliteratedText(Transliterators::Transliterator t12r,
                                      std::string *result) const {
   DCHECK(result);
   std::string full_base;
-  composition_->GetStringWithTransliterator(t12r, &full_base);
+  composition_.GetStringWithTransliterator(t12r, &full_base);
 
   const size_t t13n_start =
-      composition_->ConvertPosition(position, Transliterators::LOCAL, t12r);
-  const size_t t13n_end = composition_->ConvertPosition(
+      composition_.ConvertPosition(position, Transliterators::LOCAL, t12r);
+  const size_t t13n_end = composition_.ConvertPosition(
       position + size, Transliterators::LOCAL, t12r);
   const size_t t13n_size = t13n_end - t13n_start;
 
@@ -937,7 +941,7 @@ void Composer::AutoSwitchMode() {
 
   std::string key;
   // Key should be in half-width alphanumeric.
-  composition_->GetStringWithTransliterator(
+  composition_.GetStringWithTransliterator(
       GetTransliterator(transliteration::HALF_ASCII), &key);
 
   ModeSwitchingHandler::ModeSwitching display_mode =
@@ -1010,7 +1014,7 @@ void Composer::AutoSwitchMode() {
   }
 }
 
-bool Composer::ShouldCommit() const { return composition_->ShouldCommit(); }
+bool Composer::ShouldCommit() const { return composition_.ShouldCommit(); }
 
 bool Composer::ShouldCommitHead(size_t *length_to_commit) const {
   size_t max_remaining_composition_length;
@@ -1193,7 +1197,7 @@ bool Composer::TransformCharactersForNumbers(std::string *query) {
 
     if (append_char.empty()) {
       // Append one character.
-      Util::UCS4ToUTF8Append(iter.Get(), &transformed_query);
+      Util::Ucs4ToUtf8Append(iter.Get(), &transformed_query);
     } else {
       // Append the transformed character.
       transformed_query.append(append_char);
@@ -1213,32 +1217,10 @@ bool Composer::TransformCharactersForNumbers(std::string *query) {
 
 void Composer::SetNewInput() { is_new_input_ = true; }
 
-void Composer::CopyFrom(const Composer &src) {
-  Reset();
-
-  input_mode_ = src.input_mode_;
-  comeback_input_mode_ = src.comeback_input_mode_;
-  output_mode_ = src.output_mode_;
-  input_field_type_ = src.input_field_type_;
-
-  position_ = src.position_;
-  is_new_input_ = src.is_new_input_;
-  shifted_sequence_count_ = src.shifted_sequence_count_;
-  source_text_.assign(src.source_text_);
-  max_length_ = src.max_length_;
-
-  composition_.reset(src.composition_->Clone());
-  request_ = src.request_;
-  config_ = src.config_;
-
-  typing_corrector_.CopyFrom(src.typing_corrector_);
-}
-
 bool Composer::IsToggleable() const {
   // When |is_new_input_| is true, a new chunk is always created and, hence, key
   // toggling never happens regardless of the composition state.
-  return !is_new_input_ && composition_ &&
-         composition_->IsToggleable(position_);
+  return !is_new_input_ && composition_.IsToggleable(position_);
 }
 
 bool Composer::is_new_input() const { return is_new_input_; }
@@ -1256,6 +1238,12 @@ void Composer::set_source_text(const std::string &source_text) {
 size_t Composer::max_length() const { return max_length_; }
 void Composer::set_max_length(size_t length) { max_length_ = length; }
 
+int Composer::timeout_threshold_msec() const { return timeout_threshold_msec_; }
+
+void Composer::set_timeout_threshold_msec(int threshold_msec) {
+  timeout_threshold_msec_ = threshold_msec;
+}
+
 void Composer::SetInputFieldType(commands::Context::InputFieldType type) {
   input_field_type_ = type;
 }
