@@ -38,13 +38,14 @@
 #include "composer/internal/composition_input.h"
 #include "composer/internal/transliterators.h"
 #include "composer/table.h"
+#include "absl/container/btree_set.h"
 
 namespace mozc {
 namespace composer {
 
 namespace {
 // Max recursion count for looking up pending loop.
-const int kMaxRecursion = 4;
+constexpr int kMaxRecursion = 4;
 
 // Delete "end" from "target", if "target" ends with the "end".
 bool DeleteEnd(const std::string &end, std::string *target) {
@@ -74,7 +75,7 @@ bool DeleteEnd(const std::string &end, std::string *target) {
 // '{*}い' -> '', '{*}ぃ'
 // Here, we want to get '{*}あ' <-> '{*}ぁ' loop from the input, 'あ'
 bool GetFromPending(const Table *table, const std::string &key,
-                    int recursion_count, std::set<std::string> *result) {
+                    int recursion_count, absl::btree_set<std::string> *result) {
   DCHECK(result);
   if (recursion_count == 0) {
     // Don't find the loop within the |recursion_count|.
@@ -110,13 +111,16 @@ bool GetFromPending(const Table *table, const std::string &key,
 
 CharChunk::CharChunk(Transliterators::Transliterator transliterator,
                      const Table *table)
-    : transliterator_(transliterator),
-      table_(table),
+    : table_(table),
+      transliterator_(transliterator),
       attributes_(NO_TABLE_ATTRIBUTE),
       local_length_cache_(std::string::npos) {
   DCHECK_NE(Transliterators::LOCAL, transliterator);
 }
 
+CharChunk::CharChunk(const CharChunk &x) = default;
+CharChunk &CharChunk::operator=(const CharChunk &x) = default;
+
 void CharChunk::Clear() {
   raw_.clear();
   conversion_.clear();
@@ -241,12 +245,12 @@ void CharChunk::GetExpandedResults(std::set<std::string> *results) const {
     if (entries[i]->pending().empty()) {
       continue;
     }
-    std::set<std::string> loop_result;
+    absl::btree_set<std::string> loop_result;
     if (!GetFromPending(table_, entries[i]->pending(), kMaxRecursion,
                         &loop_result)) {
       continue;
     }
-    for (std::set<std::string>::const_iterator itr = loop_result.begin();
+    for (absl::btree_set<std::string>::const_iterator itr = loop_result.begin();
          itr != loop_result.end(); ++itr) {
       results->insert(Table::DeleteSpecialKey(*itr));
     }
@@ -296,7 +300,7 @@ void CharChunk::Combine(const CharChunk &left_chunk) {
 }
 
 bool CharChunk::AddInputInternal(std::string *input) {
-  const bool kNoLoop = false;
+  constexpr bool kNoLoop = false;
 
   size_t key_length = 0;
   bool fixed = false;
@@ -385,7 +389,7 @@ bool CharChunk::AddInputInternal(std::string *input) {
     return kNoLoop;
   }
 
-  const bool kLoop = true;
+  constexpr bool kLoop = true;
   return kLoop;
 }
 
@@ -518,39 +522,36 @@ void CharChunk::SetTransliterator(
   transliterator_ = transliterator;
 }
 
-const std::string &CharChunk::raw() const { return raw_; }
-
 void CharChunk::set_raw(const std::string &raw) {
   raw_ = raw;
   local_length_cache_ = std::string::npos;
 }
 
-const std::string &CharChunk::conversion() const { return conversion_; }
-
 void CharChunk::set_conversion(const std::string &conversion) {
   conversion_ = conversion;
   local_length_cache_ = std::string::npos;
 }
 
-const std::string &CharChunk::pending() const { return pending_; }
-
 void CharChunk::set_pending(const std::string &pending) {
   pending_ = pending;
   local_length_cache_ = std::string::npos;
 }
 
-const std::string &CharChunk::ambiguous() const { return ambiguous_; }
-
 void CharChunk::set_ambiguous(const std::string &ambiguous) {
   ambiguous_ = ambiguous;
   local_length_cache_ = std::string::npos;
 }
 
-bool CharChunk::SplitChunk(Transliterators::Transliterator t12r,
-                           const size_t position, CharChunk **left_new_chunk) {
+void CharChunk::set_attributes(TableAttributes attributes) {
+  attributes_ = attributes;
+  local_length_cache_ = std::string::npos;
+}
+
+std::unique_ptr<CharChunk> CharChunk::SplitChunk(
+    Transliterators::Transliterator t12r, const size_t position) {
   if (position <= 0 || position >= GetLength(t12r)) {
     LOG(WARNING) << "Invalid position: " << position;
-    return false;
+    return nullptr;
   }
 
   local_length_cache_ = std::string::npos;
@@ -560,28 +561,28 @@ bool CharChunk::SplitChunk(Transliterators::Transliterator t12r,
               Table::DeleteSpecialKey(conversion_ + pending_), &raw_lhs,
               &raw_rhs, &converted_lhs, &converted_rhs);
 
-  *left_new_chunk = new CharChunk(transliterator_, table_);
-  (*left_new_chunk)->set_raw(raw_lhs);
+  auto left_new_chunk = std::make_unique<CharChunk>(transliterator_, table_);
+  left_new_chunk->set_raw(raw_lhs);
   set_raw(raw_rhs);
 
   if (converted_lhs.size() > conversion_.size()) {
     // [ conversion | pending ] => [ conv | pend#1 ] [ pend#2 ]
     const std::string pending_lhs(converted_lhs, conversion_.size());
-    (*left_new_chunk)->set_conversion(conversion_);
-    (*left_new_chunk)->set_pending(pending_lhs);
+    left_new_chunk->set_conversion(conversion_);
+    left_new_chunk->set_pending(pending_lhs);
 
     conversion_.clear();
     pending_ = converted_rhs;
     ambiguous_.clear();
   } else {
     // [ conversion | pending ] => [ conv#1 ] [ conv#2 | pending ]
-    (*left_new_chunk)->set_conversion(converted_lhs);
+    left_new_chunk->set_conversion(converted_lhs);
     // left_new_chunk->set_pending("");
     const size_t pending_pos = converted_rhs.size() - pending_.size();
     conversion_.assign(converted_rhs, 0, pending_pos);
     // pending_ = pending_;
   }
-  return true;
+  return left_new_chunk;
 }
 
 Transliterators::Transliterator CharChunk::GetTransliterator(
@@ -607,17 +608,5 @@ std::string CharChunk::Transliterate(
       ->Transliterate(raw, converted);
 }
 
-CharChunk *CharChunk::Clone() const {
-  // TODO(hsumita): Implements TransliteratorFactory and uses it instead of
-  // copying a pointer.
-  CharChunk *new_char_chunk = new CharChunk(transliterator_, table_);
-  new_char_chunk->raw_.assign(raw_);
-  new_char_chunk->conversion_.assign(conversion_);
-  new_char_chunk->pending_.assign(pending_);
-  new_char_chunk->ambiguous_.assign(ambiguous_);
-  new_char_chunk->attributes_ = attributes_;
-  return new_char_chunk;
-}
-
 }  // namespace composer
 }  // namespace mozc
