@@ -39,7 +39,7 @@
 #include "composer/internal/transliterators.h"
 #include "composer/table.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 namespace composer {
@@ -75,13 +75,102 @@ size_t InsertCharacters(const std::string& input, size_t pos,
   return pos;
 }
 
+std::string ToString(const CharChunk& chunk) {
+  return absl::StrFormat(
+      "{table: %p, raw: %s, conversion: %s, pending: %s, ambiguous: %s, "
+      "transliterator: %d, attributes: %d}",
+      chunk.table(), chunk.raw(), chunk.conversion(), chunk.pending(),
+      chunk.ambiguous(), chunk.transliterator(), chunk.attributes());
+}
+
+std::string ToString(const CharChunkList& chunks) {
+  std::string s = "[\n";
+  for (const std::unique_ptr<CharChunk>& chunk : chunks) {
+    s.append("  ").append(ToString(*chunk)).append(1, '\n');
+  }
+  s.append(1, ']');
+  return s;
+}
+
+::testing::AssertionResult IsCharChunkEqual(const CharChunk& x,
+                                            const CharChunk& y) {
+  if (x.table() != y.table()) {
+    return ::testing::AssertionFailure() << "Table is different";
+  }
+  if (x.raw() != y.raw()) {
+    return ::testing::AssertionFailure()
+           << "raw is different: " << x.raw() << " vs " << y.raw();
+  }
+  if (x.conversion() != y.conversion()) {
+    return ::testing::AssertionFailure()
+           << "conversion is different: " << x.conversion() << " vs "
+           << y.conversion();
+  }
+  if (x.pending() != y.pending()) {
+    return ::testing::AssertionFailure()
+           << "pending is different: " << x.pending() << " vs " << y.pending();
+  }
+  if (x.ambiguous() != y.ambiguous()) {
+    return ::testing::AssertionFailure()
+           << "ambiguous is different: " << x.ambiguous() << " vs "
+           << y.ambiguous();
+  }
+  if (x.transliterator() != y.transliterator()) {
+    return ::testing::AssertionFailure()
+           << "transliterator is different: " << x.transliterator() << " vs "
+           << y.transliterator();
+  }
+  if (x.attributes() != y.attributes()) {
+    return ::testing::AssertionFailure()
+           << "attributes is different: " << x.attributes() << " vs "
+           << y.attributes();
+  }
+  return ::testing::AssertionSuccess();
+}
+
+::testing::AssertionResult IsCharChunkListEqual(const CharChunkList& x,
+                                                const CharChunkList& y) {
+  if (x.size() != y.size()) {
+    return ::testing::AssertionFailure()
+           << "Size is different: " << x.size() << " vs " << y.size()
+           << "\n left: " << ToString(x) << "\nright: " << ToString(y);
+  }
+  for (auto x_it = x.begin(), y_it = y.begin(); x_it != x.end();
+       ++x_it, ++y_it) {
+    if (auto ret = IsCharChunkEqual(**x_it, **y_it); !ret) {
+      const size_t index = std::distance(x.begin(), x_it);
+      return ::testing::AssertionFailure()
+             << "Chunk[" << index << "] is different\n"
+             << ret.message() << "\n left: " << ToString(**x_it)
+             << "\nright: " << ToString(**y_it);
+    }
+  }
+  return ::testing::AssertionSuccess();
+}
+
+::testing::AssertionResult IsCompositionEqual(const Composition& x,
+                                              const Composition& y) {
+  if (x.table() != y.table()) {
+    return ::testing::AssertionFailure() << "Table is different";
+  }
+  if (::testing::AssertionResult ret =
+          IsCharChunkListEqual(x.chunks(), y.chunks());
+      !ret) {
+    return ret;
+  }
+  if (x.input_t12r() != y.input_t12r()) {
+    return ::testing::AssertionFailure() << "Input transliterator is different";
+  }
+  return ::testing::AssertionSuccess();
+}
+
 }  // namespace
 
 class CompositionTest : public testing::Test {
  protected:
   void SetUp() override {
-    table_ = absl::make_unique<Table>();
-    composition_ = absl::make_unique<Composition>(table_.get());
+    table_ = std::make_unique<Table>();
+    composition_ = std::make_unique<Composition>(table_.get());
     composition_->SetInputMode(Transliterators::CONVERSION_STRING);
   }
 
@@ -100,12 +189,12 @@ static int InitComposition(Composition* comp) {
       {"あ", "", "a"},     {"", "ky", "ky"},    {"き", "", "ki"},
       {"った", "", "tta"}, {"っ", "ty", "tty"},
   };
-  static const int test_chunks_size = arraysize(test_chunks);
+  static const int test_chunks_size = std::size(test_chunks);
   CharChunkList::iterator it;
   comp->MaybeSplitChunkAt(0, &it);
   for (int i = 0; i < test_chunks_size; ++i) {
     const TestCharChunk& data = test_chunks[i];
-    CharChunk* chunk = *comp->InsertChunk(&it);
+    CharChunk* chunk = comp->InsertChunk(it)->get();
     chunk->set_conversion(data.conversion);
     chunk->set_pending(data.pending);
     chunk->set_raw(data.raw);
@@ -118,7 +207,7 @@ static CharChunk* AppendChunk(const char* conversion, const char* pending,
   CharChunkList::iterator it;
   comp->MaybeSplitChunkAt(comp->GetLength(), &it);
 
-  CharChunk* chunk = *comp->InsertChunk(&it);
+  CharChunk* chunk = comp->InsertChunk(it)->get();
   chunk->set_conversion(conversion);
   chunk->set_pending(pending);
   chunk->set_raw(raw);
@@ -139,7 +228,7 @@ TEST_F(CompositionTest, GetChunkLength) {
   };
   CharChunk* chunk = AppendChunk("", "", "", composition_.get());
 
-  for (int i = 0; i < arraysize(test_cases); ++i) {
+  for (int i = 0; i < std::size(test_cases); ++i) {
     const TestCase& test = test_cases[i];
     chunk->set_conversion(test.conversion);
     chunk->set_pending(test.pending);
@@ -282,16 +371,14 @@ TEST_F(CompositionTest, SplitRawChunk) {
       {"っ", "ty", "tty", 2, "っ", "t", "tt", "", "y", "y"},
       {"っ", "ty", "tty", 3, "", "", "", "っ", "ty", "tty"},
   };
-  for (int i = 0; i < arraysize(test_cases); ++i) {
+  for (int i = 0; i < std::size(test_cases); ++i) {
     const TestCase& test = test_cases[i];
     CharChunk right_orig_chunk(Transliterators::CONVERSION_STRING, nullptr);
     right_orig_chunk.set_conversion(test.conversion);
     right_orig_chunk.set_pending(test.pending);
     right_orig_chunk.set_raw(test.raw);
-    CharChunk* left_new_chunk_ptr = nullptr;
-    right_orig_chunk.SplitChunk(Transliterators::RAW_STRING, test.position,
-                                &left_new_chunk_ptr);
-    std::unique_ptr<CharChunk> left_new_chunk(left_new_chunk_ptr);
+    std::unique_ptr<CharChunk> left_new_chunk =
+        right_orig_chunk.SplitChunk(Transliterators::RAW_STRING, test.position);
 
     if (left_new_chunk != nullptr) {
       EXPECT_EQ(test.expected_left_conversion, left_new_chunk->conversion());
@@ -327,16 +414,14 @@ TEST_F(CompositionTest, SplitConversionChunk) {
       {"っ", "ty", "tty", 2, "っ", "t", "tt", "", "y", "y"},
       {"っ", "ty", "tty", 3, "", "", "", "っ", "ty", "tty"},
   };
-  for (int i = 0; i < arraysize(test_cases); ++i) {
+  for (int i = 0; i < std::size(test_cases); ++i) {
     const TestCase& test = test_cases[i];
     CharChunk right_orig_chunk(Transliterators::CONVERSION_STRING, nullptr);
     right_orig_chunk.set_conversion(test.conversion);
     right_orig_chunk.set_pending(test.pending);
     right_orig_chunk.set_raw(test.raw);
-    CharChunk* left_new_chunk_ptr = nullptr;
-    right_orig_chunk.SplitChunk(Transliterators::CONVERSION_STRING,
-                                test.position, &left_new_chunk_ptr);
-    std::unique_ptr<CharChunk> left_new_chunk(left_new_chunk_ptr);
+    std::unique_ptr<CharChunk> left_new_chunk = right_orig_chunk.SplitChunk(
+        Transliterators::CONVERSION_STRING, test.position);
 
     if (left_new_chunk != nullptr) {
       EXPECT_EQ(test.expected_left_conversion, left_new_chunk->conversion());
@@ -373,7 +458,7 @@ TEST_F(CompositionTest, MaybeSplitChunkAt) {
       {10, 6, 5}, {11, 5, 5}, {12, 5, 5},
   };
   const size_t dummy_position = 0;
-  for (int i = 0; i < arraysize(test_cases); ++i) {
+  for (int i = 0; i < std::size(test_cases); ++i) {
     const TestCase& test = test_cases[i];
 
     {  // Test RAW mode
@@ -462,21 +547,21 @@ TEST_F(CompositionTest, DeleteAt) {
   EXPECT_EQ("akykittatty", GetDeletedString(Transliterators::RAW_STRING, -1));
 }
 
-TEST_F(CompositionTest, DeleteAt_InvisibleCharacter) {
+TEST_F(CompositionTest, DeleteAtInvisibleCharacter) {
   CharChunkList::iterator it;
   CharChunk* chunk;
 
   composition_->MaybeSplitChunkAt(0, &it);
 
-  chunk = *composition_->InsertChunk(&it);
+  chunk = composition_->InsertChunk(it)->get();
   chunk->set_raw("1");
   chunk->set_pending(Table::ParseSpecialKey("{1}"));
 
-  chunk = *composition_->InsertChunk(&it);
+  chunk = composition_->InsertChunk(it)->get();
   chunk->set_raw("2");
   chunk->set_pending(Table::ParseSpecialKey("{2}2"));
 
-  chunk = *composition_->InsertChunk(&it);
+  chunk = composition_->InsertChunk(it)->get();
   chunk->set_raw("3");
   chunk->set_pending("3");
 
@@ -775,7 +860,7 @@ TEST_F(CompositionTest, InsertKeyAndPreeditAt) {
   EXPECT_EQ("mr@h!", comp_ascii_str);
 }
 
-TEST_F(CompositionTest, InsertKey_ForN) {
+TEST_F(CompositionTest, InsertKeyForN) {
   Table table;
   table.AddRule("a", "[A]", "");
   table.AddRule("n", "[N]", "");
@@ -798,7 +883,7 @@ TEST_F(CompositionTest, InsertKey_ForN) {
   EXPECT_EQ("ny[NYA]", comp_str);
 }
 
-TEST_F(CompositionTest, GetStringWithDisplayMode_ForKana) {
+TEST_F(CompositionTest, GetStringWithDisplayModeForKana) {
   Table table;
   // Empty table is OK.
   composition_->SetTable(&table);
@@ -1128,7 +1213,7 @@ TEST_F(CompositionTest, Issue2990253) {
   }
 }
 
-TEST_F(CompositionTest, InsertionIntoPreeditMakesInvalidText_1) {
+TEST_F(CompositionTest, InsertionIntoPreeditMakesInvalidText1) {
   // http://b/2990358
   // Test for mainly Composition::InsertAt()
 
@@ -1164,7 +1249,7 @@ TEST_F(CompositionTest, InsertionIntoPreeditMakesInvalidText_1) {
   }
 }
 
-TEST_F(CompositionTest, InsertionIntoPreeditMakesInvalidText_2) {
+TEST_F(CompositionTest, InsertionIntoPreeditMakesInvalidText2) {
   // http://b/2990358
   // Test for mainly Composition::InsertKeyAndPreeditAt()
 
@@ -1208,7 +1293,7 @@ TEST_F(CompositionTest, CombinePendingChunks) {
 
     CharChunkList::iterator it;
     comp.MaybeSplitChunkAt(pos, &it);
-    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(&it);
+    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(it);
 
     CompositionInput input;
     SetInput("n", "", false, &input);
@@ -1229,7 +1314,7 @@ TEST_F(CompositionTest, CombinePendingChunks) {
 
     CharChunkList::iterator it;
     comp.MaybeSplitChunkAt(pos, &it);
-    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(&it);
+    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(it);
     CompositionInput input;
     SetInput("n", "", false, &input);
 
@@ -1251,7 +1336,7 @@ TEST_F(CompositionTest, CombinePendingChunks) {
 
     CharChunkList::iterator it;
     comp.MaybeSplitChunkAt(2, &it);
-    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(&it);
+    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(it);
     CompositionInput input;
     SetInput("a", "", false, &input);
 
@@ -1275,7 +1360,7 @@ TEST_F(CompositionTest, CombinePendingChunks) {
 
     CharChunkList::iterator it;
     comp.MaybeSplitChunkAt(3, &it);
-    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(&it);
+    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(it);
     CompositionInput input;
     SetInput("a", "", false, &input);
 
@@ -1300,7 +1385,7 @@ TEST_F(CompositionTest, CombinePendingChunks) {
 
     CharChunkList::iterator it;
     comp.MaybeSplitChunkAt(3, &it);
-    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(&it);
+    CharChunkList::iterator chunk_it = comp.GetInsertionChunk(it);
     CompositionInput input;
     SetInput("x", "a", false, &input);
 
@@ -1675,7 +1760,7 @@ TEST_F(CompositionTest, NoTransliteration) {
   EXPECT_EQ("０1ッカっさった", GetString(*composition_));
 }
 
-TEST_F(CompositionTest, NoTransliteration_Issue3497962) {
+TEST_F(CompositionTest, NoTransliterationIssue3497962) {
   table_->AddRuleWithAttributes("2", "", "a", NEW_CHUNK | NO_TRANSLITERATION);
   table_->AddRuleWithAttributes("a2", "", "b", NO_TABLE_ATTRIBUTE);
   table_->AddRuleWithAttributes("b2", "", "c", NO_TABLE_ATTRIBUTE);
@@ -1700,7 +1785,7 @@ TEST_F(CompositionTest, SetTransliteratorOnEmpty) {
   EXPECT_EQ(1, composition_->GetLength());
 }
 
-TEST_F(CompositionTest, Clone) {
+TEST_F(CompositionTest, Copy) {
   Composition src(table_.get());
   src.SetInputMode(Transliterators::FULL_KATAKANA);
 
@@ -1712,21 +1797,16 @@ TEST_F(CompositionTest, Clone) {
   EXPECT_EQ(Transliterators::FULL_KATAKANA, src.input_t12r());
   EXPECT_EQ(3, src.chunks().size());
 
-  std::unique_ptr<Composition> dest(src.Clone());
-  ASSERT_NE(nullptr, dest.get());
-  EXPECT_EQ(src.table(), dest->table());
-  EXPECT_EQ(src.input_t12r(), dest->input_t12r());
-  ASSERT_EQ(src.chunks().size(), dest->chunks().size());
+  const Composition copy(src);
+  EXPECT_TRUE(IsCompositionEqual(src, copy));
 
-  CharChunkList::const_iterator src_it = src.chunks().begin();
-  CharChunkList::const_iterator dest_it = dest->chunks().begin();
-  for (; src_it != src.chunks().end(); ++src_it, ++dest_it) {
-    EXPECT_EQ((*src_it)->raw(), (*dest_it)->raw());
-  }
+  Composition copy2(nullptr);
+  copy2 = src;
+  EXPECT_TRUE(IsCompositionEqual(src, copy2));
 }
 
 TEST_F(CompositionTest, IsToggleable) {
-  const int kAttrs =
+  constexpr int kAttrs =
       TableAttribute::NEW_CHUNK | TableAttribute::NO_TRANSLITERATION;
   table_->AddRuleWithAttributes("1", "", "{?}あ", kAttrs);
   table_->AddRule("{?}あ1", "", "{*}あ");
