@@ -29,6 +29,8 @@
 
 #include "composer/internal/typing_model.h"
 
+#include <cstdint>
+
 #include "testing/base/public/gunit.h"
 
 namespace mozc {
@@ -38,10 +40,10 @@ class TypingModelTest : public ::testing::Test {};
 
 TEST_F(TypingModelTest, Constructor) {
   const char* characters = "abcd";
-  const uint8 costs[] = {
+  const uint8_t costs[] = {
       0, 1, 2, 3, 4, 5, 6,
   };
-  TypingModel model(characters, strlen(characters), costs, arraysize(costs),
+  TypingModel model(characters, strlen(characters), costs, std::size(costs),
                     nullptr);
   model.character_to_radix_table_['a'] = 1;
   model.character_to_radix_table_['b'] = 2;
@@ -52,10 +54,10 @@ TEST_F(TypingModelTest, Constructor) {
 
 TEST_F(TypingModelTest, GetIndex) {
   const char* characters = "abcd";
-  const uint8 costs[] = {
+  const uint8_t costs[] = {
       0, 1, 2, 3, 4, 5, 6,
   };
-  TypingModel model(characters, strlen(characters), costs, arraysize(costs),
+  TypingModel model(characters, strlen(characters), costs, std::size(costs),
                     nullptr);
   ASSERT_EQ(0, model.GetIndex(""));
   ASSERT_EQ(1, model.GetIndex("a"));
