@@ -29,12 +29,14 @@
 
 #include "composer/key_event_util.h"
 
+#include <cstdint>
 #include <string>
 
 #include "base/util.h"
 #include "composer/key_parser.h"
 #include "protocol/commands.pb.h"
 #include "testing/base/public/gunit.h"
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 using commands::KeyEvent;
@@ -53,12 +55,12 @@ namespace {
       const std::string expected_value =
           (expected_key_code == -1)
               ? "None"
-              : Util::StringPrintf("%c (%d)", expected_key_code,
-                                   expected_key_code);
+              : absl::StrFormat("%c (%d)", expected_key_code,
+                                expected_key_code);
       const std::string actual_value =
           (actual_key_code == -1)
               ? std::string("None")
-              : Util::StringPrintf("%c (%d)", actual_key_code, actual_key_code);
+              : absl::StrFormat("%c (%d)", actual_key_code, actual_key_code);
       return ::testing::AssertionFailure()
              << "Key codes are not same\n"
              << "Expected: " << expected_value << "\n"
@@ -143,27 +145,27 @@ TEST(KeyEventUtilTest, GetKeyInformation) {
   };
 
   KeyEvent key_event;
-  uint64 output;
+  uint64_t output;
 
-  for (size_t i = 0; i < arraysize(kTestKeys); ++i) {
+  for (size_t i = 0; i < std::size(kTestKeys); ++i) {
     SCOPED_TRACE(kTestKeys[i]);
     KeyParser::ParseKey(kTestKeys[i], &key_event);
     ASSERT_TRUE(KeyEventUtil::GetKeyInformation(key_event, &output));
 
-    uint64 expected = 0;
+    uint64_t expected = 0;
     if (key_event.has_key_code()) {
-      expected |= static_cast<uint64>(key_event.key_code());
+      expected |= static_cast<uint64_t>(key_event.key_code());
     }
     if (key_event.has_special_key()) {
-      expected |= static_cast<uint64>(key_event.special_key()) << 32;
+      expected |= static_cast<uint64_t>(key_event.special_key()) << 32;
     }
-    expected |= static_cast<uint64>(KeyEventUtil::GetModifiers(key_event))
+    expected |= static_cast<uint64_t>(KeyEventUtil::GetModifiers(key_event))
                 << 48;
 
     EXPECT_EQ(expected, output);
   }
 
-  const uint32 kEscapeKeyCode = 27;
+  constexpr uint32_t kEscapeKeyCode = 27;
   key_event.Clear();
   key_event.set_key_code(kEscapeKeyCode);
   // Escape key should not set on key_code field.
@@ -232,7 +234,7 @@ TEST(KeyEventUtilTest, NormalizeNumpadKey) {
       {"NUMPAD0 a", "0"},
   };
 
-  for (size_t i = 0; i < arraysize(kNormalizeNumpadKeyTestData); ++i) {
+  for (size_t i = 0; i < std::size(kNormalizeNumpadKeyTestData); ++i) {
     const NormalizeNumpadKeyTestData &data = kNormalizeNumpadKeyTestData[i];
     SCOPED_TRACE(data.from);
 
@@ -254,7 +256,7 @@ TEST(KeyEventUtilTest, MaybeGetKeyStub) {
   KeyParser::ParseKey("Space", &key_event);
   EXPECT_FALSE(KeyEventUtil::MaybeGetKeyStub(key_event, &key));
 
-  const uint32 kEscapeKeyCode = 27;
+  constexpr uint32_t kEscapeKeyCode = 27;
   key_event.Clear();
   key_event.set_key_code(kEscapeKeyCode);
   EXPECT_FALSE(KeyEventUtil::MaybeGetKeyStub(key_event, &key));
@@ -297,15 +299,15 @@ TEST(KeyEventUtilTest, RemoveModifiers) {
       },
   };
 
-  for (size_t i = 0; i < arraysize(kRemoveModifiersTestData); ++i) {
-    SCOPED_TRACE(Util::StringPrintf("index = %d", static_cast<int>(i)));
+  for (size_t i = 0; i < std::size(kRemoveModifiersTestData); ++i) {
+    SCOPED_TRACE(absl::StrFormat("index = %d", static_cast<int>(i)));
     const RemoveModifiersTestData &data = kRemoveModifiersTestData[i];
 
     KeyEvent input, remove, output;
     KeyParser::ParseKey(data.input, &input);
     KeyParser::ParseKey(data.remove, &remove);
     KeyParser::ParseKey(data.output, &output);
-    const uint32 remove_modifiers = KeyEventUtil::GetModifiers(remove);
+    const uint32_t remove_modifiers = KeyEventUtil::GetModifiers(remove);
 
     KeyEvent removed_key_event;
     KeyEventUtil::RemoveModifiers(input, remove_modifiers, &removed_key_event);
@@ -343,7 +345,7 @@ TEST(KeyEventUtilTest, HasModifiers) {
 
 TEST(KeyEventUtilTest, IsModifiers) {
   const struct IsModifiersTestData {
-    uint32 modifiers;
+    uint32_t modifiers;
     bool is_alt;
     bool is_ctrl;
     bool is_shift;
@@ -465,9 +467,9 @@ TEST(KeyEventUtilTest, IsModifiers) {
       },
   };
 
-  for (size_t i = 0; i < arraysize(kIsModifiersTestData); ++i) {
+  for (size_t i = 0; i < std::size(kIsModifiersTestData); ++i) {
     const IsModifiersTestData &data = kIsModifiersTestData[i];
-    SCOPED_TRACE(Util::StringPrintf("index: %d", static_cast<int>(i)));
+    SCOPED_TRACE(absl::StrFormat("index: %d", static_cast<int>(i)));
 
     EXPECT_EQ(data.is_alt, KeyEventUtil::IsAlt(data.modifiers));
     EXPECT_EQ(data.is_ctrl, KeyEventUtil::IsCtrl(data.modifiers));
@@ -498,7 +500,7 @@ TEST(KeyEventUtilTest, IsLowerUpperAlphabet) {
       {"Space", false, false},
   };
 
-  for (size_t i = 0; i < arraysize(kIsLowerUpperAlphabetTestData); ++i) {
+  for (size_t i = 0; i < std::size(kIsLowerUpperAlphabetTestData); ++i) {
     const IsLowerUpperAlphabetTestData &data = kIsLowerUpperAlphabetTestData[i];
     SCOPED_TRACE(data.key);
     KeyEvent key_event;
@@ -519,7 +521,7 @@ TEST(KeyEventUtilTest, IsNumpadKey) {
       {"EQUALS", true},   {"COMMA", true},   {"TEXTINPUT", false},
   };
 
-  for (size_t i = 0; i < arraysize(kIsNumpadKeyTestData); ++i) {
+  for (size_t i = 0; i < std::size(kIsNumpadKeyTestData); ++i) {
     const IsNumpadKeyTestData &data = kIsNumpadKeyTestData[i];
     SCOPED_TRACE(data.key);
     KeyEvent key_event;
