@@ -29,6 +29,7 @@
 
 #include "composer/key_parser.h"
 
+#include <cstdint>
 #include <string>
 #include <utility>
 
@@ -50,14 +51,14 @@ TEST(KeyParserTest, KeyCode) {
   EXPECT_EQ('A', key_event.key_code());
 
   // "あ" (not half width)
-  const char32 kHiraganaA = 0x3042;
+  constexpr char32 kHiraganaA = 0x3042;
   key_event.Clear();
   EXPECT_TRUE(KeyParser::ParseKey("あ", &key_event));
   EXPECT_EQ(kHiraganaA, key_event.key_code());
 }
 
 TEST(KeyParserTest, ModifierKeys) {
-  const std::pair<std::string, uint32> kTestData[] = {
+  const std::pair<std::string, uint32_t> kTestData[] = {
       std::make_pair("ctrl", commands::KeyEvent::CTRL),
       std::make_pair("leftctrl",
                      commands::KeyEvent::CTRL | commands::KeyEvent::LEFT_CTRL),
@@ -83,7 +84,7 @@ TEST(KeyParserTest, ModifierKeys) {
       std::make_pair("SHIFT", commands::KeyEvent::SHIFT),
   };
 
-  for (size_t i = 0; i < arraysize(kTestData); ++i) {
+  for (size_t i = 0; i < std::size(kTestData); ++i) {
     SCOPED_TRACE(kTestData[i].first);
     commands::KeyEvent key_event;
     EXPECT_TRUE(KeyParser::ParseKey(kTestData[i].first, &key_event));
@@ -184,7 +185,7 @@ TEST(KeyParserTest, SpecialKeys) {
       std::make_pair("on", commands::KeyEvent::ON),
   };
 
-  for (size_t i = 0; i < arraysize(kTestData); ++i) {
+  for (size_t i = 0; i < std::size(kTestData); ++i) {
     SCOPED_TRACE(kTestData[i].first);
     commands::KeyEvent key_event;
     EXPECT_TRUE(KeyParser::ParseKey(kTestData[i].first, &key_event));
