@@ -31,6 +31,7 @@
 
 #include "composer/table.h"
 
+#include <cstdint>
 #include <istream>  // NOLINT
 #include <map>
 #include <memory>
@@ -49,14 +50,16 @@
 #include "config/config_handler.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_split.h"
 
 namespace mozc {
 namespace composer {
 namespace {
-const char kDefaultPreeditTableFile[] = "system://romanji-hiragana.tsv";
-const char kRomajiPreeditTableFile[] = "system://romanji-hiragana.tsv";
+constexpr char kDefaultPreeditTableFile[] = "system://romanji-hiragana.tsv";
+constexpr char kRomajiPreeditTableFile[] = "system://romanji-hiragana.tsv";
 // Table for Kana combinations like "か゛" → "が".
-const char kKanaCombinationTableFile[] = "system://kana.tsv";
+constexpr char kKanaCombinationTableFile[] = "system://kana.tsv";
 
 // Special tables for 12keys
 const char k12keysHiraganaTableFile[] = "system://12keys-hiragana.tsv";
@@ -64,38 +67,39 @@ const char k12keysHiraganaIntuitiveTableFile[] =
     "system://12keys-hiragana_intuitive.tsv";
 const char k12keysHalfwidthasciiTableFile[] =
     "system://12keys-halfwidthascii.tsv";
-const char kFlickHiraganaTableFile[] = "system://flick-hiragana.tsv";
-const char kFlickHalfwidthasciiIosTableFile[] =
+constexpr char kFlickHiraganaTableFile[] = "system://flick-hiragana.tsv";
+constexpr char kFlickHalfwidthasciiIosTableFile[] =
     "system://flick-halfwidthascii_ios.tsv";
-const char kFlickNumberTableFile[] = "system://flick-number.tsv";
-const char kFlickHiraganaIntuitiveTableFile[] =
+constexpr char kFlickNumberTableFile[] = "system://flick-number.tsv";
+constexpr char kFlickHiraganaIntuitiveTableFile[] =
     "system://flick-hiragana_intuitive.tsv";
-const char kFlickHalfwidthasciiTableFile[] =
+constexpr char kFlickHalfwidthasciiTableFile[] =
     "system://flick-halfwidthascii.tsv";
-const char kToggleFlickHiraganaTableFile[] =
+constexpr char kToggleFlickHiraganaTableFile[] =
     "system://toggle_flick-hiragana.tsv";
-const char kToggleFlickHiraganaIntuitiveTableFile[] =
+constexpr char kToggleFlickHiraganaIntuitiveTableFile[] =
     "system://toggle_flick-hiragana_intuitive.tsv";
-const char kToggleFlickHalfwidthasciiIosTableFile[] =
+constexpr char kToggleFlickHalfwidthasciiIosTableFile[] =
     "system://toggle_flick-halfwidthascii_ios.tsv";
-const char kToggleFlickNumberTableFile[] = "system://toggle_flick-number.tsv";
-const char kToggleFlickHalfwidthasciiTableFile[] =
+constexpr char kToggleFlickNumberTableFile[] =
+    "system://toggle_flick-number.tsv";
+constexpr char kToggleFlickHalfwidthasciiTableFile[] =
     "system://toggle_flick-halfwidthascii.tsv";
 // Special tables for QWERTY mobile
-const char kQwertyMobileHiraganaTableFile[] =
+constexpr char kQwertyMobileHiraganaTableFile[] =
     "system://qwerty_mobile-hiragana.tsv";
-const char kQwertyMobileHalfwidthasciiTableFile[] =
+constexpr char kQwertyMobileHalfwidthasciiTableFile[] =
     "system://qwerty_mobile-halfwidthascii.tsv";
 // Special tables for Godan
-const char kGodanHiraganaTableFile[] = "system://godan-hiragana.tsv";
-const char kNotouchHiraganaTableFile[] = "system://notouch-hiragana.tsv";
+constexpr char kGodanHiraganaTableFile[] = "system://godan-hiragana.tsv";
+constexpr char kNotouchHiraganaTableFile[] = "system://notouch-hiragana.tsv";
 // Reuse qwerty_mobile-halfwidthascii table
-const char kNotouchHalfwidthasciiTableFile[] =
+constexpr char kNotouchHalfwidthasciiTableFile[] =
     "system://qwerty_mobile-halfwidthascii.tsv";
 
-const char kNewChunkPrefix[] = "\t";
-const char kSpecialKeyOpen[] = "\x0F";   // Shift-In of ASCII
-const char kSpecialKeyClose[] = "\x0E";  // Shift-Out of ASCII
+constexpr char kNewChunkPrefix[] = "\t";
+constexpr char kSpecialKeyOpen[] = "\x0F";   // Shift-In of ASCII
+constexpr char kSpecialKeyClose[] = "\x0E";  // Shift-Out of ASCII
 }  // namespace
 
 // ========================================
@@ -115,17 +119,17 @@ Table::Table() : entries_(new EntryTrie), case_sensitive_(false) {}
 
 Table::~Table() { ResetEntrySet(); }
 
-static const char kKuten[] = "、";
-static const char kTouten[] = "。";
-static const char kComma[] = "，";
-static const char kPeriod[] = "．";
+static constexpr char kKuten[] = "、";
+static constexpr char kTouten[] = "。";
+static constexpr char kComma[] = "，";
+static constexpr char kPeriod[] = "．";
 
-static const char kCornerOpen[] = "「";
-static const char kCornerClose[] = "」";
-static const char kSlash[] = "／";
-static const char kSquareOpen[] = "[";
-static const char kSquareClose[] = "]";
-static const char kMiddleDot[] = "・";
+static constexpr char kCornerOpen[] = "「";
+static constexpr char kCornerClose[] = "」";
+static constexpr char kSlash[] = "／";
+static constexpr char kSquareOpen[] = "[";
+static constexpr char kSquareClose[] = "]";
+static constexpr char kMiddleDot[] = "・";
 
 bool Table::InitializeWithRequestAndConfig(
     const commands::Request &request, const config::Config &config,
@@ -312,7 +316,7 @@ bool Table::IsLoopingEntry(const std::string &input,
   do {
     // If input is a prefix of key, it should be looping.
     // (ex. input="a", pending="abc").
-    if (Util::StartsWith(key, input)) {
+    if (absl::StartsWith(key, input)) {
       return true;
     }
 
@@ -346,7 +350,7 @@ const Entry *Table::AddRuleWithAttributes(const std::string &escaped_input,
                           NO_TABLE_ATTRIBUTE);
   }
 
-  const size_t kMaxSize = 300;
+  constexpr size_t kMaxSize = 300;
   if (escaped_input.size() >= kMaxSize || output.size() >= kMaxSize ||
       escaped_pending.size() >= kMaxSize) {
     LOG(ERROR) << "Invalid input/output/pending";
@@ -417,13 +421,13 @@ bool Table::LoadFromFile(const char *filepath) {
 const TypingModel *Table::typing_model() const { return typing_model_.get(); }
 
 namespace {
-const char kAttributeDelimiter[] = " ";
+constexpr char kAttributeDelimiter = ' ';
 
 TableAttributes ParseAttributes(const std::string &input) {
   TableAttributes attributes = NO_TABLE_ATTRIBUTE;
 
-  std::vector<std::string> attribute_strings;
-  Util::SplitStringAllowEmpty(input, kAttributeDelimiter, &attribute_strings);
+  std::vector<std::string> attribute_strings =
+      absl::StrSplit(input, kAttributeDelimiter, absl::AllowEmpty());
 
   for (size_t i = 0; i < attribute_strings.size(); ++i) {
     if (attribute_strings[i] == "NewChunk") {
@@ -451,8 +455,8 @@ bool Table::LoadFromStream(std::istream *is) {
       continue;
     }
 
-    std::vector<std::string> rules;
-    Util::SplitStringAllowEmpty(line, "\t", &rules);
+    std::vector<std::string> rules =
+        absl::StrSplit(line, '\t', absl::AllowEmpty());
     if (rules.size() == 4) {
       const TableAttributes attributes = ParseAttributes(rules[3]);
       AddRuleWithAttributes(rules[0], rules[1], rules[2], attributes);
@@ -643,7 +647,7 @@ const Table *TableManager::GetTable(
     const mozc::commands::Request &request, const mozc::config::Config &config,
     const mozc::DataManagerInterface &data_manager) {
   // calculate the hash depending on the request and the config
-  uint32 hash = request.special_romanji_table();
+  uint32_t hash = request.special_romanji_table();
   hash = hash * (mozc::config::Config_PreeditMethod_PreeditMethod_MAX + 1) +
          config.preedit_method();
   hash = hash * (mozc::config::Config_PunctuationMethod_PunctuationMethod_MAX +
@@ -656,7 +660,7 @@ const Table *TableManager::GetTable(
   bool update_custom_roman_table = false;
   if ((config.preedit_method() == config::Config::ROMAN) &&
       config.has_custom_roman_table() && !config.custom_roman_table().empty()) {
-    const uint32 custom_roman_table_fingerprint =
+    const uint32_t custom_roman_table_fingerprint =
         Hash::Fingerprint32(config.custom_roman_table());
     if (custom_roman_table_fingerprint != custom_roman_table_fingerprint_) {
       update_custom_roman_table = true;
