@@ -32,16 +32,17 @@
 #ifndef MOZC_COMPOSER_TABLE_H_
 #define MOZC_COMPOSER_TABLE_H_
 
+#include <cstdint>
 #include <map>
 #include <memory>
 #include <set>
 #include <string>
 #include <vector>
 
-#include "base/mozc_hash_set.h"
 #include "base/port.h"
 #include "base/trie.h"
 #include "data_manager/data_manager_interface.h"
+#include "absl/container/flat_hash_set.h"
 
 namespace mozc {
 
@@ -76,7 +77,7 @@ enum TableAttribute {
   // used with the NEW_CHUNK flag.
   END_CHUNK = 8,
 };
-typedef uint32 TableAttributes;
+typedef uint32_t TableAttributes;
 
 class Entry {
  public:
@@ -158,7 +159,7 @@ class Table {
 
   typedef Trie<const Entry *> EntryTrie;
   std::unique_ptr<EntryTrie> entries_;
-  typedef mozc_hash_set<const Entry *> EntrySet;
+  typedef absl::flat_hash_set<const Entry *> EntrySet;
   EntrySet entry_set_;
 
   // If false, input alphabet characters are normalized to lower
@@ -190,9 +191,9 @@ class TableManager {
   //  config::Config::PreeditMethod
   //  config::Config::PunctuationMethod
   //  config::Config::SymbolMethod
-  std::map<uint32, std::unique_ptr<const Table>> table_map_;
+  std::map<uint32_t, std::unique_ptr<const Table>> table_map_;
   // Fingerprint for Config::custom_roman_table;
-  uint32 custom_roman_table_fingerprint_;
+  uint32_t custom_roman_table_fingerprint_;
 };
 
 }  // namespace composer
