@@ -29,8 +29,9 @@
 
 #include "composer/table.h"
 
+#include <string>
+
 #include "base/file_util.h"
-#include "base/mozc_hash_set.h"
 #include "base/port.h"
 #include "base/system_util.h"
 #include "composer/internal/composition_input.h"
@@ -40,6 +41,7 @@
 #include "protocol/config.pb.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/container/flat_hash_set.h"
 
 namespace mozc {
 namespace composer {
@@ -104,7 +106,7 @@ TEST_F(TableTest, LookUp) {
       {"aka", false, "", ""}, {"na", true, "な", ""}, {"n", true, "ん", ""},
       {"nn", true, "ん", ""},
   };
-  static const int size = arraysize(test_cases);
+  static const int size = std::size(test_cases);
 
   Table table;
   InitTable(&table);
@@ -153,7 +155,7 @@ TEST_F(TableTest, Punctuations) {
 
   commands::Request request;
 
-  for (int i = 0; i < arraysize(test_cases); ++i) {
+  for (int i = 0; i < std::size(test_cases); ++i) {
     config::Config config;
     config.set_punctuation_method(test_cases[i].method);
     Table table;
@@ -189,7 +191,7 @@ TEST_F(TableTest, Symbols) {
 
   commands::Request request;
 
-  for (int i = 0; i < arraysize(test_cases); ++i) {
+  for (int i = 0; i < std::size(test_cases); ++i) {
     config::Config config;
     config.set_symbol_method(test_cases[i].method);
     Table table;
@@ -635,11 +637,11 @@ TEST_F(TableTest, CaseSensitiveByConfiguration) {
 // The following test checks if a case-sensitive and a case-inensitive roman
 // table enables and disables this "case-sensitive mode", respectively.
 TEST_F(TableTest, AutomaticCaseSensitiveDetection) {
-  static const char kCaseInsensitiveRomanTable[] = {
+  static constexpr char kCaseInsensitiveRomanTable[] = {
       "m\tmozc\n"    // m -> mozc
       "n\tnamazu\n"  // n -> namazu
   };
-  static const char kCaseSensitiveRomanTable[] = {
+  static constexpr char kCaseSensitiveRomanTable[] = {
       "m\tmozc\n"  // m -> mozc
       "M\tMozc\n"  // M -> Mozc
   };
@@ -997,7 +999,7 @@ TEST_F(TableTest, SpecialKeys) {
 
 TEST_F(TableTest, TableManager) {
   TableManager table_manager;
-  mozc_hash_set<const Table *> table_set;
+  absl::flat_hash_set<const Table *> table_set;
   static const commands::Request::SpecialRomanjiTable special_romanji_table[] =
       {
           commands::Request::DEFAULT_TABLE,
@@ -1024,11 +1026,11 @@ TEST_F(TableTest, TableManager) {
       config::Config::CORNER_BRACKET_SLASH,
       config::Config::SQUARE_BRACKET_MIDDLE_DOT};
 
-  for (int romanji = 0; romanji < arraysize(special_romanji_table); ++romanji) {
-    for (int preedit = 0; preedit < arraysize(preedit_method); ++preedit) {
-      for (int punctuation = 0; punctuation < arraysize(punctuation_method);
+  for (int romanji = 0; romanji < std::size(special_romanji_table); ++romanji) {
+    for (int preedit = 0; preedit < std::size(preedit_method); ++preedit) {
+      for (int punctuation = 0; punctuation < std::size(punctuation_method);
            ++punctuation) {
-        for (int symbol = 0; symbol < arraysize(symbol_method); ++symbol) {
+        for (int symbol = 0; symbol < std::size(symbol_method); ++symbol) {
           commands::Request request;
           request.set_special_romanji_table(special_romanji_table[romanji]);
           config::Config config;
