@@ -30,12 +30,14 @@
 #include "config/character_form_manager.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <map>
 #include <memory>
 #include <string>
 #include <vector>
 
 #include "base/config_file_stream.h"
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/singleton.h"
@@ -43,18 +45,17 @@
 #include "config/config_handler.h"
 #include "protocol/config.pb.h"
 #include "storage/lru_storage.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace config {
 
-using mozc::storage::LRUStorage;
+using mozc::storage::LruStorage;
 
 namespace {
 
-const uint32 kLRUSize = 128;           // enough?
-const uint32 kSeedValue = 0x7fe1fed1;  // random seed value for storage
-const char kFileName[] = "user://cform.db";
+constexpr uint32_t kLruSize = 128;           // enough?
+constexpr uint32_t kSeedValue = 0x7fe1fed1;  // random seed value for storage
+constexpr char kFileName[] = "user://cform.db";
 
 class CharacterFormManagerImpl {
  public:
@@ -85,16 +86,16 @@ class CharacterFormManagerImpl {
   // Call Clear() first if you want to set rule from scratch
   void AddRule(const std::string &key, Config::CharacterForm form);
 
-  void set_storage(LRUStorage *storage) { storage_ = storage; }
+  void set_storage(LruStorage *storage) { storage_ = storage; }
 
   void set_require_consistent_conversion(bool val) {
     require_consistent_conversion_ = val;
   }
 
  private:
-  Config::CharacterForm GetCharacterFormFromStorage(uint16 ucs2) const;
+  Config::CharacterForm GetCharacterFormFromStorage(uint16_t ucs2) const;
 
-  void SaveCharacterFormToStorage(uint16 ucs2, Config::CharacterForm);
+  void SaveCharacterFormToStorage(uint16_t ucs2, Config::CharacterForm);
 
   // Returns true if input string will be consistent character form after
   // conversion.
@@ -110,12 +111,12 @@ class CharacterFormManagerImpl {
   void ConvertStringAlternative(const std::string &str,
                                 std::string *output) const;
 
-  LRUStorage *storage_;
+  LruStorage *storage_;
 
   // store the setting of a character
-  std::map<uint16, Config::CharacterForm> conversion_table_;
+  std::map<uint16_t, Config::CharacterForm> conversion_table_;
 
-  std::map<uint16, std::vector<uint16>> group_table_;
+  std::map<uint16_t, std::vector<uint16_t>> group_table_;
 
   // When this flag is true,
   // character form conversion requires that output has consistent forms.
@@ -190,9 +191,9 @@ class ConversionCharacterFormManagerImpl : public CharacterFormManagerImpl {
 // "&" -> "&"                (Symbol is used as it is)
 // "ほげほげ" -> 0x0000      (Unknown)
 // "𠮟"       -> 0x0000      (Non BMP character is also Unknown)
-uint16 GetNormalizedCharacter(const std::string &str) {
+uint16_t GetNormalizedCharacter(const std::string &str) {
   const Util::ScriptType type = Util::GetScriptType(str);
-  uint16 ucs2 = 0x0000;
+  uint16_t ucs2 = 0x0000;
   switch (type) {
     case Util::KATAKANA:
       ucs2 = 0x30A2;  // return "ア"
@@ -211,10 +212,10 @@ uint16 GetNormalizedCharacter(const std::string &str) {
       if (Util::CharsLen(str) == 1) {  // must be 1 character
         // normalize it to half width
         std::string tmp;
-        Util::HalfWidthToFullWidth(str, &tmp);
+        japanese_util::HalfWidthToFullWidth(str, &tmp);
         char32 ucs4 = 0;
         if (Util::SplitFirstChar32(tmp, &ucs4, nullptr) && ucs4 <= 0xffff) {
-          ucs2 = static_cast<uint16>(ucs4);
+          ucs2 = static_cast<uint16_t>(ucs4);
         } else {
           ucs2 = 0x0000;  // no conversion as fall back
         }
@@ -231,11 +232,11 @@ void ConvertToAlternative(const std::string &input, std::string *output,
     case Util::FULL_WIDTH:
       if (type == Util::KATAKANA ||
           Util::IsFullWidthSymbolInHalfWidthKatakana(input)) {
-        return Util::HalfWidthToFullWidth(input, output);
+        return japanese_util::HalfWidthToFullWidth(input, output);
       }
-      return Util::FullWidthToHalfWidth(input, output);
+      return japanese_util::FullWidthToHalfWidth(input, output);
     case Util::HALF_WIDTH:
-      return Util::HalfWidthToFullWidth(input, output);
+      return japanese_util::HalfWidthToFullWidth(input, output);
     default:
       *output = input;
   }
@@ -248,12 +249,12 @@ CharacterFormManagerImpl::~CharacterFormManagerImpl() {}
 
 Config::CharacterForm CharacterFormManagerImpl::GetCharacterForm(
     const std::string &str) const {
-  const uint16 ucs2 = GetNormalizedCharacter(str);
+  const uint16_t ucs2 = GetNormalizedCharacter(str);
   if (ucs2 == 0x0000) {
     return Config::NO_CONVERSION;
   }
 
-  std::map<uint16, Config::CharacterForm>::const_iterator it =
+  std::map<uint16_t, Config::CharacterForm>::const_iterator it =
       conversion_table_.find(ucs2);
   if (it == conversion_table_.end()) {
     return Config::NO_CONVERSION;
@@ -289,12 +290,12 @@ void CharacterFormManagerImpl::GuessAndSetCharacterForm(
 
 void CharacterFormManagerImpl::SetCharacterForm(const std::string &str,
                                                 Config::CharacterForm form) {
-  const uint16 ucs2 = GetNormalizedCharacter(str);
+  const uint16_t ucs2 = GetNormalizedCharacter(str);
   if (ucs2 == 0x0000) {
     return;
   }
 
-  std::map<uint16, Config::CharacterForm>::const_iterator it =
+  std::map<uint16_t, Config::CharacterForm>::const_iterator it =
       conversion_table_.find(ucs2);
   if (it == conversion_table_.end()) {
     return;
@@ -307,7 +308,7 @@ void CharacterFormManagerImpl::SetCharacterForm(const std::string &str,
 }
 
 Config::CharacterForm CharacterFormManagerImpl::GetCharacterFormFromStorage(
-    uint16 ucs2) const {
+    uint16_t ucs2) const {
   if (storage_ == nullptr) {
     return Config::FULL_WIDTH;  // Return default setting
   }
@@ -316,12 +317,12 @@ Config::CharacterForm CharacterFormManagerImpl::GetCharacterFormFromStorage(
   if (value == nullptr) {
     return Config::FULL_WIDTH;  // Return default setting
   }
-  const uint32 ivalue = *reinterpret_cast<const uint32 *>(value);
+  const uint32_t ivalue = *reinterpret_cast<const uint32_t *>(value);
   return static_cast<Config::CharacterForm>(ivalue);
 }
 
 void CharacterFormManagerImpl::SaveCharacterFormToStorage(
-    uint16 ucs2, Config::CharacterForm form) {
+    uint16_t ucs2, Config::CharacterForm form) {
   if (form != Config::FULL_WIDTH && form != Config::HALF_WIDTH) {
     return;
   }
@@ -337,17 +338,17 @@ void CharacterFormManagerImpl::SaveCharacterFormToStorage(
   }
 
   // Do cast since CharacterForm may not be 32 bit
-  const uint32 iform = static_cast<uint32>(form);
+  const uint32_t iform = static_cast<uint32_t>(form);
 
-  std::map<uint16, std::vector<uint16>>::iterator iter =
+  std::map<uint16_t, std::vector<uint16_t>>::iterator iter =
       group_table_.find(ucs2);
   if (iter == group_table_.end()) {
     storage_->Insert(key, reinterpret_cast<const char *>(&iform));
   } else {
     // Update values in the same group.
-    const std::vector<uint16> &group = iter->second;
+    const std::vector<uint16_t> &group = iter->second;
     for (size_t i = 0; i < group.size(); ++i) {
-      const uint16 group_ucs2 = group[i];
+      const uint16_t group_ucs2 = group[i];
       const std::string group_key(reinterpret_cast<const char *>(&group_ucs2),
                                   sizeof(group_ucs2));
       storage_->Insert(group_key, reinterpret_cast<const char *>(&iform));
@@ -373,9 +374,12 @@ bool CharacterFormManagerImpl::TryConvertStringWithPreference(
 
   std::string buf;
   while (begin < end) {
-    // TODO(team): Replace by iterator.
     size_t mblen = 0;
-    const char32 ucs4 = Util::UTF8ToUCS4(begin, end, &mblen);
+    const char32 ucs4 = Util::Utf8ToUcs4(begin, end, &mblen);
+    if (mblen == 0) {  // Invalid Utf8 string
+      ++begin;
+      continue;
+    }
     const Util::ScriptType type = Util::GetScriptType(ucs4);
     // Cache previous ScriptType to reduce to call GetCharacterForm()
     Config::CharacterForm form = prev_form;
@@ -428,7 +432,7 @@ void CharacterFormManagerImpl::ConvertStringAlternative(
   std::string buf;
   while (begin < end) {
     size_t mblen = 0;
-    const char32 ucs4 = Util::UTF8ToUCS4(begin, end, &mblen);
+    const char32 ucs4 = Util::Utf8ToUcs4(begin, end, &mblen);
     const Util::ScriptType type = Util::GetScriptType(ucs4);
     // Cache previous ScriptType to reduce to call GetFormType()
     Util::FormType form = prev_form;
@@ -495,11 +499,11 @@ void CharacterFormManagerImpl::AddRule(const std::string &key,
   const char *begin = key.c_str();
   const char *end = key.c_str() + key.size();
 
-  std::vector<uint16> group;
+  std::vector<uint16_t> group;
   while (begin < end) {
     const size_t mblen = Util::OneCharLen(begin);
     const std::string tmp(begin, mblen);
-    const uint16 ucs2 = GetNormalizedCharacter(tmp);
+    const uint16_t ucs2 = GetNormalizedCharacter(tmp);
     if (ucs2 != 0x0000) {
       group.push_back(ucs2);
     }
@@ -510,13 +514,13 @@ void CharacterFormManagerImpl::AddRule(const std::string &key,
     return;
   }
 
-  const size_t kMaxGroupSize = 128;
+  constexpr size_t kMaxGroupSize = 128;
   if (group.size() > kMaxGroupSize) {
     LOG(WARNING) << "Too long rule. skipped";
     return;
   }
 
-  const size_t kMaxTableSize = 256;
+  constexpr size_t kMaxTableSize = 256;
   if (conversion_table_.size() + group.size() > kMaxTableSize ||
       group_table_.size() + group.size() > kMaxTableSize) {
     LOG(WARNING) << "conversion_table becomes too big. skipped";
@@ -530,11 +534,12 @@ void CharacterFormManagerImpl::AddRule(const std::string &key,
   // group table is used in SaveCharacterFormToStorage and this will be called
   // everytime user submits conversion.
   std::sort(group.begin(), group.end());
-  std::vector<uint16>::iterator last = std::unique(group.begin(), group.end());
+  std::vector<uint16_t>::iterator last =
+      std::unique(group.begin(), group.end());
   group.erase(last, group.end());
 
   for (size_t i = 0; i < group.size(); ++i) {
-    const uint16 ucs2 = group[i];
+    const uint16_t ucs2 = group[i];
     conversion_table_[ucs2] = form;  // overwrite
     if (group.size() > 1) {
       // add to group table
@@ -557,17 +562,17 @@ class CharacterFormManager::Data {
  private:
   std::unique_ptr<PreeditCharacterFormManagerImpl> preedit_;
   std::unique_ptr<ConversionCharacterFormManagerImpl> conversion_;
-  std::unique_ptr<LRUStorage> storage_;
+  std::unique_ptr<LruStorage> storage_;
 };
 
 CharacterFormManager::Data::Data() {
   const std::string filename = ConfigFileStream::GetFileName(kFileName);
-  const uint32 key_type = 0;
-  storage_.reset(LRUStorage::Create(filename.c_str(), sizeof(key_type),
-                                    kLRUSize, kSeedValue));
+  const uint32_t key_type = 0;
+  storage_.reset(LruStorage::Create(filename.c_str(), sizeof(key_type),
+                                    kLruSize, kSeedValue));
   LOG_IF(ERROR, storage_.get() == nullptr) << "cannot open " << filename;
-  preedit_ = absl::make_unique<PreeditCharacterFormManagerImpl>();
-  conversion_ = absl::make_unique<ConversionCharacterFormManagerImpl>();
+  preedit_ = std::make_unique<PreeditCharacterFormManagerImpl>();
+  conversion_ = std::make_unique<ConversionCharacterFormManagerImpl>();
   preedit_->set_storage(storage_.get());
   conversion_->set_storage(storage_.get());
 }
@@ -605,10 +610,10 @@ void CharacterFormManager::ConvertWidth(const std::string &input,
                                         std::string *output,
                                         Config::CharacterForm form) {
   if (form == Config::FULL_WIDTH) {
-    Util::HalfWidthToFullWidth(input, output);
+    japanese_util::HalfWidthToFullWidth(input, output);
     return;
   } else if (form == Config::HALF_WIDTH) {
-    Util::FullWidthToHalfWidth(input, output);
+    japanese_util::FullWidthToHalfWidth(input, output);
     return;
   }
 
@@ -691,7 +696,7 @@ void CharacterFormManager::SetDefaultRule() {
 }
 
 namespace {
-// Almost the same as UTF8ToUCS4, but skip halfwidth
+// Almost the same as Utf8ToUcs4, but skip halfwidth
 // voice/semi-voice sound mark as they are treated as one character.
 char32 SkipHalfWidthVoiceSoundMark(const char *begin, const char *end,
                                    size_t *mblen) {
@@ -699,7 +704,7 @@ char32 SkipHalfWidthVoiceSoundMark(const char *begin, const char *end,
   *mblen = 0;
   while (begin < end) {
     size_t tmp_mblen = 0;
-    c = Util::UTF8ToUCS4(begin, end, &tmp_mblen);
+    c = Util::Utf8ToUcs4(begin, end, &tmp_mblen);
     CHECK_GT(tmp_mblen, 0);
     *mblen += tmp_mblen;
     begin += tmp_mblen;
