@@ -29,26 +29,30 @@
 
 #include "config/config_handler.h"
 
+#include <cstdint>
+
 #ifdef OS_WIN
 #include <windows.h>
 #endif  // OS_WIN
 
 #include <atomic>
+#include <memory>
 #include <string>
 
 #include "base/file_util.h"
 #include "base/logging.h"
-#include "base/mozc_hash_set.h"
 #include "base/port.h"
 #include "base/system_util.h"
 #include "base/thread.h"
 #include "base/util.h"
 #include "protocol/config.pb.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
+#include "absl/container/flat_hash_set.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 namespace config {
@@ -98,7 +102,7 @@ TEST_F(ConfigHandlerTest, SetConfig) {
 
   const std::string config_file = FileUtil::JoinPath(
       absl::GetFlag(FLAGS_test_tmpdir), "mozc_config_test_tmp");
-  FileUtil::Unlink(config_file);
+  ASSERT_OK(FileUtil::UnlinkIfExists(config_file));
   ScopedSetConfigFileName scoped_config_file_name(config_file);
   EXPECT_EQ(config_file, ConfigHandler::GetConfigFileName());
   ASSERT_TRUE(ConfigHandler::Reload())
@@ -158,7 +162,7 @@ TEST_F(ConfigHandlerTest, SetImposedConfig) {
 
   const std::string config_file = FileUtil::JoinPath(
       absl::GetFlag(FLAGS_test_tmpdir), "mozc_config_test_tmp");
-  FileUtil::Unlink(config_file);
+  ASSERT_OK(FileUtil::UnlinkIfExists(config_file));
   ScopedSetConfigFileName scoped_config_file_name(config_file);
   ASSERT_TRUE(ConfigHandler::Reload())
       << "failed to reload: " << ConfigHandler::GetConfigFileName();
@@ -177,7 +181,7 @@ TEST_F(ConfigHandlerTest, SetImposedConfig) {
       {false, Testcase::DO_NOT_IMPOSE, false},
   };
 
-  for (size_t i = 0; i < arraysize(kTestcases); ++i) {
+  for (size_t i = 0; i < std::size(kTestcases); ++i) {
     const bool stored_config_value = kTestcases[i].stored_config_value;
     const bool expected = kTestcases[i].expected_value;
 
@@ -229,14 +233,14 @@ TEST_F(ConfigHandlerTest, SetImposedConfig) {
 
 TEST_F(ConfigHandlerTest, ConfigFileNameConfig) {
   const std::string config_file =
-      std::string("config") + std::to_string(config::CONFIG_VERSION);
+      std::string("config") + std::to_string(config::CONFIG_VERSION) + ".db";
 
   const std::string filename =
       FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), config_file);
-  FileUtil::Unlink(filename);
+  ASSERT_OK(FileUtil::UnlinkIfExists(filename));
   Config input;
   ConfigHandler::SetConfig(input);
-  FileUtil::FileExists(filename);
+  EXPECT_OK(FileUtil::FileExists(filename));
 }
 
 TEST_F(ConfigHandlerTest, SetConfigFileName) {
@@ -266,13 +270,13 @@ TEST_F(ConfigHandlerTest, LoadTestConfig) {
       "win_config1.db",
   };
 
-  for (size_t i = 0; i < arraysize(kDataFiles); ++i) {
+  for (size_t i = 0; i < std::size(kDataFiles); ++i) {
     const char *file_name = kDataFiles[i];
     const std::string &src_path = mozc::testing::GetSourceFileOrDie(
         {"data", "test", "config", file_name});
     const std::string &dest_path =
         FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(), file_name);
-    ASSERT_TRUE(FileUtil::CopyFile(src_path, dest_path))
+    ASSERT_OK(FileUtil::CopyFile(src_path, dest_path))
         << "Copy failed: " << src_path << " to " << dest_path;
 
     ScopedSetConfigFileName scoped_config_file_name("user://" +
@@ -287,13 +291,13 @@ TEST_F(ConfigHandlerTest, LoadTestConfig) {
 #ifdef OS_WIN
     // Reset the file attributes since it may contain FILE_ATTRIBUTE_READONLY.
     std::wstring wdest_path;
-    Util::UTF8ToWide(dest_path, &wdest_path);
+    Util::Utf8ToWide(dest_path, &wdest_path);
     ::SetFileAttributesW(wdest_path.c_str(), FILE_ATTRIBUTE_NORMAL);
 #endif  // OS_WIN
 
     // Remove test file just in case.
-    ASSERT_TRUE(FileUtil::Unlink(dest_path));
-    EXPECT_FALSE(FileUtil::FileExists(dest_path));
+    ASSERT_OK(FileUtil::Unlink(dest_path));
+    EXPECT_FALSE(FileUtil::FileExists(dest_path).ok());
   }
 }
 #endif  // !OS_ANDROID
@@ -307,9 +311,9 @@ TEST_F(ConfigHandlerTest, GetDefaultConfig) {
   EXPECT_EQ(output.session_keymap(), Config::KOTOERI);
 #elif defined(OS_CHROMEOS)  // __APPLE__
   EXPECT_EQ(output.session_keymap(), Config::CHROMEOS);
-#else                   // __APPLE__ || OS_CHROMEOS
+#else   // __APPLE__ || OS_CHROMEOS
   EXPECT_EQ(output.session_keymap(), Config::MSIME);
-#endif                  // __APPLE__ || OS_CHROMEOS
+#endif  // __APPLE__ || OS_CHROMEOS
   EXPECT_EQ(output.character_form_rules_size(), 13);
 
   struct TestCase {
@@ -335,8 +339,8 @@ TEST_F(ConfigHandlerTest, GetDefaultConfig) {
       {"<>=+-/*", Config::FULL_WIDTH, Config::LAST_FORM},
       {"?!", Config::FULL_WIDTH, Config::LAST_FORM},
   };
-  EXPECT_EQ(output.character_form_rules_size(), arraysize(testcases));
-  for (size_t i = 0; i < arraysize(testcases); ++i) {
+  EXPECT_EQ(output.character_form_rules_size(), std::size(testcases));
+  for (size_t i = 0; i < std::size(testcases); ++i) {
     EXPECT_EQ(output.character_form_rules(i).group(), testcases[i].group);
     EXPECT_EQ(output.character_form_rules(i).preedit_character_form(),
               testcases[i].preedit_character_form);
@@ -391,7 +395,7 @@ std::string ExtractCharacterFormRules(const Config &config) {
 class GetConfigThread final : public Thread {
  public:
   explicit GetConfigThread(
-      const mozc_hash_set<std::string> &character_form_rules_set)
+      const absl::flat_hash_set<std::string> &character_form_rules_set)
       : quitting_(false), character_form_rules_set_(character_form_rules_set) {}
 
   ~GetConfigThread() override {
@@ -412,7 +416,7 @@ class GetConfigThread final : public Thread {
 
  private:
   std::atomic<bool> quitting_;
-  const mozc_hash_set<std::string> character_form_rules_set_;
+  const absl::flat_hash_set<std::string> character_form_rules_set_;
 };
 
 TEST_F(ConfigHandlerTest, ConcurrentAccess) {
@@ -463,7 +467,7 @@ TEST_F(ConfigHandlerTest, ConcurrentAccess) {
   // |GeneralConfig|, the returned object from |ConfigHandler::GetConfig()|
   // is not predictable.  Hence we only make sure that
   // |Config::character_form_rules()| is one of expected values.
-  mozc_hash_set<std::string> character_form_rules_set;
+  absl::flat_hash_set<std::string> character_form_rules_set;
   for (const auto &config : configs) {
     character_form_rules_set.insert(ExtractCharacterFormRules(config));
   }
@@ -486,29 +490,29 @@ TEST_F(ConfigHandlerTest, ConcurrentAccess) {
   // 250 msec is good enough to crash the code if it is not guarded by
   // the lock, but feel free to change the duration.  It is basically an
   // arbitrary number.
-  const uint32 kTestDurationMSec = 250;  // 250 msec
-  const size_t kNumSetThread = 2;
-  const size_t kNumGetThread = 4;
+  constexpr uint32_t kTestDurationMSec = 250;  // 250 msec
+  constexpr size_t kNumSetThread = 2;
+  constexpr size_t kNumGetThread = 4;
   {
     // Set up background threads for concurrent access.
     std::vector<std::unique_ptr<SetConfigThread>> set_threads;
     for (size_t i = 0; i < kNumSetThread; ++i) {
-      set_threads.emplace_back(absl::make_unique<SetConfigThread>(configs));
+      set_threads.emplace_back(std::make_unique<SetConfigThread>(configs));
     }
     std::vector<std::unique_ptr<GetConfigThread>> get_threads;
     for (size_t i = 0; i < kNumGetThread; ++i) {
       get_threads.emplace_back(
-          absl::make_unique<GetConfigThread>(character_form_rules_set));
+          std::make_unique<GetConfigThread>(character_form_rules_set));
     }
     // Let background threads start accessing ConfigHandler from multiple
     // background threads.
     for (size_t i = 0; i < set_threads.size(); ++i) {
       set_threads[i]->Start(
-          Util::StringPrintf("SetConfigThread%d", static_cast<int>(i)));
+          absl::StrFormat("SetConfigThread%d", static_cast<int>(i)));
     }
     for (size_t i = 0; i < get_threads.size(); ++i) {
       get_threads[i]->Start(
-          Util::StringPrintf("GetConfigThread%d", static_cast<int>(i)));
+          absl::StrFormat("GetConfigThread%d", static_cast<int>(i)));
     }
     // Wait for a while to see if everything goes well.
     Util::Sleep(kTestDurationMSec);
