@@ -36,21 +36,20 @@
 #include <shlobj.h>
 #include <time.h>
 #include <windows.h>
-#else
+#else  // OS_WIN
 #include <pwd.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
-#endif
+#endif  // OS_WIN
 
 #ifdef __APPLE__
 #include <fstream>
 #include <string>
 
 #include "base/mac_util.h"
-#include "base/mutex.h"
-#endif
+#endif  // __APPLE__
 
 #if defined(OS_ANDROID)
 #include "config/config_handler.h"
@@ -60,6 +59,7 @@
 #include "base/file_util.h"
 #include "base/singleton.h"
 #include "base/system_util.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 namespace config {
@@ -92,7 +92,7 @@ class WinStatsConfigUtilImpl : public StatsConfigUtilInterface {
 bool WinStatsConfigUtilImpl::IsEnabled() {
 #ifdef CHANNEL_DEV
   return true;
-#else
+#else   // CHANNEL_DEV
   const REGSAM sam_desired =
       KEY_QUERY_VALUE | (SystemUtil::IsWindowsX64() ? KEY_WOW64_32KEY : 0);
   // Like the crash handler, check the "ClientStateMedium" key first.
@@ -129,9 +129,9 @@ bool WinStatsConfigUtilImpl::SetEnabled(bool val) {
   // On Dev channel, usage stats and crash report should be always sent.
   val = true;
   // We always returns true in DevChannel.
-  const bool kReturnCodeInError = true;
-#else
-  const bool kReturnCodeInError = false;
+  constexpr bool kReturnCodeInError = true;
+#else   // CHANNEL_DEV
+  constexpr bool kReturnCodeInError = false;
 #endif  // CHANNEL_DEV
 
   CRegKey key;
@@ -157,15 +157,17 @@ bool WinStatsConfigUtilImpl::SetEnabled(bool val) {
 class MacStatsConfigUtilImpl : public StatsConfigUtilInterface {
  public:
   MacStatsConfigUtilImpl();
-  virtual ~MacStatsConfigUtilImpl() {}
-  virtual bool IsEnabled();
-  virtual bool SetEnabled(bool val);
+
+  MacStatsConfigUtilImpl(const MacStatsConfigUtilImpl &) = delete;
+  MacStatsConfigUtilImpl &operator=(const MacStatsConfigUtilImpl &) = delete;
+
+  ~MacStatsConfigUtilImpl() override = default;
+  bool IsEnabled() override;
+  bool SetEnabled(bool val) override;
 
  private:
-  string config_file_;
-  Mutex mutex_;
-
-  DISALLOW_COPY_AND_ASSIGN(MacStatsConfigUtilImpl);
+  std::string config_file_;
+  absl::Mutex mutex_;
 };
 
 MacStatsConfigUtilImpl::MacStatsConfigUtilImpl() {
@@ -176,9 +178,9 @@ MacStatsConfigUtilImpl::MacStatsConfigUtilImpl() {
 bool MacStatsConfigUtilImpl::IsEnabled() {
 #ifdef CHANNEL_DEV
   return true;
-#else
-  scoped_lock l(&mutex_);
-  const bool kDefaultValue = false;
+#else   // CHANNEL_DEV
+  absl::MutexLock l(&mutex_);
+  constexpr bool kDefaultValue = false;
 
   std::ifstream ifs(config_file_.c_str(), std::ios::binary | std::ios::in);
 
@@ -203,11 +205,11 @@ bool MacStatsConfigUtilImpl::IsEnabled() {
 bool MacStatsConfigUtilImpl::SetEnabled(bool val) {
 #ifdef CHANNEL_DEV
   return true;
-#else
-  scoped_lock l(&mutex_);
+#else   // CHANNEL_DEV
+  absl::MutexLock l(&mutex_);
   const uint32 value = static_cast<uint32>(val);
 
-  if (FileUtil::FileExists(config_file_)) {
+  if (FileUtil::FileExists(config_file_).ok()) {
     ::chmod(config_file_.c_str(), S_IRUSR | S_IWUSR);  // read/write
   }
   std::ofstream ofs(config_file_.c_str(),
@@ -270,10 +272,10 @@ typedef WinStatsConfigUtilImpl DefaultConfigUtilImpl;
 typedef MacStatsConfigUtilImpl DefaultConfigUtilImpl;
 #elif defined(OS_ANDROID)
 typedef AndroidStatsConfigUtilImpl DefaultConfigUtilImpl;
-#else
+#else   // Platforms
 // Fall back mode.  Use null implementation.
 typedef NullStatsConfigUtilImpl DefaultConfigUtilImpl;
-#endif
+#endif  // Platforms
 
 StatsConfigUtilInterface &GetStatsConfigUtil() {
   if (g_stats_config_util_handler == nullptr) {
