@@ -67,9 +67,9 @@ const HKEY kHKLM_ClientState = INT2HKEY(2);
 const HKEY kHKLM_ClientStateMedium = INT2HKEY(3);
 #undef INT2HKEY
 
-const int kRunLevelLow = 0;
-const int kRunLevelMedium = 1;
-const int kRunLevelHigh = 2;
+constexpr int kRunLevelLow = 0;
+constexpr int kRunLevelMedium = 1;
+constexpr int kRunLevelHigh = 2;
 
 bool TryGetKnownKey(HKEY key, LPCWSTR sub_key, HKEY *result_key) {
   HKEY dummy = nullptr;
@@ -671,7 +671,7 @@ TEST(StatsConfigUtilTestWin, IsEnabled) {
 
 #ifdef OS_ANDROID
 TEST(StatsConfigUtilTestAndroid, DefaultValueTest) {
-  const string config_file = FileUtil::JoinPath(
+  const std::string config_file = FileUtil::JoinPath(
       absl::GetFlag(FLAGS_test_tmpdir), "mozc_stats_config_util_test_tmp");
   FileUtil::Unlink(config_file);
   ConfigHandler::SetConfigFileName(config_file);
