@@ -31,11 +31,13 @@
 
 #include <algorithm>
 #include <climits>
+#include <cstdint>
 #include <limits>
 #include <string>
 #include <utility>
 #include <vector>
 
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/number_util.h"
 #include "base/port.h"
@@ -56,11 +58,11 @@
 namespace mozc {
 namespace {
 
-using ::mozc::dictionary::POSMatcher;
+using ::mozc::dictionary::PosMatcher;
 using ::mozc::dictionary::SuppressionDictionary;
 using ::mozc::usage_stats::UsageStats;
 
-const size_t kErrorIndex = static_cast<size_t>(-1);
+constexpr size_t kErrorIndex = static_cast<size_t>(-1);
 
 size_t GetSegmentIndex(const Segments *segments, size_t segment_index) {
   const size_t history_segments_size = segments->history_segments_size();
@@ -85,6 +87,36 @@ void SetKey(Segments *segments, const std::string &key) {
   VLOG(2) << segments->DebugString();
 }
 
+bool ShouldSetKeyForPrediction(const ConversionRequest &request,
+                               const std::string &key,
+                               const Segments &segments) {
+  // (1) If should_call_set_key_in_prediction is true, invoke SetKey.
+  // (2) If the segment size is 0, invoke SetKey because the segments is not
+  //   correctly prepared.
+  //   If the key of the segments differs from the input key,
+  //   invoke SetKey because current segments should be completely reset.
+  // (3) Otherwise keep current key and candidates.
+  //
+  // This SetKey omitting is for mobile predictor.
+  // On normal inputting, we are showing suggestion results. When users
+  // push expansion button, we will add prediction results just after the
+  // suggestion results. For this, we don't reset segments for prediction.
+  // However, we don't have to do so for suggestion. Here, we are deciding
+  // whether the input key is changed or not by using segment key. This is not
+  // perfect because for roman input, conversion key is not updated by
+  // incomplete input, for example, conversion key is "あ" for the input "a",
+  // and will still be "あ" for the input "ak". For avoiding mis-reset of
+  // the results, we will reset always for suggestion request type.
+  if (request.should_call_set_key_in_prediction()) {
+    return true;  // SetKey for (1)
+  }
+  if (segments.conversion_segments_size() == 0 ||
+      segments.conversion_segment(0).key() != key) {
+    return true;  // (2)
+  }
+  return false;  // (3)
+}
+
 bool IsMobile(const ConversionRequest &request) {
   return request.request().zero_query_suggestion() &&
          request.request().mixed_conversion();
@@ -155,7 +187,7 @@ bool ExtractLastTokenWithScriptType(const std::string &text,
   //     build failure on Android is fixed.
   for (std::vector<char32>::reverse_iterator it = reverse_last_token.rbegin();
        it != reverse_last_token.rend(); ++it) {
-    Util::UCS4ToUTF8Append(*it, last_token);
+    Util::Ucs4ToUtf8Append(*it, last_token);
   }
   return true;
 }
@@ -218,16 +250,23 @@ bool TryNormalizingKeyAsMathExpression(absl::string_view s, std::string *key) {
   return true;
 }
 
+ConversionRequest CreateConversionRequestWithType(
+    const ConversionRequest &request, ConversionRequest::RequestType type) {
+  ConversionRequest new_request = request;
+  new_request.set_request_type(type);
+  return new_request;
+}
+
 }  // namespace
 
 ConverterImpl::ConverterImpl()
     : pos_matcher_(nullptr),
       immutable_converter_(nullptr),
-      general_noun_id_(std::numeric_limits<uint16>::max()) {}
+      general_noun_id_(std::numeric_limits<uint16_t>::max()) {}
 
 ConverterImpl::~ConverterImpl() = default;
 
-void ConverterImpl::Init(const POSMatcher *pos_matcher,
+void ConverterImpl::Init(const PosMatcher *pos_matcher,
                          const SuppressionDictionary *suppression_dictionary,
                          std::unique_ptr<PredictorInterface> predictor,
                          std::unique_ptr<RewriterInterface> rewriter,
@@ -241,8 +280,10 @@ void ConverterImpl::Init(const POSMatcher *pos_matcher,
   general_noun_id_ = pos_matcher_->GetGeneralNounId();
 }
 
-bool ConverterImpl::StartConversionForRequest(const ConversionRequest &request,
-                                              Segments *segments) const {
+bool ConverterImpl::StartConversionForRequest(
+    const ConversionRequest &original_request, Segments *segments) const {
+  ConversionRequest request = CreateConversionRequestWithType(
+      original_request, ConversionRequest::CONVERSION);
   if (!request.has_composer()) {
     LOG(ERROR) << "Request doesn't have composer";
     return false;
@@ -263,12 +304,7 @@ bool ConverterImpl::StartConversionForRequest(const ConversionRequest &request,
     return false;
   }
 
-  SetKey(segments, conversion_key);
-  segments->set_request_type(Segments::CONVERSION);
-  immutable_converter_->ConvertForRequest(request, segments);
-  RewriteAndSuppressCandidates(request, segments);
-  TrimCandidates(request, segments);
-  return IsValidSegments(request, *segments);
+  return Convert(request, conversion_key, segments);
 }
 
 bool ConverterImpl::StartConversion(Segments *segments,
@@ -276,13 +312,17 @@ bool ConverterImpl::StartConversion(Segments *segments,
   if (key.empty()) {
     return false;
   }
+  ConversionRequest default_request;
+  return Convert(default_request, key, segments);
+}
+
+bool ConverterImpl::Convert(const ConversionRequest &request,
+                            const std::string &key, Segments *segments) const {
   SetKey(segments, key);
-  segments->set_request_type(Segments::CONVERSION);
-  const ConversionRequest default_request;
-  immutable_converter_->ConvertForRequest(default_request, segments);
-  RewriteAndSuppressCandidates(default_request, segments);
-  TrimCandidates(default_request, segments);
-  return IsValidSegments(default_request, *segments);
+  immutable_converter_->ConvertForRequest(request, segments);
+  RewriteAndSuppressCandidates(request, segments);
+  TrimCandidates(request, segments);
+  return IsValidSegments(request, *segments);
 }
 
 bool ConverterImpl::StartReverseConversion(Segments *segments,
@@ -308,8 +348,9 @@ bool ConverterImpl::StartReverseConversion(Segments *segments,
     }
   }
 
-  segments->set_request_type(Segments::REVERSE_CONVERSION);
-  if (!immutable_converter_->Convert(segments)) {
+  ConversionRequest default_request;
+  default_request.set_request_type(ConversionRequest::REVERSE_CONVERSION);
+  if (!immutable_converter_->ConvertForRequest(default_request, segments)) {
     return false;
   }
   if (segments->segments_size() == 0) {
@@ -354,44 +395,18 @@ void ConverterImpl::MaybeSetConsumedKeySizeToSegment(size_t consumed_key_size,
 
 // TODO(noriyukit): |key| can be a member of ConversionRequest.
 bool ConverterImpl::Predict(const ConversionRequest &request,
-                            const std::string &key,
-                            const Segments::RequestType request_type,
-                            Segments *segments) const {
-  const Segments::RequestType original_request_type = segments->request_type();
-  if ((original_request_type != Segments::PREDICTION &&
-       original_request_type != Segments::PARTIAL_PREDICTION) ||
-      segments->conversion_segments_size() == 0 ||
-      segments->conversion_segment(0).key() != key) {
-    // - If the original request is not prediction relating one
-    //   (e.g. conversion), invoke SetKey because current segments has
-    //   data for conversion, not prediction.
-    // - If the segment size is 0, invoke SetKey because the segments is not
-    //   correctly prepared.
-    // - If the key of the segments differs from the input key,
-    //   invoke SetKey because current segments should be completely reset.
-    // - Otherwise keep current key and candidates.
-    //
-    // This SetKey omitting is for mobile predictor.
-    // On normal inputting, we are showing suggestion results. When users
-    // push expansion button, we will add prediction results just after the
-    // suggestion results. For this, we don't reset segments for prediction.
-    // However, we don't have to do so for suggestion. Here, we are deciding
-    // whether the input key is changed or not by using segment key. This is not
-    // perfect because for roman input, conversion key is not updated by
-    // incomplete input, for example, conversion key is "あ" for the input "a",
-    // and will still be "あ" for the input "ak". For avoiding mis-reset of
-    // the results, we will reset always for suggestion request type.
+                            const std::string &key, Segments *segments) const {
+  if (ShouldSetKeyForPrediction(request, key, *segments)) {
     SetKey(segments, key);
   }
   DCHECK_EQ(1, segments->conversion_segments_size());
   DCHECK_EQ(key, segments->conversion_segment(0).key());
 
-  segments->set_request_type(request_type);
   predictor_->PredictForRequest(request, segments);
   RewriteAndSuppressCandidates(request, segments);
   TrimCandidates(request, segments);
-  if (request_type == Segments::PARTIAL_SUGGESTION ||
-      request_type == Segments::PARTIAL_PREDICTION) {
+  if (request.request_type() == ConversionRequest::PARTIAL_SUGGESTION ||
+      request.request_type() == ConversionRequest::PARTIAL_PREDICTION) {
     // Here 1st segment's key is the query string of
     // the partial prediction/suggestion.
     // e.g. If the composition is "わた|しは", the key is "わた".
@@ -407,8 +422,10 @@ bool ConverterImpl::Predict(const ConversionRequest &request,
   return IsValidSegments(request, *segments);
 }
 
-bool ConverterImpl::StartPredictionForRequest(const ConversionRequest &request,
-                                              Segments *segments) const {
+bool ConverterImpl::StartPredictionForRequest(
+    const ConversionRequest &original_request, Segments *segments) const {
+  ConversionRequest request = CreateConversionRequestWithType(
+      original_request, ConversionRequest::PREDICTION);
   if (!request.has_composer()) {
     LOG(ERROR) << "Composer is nullptr";
     return false;
@@ -416,37 +433,44 @@ bool ConverterImpl::StartPredictionForRequest(const ConversionRequest &request,
 
   std::string prediction_key;
   request.composer().GetQueryForPrediction(&prediction_key);
-  return Predict(request, prediction_key, Segments::PREDICTION, segments);
+  return Predict(request, prediction_key, segments);
 }
 
 bool ConverterImpl::StartPrediction(Segments *segments,
                                     const std::string &key) const {
-  const ConversionRequest default_request;
-  return Predict(default_request, key, Segments::PREDICTION, segments);
+  ConversionRequest default_request;
+  default_request.set_request_type(ConversionRequest::PREDICTION);
+  return Predict(default_request, key, segments);
 }
 
 bool ConverterImpl::StartSuggestion(Segments *segments,
                                     const std::string &key) const {
-  const ConversionRequest default_request;
-  return Predict(default_request, key, Segments::SUGGESTION, segments);
+  ConversionRequest default_request;
+  default_request.set_request_type(ConversionRequest::SUGGESTION);
+  return Predict(default_request, key, segments);
 }
 
-bool ConverterImpl::StartSuggestionForRequest(const ConversionRequest &request,
-                                              Segments *segments) const {
+bool ConverterImpl::StartSuggestionForRequest(
+    const ConversionRequest &original_request, Segments *segments) const {
+  ConversionRequest request = CreateConversionRequestWithType(
+      original_request, ConversionRequest::SUGGESTION);
   DCHECK(request.has_composer());
   std::string prediction_key;
   request.composer().GetQueryForPrediction(&prediction_key);
-  return Predict(request, prediction_key, Segments::SUGGESTION, segments);
+  return Predict(request, prediction_key, segments);
 }
 
 bool ConverterImpl::StartPartialSuggestion(Segments *segments,
                                            const std::string &key) const {
-  const ConversionRequest default_request;
-  return Predict(default_request, key, Segments::PARTIAL_SUGGESTION, segments);
+  ConversionRequest default_request;
+  default_request.set_request_type(ConversionRequest::PARTIAL_SUGGESTION);
+  return Predict(default_request, key, segments);
 }
 
 bool ConverterImpl::StartPartialSuggestionForRequest(
-    const ConversionRequest &request, Segments *segments) const {
+    const ConversionRequest &original_request, Segments *segments) const {
+  ConversionRequest request = CreateConversionRequestWithType(
+      original_request, ConversionRequest::PARTIAL_SUGGESTION);
   DCHECK(request.has_composer());
   const size_t cursor = request.composer().GetCursor();
   if (cursor == 0 || cursor == request.composer().GetLength()) {
@@ -456,18 +480,20 @@ bool ConverterImpl::StartPartialSuggestionForRequest(
   std::string conversion_key;
   request.composer().GetQueryForConversion(&conversion_key);
   conversion_key = std::string(Util::Utf8SubString(conversion_key, 0, cursor));
-  return Predict(request, conversion_key, Segments::PARTIAL_SUGGESTION,
-                 segments);
+  return Predict(request, conversion_key, segments);
 }
 
 bool ConverterImpl::StartPartialPrediction(Segments *segments,
                                            const std::string &key) const {
-  const ConversionRequest default_request;
-  return Predict(default_request, key, Segments::PARTIAL_PREDICTION, segments);
+  ConversionRequest default_request;
+  default_request.set_request_type(ConversionRequest::PARTIAL_PREDICTION);
+  return Predict(default_request, key, segments);
 }
 
 bool ConverterImpl::StartPartialPredictionForRequest(
-    const ConversionRequest &request, Segments *segments) const {
+    const ConversionRequest &original_request, Segments *segments) const {
+  ConversionRequest request = CreateConversionRequestWithType(
+      original_request, ConversionRequest::PARTIAL_PREDICTION);
   DCHECK(request.has_composer());
   const size_t cursor = request.composer().GetCursor();
   if (cursor == 0 || cursor == request.composer().GetLength()) {
@@ -478,8 +504,7 @@ bool ConverterImpl::StartPartialPredictionForRequest(
   request.composer().GetQueryForConversion(&conversion_key);
   conversion_key = std::string(Util::Utf8SubString(conversion_key, 0, cursor));
 
-  return Predict(request, conversion_key, Segments::PARTIAL_PREDICTION,
-                 segments);
+  return Predict(request, conversion_key, segments);
 }
 
 bool ConverterImpl::FinishConversion(const ConversionRequest &request,
@@ -499,7 +524,7 @@ bool ConverterImpl::FinishConversion(const ConversionRequest &request,
       seg->set_segment_type(Segment::FIXED_VALUE);
     }
     if (seg->candidates_size() > 0) {
-      CompletePOSIds(seg->mutable_candidate(0));
+      CompletePosIds(seg->mutable_candidate(0));
     }
   }
 
@@ -509,9 +534,8 @@ bool ConverterImpl::FinishConversion(const ConversionRequest &request,
 
   // Remove the front segments except for some segments which will be
   // used as history segments.
-  const int start_index =
-      std::max(0, static_cast<int>(segments->segments_size() -
-                                   segments->max_history_segments_size()));
+  const int start_index = std::max<int>(
+      0, segments->segments_size() - segments->max_history_segments_size());
   for (int i = 0; i < start_index; ++i) {
     segments->pop_front_segment();
   }
@@ -551,7 +575,7 @@ bool ConverterImpl::ReconstructHistory(
 
   std::string key;
   std::string value;
-  uint16 id;
+  uint16_t id;
   if (!GetLastConnectivePart(preceding_text, &key, &value, &id)) {
     return false;
   }
@@ -644,23 +668,6 @@ bool ConverterImpl::FocusSegmentValue(Segments *segments, size_t segment_index,
   return rewriter_->Focus(segments, segment_index, candidate_index);
 }
 
-bool ConverterImpl::FreeSegmentValue(Segments *segments,
-                                     size_t segment_index) const {
-  segment_index = GetSegmentIndex(segments, segment_index);
-  if (segment_index == kErrorIndex) {
-    return false;
-  }
-
-  Segment *segment = segments->mutable_segment(segment_index);
-  segment->set_segment_type(Segment::FREE);
-
-  if (segments->request_type() != Segments::CONVERSION) {
-    return false;
-  }
-
-  return immutable_converter_->Convert(segments);
-}
-
 bool ConverterImpl::CommitSegments(
     Segments *segments, const std::vector<size_t> &candidate_index) const {
   const size_t conversion_segment_index = segments->history_segments_size();
@@ -681,7 +688,7 @@ bool ConverterImpl::ResizeSegment(Segments *segments,
                                   const ConversionRequest &request,
                                   size_t segment_index,
                                   int offset_length) const {
-  if (segments->request_type() != Segments::CONVERSION) {
+  if (request.request_type() != ConversionRequest::CONVERSION) {
     return false;
   }
 
@@ -759,20 +766,18 @@ bool ConverterImpl::ResizeSegment(Segments *segments,
       Segment *segment2 = segments->mutable_segment(segment_index + 1);
       segment2->set_segment_type(Segment::FREE);
       std::string tmp;
-      Util::Utf8SubString(
-          cur_segment_key,
-          std::max(static_cast<size_t>(0), cur_length + offset_length),
-          cur_length, &tmp);
+      Util::Utf8SubString(cur_segment_key,
+                          std::max<size_t>(0, cur_length + offset_length),
+                          cur_length, &tmp);
       tmp += segment2->key();
       segment2->set_key(tmp);
     } else {
       Segment *segment2 = segments->add_segment();
       segment2->set_segment_type(Segment::FREE);
       std::string new_key;
-      Util::Utf8SubString(
-          cur_segment_key,
-          std::max(static_cast<size_t>(0), cur_length + offset_length),
-          cur_length, &new_key);
+      Util::Utf8SubString(cur_segment_key,
+                          std::max<size_t>(0, cur_length + offset_length),
+                          cur_length, &new_key);
       segment2->set_key(new_key);
     }
   }
@@ -789,13 +794,13 @@ bool ConverterImpl::ResizeSegment(Segments *segments,
                                   const ConversionRequest &request,
                                   size_t start_segment_index,
                                   size_t segments_size,
-                                  const uint8 *new_size_array,
+                                  const uint8_t *new_size_array,
                                   size_t array_size) const {
-  if (segments->request_type() != Segments::CONVERSION) {
+  if (request.request_type() != ConversionRequest::CONVERSION) {
     return false;
   }
 
-  const size_t kMaxArraySize = 256;
+  constexpr size_t kMaxArraySize = 256;
   start_segment_index = GetSegmentIndex(segments, start_segment_index);
   const size_t end_segment_index = start_segment_index + segments_size;
   if (start_segment_index == kErrorIndex ||
@@ -847,7 +852,7 @@ bool ConverterImpl::ResizeSegment(Segments *segments,
   return true;
 }
 
-void ConverterImpl::CompletePOSIds(Segment::Candidate *candidate) const {
+void ConverterImpl::CompletePosIds(Segment::Candidate *candidate) const {
   DCHECK(candidate);
   if (candidate->value.empty() || candidate->key.empty()) {
     return;
@@ -861,13 +866,14 @@ void ConverterImpl::CompletePOSIds(Segment::Candidate *candidate) const {
   // "する" "して", which are not always acceptable for non-sahen words.
   candidate->lid = general_noun_id_;
   candidate->rid = general_noun_id_;
-  const size_t kExpandSizeStart = 5;
-  const size_t kExpandSizeDiff = 50;
-  const size_t kExpandSizeMax = 80;
+  constexpr size_t kExpandSizeStart = 5;
+  constexpr size_t kExpandSizeDiff = 50;
+  constexpr size_t kExpandSizeMax = 80;
   // In almost all cases, user chooses the top candidate.
   // In order to reduce the latency, first, expand 5 candidates.
   // If no valid candidates are found within 5 candidates, expand
   // candidates step-by-step.
+  ConversionRequest request;
   for (size_t size = kExpandSizeStart; size < kExpandSizeMax;
        size += kExpandSizeDiff) {
     Segments segments;
@@ -877,10 +883,10 @@ void ConverterImpl::CompletePOSIds(Segment::Candidate *candidate) const {
     // However, PREDICTION mode produces "predictions", meaning
     // that keys of result candidate are not always the same as
     // query key. It would be nice to have PREDICTION_REALTIME_CONVERSION_ONLY.
-    segments.set_request_type(Segments::PREDICTION);
-    segments.set_max_prediction_candidates_size(size);
-    // In order to complete POSIds, call ImmutableConverter again.
-    if (!immutable_converter_->Convert(&segments)) {
+    request.set_request_type(ConversionRequest::PREDICTION);
+    request.set_max_conversion_candidates_size(size);
+    // In order to complete PosIds, call ImmutableConverter again.
+    if (!immutable_converter_->ConvertForRequest(request, &segments)) {
       LOG(ERROR) << "ImmutableConverter::Convert() failed";
       return;
     }
@@ -947,7 +953,7 @@ void ConverterImpl::TrimCandidates(const ConversionRequest &request,
     const int candidates_size = seg->candidates_size();
     // A segment should have at least one candidate.
     const int candidates_limit =
-        std::max(1, limit - static_cast<int>(seg->meta_candidates_size()));
+        std::max<int>(1, limit - seg->meta_candidates_size());
     if (candidates_size < candidates_limit) {
       continue;
     }
@@ -969,10 +975,11 @@ void ConverterImpl::CommitUsageStats(const Segments *segments,
 
   // Timing stats are scaled by 1,000 to improve the accuracy of average values.
 
-  uint64 submitted_total_length = 0;
+  uint64_t submitted_total_length = 0;
   for (size_t i = 0; i < segment_length; ++i) {
     const Segment &segment = segments->segment(begin_segment_index + i);
-    const uint32 submitted_length = Util::CharsLen(segment.candidate(0).value);
+    const uint32_t submitted_length =
+        Util::CharsLen(segment.candidate(0).value);
     UsageStats::UpdateTiming("SubmittedSegmentLengthx1000",
                              submitted_length * 1000);
     submitted_total_length += submitted_length;
@@ -987,7 +994,7 @@ void ConverterImpl::CommitUsageStats(const Segments *segments,
 
 bool ConverterImpl::GetLastConnectivePart(const std::string &preceding_text,
                                           std::string *key, std::string *value,
-                                          uint16 *id) const {
+                                          uint16_t *id) const {
   key->clear();
   value->clear();
   *id = general_noun_id_;
@@ -1002,13 +1009,13 @@ bool ConverterImpl::GetLastConnectivePart(const std::string &preceding_text,
   // Currently only NUMBER and ALPHABET are supported.
   switch (last_script_type) {
     case Util::NUMBER: {
-      Util::FullWidthAsciiToHalfWidthAscii(last_token, key);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(last_token, key);
       swap(*value, last_token);
       *id = pos_matcher_->GetNumberId();
       return true;
     }
     case Util::ALPHABET: {
-      Util::FullWidthAsciiToHalfWidthAscii(last_token, key);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(last_token, key);
       swap(*value, last_token);
       *id = pos_matcher_->GetUniqueNounId();
       return true;
