@@ -27,6 +27,7 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include <cstdint>
 #include <iostream>
 #include <memory>
 #include <set>
@@ -41,10 +42,11 @@
 #include "base/number_util.h"
 #include "base/port.h"
 #include "base/singleton.h"
+#include "base/status.h"
 #include "base/system_util.h"
-#include "base/util.h"
 #include "composer/composer.h"
 #include "composer/table.h"
+#include "config/config_handler.h"
 #include "converter/converter_interface.h"
 #include "converter/lattice.h"
 #include "converter/pos_id_printer.h"
@@ -56,8 +58,11 @@
 #include "request/conversion_request.h"
 #include "session/request_test_util.h"
 #include "absl/flags/flag.h"
+#include "absl/strings/str_format.h"
+#include "absl/strings/str_join.h"
+#include "absl/strings/str_split.h"
 
-ABSL_FLAG(int32, max_conversion_candidates_size, 200,
+ABSL_FLAG(int32_t, max_conversion_candidates_size, 200,
           "maximum candidates size");
 ABSL_FLAG(std::string, user_profile_dir, "", "path to user profile directory");
 ABSL_FLAG(std::string, engine_name, "default",
@@ -80,10 +85,6 @@ ABSL_FLAG(std::string, id_def, "",
 namespace mozc {
 namespace {
 
-using composer::Composer;
-using composer::Table;
-using config::Config;
-
 // Wrapper class for pos id printing
 class PosIdPrintUtil {
  public:
@@ -101,7 +102,7 @@ class PosIdPrintUtil {
     if (pos_string.empty()) {
       return std::to_string(id);
     }
-    return Util::StringPrintf("%s (%d)", pos_string.c_str(), id);
+    return absl::StrFormat("%s (%d)", pos_string.c_str(), id);
   }
 
   std::unique_ptr<InputFileStream> pos_id_;
@@ -127,7 +128,7 @@ std::string SegmentTypeToString(Segment::SegmentType type) {
 #undef RETURN_STR
 }
 
-std::string CandidateAttributesToString(uint32 attrs) {
+std::string CandidateAttributesToString(uint32_t attrs) {
   std::vector<std::string> v;
 #define ADD_STR(fieldname)                                              \
   do {                                                                  \
@@ -151,9 +152,7 @@ std::string CandidateAttributesToString(uint32 attrs) {
   ADD_STR(USER_HISTORY_PREDICTION);
 
 #undef ADD_STR
-  std::string s;
-  Util::JoinStrings(v, " | ", &s);
-  return s;
+  return absl::StrJoin(v, " | ");
 }
 
 std::string NumberStyleToString(NumberUtil::NumberString::Style style) {
@@ -199,9 +198,7 @@ std::string InnerSegmentBoundaryToString(const Segment::Candidate &cand) {
     s.append(1, '>');
     pieces.push_back(s);
   }
-  std::string s;
-  Util::JoinStrings(pieces, " | ", &s);
-  return s;
+  return absl::StrJoin(pieces, " | ");
 }
 
 void PrintCandidate(const Segment &parent, int num,
@@ -212,9 +209,8 @@ void PrintCandidate(const Segment &parent, int num,
   }
   lines.push_back("content_vk: " + cand.content_value + "  " +
                   cand.content_key);
-  lines.push_back(Util::StringPrintf("cost: %d  scost: %d  wcost: %d",
-                                     cand.cost, cand.structure_cost,
-                                     cand.wcost));
+  lines.push_back(absl::StrFormat("cost: %d  scost: %d  wcost: %d", cand.cost,
+                                  cand.structure_cost, cand.wcost));
   lines.push_back("lid: " + PosIdPrintUtil::IdToString(cand.lid));
   lines.push_back("rid: " + PosIdPrintUtil::IdToString(cand.rid));
   lines.push_back("attr: " + CandidateAttributesToString(cand.attributes));
@@ -254,10 +250,11 @@ void PrintSegments(const Segments &segments, std::ostream *os) {
   }
 }
 
-bool ExecCommand(const ConverterInterface &converter, Segments *segments,
-                 const std::string &line, const commands::Request &request) {
-  std::vector<std::string> fields;
-  Util::SplitStringUsing(line, "\t ", &fields);
+bool ExecCommand(const ConverterInterface &converter, const std::string &line,
+                 const commands::Request &request, config::Config *config,
+                 ConversionRequest *conversion_request, Segments *segments) {
+  std::vector<std::string> fields =
+      absl::StrSplit(line, absl::ByAnyChar("\t "), absl::SkipEmpty());
 
 #define CHECK_FIELDS_LENGTH(length) \
   if (fields.size() < (length)) {   \
@@ -268,18 +265,14 @@ bool ExecCommand(const ConverterInterface &converter, Segments *segments,
 
   const std::string &func = fields[0];
 
-  const Config config;
-
-  segments->set_max_conversion_candidates_size(
-      absl::GetFlag(FLAGS_max_conversion_candidates_size));
+  composer::Composer composer(&composer::Table::GetDefaultTable(), &request,
+                              config);
+  conversion_request->set_composer(&composer);
 
   if (func == "startconversion" || func == "start" || func == "s") {
     CHECK_FIELDS_LENGTH(2);
-    Table table;
-    Composer composer(&table, &request, &config);
     composer.SetPreeditTextForTestOnly(fields[1]);
-    ConversionRequest conversion_request(&composer, &request, &config);
-    return converter.StartConversionForRequest(conversion_request, segments);
+    return converter.StartConversionForRequest(*conversion_request, segments);
   } else if (func == "convertwithnodeinfo" || func == "cn") {
     CHECK_FIELDS_LENGTH(5);
     Lattice::SetDebugDisplayNode(
@@ -293,32 +286,21 @@ bool ExecCommand(const ConverterInterface &converter, Segments *segments,
     CHECK_FIELDS_LENGTH(2);
     return converter.StartReverseConversion(segments, fields[1]);
   } else if (func == "startprediction" || func == "predict" || func == "p") {
-    Table table;
-    Composer composer(&table, &request, &config);
     if (fields.size() >= 2) {
       composer.SetPreeditTextForTestOnly(fields[1]);
-      ConversionRequest conversion_request(&composer, &request, &config);
-      return converter.StartPredictionForRequest(conversion_request, segments);
+      return converter.StartPredictionForRequest(*conversion_request, segments);
     } else {
-      ConversionRequest conversion_request(&composer, &request, &config);
-      return converter.StartPredictionForRequest(conversion_request, segments);
+      return converter.StartPredictionForRequest(*conversion_request, segments);
     }
   } else if (func == "startsuggestion" || func == "suggest") {
-    Table table;
-    Composer composer(&table, &request, &config);
     if (fields.size() >= 2) {
       composer.SetPreeditTextForTestOnly(fields[1]);
-      ConversionRequest conversion_request(&composer, &request, &config);
-      return converter.StartSuggestionForRequest(conversion_request, segments);
+      return converter.StartSuggestionForRequest(*conversion_request, segments);
     } else {
-      ConversionRequest conversion_request(&composer, &request, &config);
-      return converter.StartSuggestionForRequest(conversion_request, segments);
+      return converter.StartSuggestionForRequest(*conversion_request, segments);
     }
   } else if (func == "finishconversion" || func == "finish") {
-    Table table;
-    Composer composer(&table, &request, &config);
-    ConversionRequest conversion_request(&composer, &request, &config);
-    return converter.FinishConversion(conversion_request, segments);
+    return converter.FinishConversion(*conversion_request, segments);
   } else if (func == "resetconversion" || func == "reset") {
     return converter.ResetConversion(segments);
   } else if (func == "cancelconversion" || func == "cancel") {
@@ -335,10 +317,7 @@ bool ExecCommand(const ConverterInterface &converter, Segments *segments,
         if (!(converter.CommitSegmentValue(segments, i, 0))) return false;
       }
     }
-    Table table;
-    Composer composer(&table, &request, &config);
-    ConversionRequest conversion_request(&composer, &request, &config);
-    return converter.FinishConversion(conversion_request, segments);
+    return converter.FinishConversion(*conversion_request, segments);
   } else if (func == "focussegmentvalue" || func == "focus") {
     CHECK_FIELDS_LENGTH(3);
     return converter.FocusSegmentValue(segments,
@@ -349,30 +328,25 @@ bool ExecCommand(const ConverterInterface &converter, Segments *segments,
     std::vector<size_t> singleton_vector;
     singleton_vector.push_back(NumberUtil::SimpleAtoi(fields[1]));
     return converter.CommitSegments(segments, singleton_vector);
-  } else if (func == "freesegmentvalue" || func == "free") {
-    CHECK_FIELDS_LENGTH(2);
-    return converter.FreeSegmentValue(segments,
-                                      NumberUtil::SimpleAtoi(fields[1]));
   } else if (func == "resizesegment" || func == "resize") {
-    const ConversionRequest request;
     if (fields.size() == 3) {
-      return converter.ResizeSegment(segments, request,
+      return converter.ResizeSegment(segments, *conversion_request,
                                      NumberUtil::SimpleAtoi(fields[1]),
                                      NumberUtil::SimpleAtoi(fields[2]));
     } else if (fields.size() > 3) {
-      std::vector<uint8> new_arrays;
+      std::vector<uint8_t> new_arrays;
       for (size_t i = 3; i < fields.size(); ++i) {
         new_arrays.push_back(
-            static_cast<uint8>(NumberUtil::SimpleAtoi(fields[i])));
+            static_cast<uint8_t>(NumberUtil::SimpleAtoi(fields[i])));
       }
       return converter.ResizeSegment(
-          segments, request, NumberUtil::SimpleAtoi(fields[1]),
+          segments, *conversion_request, NumberUtil::SimpleAtoi(fields[1]),
           NumberUtil::SimpleAtoi(fields[2]), &new_arrays[0], new_arrays.size());
     }
   } else if (func == "disableuserhistory") {
-    segments->set_user_history_enabled(false);
+    config->set_history_learning_level(config::Config::NO_HISTORY);
   } else if (func == "enableuserhistory") {
-    segments->set_user_history_enabled(true);
+    config->set_history_learning_level(config::Config::DEFAULT_HISTORY);
   } else {
     LOG(WARNING) << "Unknown command: " << func;
     return false;
@@ -424,7 +398,7 @@ bool IsConsistentEngineNameAndType(const std::string &engine_name,
                                    const std::string &engine_type) {
   using NameAndTypeSet = std::set<std::pair<std::string, std::string>>;
   static const NameAndTypeSet *kConsistentPairs =
-      new NameAndTypeSet({// 
+      new NameAndTypeSet({
                           {"oss", "desktop"},
                           {"mock", "desktop"},
                           {"mock", "mobile"},
@@ -468,17 +442,18 @@ int main(int argc, char **argv) {
             << "\nData file: " << absl::GetFlag(FLAGS_engine_data_path)
             << "\nid.def: " << absl::GetFlag(FLAGS_id_def) << std::endl;
 
-  std::unique_ptr<mozc::DataManager> data_manager(new mozc::DataManager);
-  const auto status = data_manager->InitFromFile(
-      absl::GetFlag(FLAGS_engine_data_path), absl::GetFlag(FLAGS_magic));
-  CHECK_EQ(status, mozc::DataManager::Status::OK);
+  absl::StatusOr<std::unique_ptr<mozc::DataManager>> data_manager =
+      mozc::DataManager::CreateFromFile(absl::GetFlag(FLAGS_engine_data_path),
+                                        absl::GetFlag(FLAGS_magic));
+  CHECK_OK(data_manager);
 
   mozc::commands::Request request;
   std::unique_ptr<mozc::EngineInterface> engine;
   if (absl::GetFlag(FLAGS_engine_type) == "desktop") {
-    engine = mozc::Engine::CreateDesktopEngine(std::move(data_manager)).value();
+    engine =
+        mozc::Engine::CreateDesktopEngine(*std::move(data_manager)).value();
   } else if (absl::GetFlag(FLAGS_engine_type) == "mobile") {
-    engine = mozc::Engine::CreateMobileEngine(std::move(data_manager)).value();
+    engine = mozc::Engine::CreateMobileEngine(*std::move(data_manager)).value();
     mozc::commands::RequestForUnitTest::FillMobileRequest(&request);
   } else {
     LOG(FATAL) << "Invalid type: --engine_type="
@@ -497,8 +472,16 @@ int main(int argc, char **argv) {
   mozc::Segments segments;
   std::string line;
 
+  mozc::config::Config config;
+  mozc::config::ConfigHandler::GetDefaultConfig(&config);
+  mozc::ConversionRequest conversion_request =
+      mozc::ConversionRequest(nullptr, &request, &config);
+  conversion_request.set_max_conversion_candidates_size(
+      absl::GetFlag(FLAGS_max_conversion_candidates_size));
+
   while (!std::getline(std::cin, line).fail()) {
-    if (mozc::ExecCommand(*converter, &segments, line, request)) {
+    if (mozc::ExecCommand(*converter, line, request, &config,
+                          &conversion_request, &segments)) {
       if (absl::GetFlag(FLAGS_output_debug_string)) {
         mozc::PrintSegments(segments, &std::cout);
       }
