@@ -29,6 +29,7 @@
 
 #include "converter/converter_mock.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -36,7 +37,6 @@
 #include "request/conversion_request.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -48,7 +48,7 @@ void SetSegments(Segments *segments, absl::string_view cand_value) {
   Segment::Candidate *candidate = segment->add_candidate();
 #ifdef ABSL_USES_STD_STRING_VIEW
   candidate->value = cand_value;
-#else
+#else   // ABSL_USES_STD_STRING_VIEW
   candidate->value = std::string(cand_value);
 #endif  // ABSL_USES_STD_STRING_VIEW
 
@@ -60,7 +60,7 @@ void SetSegments(Segments *segments, absl::string_view cand_value) {
 
 class ConverterMockTest : public ::testing::Test {
  protected:
-  void SetUp() override { mock_ = absl::make_unique<ConverterMock>(); }
+  void SetUp() override { mock_ = std::make_unique<ConverterMock>(); }
 
   ConverterMock *GetMock() { return mock_.get(); }
 
@@ -196,16 +196,6 @@ TEST_F(ConverterMockTest, SetFocusSegmentValue) {
   EXPECT_EQ(expect.DebugString(), output.DebugString());
 }
 
-TEST_F(ConverterMockTest, SetFreeSegmentValue) {
-  ConverterInterface *converter = GetMock();
-
-  Segments output, expect;
-  SetSegments(&expect, "FreeSegmentValue");
-  GetMock()->SetFreeSegmentValue(&expect, true);
-  EXPECT_TRUE(converter->FreeSegmentValue(&output, 1));
-  EXPECT_EQ(expect.DebugString(), output.DebugString());
-}
-
 TEST_F(ConverterMockTest, SetCommitSegments) {
   ConverterInterface *converter = GetMock();
 
@@ -235,10 +225,10 @@ TEST_F(ConverterMockTest, SetResizeSegment2) {
   Segments output, expect;
   SetSegments(&expect, "ResizeSegment2");
   GetMock()->SetResizeSegment2(&expect, true);
-  uint8 size_array[] = {1, 2, 3};
+  uint8_t size_array[] = {1, 2, 3};
   const ConversionRequest default_request;
   EXPECT_TRUE(converter->ResizeSegment(&output, default_request, 1, 5,
-                                       size_array, arraysize(size_array)));
+                                       size_array, std::size(size_array)));
   EXPECT_EQ(expect.DebugString(), output.DebugString());
 }
 TEST_F(ConverterMockTest, GetStartConversion) {
@@ -437,24 +427,6 @@ TEST_F(ConverterMockTest, GetFocusSegmentValue) {
   EXPECT_EQ(input_cidx, last_cidx);
 }
 
-TEST_F(ConverterMockTest, GetFreeSegmentValue) {
-  ConverterInterface *converter = GetMock();
-
-  Segments input;
-  size_t input_idx = 1;
-  SetSegments(&input, "FreeSegmentValue");
-  const std::string input_str = input.DebugString();
-  converter->FreeSegmentValue(&input, input_idx);
-
-  Segments last_segment;
-  size_t last_idx;
-  GetMock()->GetFreeSegmentValue(&last_segment, &last_idx);
-  const std::string last_segment_str = last_segment.DebugString();
-
-  EXPECT_EQ(input_str, last_segment_str);
-  EXPECT_EQ(input_idx, last_idx);
-}
-
 TEST_F(ConverterMockTest, GetCommitSegments) {
   ConverterInterface *converter = GetMock();
 
@@ -505,16 +477,16 @@ TEST_F(ConverterMockTest, GetResizeSegment2) {
 
   Segments input;
   size_t input_idx = 1, input_size = 3;
-  uint8 input_array[] = {1, 2, 3};
+  uint8_t input_array[] = {1, 2, 3};
   SetSegments(&input, "ResizeSegment2");
   const std::string input_str = input.DebugString();
   const ConversionRequest default_request;
   converter->ResizeSegment(&input, default_request, input_idx, input_size,
-                           input_array, arraysize(input_array));
+                           input_array, std::size(input_array));
 
   Segments last_segment;
   size_t last_idx, last_size;
-  uint8 *last_array;
+  uint8_t *last_array;
   size_t last_array_size;
 
   GetMock()->GetResizeSegment2(&last_segment, &last_idx, &last_size,
@@ -524,8 +496,8 @@ TEST_F(ConverterMockTest, GetResizeSegment2) {
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_idx, last_idx);
   EXPECT_EQ(input_size, last_size);
-  EXPECT_EQ(arraysize(input_array), last_array_size);
-  for (int i = 0; i < arraysize(input_array); ++i) {
+  EXPECT_EQ(std::size(input_array), last_array_size);
+  for (int i = 0; i < std::size(input_array); ++i) {
     EXPECT_EQ(input_array[i], *(last_array + i));
   }
 }
