@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -48,8 +48,6 @@
 namespace mozc {
 namespace {
 
-using commands::Request;
-using composer::Composer;
 using composer::Table;
 
 class ConverterRegressionTest : public ::testing::Test {
@@ -58,7 +56,7 @@ class ConverterRegressionTest : public ::testing::Test {
 };
 
 TEST_F(ConverterRegressionTest, QueryOfDeathTest) {
-  std::unique_ptr<EngineInterface> engine(EngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine = EngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
 
   CHECK(converter);
@@ -89,7 +87,7 @@ TEST_F(ConverterRegressionTest, QueryOfDeathTest) {
 }
 
 TEST_F(ConverterRegressionTest, Regression3323108) {
-  std::unique_ptr<EngineInterface> engine(EngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine = EngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   Segments segments;
 
