@@ -29,6 +29,7 @@
 
 #include "converter/converter.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <vector>
@@ -80,7 +81,6 @@
 #include "transliteration/transliteration.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
-#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -90,7 +90,7 @@ using dictionary::DictionaryImpl;
 using dictionary::DictionaryInterface;
 using dictionary::DictionaryMock;
 using dictionary::PosGroup;
-using dictionary::POSMatcher;
+using dictionary::PosMatcher;
 using dictionary::SuffixDictionary;
 using dictionary::SuppressionDictionary;
 using dictionary::SystemDictionary;
@@ -126,7 +126,7 @@ class StubRewriter : public RewriterInterface {
 SuffixDictionary *CreateSuffixDictionaryFromDataManager(
     const DataManagerInterface &data_manager) {
   absl::string_view suffix_key_array_data, suffix_value_array_data;
-  const uint32 *token_array;
+  const uint32_t *token_array;
   data_manager.GetSuffixDictionaryData(&suffix_key_array_data,
                                        &suffix_value_array_data, &token_array);
   return new SuffixDictionary(suffix_key_array_data, suffix_value_array_data,
@@ -194,7 +194,7 @@ class ConverterTest : public ::testing::Test {
     std::unique_ptr<const SuggestionFilter> suggestion_filter;
     std::unique_ptr<ImmutableConverterInterface> immutable_converter;
     std::unique_ptr<ConverterImpl> converter;
-    dictionary::POSMatcher pos_matcher;
+    dictionary::PosMatcher pos_matcher;
   };
 
   // Returns initialized predictor for the given type.
@@ -204,10 +204,10 @@ class ConverterTest : public ::testing::Test {
   // initializing. Prease see mozc/engine/engine.cc for details.
   // Caller should manage the ownership.
   std::unique_ptr<PredictorInterface> CreatePredictor(
-      PredictorType predictor_type, const POSMatcher *pos_matcher,
+      PredictorType predictor_type, const PosMatcher *pos_matcher,
       const ConverterAndData &converter_and_data) {
     if (predictor_type == STUB_PREDICTOR) {
-      return absl::make_unique<StubPredictor>();
+      return std::make_unique<StubPredictor>();
     }
 
     std::unique_ptr<PredictorInterface> (*predictor_factory)(
@@ -235,7 +235,7 @@ class ConverterTest : public ::testing::Test {
 
     // Create a predictor with three sub-predictors, dictionary predictor, user
     // history predictor, and extra predictor.
-    auto dictionary_predictor = absl::make_unique<DictionaryPredictor>(
+    auto dictionary_predictor = std::make_unique<DictionaryPredictor>(
         *converter_and_data.data_manager, converter_and_data.converter.get(),
         converter_and_data.immutable_converter.get(),
         converter_and_data.dictionary.get(),
@@ -244,7 +244,7 @@ class ConverterTest : public ::testing::Test {
         pos_matcher, converter_and_data.suggestion_filter.get());
     CHECK(dictionary_predictor);
 
-    auto user_history_predictor = absl::make_unique<UserHistoryPredictor>(
+    auto user_history_predictor = std::make_unique<UserHistoryPredictor>(
         converter_and_data.dictionary.get(), pos_matcher,
         converter_and_data.suppression_dictionary.get(),
         enable_content_word_learning);
@@ -264,31 +264,31 @@ class ConverterTest : public ::testing::Test {
       std::unique_ptr<RewriterInterface> rewriter, PredictorType predictor_type,
       ConverterAndData *converter_and_data) {
     converter_and_data->data_manager =
-        absl::make_unique<testing::MockDataManager>();
+        std::make_unique<testing::MockDataManager>();
     const auto &data_manager = *converter_and_data->data_manager;
 
     const char *dictionary_data = nullptr;
     int dictionary_size = 0;
     data_manager.GetSystemDictionaryData(&dictionary_data, &dictionary_size);
 
-    converter_and_data->pos_matcher.Set(data_manager.GetPOSMatcherData());
+    converter_and_data->pos_matcher.Set(data_manager.GetPosMatcherData());
 
     std::unique_ptr<SystemDictionary> sysdic =
         SystemDictionary::Builder(dictionary_data, dictionary_size)
             .Build()
             .value();
-    auto value_dic = absl::make_unique<ValueDictionary>(
+    auto value_dic = std::make_unique<ValueDictionary>(
         converter_and_data->pos_matcher, &sysdic->value_trie());
     converter_and_data->user_dictionary = std::move(user_dictionary);
     converter_and_data->suppression_dictionary =
         std::move(suppression_dictionary);
-    converter_and_data->dictionary = absl::make_unique<DictionaryImpl>(
+    converter_and_data->dictionary = std::make_unique<DictionaryImpl>(
         std::move(sysdic), std::move(value_dic),
         converter_and_data->user_dictionary.get(),
         converter_and_data->suppression_dictionary.get(),
         &converter_and_data->pos_matcher);
     converter_and_data->pos_group =
-        absl::make_unique<PosGroup>(data_manager.GetPosGroupData());
+        std::make_unique<PosGroup>(data_manager.GetPosGroupData());
     converter_and_data->suggestion_filter.reset(
         CreateSuggestionFilter(data_manager));
     converter_and_data->suffix_dictionary.reset(
@@ -298,7 +298,7 @@ class ConverterTest : public ::testing::Test {
     converter_and_data->segmenter.reset(
         Segmenter::CreateFromDataManager(data_manager));
     converter_and_data->immutable_converter =
-        absl::make_unique<ImmutableConverterImpl>(
+        std::make_unique<ImmutableConverterImpl>(
             converter_and_data->dictionary.get(),
             converter_and_data->suffix_dictionary.get(),
             converter_and_data->suppression_dictionary.get(),
@@ -307,7 +307,7 @@ class ConverterTest : public ::testing::Test {
             &converter_and_data->pos_matcher,
             converter_and_data->pos_group.get(),
             converter_and_data->suggestion_filter.get());
-    converter_and_data->converter = absl::make_unique<ConverterImpl>();
+    converter_and_data->converter = std::make_unique<ConverterImpl>();
 
     auto predictor = CreatePredictor(
         predictor_type, &converter_and_data->pos_matcher, *converter_and_data);
@@ -320,21 +320,21 @@ class ConverterTest : public ::testing::Test {
   std::unique_ptr<ConverterAndData> CreateConverterAndData(
       std::unique_ptr<RewriterInterface> rewriter,
       PredictorType predictor_type) {
-    auto ret = absl::make_unique<ConverterAndData>();
-    InitConverterAndData(absl::make_unique<UserDictionaryStub>(),
-                         absl::make_unique<SuppressionDictionary>(),
+    auto ret = std::make_unique<ConverterAndData>();
+    InitConverterAndData(std::make_unique<UserDictionaryStub>(),
+                         std::make_unique<SuppressionDictionary>(),
                          std::move(rewriter), predictor_type, ret.get());
     return ret;
   }
 
   std::unique_ptr<ConverterAndData> CreateStubbedConverterAndData() {
-    return CreateConverterAndData(absl::make_unique<StubRewriter>(),
+    return CreateConverterAndData(std::make_unique<StubRewriter>(),
                                   STUB_PREDICTOR);
   }
 
   std::unique_ptr<ConverterAndData>
   CreateConverterAndDataWithInsertDummyWordsRewriter() {
-    return CreateConverterAndData(absl::make_unique<InsertDummyWordsRewriter>(),
+    return CreateConverterAndData(std::make_unique<InsertDummyWordsRewriter>(),
                                   STUB_PREDICTOR);
   }
 
@@ -343,13 +343,13 @@ class ConverterTest : public ::testing::Test {
       const std::vector<UserDefinedEntry> &user_defined_entries,
       std::unique_ptr<RewriterInterface> rewriter,
       PredictorType predictor_type) {
-    auto ret = absl::make_unique<ConverterAndData>();
+    auto ret = std::make_unique<ConverterAndData>();
 
-    ret->pos_matcher.Set(mock_data_manager_.GetPOSMatcherData());
+    ret->pos_matcher.Set(mock_data_manager_.GetPosMatcherData());
 
-    auto suppression_dictionary = absl::make_unique<SuppressionDictionary>();
-    auto user_dictionary = absl::make_unique<dictionary::UserDictionary>(
-        dictionary::UserPOS::CreateFromDataManager(mock_data_manager_),
+    auto suppression_dictionary = std::make_unique<SuppressionDictionary>();
+    auto user_dictionary = std::make_unique<dictionary::UserDictionary>(
+        dictionary::UserPos::CreateFromDataManager(mock_data_manager_),
         ret->pos_matcher, suppression_dictionary.get());
     {
       user_dictionary::UserDictionaryStorage storage;
@@ -369,10 +369,8 @@ class ConverterTest : public ::testing::Test {
     return ret;
   }
 
-  EngineInterface *CreateEngineWithMobilePredictor() {
-    return Engine::CreateMobileEngineHelper<testing::MockDataManager>()
-        .value()
-        .release();
+  std::unique_ptr<EngineInterface> CreateEngineWithMobilePredictor() {
+    return Engine::CreateMobileEngineHelper<testing::MockDataManager>().value();
   }
 
   bool FindCandidateByValue(absl::string_view value,
@@ -406,7 +404,8 @@ class ConverterTest : public ::testing::Test {
 // just checking whether this causes segmentation fault or not.
 // TODO(toshiyuki): make dictionary mock and test strictly.
 TEST_F(ConverterTest, CanConvertTest) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   {
@@ -423,7 +422,8 @@ namespace {
 std::string ContextAwareConvert(const std::string &first_key,
                                 const std::string &first_value,
                                 const std::string &second_key) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
 
@@ -522,7 +522,8 @@ TEST_F(ConverterTest, ContextAwareConversionTest) {
 }
 
 TEST_F(ConverterTest, CommitSegmentValue) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -574,7 +575,8 @@ TEST_F(ConverterTest, CommitSegmentValue) {
 }
 
 TEST_F(ConverterTest, CommitSegments) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -648,7 +650,8 @@ TEST_F(ConverterTest, CommitSegments) {
 }
 
 TEST_F(ConverterTest, CommitPartialSuggestionSegmentValue) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -694,7 +697,8 @@ TEST_F(ConverterTest, CommitPartialSuggestionSegmentValue) {
 }
 
 TEST_F(ConverterTest, CommitPartialSuggestionUsageStats) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -762,7 +766,8 @@ TEST_F(ConverterTest, CommitPartialSuggestionUsageStats) {
 }
 
 TEST_F(ConverterTest, CommitAutoPartialSuggestionUsageStats) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -814,7 +819,8 @@ TEST_F(ConverterTest, CommitAutoPartialSuggestionUsageStats) {
 }
 
 TEST_F(ConverterTest, CandidateKeyTest) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -825,7 +831,8 @@ TEST_F(ConverterTest, CandidateKeyTest) {
 }
 
 TEST_F(ConverterTest, Regression3437022) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   Segments segments;
 
@@ -889,23 +896,25 @@ TEST_F(ConverterTest, Regression3437022) {
   dic->UnLock();
 }
 
-TEST_F(ConverterTest, CompletePOSIds) {
+TEST_F(ConverterTest, CompletePosIds) {
   const char *kTestKeys[] = {
       "きょうと", "いきます",         "うつくしい",
       "おおきな", "いっちゃわないね", "わたしのなまえはなかのです",
   };
 
-  std::unique_ptr<ConverterAndData> converter_and_data(
-      CreateStubbedConverterAndData());
+  std::unique_ptr<ConverterAndData> converter_and_data =
+      CreateStubbedConverterAndData();
   ConverterImpl *converter = converter_and_data->converter.get();
-  for (size_t i = 0; i < arraysize(kTestKeys); ++i) {
+  for (size_t i = 0; i < std::size(kTestKeys); ++i) {
     Segments segments;
-    segments.set_request_type(Segments::PREDICTION);
     Segment *seg = segments.add_segment();
     seg->set_key(kTestKeys[i]);
     seg->set_segment_type(Segment::FREE);
-    segments.set_max_prediction_candidates_size(20);
-    CHECK(converter_and_data->immutable_converter->Convert(&segments));
+    ConversionRequest request;
+    request.set_request_type(ConversionRequest::PREDICTION);
+    request.set_max_conversion_candidates_size(20);
+    CHECK(converter_and_data->immutable_converter->ConvertForRequest(
+        request, &segments));
     const int lid = segments.segment(0).candidate(0).lid;
     const int rid = segments.segment(0).candidate(0).rid;
     Segment::Candidate candidate;
@@ -913,7 +922,7 @@ TEST_F(ConverterTest, CompletePOSIds) {
     candidate.key = segments.segment(0).candidate(0).key;
     candidate.lid = 0;
     candidate.rid = 0;
-    converter->CompletePOSIds(&candidate);
+    converter->CompletePosIds(&candidate);
     EXPECT_EQ(lid, candidate.lid);
     EXPECT_EQ(rid, candidate.rid);
     EXPECT_NE(candidate.lid, 0);
@@ -926,7 +935,7 @@ TEST_F(ConverterTest, CompletePOSIds) {
     candidate.value = "test";
     candidate.lid = 10;
     candidate.rid = 11;
-    converter->CompletePOSIds(&candidate);
+    converter->CompletePosIds(&candidate);
     EXPECT_EQ(10, candidate.lid);
     EXPECT_EQ(11, candidate.rid);
   }
@@ -934,17 +943,18 @@ TEST_F(ConverterTest, CompletePOSIds) {
 
 TEST_F(ConverterTest, Regression3046266) {
   // Shouldn't correct nodes at the beginning of a sentence.
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   Segments segments;
 
   // Can be any string that has "ん" at the end
-  const char kKey1[] = "かん";
+  constexpr char kKey1[] = "かん";
 
   // Can be any string that has a vowel at the beginning
-  const char kKey2[] = "あか";
+  constexpr char kKey2[] = "あか";
 
-  const char kValueNotExpected[] = "中";
+  constexpr char kValueNotExpected[] = "中";
 
   EXPECT_TRUE(converter->StartConversion(&segments, kKey1));
   EXPECT_EQ(1, segments.conversion_segments_size());
@@ -964,12 +974,13 @@ TEST_F(ConverterTest, Regression3046266) {
 
 TEST_F(ConverterTest, Regression5502496) {
   // Make sure key correction works for the first word of a sentence.
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   Segments segments;
 
-  const char kKey[] = "みんあ";
-  const char kValueExpected[] = "みんな";
+  constexpr char kKey[] = "みんあ";
+  constexpr char kValueExpected[] = "みんな";
 
   EXPECT_TRUE(converter->StartConversion(&segments, kKey));
   EXPECT_EQ(1, segments.conversion_segments_size());
@@ -987,7 +998,8 @@ TEST_F(ConverterTest, StartSuggestionForRequest) {
   commands::Request client_request;
   client_request.set_mixed_conversion(true);
 
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
 
@@ -1004,7 +1016,8 @@ TEST_F(ConverterTest, StartSuggestionForRequest) {
     composer.InsertCharacter("shi");
 
     Segments segments;
-    const ConversionRequest request(&composer, &client_request, &config);
+    ConversionRequest request(&composer, &client_request, &config);
+    request.set_request_type(ConversionRequest::SUGGESTION);
     EXPECT_TRUE(converter->StartSuggestionForRequest(request, &segments));
     EXPECT_EQ(1, segments.segments_size());
     ASSERT_TRUE(segments.segment(0).meta_candidates_size() >=
@@ -1020,7 +1033,8 @@ TEST_F(ConverterTest, StartSuggestionForRequest) {
     composer.InsertCharacter("si");
 
     Segments segments;
-    const ConversionRequest request(&composer, &client_request, &config);
+    ConversionRequest request(&composer, &client_request, &config);
+    request.set_request_type(ConversionRequest::SUGGESTION);
     EXPECT_TRUE(converter->StartSuggestionForRequest(request, &segments));
     EXPECT_EQ(1, segments.segments_size());
     ASSERT_TRUE(segments.segment(0).meta_candidates_size() >=
@@ -1032,7 +1046,8 @@ TEST_F(ConverterTest, StartSuggestionForRequest) {
 }
 
 TEST_F(ConverterTest, StartPartialPrediction) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1043,7 +1058,8 @@ TEST_F(ConverterTest, StartPartialPrediction) {
 }
 
 TEST_F(ConverterTest, StartPartialSuggestion) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1053,8 +1069,8 @@ TEST_F(ConverterTest, StartPartialSuggestion) {
   EXPECT_EQ("わたしは", segments.segment(0).candidate(0).content_key);
 }
 
-TEST_F(ConverterTest, StartPartialPrediction_mobile) {
-  std::unique_ptr<EngineInterface> engine(CreateEngineWithMobilePredictor());
+TEST_F(ConverterTest, StartPartialPredictionMobile) {
+  std::unique_ptr<EngineInterface> engine = CreateEngineWithMobilePredictor();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1064,8 +1080,8 @@ TEST_F(ConverterTest, StartPartialPrediction_mobile) {
   EXPECT_EQ("わたしは", segments.segment(0).candidate(0).content_key);
 }
 
-TEST_F(ConverterTest, StartPartialSuggestion_mobile) {
-  std::unique_ptr<EngineInterface> engine(CreateEngineWithMobilePredictor());
+TEST_F(ConverterTest, StartPartialSuggestionMobile) {
+  std::unique_ptr<EngineInterface> engine = CreateEngineWithMobilePredictor();
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1109,36 +1125,19 @@ TEST_F(ConverterTest, MaybeSetConsumedKeySizeToSegment) {
             segment.meta_candidate(1).consumed_key_size);
 }
 
-TEST_F(ConverterTest, Predict_SetKey) {
-  const char kPredictionKey[] = "prediction key";
-  const char kPredictionKey2[] = "prediction key2";
+TEST_F(ConverterTest, PredictSetKey) {
+  constexpr char kPredictionKey[] = "prediction key";
+  constexpr char kPredictionKey2[] = "prediction key2";
   // Tests whether SetKey method is called or not.
   struct TestData {
-    const Segments::RequestType request_type;
+    const bool should_call_set_key_in_prediction;
     const char *key;
     const bool expect_reset;
   };
   const TestData test_data_list[] = {
-      {Segments::CONVERSION, nullptr, true},
-      {Segments::CONVERSION, kPredictionKey, true},
-      {Segments::CONVERSION, kPredictionKey2, true},
-      {Segments::REVERSE_CONVERSION, nullptr, true},
-      {Segments::REVERSE_CONVERSION, kPredictionKey, true},
-      {Segments::REVERSE_CONVERSION, kPredictionKey2, true},
-      {Segments::PREDICTION, nullptr, true},
-      {Segments::PREDICTION, kPredictionKey2, true},
-      {Segments::SUGGESTION, nullptr, true},
-      {Segments::SUGGESTION, kPredictionKey2, true},
-      {Segments::PARTIAL_PREDICTION, nullptr, true},
-      {Segments::PARTIAL_PREDICTION, kPredictionKey2, true},
-      {Segments::PARTIAL_SUGGESTION, nullptr, true},
-      {Segments::PARTIAL_SUGGESTION, kPredictionKey2, true},
-      // If we are predicting, and one or more segment exists,
-      // and the segments's key equals to the input key, then do not reset.
-      {Segments::PREDICTION, kPredictionKey, false},
-      {Segments::SUGGESTION, kPredictionKey, true},
-      {Segments::PARTIAL_PREDICTION, kPredictionKey, false},
-      {Segments::PARTIAL_SUGGESTION, kPredictionKey, true},
+      {true, nullptr, true},          {true, kPredictionKey, true},
+      {true, kPredictionKey2, true},  {false, nullptr, true},
+      {false, kPredictionKey, false}, {false, kPredictionKey2, true},
   };
 
   std::unique_ptr<ConverterAndData> converter_and_data(
@@ -1148,10 +1147,9 @@ TEST_F(ConverterTest, Predict_SetKey) {
 
   // Note that TearDown method will reset above stubs.
 
-  for (size_t i = 0; i < arraysize(test_data_list); ++i) {
+  for (size_t i = 0; i < std::size(test_data_list); ++i) {
     const TestData &test_data = test_data_list[i];
     Segments segments;
-    segments.set_request_type(test_data.request_type);
 
     if (test_data.key) {
       Segment *seg = segments.add_segment();
@@ -1160,9 +1158,11 @@ TEST_F(ConverterTest, Predict_SetKey) {
       // The segment has a candidate.
       seg->add_candidate();
     }
-    const ConversionRequest request;
-    converter->Predict(request, kPredictionKey, Segments::PREDICTION,
-                       &segments);
+    ConversionRequest request;
+    request.set_request_type(ConversionRequest::PREDICTION);
+    request.set_should_call_set_key_in_prediction(
+        test_data.should_call_set_key_in_prediction);
+    converter->Predict(request, kPredictionKey, &segments);
 
     EXPECT_EQ(1, segments.conversion_segments_size());
     EXPECT_EQ(kPredictionKey, segments.conversion_segment(0).key());
@@ -1174,30 +1174,30 @@ TEST_F(ConverterTest, Predict_SetKey) {
 TEST_F(ConverterTest, VariantExpansionForSuggestion) {
   // Create Converter with mock user dictionary
   testing::MockDataManager data_manager;
-  auto mock_user_dictionary = absl::make_unique<DictionaryMock>();
+  auto mock_user_dictionary = std::make_unique<DictionaryMock>();
 
   mock_user_dictionary->AddLookupPredictive("てすと", "てすと", "<>!?",
                                             Token::USER_DICTIONARY);
   mock_user_dictionary->AddLookupPrefix("てすと", "てすと", "<>!?",
                                         Token::USER_DICTIONARY);
-  auto suppression_dictionary = absl::make_unique<SuppressionDictionary>();
+  auto suppression_dictionary = std::make_unique<SuppressionDictionary>();
 
   const char *dictionary_data = nullptr;
   int dictionary_size = 0;
   data_manager.GetSystemDictionaryData(&dictionary_data, &dictionary_size);
 
-  const dictionary::POSMatcher pos_matcher(data_manager.GetPOSMatcherData());
+  const dictionary::PosMatcher pos_matcher(data_manager.GetPosMatcherData());
 
   std::unique_ptr<SystemDictionary> sysdic =
       SystemDictionary::Builder(dictionary_data, dictionary_size)
           .Build()
           .value();
   auto value_dic =
-      absl::make_unique<ValueDictionary>(pos_matcher, &sysdic->value_trie());
-  auto dictionary = absl::make_unique<DictionaryImpl>(
+      std::make_unique<ValueDictionary>(pos_matcher, &sysdic->value_trie());
+  auto dictionary = std::make_unique<DictionaryImpl>(
       std::move(sysdic), std::move(value_dic), mock_user_dictionary.get(),
       suppression_dictionary.get(), &pos_matcher);
-  auto pos_group = absl::make_unique<PosGroup>(data_manager.GetPosGroupData());
+  PosGroup pos_group(data_manager.GetPosGroupData());
   std::unique_ptr<const DictionaryInterface> suffix_dictionary(
       CreateSuffixDictionaryFromDataManager(data_manager));
   std::unique_ptr<const Connector> connector =
@@ -1206,32 +1206,32 @@ TEST_F(ConverterTest, VariantExpansionForSuggestion) {
       Segmenter::CreateFromDataManager(data_manager));
   std::unique_ptr<const SuggestionFilter> suggestion_filter(
       CreateSuggestionFilter(data_manager));
-  auto immutable_converter = absl::make_unique<ImmutableConverterImpl>(
+  auto immutable_converter = std::make_unique<ImmutableConverterImpl>(
       dictionary.get(), suffix_dictionary.get(), suppression_dictionary.get(),
-      connector.get(), segmenter.get(), &pos_matcher, pos_group.get(),
+      connector.get(), segmenter.get(), &pos_matcher, &pos_group,
       suggestion_filter.get());
   std::unique_ptr<const SuggestionFilter> suggegstion_filter(
       CreateSuggestionFilter(data_manager));
-  auto converter = absl::make_unique<ConverterImpl>();
+  ConverterImpl converter;
   const DictionaryInterface *kNullDictionary = nullptr;
-  converter->Init(
+  converter.Init(
       &pos_matcher, suppression_dictionary.get(),
       DefaultPredictor::CreateDefaultPredictor(
-          absl::make_unique<DictionaryPredictor>(
-              data_manager, converter.get(), immutable_converter.get(),
+          std::make_unique<DictionaryPredictor>(
+              data_manager, &converter, immutable_converter.get(),
               dictionary.get(), suffix_dictionary.get(), connector.get(),
               segmenter.get(), &pos_matcher, suggegstion_filter.get()),
-          absl::make_unique<UserHistoryPredictor>(
-              dictionary.get(), &pos_matcher, suppression_dictionary.get(),
-              false)),
-      absl::make_unique<RewriterImpl>(converter.get(), &data_manager,
-                                      pos_group.get(), kNullDictionary),
+          std::make_unique<UserHistoryPredictor>(dictionary.get(), &pos_matcher,
+                                                 suppression_dictionary.get(),
+                                                 false)),
+      std::make_unique<RewriterImpl>(&converter, &data_manager, &pos_group,
+                                     kNullDictionary),
       immutable_converter.get());
 
   Segments segments;
   {
     // Dictionary suggestion
-    EXPECT_TRUE(converter->StartSuggestion(&segments, "てすと"));
+    EXPECT_TRUE(converter.StartSuggestion(&segments, "てすと"));
     EXPECT_EQ(1, segments.conversion_segments_size());
     EXPECT_LE(1, segments.conversion_segment(0).candidates_size());
     EXPECT_TRUE(FindCandidateByValue("<>!?", segments.conversion_segment(0)));
@@ -1241,7 +1241,7 @@ TEST_F(ConverterTest, VariantExpansionForSuggestion) {
   {
     // Realtime conversion
     segments.Clear();
-    EXPECT_TRUE(converter->StartSuggestion(&segments, "てすとの"));
+    EXPECT_TRUE(converter.StartSuggestion(&segments, "てすとの"));
     EXPECT_EQ(1, segments.conversion_segments_size());
     EXPECT_LE(1, segments.conversion_segment(0).candidates_size());
     EXPECT_TRUE(FindCandidateByValue("<>!?の", segments.conversion_segment(0)));
@@ -1251,7 +1251,8 @@ TEST_F(ConverterTest, VariantExpansionForSuggestion) {
 }
 
 TEST_F(ConverterTest, ComposerKeySelection) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
   composer::Table table;
   config::Config config;
@@ -1306,9 +1307,10 @@ TEST_F(ConverterTest, SuppressionDictionaryForRewriter) {
   }
 }
 
-TEST_F(ConverterTest, EmptyConvertReverse_Issue8661091) {
+TEST_F(ConverterTest, EmptyConvertReverseIssue8661091) {
   // This is a test case against b/8661091.
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
 
   Segments segments;
@@ -1316,7 +1318,8 @@ TEST_F(ConverterTest, EmptyConvertReverse_Issue8661091) {
 }
 
 TEST_F(ConverterTest, StartReverseConversion) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   const ConverterInterface *converter = engine->GetConverter();
 
   const std::string kHonKanji = "本";
@@ -1468,7 +1471,7 @@ TEST_F(ConverterTest, GetLastConnectivePart) {
   {
     std::string key;
     std::string value;
-    uint16 id = 0;
+    uint16_t id = 0;
     EXPECT_FALSE(converter->GetLastConnectivePart("", &key, &value, &id));
     EXPECT_FALSE(converter->GetLastConnectivePart(" ", &key, &value, &id));
     EXPECT_FALSE(converter->GetLastConnectivePart("  ", &key, &value, &id));
@@ -1477,7 +1480,7 @@ TEST_F(ConverterTest, GetLastConnectivePart) {
   {
     std::string key;
     std::string value;
-    uint16 id = 0;
+    uint16_t id = 0;
     EXPECT_TRUE(converter->GetLastConnectivePart("a", &key, &value, &id));
     EXPECT_EQ("a", key);
     EXPECT_EQ("a", value);
@@ -1506,7 +1509,7 @@ TEST_F(ConverterTest, GetLastConnectivePart) {
   {
     std::string key;
     std::string value;
-    uint16 id = 0;
+    uint16_t id = 0;
     EXPECT_TRUE(converter->GetLastConnectivePart("10", &key, &value, &id));
     EXPECT_EQ("10", key);
     EXPECT_EQ("10", value);
@@ -1524,16 +1527,17 @@ TEST_F(ConverterTest, GetLastConnectivePart) {
   {
     std::string key;
     std::string value;
-    uint16 id = 0;
+    uint16_t id = 0;
     EXPECT_FALSE(converter->GetLastConnectivePart("あ", &key, &value, &id));
   }
 }
 
 TEST_F(ConverterTest, ReconstructHistory) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
 
-  const char kTen[] = "１０";
+  constexpr char kTen[] = "１０";
 
   Segments segments;
   EXPECT_TRUE(converter->ReconstructHistory(&segments, kTen));
@@ -1553,7 +1557,8 @@ TEST_F(ConverterTest, ReconstructHistory) {
 }
 
 TEST_F(ConverterTest, LimitCandidatesSize) {
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface *converter = engine->GetConverter();
 
   composer::Table table;
@@ -1602,7 +1607,7 @@ TEST_F(ConverterTest, UserEntryShouldBePromoted) {
 
   std::unique_ptr<ConverterAndData> ret =
       CreateConverterAndDataWithUserDefinedEntries(
-          user_defined_entries, absl::make_unique<StubRewriter>(),
+          user_defined_entries, std::make_unique<StubRewriter>(),
           STUB_PREDICTOR);
 
   ConverterInterface *converter = ret->converter.get();
@@ -1616,7 +1621,7 @@ TEST_F(ConverterTest, UserEntryShouldBePromoted) {
   }
 }
 
-TEST_F(ConverterTest, UserEntryShouldBePromoted_MobilePrediction) {
+TEST_F(ConverterTest, UserEntryShouldBePromotedMobilePrediction) {
   using user_dictionary::UserDictionary;
   std::vector<UserDefinedEntry> user_defined_entries;
   // "哀" is not in the test dictionary
@@ -1625,7 +1630,7 @@ TEST_F(ConverterTest, UserEntryShouldBePromoted_MobilePrediction) {
 
   std::unique_ptr<ConverterAndData> ret =
       CreateConverterAndDataWithUserDefinedEntries(
-          user_defined_entries, absl::make_unique<StubRewriter>(),
+          user_defined_entries, std::make_unique<StubRewriter>(),
           MOBILE_PREDICTOR);
 
   ConverterInterface *converter = ret->converter.get();
@@ -1661,7 +1666,7 @@ TEST_F(ConverterTest, SuppressionEntryShouldBePrioritized) {
 
   std::unique_ptr<ConverterAndData> ret =
       CreateConverterAndDataWithUserDefinedEntries(
-          user_defined_entries, absl::make_unique<StubRewriter>(),
+          user_defined_entries, std::make_unique<StubRewriter>(),
           STUB_PREDICTOR);
 
   ConverterInterface *converter = ret->converter.get();
@@ -1675,7 +1680,7 @@ TEST_F(ConverterTest, SuppressionEntryShouldBePrioritized) {
   }
 }
 
-TEST_F(ConverterTest, SuppressionEntryShouldBePrioritized_Prediction) {
+TEST_F(ConverterTest, SuppressionEntryShouldBePrioritizedPrediction) {
   using user_dictionary::UserDictionary;
   std::vector<UserDefinedEntry> user_defined_entries;
   // "哀" is not in the test dictionary
@@ -1685,10 +1690,10 @@ TEST_F(ConverterTest, SuppressionEntryShouldBePrioritized_Prediction) {
       UserDefinedEntry("あい", "哀", UserDictionary::SUPPRESSION_WORD));
 
   PredictorType types[] = {DEFAULT_PREDICTOR, MOBILE_PREDICTOR};
-  for (int i = 0; i < arraysize(types); ++i) {
+  for (int i = 0; i < std::size(types); ++i) {
     std::unique_ptr<ConverterAndData> ret =
         CreateConverterAndDataWithUserDefinedEntries(
-            user_defined_entries, absl::make_unique<StubRewriter>(), types[i]);
+            user_defined_entries, std::make_unique<StubRewriter>(), types[i]);
     ConverterInterface *converter = ret->converter.get();
     CHECK(converter);
     {
@@ -1709,7 +1714,7 @@ TEST_F(ConverterTest, AbbreviationShouldBeIndependent) {
 
   std::unique_ptr<ConverterAndData> ret =
       CreateConverterAndDataWithUserDefinedEntries(
-          user_defined_entries, absl::make_unique<StubRewriter>(),
+          user_defined_entries, std::make_unique<StubRewriter>(),
           STUB_PREDICTOR);
 
   ConverterInterface *converter = ret->converter.get();
@@ -1723,17 +1728,17 @@ TEST_F(ConverterTest, AbbreviationShouldBeIndependent) {
   }
 }
 
-TEST_F(ConverterTest, AbbreviationShouldBeIndependent_Prediction) {
+TEST_F(ConverterTest, AbbreviationShouldBeIndependentPrediction) {
   using user_dictionary::UserDictionary;
   std::vector<UserDefinedEntry> user_defined_entries;
   user_defined_entries.push_back(
       UserDefinedEntry("じゅ", "Google+", UserDictionary::ABBREVIATION));
 
   PredictorType types[] = {DEFAULT_PREDICTOR, MOBILE_PREDICTOR};
-  for (int i = 0; i < arraysize(types); ++i) {
+  for (int i = 0; i < std::size(types); ++i) {
     std::unique_ptr<ConverterAndData> ret =
         CreateConverterAndDataWithUserDefinedEntries(
-            user_defined_entries, absl::make_unique<StubRewriter>(), types[i]);
+            user_defined_entries, std::make_unique<StubRewriter>(), types[i]);
 
     ConverterInterface *converter = ret->converter.get();
     CHECK(converter);
@@ -1756,7 +1761,7 @@ TEST_F(ConverterTest, SuggestionOnlyShouldBeIndependent) {
 
   std::unique_ptr<ConverterAndData> ret =
       CreateConverterAndDataWithUserDefinedEntries(
-          user_defined_entries, absl::make_unique<StubRewriter>(),
+          user_defined_entries, std::make_unique<StubRewriter>(),
           STUB_PREDICTOR);
 
   ConverterInterface *converter = ret->converter.get();
@@ -1770,17 +1775,17 @@ TEST_F(ConverterTest, SuggestionOnlyShouldBeIndependent) {
   }
 }
 
-TEST_F(ConverterTest, SuggestionOnlyShouldBeIndependent_Prediction) {
+TEST_F(ConverterTest, SuggestionOnlyShouldBeIndependentPrediction) {
   using user_dictionary::UserDictionary;
   std::vector<UserDefinedEntry> user_defined_entries;
   user_defined_entries.push_back(
       UserDefinedEntry("じゅ", "Google+", UserDictionary::SUGGESTION_ONLY));
 
   PredictorType types[] = {DEFAULT_PREDICTOR, MOBILE_PREDICTOR};
-  for (int i = 0; i < arraysize(types); ++i) {
+  for (int i = 0; i < std::size(types); ++i) {
     std::unique_ptr<ConverterAndData> ret =
         CreateConverterAndDataWithUserDefinedEntries(
-            user_defined_entries, absl::make_unique<StubRewriter>(), types[i]);
+            user_defined_entries, std::make_unique<StubRewriter>(), types[i]);
 
     ConverterInterface *converter = ret->converter.get();
     CHECK(converter);
