@@ -30,6 +30,7 @@
 #ifndef MOZC_CONVERTER_IMMUTABLE_CONVERTER_H_
 #define MOZC_CONVERTER_IMMUTABLE_CONVERTER_H_
 
+#include <cstdint>
 #include <string>
 #include <vector>
 
@@ -61,7 +62,7 @@ class ImmutableConverterImpl : public ImmutableConverterInterface {
       const dictionary::DictionaryInterface *suffix_dictionary,
       const dictionary::SuppressionDictionary *suppression_dictionary,
       const Connector *connector, const Segmenter *segmenter,
-      const dictionary::POSMatcher *pos_matcher,
+      const dictionary::PosMatcher *pos_matcher,
       const dictionary::PosGroup *pos_group,
       const SuggestionFilter *suggestion_filter);
   ~ImmutableConverterImpl() override = default;
@@ -95,9 +96,9 @@ class ImmutableConverterImpl : public ImmutableConverterInterface {
     MOBILE,
   };
 
-  void ExpandCandidates(const std::string &original_key, NBestGenerator *nbest,
-                        Segment *segment, Segments::RequestType request_type,
-                        size_t expand_size) const;
+  void ExpandCandidates(const ConversionRequest &request,
+                        const std::string &original_key, NBestGenerator *nbest,
+                        Segment *segment, size_t expand_size) const;
   void InsertDummyCandidates(Segment *segment, size_t expand_size) const;
   Node *Lookup(const int begin_pos, const int end_pos,
                const ConversionRequest &request, bool is_reverse,
@@ -143,35 +144,39 @@ class ImmutableConverterImpl : public ImmutableConverterInterface {
 
   // Inserts first segment from conversion result to candidates.
   // Costs will be modified using the existing candidates.
-  void InsertFirstSegmentToCandidates(Segments *segments,
+  void InsertFirstSegmentToCandidates(const ConversionRequest &request,
+                                      Segments *segments,
                                       const Lattice &lattice,
-                                      const std::vector<uint16> &group,
+                                      const std::vector<uint16_t> &group,
                                       size_t max_candidates_size,
                                       FilterType filter_type,
                                       bool allow_exact) const;
 
-  void InsertCandidates(Segments *segments, const Lattice &lattice,
-                        const std::vector<uint16> &group,
+  void InsertCandidates(const ConversionRequest &request, Segments *segments,
+                        const Lattice &lattice,
+                        const std::vector<uint16_t> &group,
                         size_t max_candidates_size, InsertCandidatesType type,
                         FilterType filter_type) const;
 
   // Helper function for InsertCandidates().
   // Returns true if |node| is valid node for segment end.
-  bool IsSegmentEndNode(const Segments &segments, const Node *node,
-                        const std::vector<uint16> &group,
+  bool IsSegmentEndNode(const ConversionRequest &request,
+                        const Segments &segments, const Node *node,
+                        const std::vector<uint16_t> &group,
                         bool is_single_segment) const;
 
   // Helper function for InsertCandidates().
   // Returns the segment for inserting candidates.
   Segment *GetInsertTargetSegment(const Lattice &lattice,
-                                  const std::vector<uint16> &group,
+                                  const std::vector<uint16_t> &group,
                                   InsertCandidatesType type, size_t begin_pos,
                                   const Node *node, Segments *segments) const;
 
   bool MakeSegments(const ConversionRequest &request, const Lattice &lattice,
-                    const std::vector<uint16> &group, Segments *segments) const;
+                    const std::vector<uint16_t> &group,
+                    Segments *segments) const;
 
-  void MakeGroup(const Segments &segments, std::vector<uint16> *group) const;
+  void MakeGroup(const Segments &segments, std::vector<uint16_t> *group) const;
 
   inline int GetCost(const Node *lnode, const Node *rnode) const {
     const int kInvalidPenaltyCost = 100000;
@@ -187,18 +192,18 @@ class ImmutableConverterImpl : public ImmutableConverterInterface {
   const dictionary::SuppressionDictionary *suppression_dictionary_;
   const Connector *connector_;
   const Segmenter *segmenter_;
-  const dictionary::POSMatcher *pos_matcher_;
+  const dictionary::PosMatcher *pos_matcher_;
   const dictionary::PosGroup *pos_group_;
   const SuggestionFilter *suggestion_filter_;
 
   // Cache for POS ids.
-  const uint16 first_name_id_;
-  const uint16 last_name_id_;
-  const uint16 number_id_;
-  const uint16 unknown_id_;
+  const uint16_t first_name_id_;
+  const uint16_t last_name_id_;
+  const uint16_t number_id_;
+  const uint16_t unknown_id_;
 
   // Cache for transition cost.
-  const int32 last_to_first_name_transition_cost_;
+  const int32_t last_to_first_name_transition_cost_;
 
   DISALLOW_COPY_AND_ASSIGN(ImmutableConverterImpl);
 };
