@@ -29,6 +29,7 @@
 
 #include "converter/immutable_converter.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <utility>
@@ -58,7 +59,7 @@
 #include "request/conversion_request.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/match.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -67,7 +68,6 @@ namespace {
 using dictionary::DictionaryImpl;
 using dictionary::DictionaryInterface;
 using dictionary::PosGroup;
-using dictionary::POSMatcher;
 using dictionary::SuffixDictionary;
 using dictionary::SuppressionDictionary;
 using dictionary::SystemDictionary;
@@ -84,7 +84,7 @@ void SetCandidate(absl::string_view key, absl::string_view value,
   candidate->value = value;
   candidate->content_key = key;
   candidate->content_value = value;
-#else
+#else   // ABSL_USES_STD_STRING_VIEW
   candidate->key = std::string(key);
   candidate->value = std::string(value);
   candidate->content_key = std::string(key);
@@ -92,29 +92,6 @@ void SetCandidate(absl::string_view key, absl::string_view value,
 #endif  // ABSL_USES_STD_STRING_VIEW
 }
 
-const ConversionRequest &GetSimplifiedRankingConversionRequest() {
-  class ConversionRequestInitializer {
-   public:
-    ConversionRequestInitializer() {
-      request_.mutable_decoder_experiment_params()
-          ->set_enable_simplified_ranking(true);
-      conversion_request_ =
-          absl::make_unique<ConversionRequest>(nullptr, &request_, &config_);
-    }
-
-    const ConversionRequest &Get() const { return *conversion_request_; }
-
-   private:
-    std::unique_ptr<ConversionRequest> conversion_request_;
-    commands::Request request_;
-    config::Config config_;
-  };
-
-  static const ConversionRequestInitializer *initializer =
-      new ConversionRequestInitializer;
-  return initializer->Get();
-}
-
 class MockDataAndImmutableConverter {
  public:
   // Initializes data and immutable converter with given dictionaries. If
@@ -124,11 +101,11 @@ class MockDataAndImmutableConverter {
   explicit MockDataAndImmutableConverter(
       const DictionaryInterface *dictionary = nullptr,
       const DictionaryInterface *suffix_dictionary = nullptr) {
-    data_manager_ = absl::make_unique<testing::MockDataManager>();
+    data_manager_ = std::make_unique<testing::MockDataManager>();
 
-    pos_matcher_.Set(data_manager_->GetPOSMatcherData());
+    pos_matcher_.Set(data_manager_->GetPosMatcherData());
 
-    suppression_dictionary_ = absl::make_unique<SuppressionDictionary>();
+    suppression_dictionary_ = std::make_unique<SuppressionDictionary>();
     CHECK(suppression_dictionary_.get());
 
     if (dictionary) {
@@ -142,9 +119,9 @@ class MockDataAndImmutableConverter {
           SystemDictionary::Builder(dictionary_data, dictionary_size)
               .Build()
               .value();
-      auto value_dic = absl::make_unique<ValueDictionary>(
-          pos_matcher_, &sysdic->value_trie());
-      dictionary_ = absl::make_unique<DictionaryImpl>(
+      auto value_dic = std::make_unique<ValueDictionary>(pos_matcher_,
+                                                         &sysdic->value_trie());
+      dictionary_ = std::make_unique<DictionaryImpl>(
           std::move(sysdic), std::move(value_dic), &user_dictionary_stub_,
           suppression_dictionary_.get(), &pos_matcher_);
     }
@@ -152,10 +129,10 @@ class MockDataAndImmutableConverter {
 
     if (!suffix_dictionary) {
       absl::string_view suffix_key_array_data, suffix_value_array_data;
-      const uint32 *token_array;
+      const uint32_t *token_array;
       data_manager_->GetSuffixDictionaryData(
           &suffix_key_array_data, &suffix_value_array_data, &token_array);
-      suffix_dictionary_ = absl::make_unique<SuffixDictionary>(
+      suffix_dictionary_ = std::make_unique<SuffixDictionary>(
           suffix_key_array_data, suffix_value_array_data, token_array);
       suffix_dictionary = suffix_dictionary_.get();
     }
@@ -166,17 +143,17 @@ class MockDataAndImmutableConverter {
     segmenter_.reset(Segmenter::CreateFromDataManager(*data_manager_));
     CHECK(segmenter_.get());
 
-    pos_group_ = absl::make_unique<PosGroup>(data_manager_->GetPosGroupData());
+    pos_group_ = std::make_unique<PosGroup>(data_manager_->GetPosGroupData());
     CHECK(pos_group_.get());
 
     {
       const char *data = nullptr;
       size_t size = 0;
       data_manager_->GetSuggestionFilterData(&data, &size);
-      suggestion_filter_ = absl::make_unique<SuggestionFilter>(data, size);
+      suggestion_filter_ = std::make_unique<SuggestionFilter>(data, size);
     }
 
-    immutable_converter_ = absl::make_unique<ImmutableConverterImpl>(
+    immutable_converter_ = std::make_unique<ImmutableConverterImpl>(
         dictionary_.get(), suffix_dictionary, suppression_dictionary_.get(),
         connector_.get(), segmenter_.get(), &pos_matcher_, pos_group_.get(),
         suggestion_filter_.get());
@@ -196,7 +173,7 @@ class MockDataAndImmutableConverter {
   std::unique_ptr<const SuggestionFilter> suggestion_filter_;
   std::unique_ptr<ImmutableConverterImpl> immutable_converter_;
   UserDictionaryStub user_dictionary_stub_;
-  dictionary::POSMatcher pos_matcher_;
+  dictionary::PosMatcher pos_matcher_;
 };
 
 }  // namespace
@@ -205,12 +182,14 @@ TEST(ImmutableConverterTest, KeepKeyForPrediction) {
   std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
-  segments.set_request_type(Segments::PREDICTION);
-  segments.set_max_prediction_candidates_size(10);
+  ConversionRequest request;
+  request.set_request_type(ConversionRequest::PREDICTION);
+  request.set_max_conversion_candidates_size(10);
   Segment *segment = segments.add_segment();
   const std::string kRequestKey = "よろしくおねがいしま";
   segment->set_key(kRequestKey);
-  EXPECT_TRUE(data_and_converter->GetConverter()->Convert(&segments));
+  EXPECT_TRUE(data_and_converter->GetConverter()->ConvertForRequest(request,
+                                                                    &segments));
   EXPECT_EQ(1, segments.segments_size());
   EXPECT_GT(segments.segment(0).candidates_size(), 0);
   EXPECT_EQ(kRequestKey, segments.segment(0).key());
@@ -335,38 +314,25 @@ TEST(ImmutableConverterTest, AddPredictiveNodes) {
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
   {
-    EXPECT_EQ(segments.request_type(), Segments::CONVERSION);
-    const ConversionRequest request;
+    ConversionRequest request;
+    request.set_request_type(ConversionRequest::CONVERSION);
     converter->MakeLatticeNodesForPredictiveNodes(segments, request, &lattice);
     EXPECT_TRUE(dictionary->received_target_query());
   }
-
-  {
-    dictionary->clear_received_target_query();
-    converter->MakeLatticeNodesForPredictiveNodes(
-        segments, GetSimplifiedRankingConversionRequest(), &lattice);
-    EXPECT_FALSE(dictionary->received_target_query());
-  }
-
-  {
-    segments.set_request_type(Segments::SUGGESTION);
-    dictionary->clear_received_target_query();
-    converter->MakeLatticeNodesForPredictiveNodes(
-        segments, GetSimplifiedRankingConversionRequest(), &lattice);
-    EXPECT_TRUE(dictionary->received_target_query());
-  }
 }
 
 TEST(ImmutableConverterTest, InnerSegmenBoundaryForPrediction) {
   std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
-  segments.set_request_type(Segments::PREDICTION);
-  segments.set_max_prediction_candidates_size(1);
   Segment *segment = segments.add_segment();
   const std::string kRequestKey = "わたしのなまえはなかのです";
   segment->set_key(kRequestKey);
-  EXPECT_TRUE(data_and_converter->GetConverter()->Convert(&segments));
+  ConversionRequest request;
+  request.set_request_type(ConversionRequest::PREDICTION);
+  request.set_max_conversion_candidates_size(1);
+  EXPECT_TRUE(data_and_converter->GetConverter()->ConvertForRequest(request,
+                                                                    &segments));
   ASSERT_EQ(1, segments.segments_size());
   ASSERT_EQ(1, segments.segment(0).candidates_size());
 
@@ -405,7 +371,6 @@ TEST(ImmutableConverterTest, NoInnerSegmenBoundaryForConversion) {
   std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
-  segments.set_request_type(Segments::CONVERSION);
   Segment *segment = segments.add_segment();
   const std::string kRequestKey = "わたしのなまえはなかのです";
   segment->set_key(kRequestKey);
@@ -424,7 +389,6 @@ TEST(ImmutableConverterTest, NotConnectedTest) {
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
   Segments segments;
-  segments.set_request_type(Segments::CONVERSION);
 
   Segment *segment = segments.add_segment();
   segment->set_segment_type(Segment::FIXED_BOUNDARY);
@@ -439,7 +403,7 @@ TEST(ImmutableConverterTest, NotConnectedTest) {
   const ConversionRequest request;
   converter->MakeLattice(request, &segments, &lattice);
 
-  std::vector<uint16> group;
+  std::vector<uint16_t> group;
   converter->MakeGroup(segments, &group);
   converter->Viterbi(segments, &lattice);
 
@@ -479,7 +443,6 @@ TEST(ImmutableConverterTest, HistoryKeyLengthIsVeryLong) {
   }
 
   // Set up a conversion segment.
-  segments.set_request_type(Segments::CONVERSION);
   Segment *segment = segments.add_segment();
   const std::string kRequestKey = "あ";
   segment->set_key(kRequestKey);
@@ -500,13 +463,14 @@ bool AutoPartialSuggestionTestHelper(const ConversionRequest &request) {
   std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
-  segments.set_request_type(Segments::PREDICTION);
-  segments.set_max_prediction_candidates_size(10);
+  ConversionRequest conversion_request = request;
+  conversion_request.set_request_type(ConversionRequest::PREDICTION);
+  conversion_request.set_max_conversion_candidates_size(10);
   Segment *segment = segments.add_segment();
   const std::string kRequestKey = "わたしのなまえはなかのです";
   segment->set_key(kRequestKey);
-  EXPECT_TRUE(data_and_converter->GetConverter()->ConvertForRequest(request,
-                                                                    &segments));
+  EXPECT_TRUE(data_and_converter->GetConverter()->ConvertForRequest(
+      conversion_request, &segments));
   EXPECT_EQ(1, segments.conversion_segments_size());
   EXPECT_LT(0, segments.segment(0).candidates_size());
   bool includes_only_first = false;
@@ -514,7 +478,7 @@ bool AutoPartialSuggestionTestHelper(const ConversionRequest &request) {
   for (size_t i = 0; i < segments.segment(0).candidates_size(); ++i) {
     const Segment::Candidate &cand = segments.segment(0).candidate(i);
     if (cand.key.size() < segment_key.size() &&
-        Util::StartsWith(segment_key, cand.key)) {
+        absl::StartsWith(segment_key, cand.key)) {
       includes_only_first = true;
       break;
     }
@@ -552,8 +516,10 @@ TEST(ImmutableConverterTest, AutoPartialSuggestionDefault) {
 TEST(ImmutableConverterTest, AutoPartialSuggestionForSingleSegment) {
   const commands::Request request;
   ConversionRequest conversion_request;
+  conversion_request.set_request_type(ConversionRequest::PREDICTION);
   conversion_request.set_request(&request);
   conversion_request.set_create_partial_candidates(true);
+  conversion_request.set_max_conversion_candidates_size(10);
 
   std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
@@ -562,10 +528,8 @@ TEST(ImmutableConverterTest, AutoPartialSuggestionForSingleSegment) {
       "なのは",
       "まほうしょうじょ",
   };
-  for (size_t testcase = 0; testcase < arraysize(kRequestKeys); ++testcase) {
+  for (size_t testcase = 0; testcase < std::size(kRequestKeys); ++testcase) {
     Segments segments;
-    segments.set_request_type(Segments::PREDICTION);
-    segments.set_max_prediction_candidates_size(10);
     Segment *segment = segments.add_segment();
     segment->set_key(kRequestKeys[testcase]);
     EXPECT_TRUE(data_and_converter->GetConverter()->ConvertForRequest(
