@@ -30,6 +30,7 @@
 #include "converter/nbest_generator.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <string>
 #include <vector>
 
@@ -43,14 +44,14 @@
 #include "converter/segments.h"
 #include "dictionary/pos_matcher.h"
 
-using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosMatcher;
 using mozc::dictionary::SuppressionDictionary;
 
 namespace mozc {
 namespace {
 
-const int kFreeListSize = 512;
-const int kCostDiff = 3453;  // log prob of 1/1000
+constexpr int kFreeListSize = 512;
+constexpr int kCostDiff = 3453;  // log prob of 1/1000
 
 }  // namespace
 
@@ -59,17 +60,17 @@ using converter::CandidateFilter;
 struct NBestGenerator::QueueElement {
   const Node *node;
   const QueueElement *next;
-  int32 fx;  // f(x) = h(x) + g(x): cost function for A* search
-  int32 gx;  // g(x)
+  int32_t fx;  // f(x) = h(x) + g(x): cost function for A* search
+  int32_t gx;  // g(x)
   // transition cost part of g(x).
   // Do not take the transition costs to edge nodes.
-  int32 structure_gx;
-  int32 w_gx;
+  int32_t structure_gx;
+  int32_t w_gx;
 };
 
 const NBestGenerator::QueueElement *NBestGenerator::CreateNewElement(
-    const Node *node, const QueueElement *next, int32 fx, int32 gx,
-    int32 structure_gx, int32 w_gx) {
+    const Node *node, const QueueElement *next, int32_t fx, int32_t gx,
+    int32_t structure_gx, int32_t w_gx) {
   QueueElement *elm = freelist_.Alloc();
   DCHECK(elm);
   elm->node = node;
@@ -105,7 +106,7 @@ inline void NBestGenerator::Agenda::Pop() {
 NBestGenerator::NBestGenerator(const SuppressionDictionary *suppression_dic,
                                const Segmenter *segmenter,
                                const Connector *connector,
-                               const POSMatcher *pos_matcher,
+                               const PosMatcher *pos_matcher,
                                const Lattice *lattice,
                                const SuggestionFilter *suggestion_filter,
                                bool apply_suggestion_filter_for_exact_match)
@@ -114,15 +115,10 @@ NBestGenerator::NBestGenerator(const SuppressionDictionary *suppression_dic,
       connector_(connector),
       pos_matcher_(pos_matcher),
       lattice_(lattice),
-      begin_node_(nullptr),
-      end_node_(nullptr),
       freelist_(kFreeListSize),
       filter_(new CandidateFilter(suppression_dic, pos_matcher,
                                   suggestion_filter,
-                                  apply_suggestion_filter_for_exact_match)),
-      viterbi_result_checked_(false),
-      check_mode_(STRICT),
-      boundary_checker_(nullptr) {
+                                  apply_suggestion_filter_for_exact_match)) {
   DCHECK(suppression_dictionary_);
   DCHECK(segmenter);
   DCHECK(connector);
@@ -140,6 +136,7 @@ void NBestGenerator::Reset(const Node *begin_node, const Node *end_node,
                            const BoundaryCheckMode mode) {
   agenda_.Clear();
   freelist_.Free();
+  top_nodes_.clear();
   filter_->Reset();
   viterbi_result_checked_ = false;
   check_mode_ = mode;
@@ -174,8 +171,8 @@ void NBestGenerator::Reset(const Node *begin_node, const Node *end_node,
 }
 
 void NBestGenerator::MakeCandidate(
-    Segment::Candidate *candidate, int32 cost, int32 structure_cost,
-    int32 wcost, const std::vector<const Node *> &nodes) const {
+    Segment::Candidate *candidate, int32_t cost, int32_t structure_cost,
+    int32_t wcost, const std::vector<const Node *> &nodes) const {
   CHECK(!nodes.empty());
 
   candidate->Init();
@@ -240,7 +237,7 @@ void NBestGenerator::MakeCandidate(
     for (size_t i = 1; i < nodes.size(); ++i) {
       const Node *lnode = nodes[i - 1];
       const Node *rnode = nodes[i];
-      const bool kMultipleSegments = false;
+      constexpr bool kMultipleSegments = false;
       if (segmenter_->IsBoundary(*lnode, *rnode, kMultipleSegments)) {
         candidate->PushBackInnerSegmentBoundary(
             key_len, value_len, content_key_len, content_value_len);
@@ -273,9 +270,9 @@ void NBestGenerator::MakeCandidate(
   }
 }
 
-bool NBestGenerator::Next(const std::string &original_key,
-                          Segment::Candidate *candidate,
-                          Segments::RequestType request_type) {
+bool NBestGenerator::Next(const ConversionRequest &request,
+                          const std::string &original_key,
+                          Segment::Candidate *candidate) {
   DCHECK(begin_node_);
   DCHECK(end_node_);
 
@@ -315,7 +312,7 @@ bool NBestGenerator::Next(const std::string &original_key,
   if (!viterbi_result_checked_) {
     // Use CandidateFilter so that filter is initialized with the
     // Viterbi-best path.
-    switch (InsertTopResult(original_key, candidate, request_type)) {
+    switch (InsertTopResult(request, original_key, candidate)) {
       case CandidateFilter::GOOD_CANDIDATE:
         return true;
       case CandidateFilter::STOP_ENUMERATION:
@@ -351,10 +348,13 @@ bool NBestGenerator::Next(const std::string &original_key,
         nodes_.push_back(elm->node);
       }
       CHECK(!nodes_.empty());
+      if (top_nodes_.empty()) {
+        top_nodes_ = nodes_;
+      }
 
       MakeCandidate(candidate, top->gx, top->structure_gx, top->w_gx, nodes_);
       const int filter_result = filter_->FilterCandidate(
-          original_key, candidate, nodes_, request_type);
+          request, original_key, candidate, top_nodes_, nodes_);
       nodes_.clear();
 
       switch (filter_result) {
@@ -451,18 +451,18 @@ bool NBestGenerator::Next(const std::string &original_key,
         }
 
         if (boundary_result == VALID_WEAK_CONNECTED) {
-          const int kWeakConnectedPenalty = 3453;  // log prob of 1/1000
+          constexpr int kWeakConnectedPenalty = 3453;  // log prob of 1/1000
           cost_diff += kWeakConnectedPenalty;
           structure_cost_diff += kWeakConnectedPenalty / 2;
           wcost_diff += kWeakConnectedPenalty / 2;
         }
 
-        const int32 gx = cost_diff + top->gx;
+        const int32_t gx = cost_diff + top->gx;
         // |lnode->cost| is heuristics function of A* search, h(x).
         // After Viterbi search, we already know an exact value of h(x).
-        const int32 fx = lnode->cost + gx;
-        const int32 structure_gx = structure_cost_diff + top->structure_gx;
-        const int32 w_gx = wcost_diff + top->w_gx;
+        const int32_t fx = lnode->cost + gx;
+        const int32_t structure_gx = structure_cost_diff + top->structure_gx;
+        const int32_t w_gx = wcost_diff + top->w_gx;
         if (is_left_edge) {
           // We only need to only 1 left node here.
           // Even if expand all left nodes, all the |value| part should
@@ -556,9 +556,9 @@ NBestGenerator::BoundaryCheckResult NBestGenerator::CheckStrict(
   }
 }
 
-int NBestGenerator::InsertTopResult(const std::string &original_key,
-                                    Segment::Candidate *candidate,
-                                    Segments::RequestType request_type) {
+int NBestGenerator::InsertTopResult(const ConversionRequest &request,
+                                    const std::string &original_key,
+                                    Segment::Candidate *candidate) {
   nodes_.clear();
   int total_wcost = 0;
   for (const Node *node = begin_node_->next; node != end_node_;
@@ -570,6 +570,10 @@ int NBestGenerator::InsertTopResult(const std::string &original_key,
   }
   DCHECK(!nodes_.empty());
 
+  if (top_nodes_.empty()) {
+    top_nodes_ = nodes_;
+  }
+
   const int cost = end_node_->cost - begin_node_->cost - end_node_->wcost;
   const int structure_cost =
       end_node_->prev->cost - begin_node_->next->cost - total_wcost;
@@ -578,20 +582,20 @@ int NBestGenerator::InsertTopResult(const std::string &original_key,
 
   MakeCandidate(candidate, cost, structure_cost, wcost, nodes_);
 
-  if (request_type == Segments::SUGGESTION) {
+  if (request.request_type() == ConversionRequest::SUGGESTION) {
     candidate->attributes |= Segment::Candidate::REALTIME_CONVERSION;
   }
 
   viterbi_result_checked_ = true;
-  const int result =
-      filter_->FilterCandidate(original_key, candidate, nodes_, request_type);
+  const int result = filter_->FilterCandidate(request, original_key, candidate,
+                                              top_nodes_, nodes_);
   nodes_.clear();
   return result;
 }
 
 int NBestGenerator::GetTransitionCost(const Node *lnode,
                                       const Node *rnode) const {
-  const int kInvalidPenaltyCost = 100000;
+  constexpr int kInvalidPenaltyCost = 100000;
   if (rnode->constrained_prev != nullptr && lnode != rnode->constrained_prev) {
     return kInvalidPenaltyCost;
   }
