@@ -29,6 +29,7 @@
 
 #include "converter/nbest_generator.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -54,7 +55,6 @@
 #include "request/conversion_request.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -63,7 +63,6 @@ namespace {
 using dictionary::DictionaryImpl;
 using dictionary::DictionaryInterface;
 using dictionary::PosGroup;
-using dictionary::POSMatcher;
 using dictionary::SuffixDictionary;
 using dictionary::SuppressionDictionary;
 using dictionary::SystemDictionary;
@@ -74,11 +73,11 @@ class MockDataAndImmutableConverter {
  public:
   // Initializes data and immutable converter with given dictionaries.
   MockDataAndImmutableConverter() {
-    data_manager_ = absl::make_unique<testing::MockDataManager>();
+    data_manager_ = std::make_unique<testing::MockDataManager>();
 
-    pos_matcher_.Set(data_manager_->GetPOSMatcherData());
+    pos_matcher_.Set(data_manager_->GetPosMatcherData());
 
-    suppression_dictionary_ = absl::make_unique<SuppressionDictionary>();
+    suppression_dictionary_ = std::make_unique<SuppressionDictionary>();
     CHECK(suppression_dictionary_);
 
     const char *dictionary_data = nullptr;
@@ -89,17 +88,17 @@ class MockDataAndImmutableConverter {
             .Build()
             .value();
     auto value_dic =
-        absl::make_unique<ValueDictionary>(pos_matcher_, &sysdic->value_trie());
-    dictionary_ = absl::make_unique<DictionaryImpl>(
+        std::make_unique<ValueDictionary>(pos_matcher_, &sysdic->value_trie());
+    dictionary_ = std::make_unique<DictionaryImpl>(
         std::move(sysdic), std::move(value_dic), &user_dictionary_stub_,
         suppression_dictionary_.get(), &pos_matcher_);
     CHECK(dictionary_);
 
     absl::string_view suffix_key_array_data, suffix_value_array_data;
-    const uint32 *token_array = nullptr;
+    const uint32_t *token_array = nullptr;
     data_manager_->GetSuffixDictionaryData(
         &suffix_key_array_data, &suffix_value_array_data, &token_array);
-    suffix_dictionary_ = absl::make_unique<SuffixDictionary>(
+    suffix_dictionary_ = std::make_unique<SuffixDictionary>(
         suffix_key_array_data, suffix_value_array_data, token_array);
     CHECK(suffix_dictionary_);
 
@@ -108,17 +107,17 @@ class MockDataAndImmutableConverter {
     segmenter_.reset(Segmenter::CreateFromDataManager(*data_manager_));
     CHECK(segmenter_);
 
-    pos_group_ = absl::make_unique<PosGroup>(data_manager_->GetPosGroupData());
+    pos_group_ = std::make_unique<PosGroup>(data_manager_->GetPosGroupData());
     CHECK(pos_group_);
 
     {
       const char *data = nullptr;
       size_t size = 0;
       data_manager_->GetSuggestionFilterData(&data, &size);
-      suggestion_filter_ = absl::make_unique<SuggestionFilter>(data, size);
+      suggestion_filter_ = std::make_unique<SuggestionFilter>(data, size);
     }
 
-    immutable_converter_ = absl::make_unique<ImmutableConverterImpl>(
+    immutable_converter_ = std::make_unique<ImmutableConverterImpl>(
         dictionary_.get(), suffix_dictionary_.get(),
         suppression_dictionary_.get(), connector_.get(), segmenter_.get(),
         &pos_matcher_, pos_group_.get(), suggestion_filter_.get());
@@ -128,7 +127,7 @@ class MockDataAndImmutableConverter {
   ImmutableConverterImpl *GetConverter() { return immutable_converter_.get(); }
 
   std::unique_ptr<NBestGenerator> CreateNBestGenerator(const Lattice *lattice) {
-    return absl::make_unique<NBestGenerator>(
+    return std::make_unique<NBestGenerator>(
         suppression_dictionary_.get(), segmenter_.get(), connector_.get(),
         &pos_matcher_, lattice, suggestion_filter_.get(), true);
   }
@@ -144,35 +143,36 @@ class MockDataAndImmutableConverter {
   std::unique_ptr<const SuggestionFilter> suggestion_filter_;
   std::unique_ptr<ImmutableConverterImpl> immutable_converter_;
   UserDictionaryStub user_dictionary_stub_;
-  dictionary::POSMatcher pos_matcher_;
+  dictionary::PosMatcher pos_matcher_;
 };
 
 }  // namespace
 
 class NBestGeneratorTest : public ::testing::Test {
  protected:
-  void GatherCandidates(size_t size, Segments::RequestType request_type,
+  void GatherCandidates(size_t size, const ConversionRequest &request,
                         NBestGenerator *nbest, Segment *segment) const {
     while (segment->candidates_size() < size) {
       Segment::Candidate *candidate = segment->push_back_candidate();
       candidate->Init();
 
-      if (!nbest->Next(segment->key(), candidate, request_type)) {
+      if (!nbest->Next(request, segment->key(), candidate)) {
         segment->pop_back_candidate();
         break;
       }
     }
   }
 
-  const Node *GetEndNode(const ImmutableConverterImpl &converter,
+  const Node *GetEndNode(const ConversionRequest &request,
+                         const ImmutableConverterImpl &converter,
                          const Segments &segments, const Node &begin_node,
-                         const std::vector<uint16> &group,
+                         const std::vector<uint16_t> &group,
                          bool is_single_segment) {
     const Node *end_node = nullptr;
     for (Node *node = begin_node.next; node->next != nullptr;
          node = node->next) {
       end_node = node->next;
-      if (converter.IsSegmentEndNode(segments, node, group,
+      if (converter.IsSegmentEndNode(request, segments, node, group,
                                      is_single_segment)) {
         break;
       }
@@ -182,11 +182,10 @@ class NBestGeneratorTest : public ::testing::Test {
 };
 
 TEST_F(NBestGeneratorTest, MultiSegmentConnectionTest) {
-  auto data_and_converter = absl::make_unique<MockDataAndImmutableConverter>();
+  auto data_and_converter = std::make_unique<MockDataAndImmutableConverter>();
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
   Segments segments;
-  segments.set_request_type(Segments::CONVERSION);
   {
     Segment *segment = segments.add_segment();
     segment->set_segment_type(Segment::FIXED_BOUNDARY);
@@ -199,26 +198,25 @@ TEST_F(NBestGeneratorTest, MultiSegmentConnectionTest) {
 
   Lattice lattice;
   lattice.SetKey("しんこうする");
-  const ConversionRequest request;
+  ConversionRequest request;
+  request.set_request_type(ConversionRequest::CONVERSION);
   converter->MakeLattice(request, &segments, &lattice);
 
-  std::vector<uint16> group;
+  std::vector<uint16_t> group;
   converter->MakeGroup(segments, &group);
   converter->Viterbi(segments, &lattice);
 
   std::unique_ptr<NBestGenerator> nbest_generator =
       data_and_converter->CreateNBestGenerator(&lattice);
 
-  const bool kSingleSegment = false;  // For 'normal' conversion
+  constexpr bool kSingleSegment = false;  // For 'normal' conversion
   const Node *begin_node = lattice.bos_nodes();
-  const Node *end_node =
-      GetEndNode(*converter, segments, *begin_node, group, kSingleSegment);
-
+  const Node *end_node = GetEndNode(request, *converter, segments, *begin_node,
+                                    group, kSingleSegment);
   {
     nbest_generator->Reset(begin_node, end_node, NBestGenerator::STRICT);
     Segment result_segment;
-    GatherCandidates(10, Segments::CONVERSION, nbest_generator.get(),
-                     &result_segment);
+    GatherCandidates(10, request, nbest_generator.get(), &result_segment);
     // The top result is treated exceptionally and has no boundary check
     // in NBestGenerator.
     // The best route is calculated in ImmutalbeConverter with boundary check.
@@ -231,8 +229,7 @@ TEST_F(NBestGeneratorTest, MultiSegmentConnectionTest) {
   {
     nbest_generator->Reset(begin_node, end_node, NBestGenerator::ONLY_MID);
     Segment result_segment;
-    GatherCandidates(10, Segments::CONVERSION, nbest_generator.get(),
-                     &result_segment);
+    GatherCandidates(10, request, nbest_generator.get(), &result_segment);
     ASSERT_EQ(3, result_segment.candidates_size());
     EXPECT_EQ("進行", result_segment.candidate(0).value);
     EXPECT_EQ("信仰", result_segment.candidate(1).value);
@@ -241,11 +238,10 @@ TEST_F(NBestGeneratorTest, MultiSegmentConnectionTest) {
 }
 
 TEST_F(NBestGeneratorTest, SingleSegmentConnectionTest) {
-  auto data_and_converter = absl::make_unique<MockDataAndImmutableConverter>();
+  auto data_and_converter = std::make_unique<MockDataAndImmutableConverter>();
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
   Segments segments;
-  segments.set_request_type(Segments::CONVERSION);
   std::string kText = "わたしのなまえはなかのです";
   {
     Segment *segment = segments.add_segment();
@@ -255,26 +251,25 @@ TEST_F(NBestGeneratorTest, SingleSegmentConnectionTest) {
 
   Lattice lattice;
   lattice.SetKey(kText);
-  const ConversionRequest request;
+  ConversionRequest request;
+  request.set_request_type(ConversionRequest::CONVERSION);
   converter->MakeLattice(request, &segments, &lattice);
 
-  std::vector<uint16> group;
+  std::vector<uint16_t> group;
   converter->MakeGroup(segments, &group);
   converter->Viterbi(segments, &lattice);
 
   std::unique_ptr<NBestGenerator> nbest_generator =
       data_and_converter->CreateNBestGenerator(&lattice);
 
-  const bool kSingleSegment = true;  // For realtime conversion
+  constexpr bool kSingleSegment = true;  // For realtime conversion
   const Node *begin_node = lattice.bos_nodes();
-  const Node *end_node =
-      GetEndNode(*converter, segments, *begin_node, group, kSingleSegment);
-
+  const Node *end_node = GetEndNode(request, *converter, segments, *begin_node,
+                                    group, kSingleSegment);
   {
     nbest_generator->Reset(begin_node, end_node, NBestGenerator::STRICT);
     Segment result_segment;
-    GatherCandidates(10, Segments::CONVERSION, nbest_generator.get(),
-                     &result_segment);
+    GatherCandidates(10, request, nbest_generator.get(), &result_segment);
     // Top result should be inserted, but other candidates will be cut
     // due to boundary check.
     ASSERT_EQ(1, result_segment.candidates_size());
@@ -283,8 +278,7 @@ TEST_F(NBestGeneratorTest, SingleSegmentConnectionTest) {
   {
     nbest_generator->Reset(begin_node, end_node, NBestGenerator::ONLY_EDGE);
     Segment result_segment;
-    GatherCandidates(10, Segments::CONVERSION, nbest_generator.get(),
-                     &result_segment);
+    GatherCandidates(10, request, nbest_generator.get(), &result_segment);
     // We can get several candidates.
     ASSERT_LT(1, result_segment.candidates_size());
     EXPECT_EQ("私の名前は中ノです", result_segment.candidate(0).value);
@@ -292,11 +286,10 @@ TEST_F(NBestGeneratorTest, SingleSegmentConnectionTest) {
 }
 
 TEST_F(NBestGeneratorTest, InnerSegmentBoundary) {
-  auto data_and_converter = absl::make_unique<MockDataAndImmutableConverter>();
+  auto data_and_converter = std::make_unique<MockDataAndImmutableConverter>();
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
   Segments segments;
-  segments.set_request_type(Segments::PREDICTION);
   const std::string kInput = "とうきょうかなごやにいきたい";
   {
     Segment *segment = segments.add_segment();
@@ -306,25 +299,25 @@ TEST_F(NBestGeneratorTest, InnerSegmentBoundary) {
 
   Lattice lattice;
   lattice.SetKey(kInput);
-  const ConversionRequest request;
+  ConversionRequest request;
+  request.set_request_type(ConversionRequest::PREDICTION);
   converter->MakeLattice(request, &segments, &lattice);
 
-  std::vector<uint16> group;
+  std::vector<uint16_t> group;
   converter->MakeGroup(segments, &group);
   converter->Viterbi(segments, &lattice);
 
   std::unique_ptr<NBestGenerator> nbest_generator =
       data_and_converter->CreateNBestGenerator(&lattice);
 
-  const bool kSingleSegment = true;  // For realtime conversion
+  constexpr bool kSingleSegment = true;  // For realtime conversion
   const Node *begin_node = lattice.bos_nodes();
-  const Node *end_node =
-      GetEndNode(*converter, segments, *begin_node, group, kSingleSegment);
+  const Node *end_node = GetEndNode(request, *converter, segments, *begin_node,
+                                    group, kSingleSegment);
 
   nbest_generator->Reset(begin_node, end_node, NBestGenerator::ONLY_EDGE);
   Segment result_segment;
-  GatherCandidates(10, Segments::PREDICTION, nbest_generator.get(),
-                   &result_segment);
+  GatherCandidates(10, request, nbest_generator.get(), &result_segment);
   ASSERT_LE(1, result_segment.candidates_size());
 
   const Segment::Candidate &top_cand = result_segment.candidate(0);
