@@ -30,26 +30,60 @@
 #ifndef MOZC_CONVERTER_NODE_LIST_BUILDER_H_
 #define MOZC_CONVERTER_NODE_LIST_BUILDER_H_
 
+#include <cstdint>
+
 #include "base/logging.h"
 #include "base/port.h"
+#include "base/util.h"
 #include "converter/node.h"
 #include "converter/node_allocator.h"
 #include "dictionary/dictionary_interface.h"
 #include "dictionary/dictionary_token.h"
+#include "protocol/commands.pb.h"
+#include "request/conversion_request.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
 
 // The cost is 500 * log(30): 30 times in freq.
-static const int32 kKanaModifierInsensitivePenalty = 1700;
+static const int32_t kKanaModifierInsensitivePenalty = 1700;
+
+struct SpatialCostParams {
+  int penalty = kKanaModifierInsensitivePenalty;
+  int min_char_length = 0;
+  int GetPenalty(absl::string_view key) const {
+    return (min_char_length > 0 && Util::CharsLen(key) < min_char_length)
+               ? kKanaModifierInsensitivePenalty
+               : penalty;
+  }
+};
+
+// Propagates the spatial_cost_params only when enable_new_spatial_scoring is
+// enabled.
+inline SpatialCostParams GetSpatialCostParams(
+    const ConversionRequest &request) {
+  const auto &experiment_params = request.request().decoder_experiment_params();
+  SpatialCostParams result;
+  if (experiment_params.enable_new_spatial_scoring()) {
+    result.penalty = experiment_params.spatial_cost_penalty();
+    result.min_char_length =
+        experiment_params.spatial_cost_penalty_min_char_length();
+  }
+  return result;
+}
 
 // Provides basic functionality for building a list of nodes.
 // This class is defined inline because it contributes to the performance of
 // dictionary lookup.
 class BaseNodeListBuilder : public dictionary::DictionaryInterface::Callback {
  public:
-  BaseNodeListBuilder(mozc::NodeAllocator *allocator, int limit)
-      : allocator_(allocator), limit_(limit), penalty_(0), result_(nullptr) {
+  BaseNodeListBuilder(mozc::NodeAllocator *allocator, int limit,
+                      const SpatialCostParams &spatial_cost_param)
+      : allocator_(allocator),
+        limit_(limit),
+        penalty_(0),
+        spatial_cost_params_(spatial_cost_param),
+        result_(nullptr) {
     DCHECK(allocator_) << "Allocator must not be nullptr";
   }
 
@@ -58,8 +92,8 @@ class BaseNodeListBuilder : public dictionary::DictionaryInterface::Callback {
 
   // Determines a penalty for tokens of this (key, actual_key) pair.
   ResultType OnActualKey(absl::string_view key, absl::string_view actual_key,
-                         bool is_expanded) override {
-    penalty_ = is_expanded ? kKanaModifierInsensitivePenalty : 0;
+                         int num_expanded) override {
+    penalty_ = num_expanded > 0 ? spatial_cost_params_.GetPenalty(key) : 0;
     return TRAVERSE_CONTINUE;
   }
 
@@ -93,6 +127,7 @@ class BaseNodeListBuilder : public dictionary::DictionaryInterface::Callback {
   NodeAllocator *allocator_;
   int limit_;
   int penalty_;
+  const SpatialCostParams spatial_cost_params_;
   Node *result_;
 };
 
@@ -101,8 +136,9 @@ class BaseNodeListBuilder : public dictionary::DictionaryInterface::Callback {
 class NodeListBuilderForLookupPrefix : public BaseNodeListBuilder {
  public:
   NodeListBuilderForLookupPrefix(mozc::NodeAllocator *allocator, int limit,
-                                 size_t min_key_length)
-      : BaseNodeListBuilder(allocator, limit),
+                                 size_t min_key_length,
+                                 const SpatialCostParams &spatial_cost_params)
+      : BaseNodeListBuilder(allocator, limit, spatial_cost_params),
         min_key_length_(min_key_length) {}
 
   NodeListBuilderForLookupPrefix(const NodeListBuilderForLookupPrefix &) =
