@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,20 +34,20 @@
 
 #include "base/file_stream.h"
 #include "base/file_util.h"
-#include "base/flags.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
+#include "absl/flags/flag.h"
 
 namespace mozc {
 namespace internal {
 
 class PosIdPrinterTest : public ::testing::Test {
  protected:
-  virtual void SetUp() {
+  void SetUp() override {
     const std::string test_id_def_path =
         testing::GetSourceFileOrDie({"data", "test", "dictionary", "id.def"});
-    pos_id_.reset(new InputFileStream(test_id_def_path.c_str()));
-    pos_id_printer_.reset(new PosIdPrinter(pos_id_.get()));
+    pos_id_ = std::make_unique<InputFileStream>(test_id_def_path.c_str());
+    pos_id_printer_ = std::make_unique<PosIdPrinter>(pos_id_.get());
   }
 
   std::unique_ptr<InputFileStream> pos_id_;
