@@ -29,8 +29,10 @@
 
 #include "converter/quality_regression_util.h"
 
+#include <cstdint>
 #include <sstream>  // NOLINT
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "base/file_stream.h"
@@ -44,21 +46,31 @@
 #include "converter/segments.h"
 #include "protocol/commands.pb.h"
 #include "request/conversion_request.h"
+#include "absl/status/status.h"
+#include "absl/status/statusor.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_join.h"
+#include "absl/strings/str_split.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace quality_regression {
 namespace {
 
-const char kConversionExpect[] = "Conversion Expected";
-const char kConversionNotExpect[] = "Conversion Not Expected";
-const char kReverseConversionExpect[] = "ReverseConversion Expected";
-const char kReverseConversionNotExpect[] = "ReverseConversion Not Expected";
+constexpr char kConversionExpect[] = "Conversion Expected";
+constexpr char kConversionNotExpect[] = "Conversion Not Expected";
+constexpr char kConversionMatch[] = "Conversion Match";
+constexpr char kConversionNotMatch[] = "Conversion Not Match";
+constexpr char kReverseConversionExpect[] = "ReverseConversion Expected";
+constexpr char kReverseConversionNotExpect[] = "ReverseConversion Not Expected";
 // For now, suggestion and prediction are using same implementation
-const char kPredictionExpect[] = "Prediction Expected";
-const char kPredictionNotExpect[] = "Prediction Not Expected";
-const char kSuggestionExpect[] = "Suggestion Expected";
-const char kSuggestionNotExpect[] = "Suggestion Not Expected";
+constexpr char kPredictionExpect[] = "Prediction Expected";
+constexpr char kPredictionNotExpect[] = "Prediction Not Expected";
+constexpr char kSuggestionExpect[] = "Suggestion Expected";
+constexpr char kSuggestionNotExpect[] = "Suggestion Not Expected";
+// Zero query
+constexpr char kZeroQueryExpect[] = "ZeroQuery Expected";
+constexpr char kZeroQueryNotExpect[] = "ZeroQuery Not Expected";
 
 // copied from evaluation/quality_regression/evaluator.cc
 int GetRank(const std::string &value, const Segments *segments,
@@ -90,7 +102,7 @@ int GetRank(const std::string &value, const Segments *segments,
   return -1;
 }
 
-uint32 GetPlatformFromString(absl::string_view str) {
+absl::StatusOr<uint32_t> GetPlatformFromString(absl::string_view str) {
   std::string lower;
   lower.assign(str.data(), str.size());
   Util::LowerString(&lower);
@@ -106,8 +118,8 @@ uint32 GetPlatformFromString(absl::string_view str) {
   if (str == "mobile_ambiguous") {
     return QualityRegressionUtil::MOBILE_AMBIGUOUS;
   }
-  LOG(FATAL) << "Unknown platform name: " << str;
-  return QualityRegressionUtil::DESKTOP;
+  return absl::InvalidArgumentError(
+      absl::StrCat("Unknown platform name: ", str));
 }
 }  // namespace
 
@@ -119,30 +131,53 @@ std::string QualityRegressionUtil::TestItem::OutputAsTSV() const {
   return os.str();
 }
 
-bool QualityRegressionUtil::TestItem::ParseFromTSV(const std::string &line) {
-  std::vector<absl::string_view> tokens;
-  Util::SplitStringUsing(line, "\t", &tokens);
-  if (tokens.size() < 6) {
-    return false;
+absl::Status QualityRegressionUtil::TestItem::ParseFromTSV(
+    const std::string &line) {
+  std::vector<absl::string_view> tokens =
+      absl::StrSplit(line, '\t', absl::SkipEmpty());
+  if (tokens.size() < 4) {
+    return absl::InvalidArgumentError(
+        absl::StrCat("Invalid token size: ", line));
   }
   label.assign(tokens[0].data(), tokens[0].size());
   key.assign(tokens[1].data(), tokens[1].size());
-  TextNormalizer::NormalizeText(tokens[2], &expected_value);
+  expected_value = TextNormalizer::NormalizeText(tokens[2]);
   command.assign(tokens[3].data(), tokens[3].size());
-  expected_rank = NumberUtil::SimpleAtoi(tokens[4]);
-  NumberUtil::SafeStrToDouble(tokens[5], &accuracy);
+
+  if (tokens.size() == 4) {
+    if (absl::StartsWith(command, kConversionExpect) &&
+        command != kConversionExpect) {
+      constexpr int kSize = std::size(kConversionExpect);  // Size with '\0'.
+      expected_rank = NumberUtil::SimpleAtoi(command.substr(kSize));
+      command = kConversionExpect;
+    } else {
+      expected_rank = 0;
+    }
+  } else {
+    expected_rank = NumberUtil::SimpleAtoi(tokens[4]);
+  }
+
+  if (tokens.size() > 5) {
+    NumberUtil::SafeStrToDouble(tokens[5], &accuracy);
+  } else {
+    accuracy = 1.0;
+  }
   platform = 0;
   if (tokens.size() >= 7) {
-    std::vector<absl::string_view> platforms;
-    Util::SplitStringUsing(tokens[6], ",", &platforms);
+    std::vector<absl::string_view> platforms =
+        absl::StrSplit(tokens[6], ',', absl::SkipEmpty());
     for (size_t i = 0; i < platforms.size(); ++i) {
-      platform |= GetPlatformFromString(platforms[i]);
+      auto result = GetPlatformFromString(platforms[i]);
+      if (!result.ok()) {
+        return std::move(result.status());
+      }
+      platform |= *result;
     }
   } else {
     // Default platform: desktop
     platform = QualityRegressionUtil::DESKTOP;
   }
-  return true;
+  return absl::OkStatus();
 }
 
 QualityRegressionUtil::QualityRegressionUtil(ConverterInterface *converter)
@@ -153,34 +188,55 @@ QualityRegressionUtil::QualityRegressionUtil(ConverterInterface *converter)
 
 QualityRegressionUtil::~QualityRegressionUtil() {}
 
-// static
-bool QualityRegressionUtil::ParseFile(const std::string &filename,
-                                      std::vector<TestItem> *outputs) {
+namespace {
+absl::Status ParseFileInternal(
+    const std::string &filename,
+    std::vector<QualityRegressionUtil::TestItem> *outputs) {
   // TODO(taku): support an XML file of Mozcsu.
-  outputs->clear();
   InputFileStream ifs(filename.c_str());
   if (!ifs.good()) {
-    return false;
+    return absl::UnavailableError(absl::StrCat("Failed to read: ", filename));
   }
   std::string line;
   while (!std::getline(ifs, line).fail()) {
     if (line.empty() || line.c_str()[0] == '#') {
       continue;
     }
-    TestItem item;
-    if (!item.ParseFromTSV(line)) {
-      LOG(ERROR) << "Cannot parse: " << line;
-      return false;
+    QualityRegressionUtil::TestItem item;
+    if (!item.ParseFromTSV(line).ok()) {
+      return absl::InvalidArgumentError(
+          absl::StrCat("Failed to parse: ", line));
     }
     outputs->push_back(item);
   }
-  return true;
+  return absl::OkStatus();
+}
+}  // namespace
+
+// static
+absl::Status QualityRegressionUtil::ParseFile(const std::string &filename,
+                                              std::vector<TestItem> *outputs) {
+  outputs->clear();
+  return ParseFileInternal(filename, outputs);
+}
+
+// static
+absl::Status QualityRegressionUtil::ParseFiles(
+    const std::vector<std::string> &filenames, std::vector<TestItem> *outputs) {
+  outputs->clear();
+  for (const std::string &filename : filenames) {
+    const absl::Status result = ParseFileInternal(filename, outputs);
+    if (!result.ok()) {
+      return result;
+    }
+  }
+  return absl::OkStatus();
 }
 
 // static
 
-bool QualityRegressionUtil::ConvertAndTest(const TestItem &item,
-                                           std::string *actual_value) {
+absl::StatusOr<bool> QualityRegressionUtil::ConvertAndTest(
+    const TestItem &item, std::string *actual_value) {
   const std::string &key = item.key;
   const std::string &expected_value = item.expected_value;
   const std::string &command = item.command;
@@ -193,26 +249,55 @@ bool QualityRegressionUtil::ConvertAndTest(const TestItem &item,
 
   composer::Table table;
 
-  if (command == kConversionExpect || command == kConversionNotExpect) {
+  if (command == kConversionExpect || command == kConversionNotExpect ||
+      command == kConversionMatch || command == kConversionNotMatch) {
     composer::Composer composer(&table, request_.get(), config_.get());
     composer.SetPreeditTextForTestOnly(key);
-    ConversionRequest request(&composer, request_.get(), config_.get());
-    converter_->StartConversionForRequest(request, segments_.get());
+    ConversionRequest conversion_request(&composer, request_.get(),
+                                         config_.get());
+    converter_->StartConversionForRequest(conversion_request, segments_.get());
   } else if (command == kReverseConversionExpect ||
              command == kReverseConversionNotExpect) {
     converter_->StartReverseConversion(segments_.get(), key);
   } else if (command == kPredictionExpect || command == kPredictionNotExpect) {
     composer::Composer composer(&table, request_.get(), config_.get());
     composer.SetPreeditTextForTestOnly(key);
-    ConversionRequest request(&composer, request_.get(), config_.get());
-    converter_->StartPredictionForRequest(request, segments_.get());
+    ConversionRequest conversion_request(&composer, request_.get(),
+                                         config_.get());
+    converter_->StartPredictionForRequest(conversion_request, segments_.get());
+
   } else if (command == kSuggestionExpect || command == kSuggestionNotExpect) {
     composer::Composer composer(&table, request_.get(), config_.get());
     composer.SetPreeditTextForTestOnly(key);
-    ConversionRequest request(&composer, request_.get(), config_.get());
-    converter_->StartSuggestionForRequest(request, segments_.get());
+    ConversionRequest conversion_request(&composer, request_.get(),
+                                         config_.get());
+    converter_->StartSuggestionForRequest(conversion_request, segments_.get());
+  } else if (command == kZeroQueryExpect || command == kZeroQueryNotExpect) {
+    commands::Request request = *request_;
+    request.set_zero_query_suggestion(true);
+    request.set_mixed_conversion(true);
+    {
+      composer::Composer composer(&table, &request, config_.get());
+      composer.SetPreeditTextForTestOnly(key);
+      ConversionRequest conversion_request(&composer, &request, config_.get());
+      conversion_request.set_max_conversion_candidates_size(10);
+      converter_->StartSuggestionForRequest(conversion_request,
+                                            segments_.get());
+      converter_->CommitSegmentValue(segments_.get(), 0, 0);
+      converter_->FinishConversion(conversion_request, segments_.get());
+    }
+    {
+      // Issues zero-query request.
+      composer::Composer composer(&table, &request, config_.get());
+      ConversionRequest conversion_request(&composer, &request, config_.get());
+      conversion_request.set_max_conversion_candidates_size(10);
+      converter_->StartPredictionForRequest(conversion_request,
+                                            segments_.get());
+      segments_->clear_history_segments();
+    }
   } else {
-    LOG(FATAL) << "Unknown command: " << command;
+    return absl::InvalidArgumentError(
+        absl::StrCat("Unknown command: ", item.OutputAsTSV()));
   }
 
   // No results is OK if "prediction not expect" command
@@ -227,13 +312,21 @@ bool QualityRegressionUtil::ConvertAndTest(const TestItem &item,
     *actual_value += segments_->segment(i).candidate(0).value;
   }
 
-  const int32 actual_rank = GetRank(expected_value, segments_.get(), 0, 0);
+  if (command == kConversionMatch) {
+    return (actual_value->find(expected_value) != std::string::npos);
+  }
+  if (command == kConversionNotMatch) {
+    return (actual_value->find(expected_value) == std::string::npos);
+  }
+
+  const int32_t actual_rank = GetRank(expected_value, segments_.get(), 0, 0);
 
   bool result = (actual_rank >= 0 && actual_rank <= expected_rank);
 
   if (command == kConversionNotExpect ||
       command == kReverseConversionNotExpect ||
-      command == kPredictionNotExpect || command == kSuggestionNotExpect) {
+      command == kPredictionNotExpect || command == kSuggestionNotExpect ||
+      command == kZeroQueryNotExpect) {
     result = !result;
   }
 
@@ -248,7 +341,8 @@ void QualityRegressionUtil::SetConfig(const config::Config &config) {
   *config_ = config;
 }
 
-std::string QualityRegressionUtil::GetPlatformString(uint32 platform_bitfiled) {
+std::string QualityRegressionUtil::GetPlatformString(
+    uint32_t platform_bitfiled) {
   std::vector<std::string> v;
   if (platform_bitfiled & DESKTOP) {
     v.push_back("DESKTOP");
@@ -265,9 +359,7 @@ std::string QualityRegressionUtil::GetPlatformString(uint32 platform_bitfiled) {
   if (v.empty()) {
     v.push_back("UNKNOWN");
   }
-  std::string s;
-  Util::JoinStrings(v, "|", &s);
-  return s;
+  return absl::StrJoin(v, "|");
 }
 
 }  // namespace quality_regression
