@@ -30,18 +30,20 @@
 #include "converter/segments.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <limits>
 #include <sstream>  // For DebugString()
 #include <string>
+#include <utility>
 
 #include "base/logging.h"
 #include "base/util.h"
+#include "absl/strings/str_format.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
-const size_t kMaxHistorySize = 32;
-const size_t kMaxConversionCandidatesSize = 200;
+constexpr size_t kMaxHistorySize = 32;
 }  // namespace
 
 absl::string_view Segment::Candidate::functional_key() const {
@@ -58,38 +60,30 @@ absl::string_view Segment::Candidate::functional_value() const {
                                  value.size() - content_value.size());
 }
 
-void Segment::Candidate::CopyFrom(const Candidate &src) {
-  Init();
-
-  key = src.key;
-  value = src.value;
-  content_key = src.content_key;
-  content_value = src.content_value;
-  consumed_key_size = src.consumed_key_size;
-
-  prefix = src.prefix;
-  suffix = src.suffix;
-  usage_id = src.usage_id;
-  description = src.description;
-  usage_title = src.usage_title;
-  usage_description = src.usage_description;
-
-  cost = src.cost;
-  wcost = src.wcost;
-  structure_cost = src.structure_cost;
-
-  lid = src.lid;
-  rid = src.rid;
-
-  attributes = src.attributes;
-
-  style = src.style;
-  command = src.command;
-
-  inner_segment_boundary = src.inner_segment_boundary;
-
+void Segment::Candidate::Init() {
+  key.clear();
+  value.clear();
+  content_value.clear();
+  content_key.clear();
+  consumed_key_size = 0;
+  prefix.clear();
+  suffix.clear();
+  description.clear();
+  usage_title.clear();
+  usage_description.clear();
+  cost = 0;
+  structure_cost = 0;
+  wcost = 0;
+  lid = 0;
+  rid = 0;
+  usage_id = 0;
+  attributes = 0;
+  source_info = SOURCE_INFO_NONE;
+  style = NumberUtil::NumberString::DEFAULT_STYLE;
+  command = DEFAULT_COMMAND;
+  inner_segment_boundary.clear();
 #ifndef NDEBUG
-  log = src.log;
+  log.clear();
 #endif  // NDEBUG
 }
 
@@ -119,24 +113,24 @@ bool Segment::Candidate::IsValid() const {
 bool Segment::Candidate::EncodeLengths(size_t key_len, size_t value_len,
                                        size_t content_key_len,
                                        size_t content_value_len,
-                                       uint32 *result) {
-  if (key_len > std::numeric_limits<uint8>::max() ||
-      value_len > std::numeric_limits<uint8>::max() ||
-      content_key_len > std::numeric_limits<uint8>::max() ||
-      content_value_len > std::numeric_limits<uint8>::max()) {
+                                       uint32_t *result) {
+  if (key_len > std::numeric_limits<uint8_t>::max() ||
+      value_len > std::numeric_limits<uint8_t>::max() ||
+      content_key_len > std::numeric_limits<uint8_t>::max() ||
+      content_value_len > std::numeric_limits<uint8_t>::max()) {
     return false;
   }
-  *result = (static_cast<uint32>(key_len) << 24) |
-            (static_cast<uint32>(value_len) << 16) |
-            (static_cast<uint32>(content_key_len) << 8) |
-            static_cast<uint32>(content_value_len);
+  *result = (static_cast<uint32_t>(key_len) << 24) |
+            (static_cast<uint32_t>(value_len) << 16) |
+            (static_cast<uint32_t>(content_key_len) << 8) |
+            static_cast<uint32_t>(content_value_len);
   return true;
 }
 
 bool Segment::Candidate::PushBackInnerSegmentBoundary(
     size_t key_len, size_t value_len, size_t content_key_len,
     size_t content_value_len) {
-  uint32 encoded;
+  uint32_t encoded;
   if (EncodeLengths(key_len, value_len, content_key_len, content_value_len,
                     &encoded)) {
     inner_segment_boundary.push_back(encoded);
@@ -164,13 +158,13 @@ std::string Segment::Candidate::DebugString() const {
   if (!inner_segment_boundary.empty()) {
     os << " segbdd=";
     for (size_t i = 0; i < inner_segment_boundary.size(); ++i) {
-      const uint32 encoded_lengths = inner_segment_boundary[i];
+      const uint32_t encoded_lengths = inner_segment_boundary[i];
       const int key_len = encoded_lengths >> 24;
       const int value_len = (encoded_lengths >> 16) & 0xff;
       const int content_key_len = (encoded_lengths >> 8) & 0xff;
       const int content_value_len = encoded_lengths & 0xff;
-      os << Util::StringPrintf("<%d,%d,%d,%d>", key_len, value_len,
-                               content_key_len, content_value_len);
+      os << absl::StrFormat("<%d,%d,%d,%d>", key_len, value_len,
+                            content_key_len, content_value_len);
     }
   }
   os << ")" << std::endl;
@@ -179,41 +173,66 @@ std::string Segment::Candidate::DebugString() const {
 
 void Segment::Candidate::InnerSegmentIterator::Next() {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
-  const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_++];
+  const uint32_t encoded_lengths = candidate_->inner_segment_boundary[index_++];
   key_offset_ += encoded_lengths >> 24;
   value_offset_ += (encoded_lengths >> 16) & 0xff;
 }
 
 absl::string_view Segment::Candidate::InnerSegmentIterator::GetKey() const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
-  const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
+  const uint32_t encoded_lengths = candidate_->inner_segment_boundary[index_];
   return absl::string_view(key_offset_, encoded_lengths >> 24);
 }
 
 absl::string_view Segment::Candidate::InnerSegmentIterator::GetValue() const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
-  const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
+  const uint32_t encoded_lengths = candidate_->inner_segment_boundary[index_];
   return absl::string_view(value_offset_, (encoded_lengths >> 16) & 0xff);
 }
 
 absl::string_view Segment::Candidate::InnerSegmentIterator::GetContentKey()
     const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
-  const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
+  const uint32_t encoded_lengths = candidate_->inner_segment_boundary[index_];
   return absl::string_view(key_offset_, (encoded_lengths >> 8) & 0xff);
 }
 
 absl::string_view Segment::Candidate::InnerSegmentIterator::GetContentValue()
     const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
-  const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
+  const uint32_t encoded_lengths = candidate_->inner_segment_boundary[index_];
   return absl::string_view(value_offset_, encoded_lengths & 0xff);
 }
 
-Segment::Segment()
-    : segment_type_(FREE), pool_(new ObjectPool<Candidate>(16)) {}
+constexpr int kCandidatesPoolSize = 16;
+Segment::Segment() : segment_type_(FREE), pool_(kCandidatesPoolSize) {}
 
-Segment::~Segment() {}
+Segment::Segment(const Segment &x)
+    : removed_candidates_for_debug_(x.removed_candidates_for_debug_),
+      segment_type_(x.segment_type_),
+      key_(x.key_),
+      meta_candidates_(x.meta_candidates_),
+      pool_(x.pool_.size()) {
+  // Deep-copy candidates.
+  for (const Candidate *cand : x.candidates_) {
+    *add_candidate() = *cand;
+  }
+}
+
+Segment &Segment::operator=(const Segment &x) {
+  removed_candidates_for_debug_ = x.removed_candidates_for_debug_;
+  segment_type_ = x.segment_type_;
+  key_ = x.key_;
+  meta_candidates_ = x.meta_candidates_;
+  // Deep-copy candidates.
+  clear_candidates();
+  for (const Candidate *cand : x.candidates_) {
+    *add_candidate() = *cand;
+  }
+  return *this;
+}
+
+Segment::~Segment() = default;
 
 Segment::SegmentType Segment::segment_type() const { return segment_type_; }
 
@@ -253,42 +272,24 @@ Segment::Candidate *Segment::mutable_candidate(int i) {
   return candidates_[i];
 }
 
-int Segment::indexOf(const Segment::Candidate *candidate) {
-  if (candidate == nullptr) {
-    return static_cast<int>(candidates_size());
-  }
-
-  for (int i = 0; i < static_cast<int>(candidates_.size()); ++i) {
-    if (candidates_[i] == candidate) {
-      return i;
-    }
-  }
-
-  for (int i = 0; i < static_cast<int>(meta_candidates_.size()); ++i) {
-    if (&(meta_candidates_[i]) == candidate) {
-      return -i - 1;
-    }
-  }
-
-  return static_cast<int>(candidates_size());
-}
-
 size_t Segment::candidates_size() const { return candidates_.size(); }
 
 void Segment::clear_candidates() {
-  pool_->Free();
+  pool_.clear();
   candidates_.clear();
 }
 
 Segment::Candidate *Segment::push_back_candidate() {
-  Candidate *candidate = pool_->Alloc();
+  Candidate *candidate =
+      pool_.emplace_back(std::make_unique<Candidate>()).get();
   candidate->Init();
   candidates_.push_back(candidate);
   return candidate;
 }
 
 Segment::Candidate *Segment::push_front_candidate() {
-  Candidate *candidate = pool_->Alloc();
+  Candidate *candidate =
+      pool_.emplace_back(std::make_unique<Candidate>()).get();
   candidate->Init();
   candidates_.push_front(candidate);
   return candidate;
@@ -307,24 +308,52 @@ Segment::Candidate *Segment::insert_candidate(int i) {
                 << candidates_.size();
     i = static_cast<int>(candidates_.size());
   }
-  Candidate *candidate = pool_->Alloc();
+  Candidate *candidate =
+      pool_.emplace_back(std::make_unique<Candidate>()).get();
   candidate->Init();
   candidates_.insert(candidates_.begin() + i, candidate);
   return candidate;
 }
 
+void Segment::insert_candidate(int i, std::unique_ptr<Candidate> candidate) {
+  Candidate *cand_ptr = pool_.emplace_back(std::move(candidate)).get();
+  if (i <= 0) {
+    candidates_.push_front(cand_ptr);
+  } else if (i >= static_cast<int>(candidates_.size())) {
+    candidates_.push_back(cand_ptr);
+  } else {
+    candidates_.insert(candidates_.begin() + i, cand_ptr);
+  }
+}
+
+void Segment::insert_candidates(
+    int i, std::vector<std::unique_ptr<Candidate>> &&candidates) {
+  if (i < 0) {
+    i = 0;
+  } else if (i > static_cast<int>(candidates_.size())) {
+    i = static_cast<int>(candidates_.size());
+  }
+
+  const size_t orig_size = candidates_.size();
+  candidates_.resize(orig_size + candidates.size());
+  std::copy_backward(candidates_.begin() + i, candidates_.begin() + orig_size,
+                     candidates_.end());
+  for (const auto &candidate : candidates) {
+    candidates_[i++] = candidate.get();
+  }
+
+  pool_.insert(pool_.end(), std::make_move_iterator(candidates.begin()),
+               std::make_move_iterator(candidates.end()));
+}
+
 void Segment::pop_front_candidate() {
   if (!candidates_.empty()) {
-    Candidate *c = candidates_.front();
-    pool_->Release(c);
     candidates_.pop_front();
   }
 }
 
 void Segment::pop_back_candidate() {
   if (!candidates_.empty()) {
-    Candidate *c = candidates_.back();
-    pool_->Release(c);
     candidates_.pop_back();
   }
 }
@@ -334,7 +363,6 @@ void Segment::erase_candidate(int i) {
     LOG(WARNING) << "invalid index";
     return;
   }
-  pool_->Release(mutable_candidate(i));
   candidates_.erase(candidates_.begin() + i);
 }
 
@@ -345,9 +373,6 @@ void Segment::erase_candidates(int i, size_t size) {
     LOG(WARNING) << "invalid index";
     return;
   }
-  for (int j = i; j < static_cast<int>(end); ++j) {
-    pool_->Release(mutable_candidate(j));
-  }
   candidates_.erase(candidates_.begin() + i, candidates_.begin() + end);
 }
 
@@ -424,23 +449,6 @@ void Segment::Clear() {
   segment_type_ = FREE;
 }
 
-void Segment::CopyFrom(const Segment &src) {
-  Clear();
-
-  key_ = src.key();
-  segment_type_ = src.segment_type();
-
-  for (size_t i = 0; i < src.candidates_size(); ++i) {
-    Candidate *candidate = add_candidate();
-    candidate->CopyFrom(src.candidate(i));
-  }
-
-  for (size_t i = 0; i < src.meta_candidates_size(); ++i) {
-    Candidate *meta_candidate = add_meta_candidate();
-    meta_candidate->CopyFrom(src.meta_candidate(i));
-  }
-}
-
 std::string Segment::DebugString() const {
   std::stringstream os;
   os << "[segtype=" << segment_type() << " key=" << key() << std::endl;
@@ -458,36 +466,43 @@ std::string Segment::DebugString() const {
   return os.str();
 }
 
-void Segments::RevertEntry::CopyFrom(const RevertEntry &src) {
-  revert_entry_type = src.revert_entry_type;
-  id = src.id;
-  timestamp = src.timestamp;
-  key = src.key;
-}
-
 Segments::Segments()
     : max_history_segments_size_(0),
-      max_prediction_candidates_size_(0),
-      max_conversion_candidates_size_(kMaxConversionCandidatesSize),
       resized_(false),
-      user_history_enabled_(true),
-      request_type_(Segments::CONVERSION),
-      pool_(new ObjectPool<Segment>(32)),
+      pool_(32),
       cached_lattice_(new Lattice()) {}
 
-Segments::~Segments() {}
-
-Segments::RequestType Segments::request_type() const { return request_type_; }
-
-void Segments::set_request_type(Segments::RequestType request_type) {
-  request_type_ = request_type;
+Segments::Segments(const Segments &x)
+    : max_history_segments_size_(x.max_history_segments_size_),
+      resized_(x.resized_),
+      pool_(32),
+      revert_entries_(x.revert_entries_),
+      cached_lattice_(new Lattice()) {
+  // Deep-copy segments.
+  for (const Segment *segment : x.segments_) {
+    *add_segment() = *segment;
+  }
+  // Note: cached_lattice_ is not copied to follow the old copy policy.
+  // TODO(noriyukit): This design is not intuitive. It'd be better to manage
+  // cached_lattice_ in a better way.
 }
 
-void Segments::set_user_history_enabled(bool user_history_enabled) {
-  user_history_enabled_ = user_history_enabled;
+Segments &Segments::operator=(const Segments &x) {
+  Clear();
+
+  max_history_segments_size_ = x.max_history_segments_size_;
+  resized_ = x.resized_;
+  // Deep-copy segments.
+  for (const Segment *segment : x.segments_) {
+    *add_segment() = *segment;
+  }
+  revert_entries_ = x.revert_entries_;
+  // Note: cached_lattice_ is not copied; see the comment for the copy
+  // constructor.
+  return *this;
 }
 
-bool Segments::user_history_enabled() const { return user_history_enabled_; }
+Segments::~Segments() = default;
 
 const Segment &Segments::segment(size_t i) const { return *segments_[i]; }
 
@@ -510,21 +525,21 @@ Segment *Segments::mutable_conversion_segment(size_t i) {
 Segment *Segments::add_segment() { return push_back_segment(); }
 
 Segment *Segments::insert_segment(size_t i) {
-  Segment *segment = pool_->Alloc();
+  Segment *segment = pool_.Alloc();
   segment->Clear();
   segments_.insert(segments_.begin() + i, segment);
   return segment;
 }
 
 Segment *Segments::push_back_segment() {
-  Segment *segment = pool_->Alloc();
+  Segment *segment = pool_.Alloc();
   segment->Clear();
   segments_.push_back(segment);
   return segment;
 }
 
 Segment *Segments::push_front_segment() {
-  Segment *segment = pool_->Alloc();
+  Segment *segment = pool_.Alloc();
   segment->Clear();
   segments_.push_front(segment);
   return segment;
@@ -552,7 +567,7 @@ void Segments::erase_segment(size_t i) {
   if (i >= segments_size()) {
     return;
   }
-  pool_->Release(mutable_segment(i));
+  pool_.Release(mutable_segment(i));
   segments_.erase(segments_.begin() + i);
 }
 
@@ -562,7 +577,7 @@ void Segments::erase_segments(size_t i, size_t size) {
     return;
   }
   for (size_t j = i; j < end; ++j) {
-    pool_->Release(mutable_segment(j));
+    pool_.Release(mutable_segment(j));
   }
   segments_.erase(segments_.begin() + i, segments_.begin() + end);
 }
@@ -570,7 +585,7 @@ void Segments::erase_segments(size_t i, size_t size) {
 void Segments::pop_front_segment() {
   if (!segments_.empty()) {
     Segment *seg = segments_.front();
-    pool_->Release(seg);
+    pool_.Release(seg);
     segments_.pop_front();
   }
 }
@@ -578,7 +593,7 @@ void Segments::pop_front_segment() {
 void Segments::pop_back_segment() {
   if (!segments_.empty()) {
     Segment *seg = segments_.back();
-    pool_->Release(seg);
+    pool_.Release(seg);
     segments_.pop_back();
   }
 }
@@ -588,29 +603,8 @@ void Segments::Clear() {
   clear_revert_entries();
 }
 
-void Segments::CopyFrom(const Segments &src) {
-  Clear();
-  max_history_segments_size_ = src.max_history_segments_size();
-  max_prediction_candidates_size_ = src.max_prediction_candidates_size();
-  max_conversion_candidates_size_ = src.max_conversion_candidates_size();
-  resized_ = src.resized();
-  user_history_enabled_ = src.user_history_enabled();
-
-  request_type_ = src.request_type();
-
-  for (size_t i = 0; i < src.segments_size(); ++i) {
-    Segment *segment = add_segment();
-    segment->CopyFrom(src.segment(i));
-  }
-
-  for (size_t i = 0; i < src.revert_entries_size(); ++i) {
-    RevertEntry *revert_entry = push_back_revert_entry();
-    revert_entry->CopyFrom(src.revert_entry(i));
-  }
-}
-
 void Segments::clear_segments() {
-  pool_->Free();
+  pool_.Free();
   resized_ = false;
   segments_.clear();
 }
@@ -629,7 +623,7 @@ void Segments::clear_history_segments() {
 void Segments::clear_conversion_segments() {
   const size_t size = history_segments_size();
   for (size_t i = size; i < segments_size(); ++i) {
-    pool_->Release(mutable_segment(i));
+    pool_.Release(mutable_segment(i));
   }
   resized_ = false;
   segments_.resize(size);
@@ -649,22 +643,6 @@ void Segments::set_resized(bool resized) { resized_ = resized; }
 
 bool Segments::resized() const { return resized_; }
 
-size_t Segments::max_prediction_candidates_size() const {
-  return max_prediction_candidates_size_;
-}
-
-void Segments::set_max_prediction_candidates_size(size_t size) {
-  max_prediction_candidates_size_ = size;
-}
-
-size_t Segments::max_conversion_candidates_size() const {
-  return max_conversion_candidates_size_;
-}
-
-void Segments::set_max_conversion_candidates_size(size_t size) {
-  max_conversion_candidates_size_ = size;
-}
-
 void Segments::clear_revert_entries() { revert_entries_.clear(); }
 
 size_t Segments::revert_entries_size() const { return revert_entries_.size(); }
