@@ -30,6 +30,7 @@
 #ifndef MOZC_CONVERTER_SEGMENTS_H_
 #define MOZC_CONVERTER_SEGMENTS_H_
 
+#include <cstdint>
 #include <deque>
 #include <memory>
 #include <string>
@@ -43,7 +44,7 @@
 
 namespace mozc {
 
-class Segment {
+class Segment final {
  public:
   enum SegmentType {
     FREE,            // FULL automatic conversion.
@@ -141,7 +142,7 @@ class Segment {
     std::string content_key;
     std::string content_value;
 
-    size_t consumed_key_size;
+    size_t consumed_key_size = 0;
 
     // Meta information
     std::string prefix;
@@ -150,7 +151,7 @@ class Segment {
     std::string description;
 
     // Usage ID
-    int32 usage_id;
+    int32_t usage_id = 0;
     // Title of the usage containing basic form of this candidate.
     std::string usage_title;
     // Content of the usage.
@@ -159,38 +160,39 @@ class Segment {
     // Context "sensitive" candidate cost.
     // Taking adjacent words/nodes into consideration.
     // Basically, candidate is sorted by this cost.
-    int32 cost;
+    int32_t cost = 0;
     // Context "free" candidate cost
     // NOT taking adjacent words/nodes into consideration.
-    int32 wcost;
+    int32_t wcost = 0;
     // (cost without transition cost between left/right boundaries)
     // Cost of only transitions (cost without word cost adjacent context)
-    int32 structure_cost;
+    int32_t structure_cost = 0;
 
     // lid of left-most node
-    uint16 lid;
+    uint16_t lid = 0;
     // rid of right-most node
-    uint16 rid;
+    uint16_t rid = 0;
 
     // Attributes of this candidate. Can set multiple attributes
     // defined in enum |Attribute|.
-    uint32 attributes;
+    uint32_t attributes = 0;
 
     // Candidate's source info which will be used for usage stats.
-    uint32 source_info;
+    uint32_t source_info = SOURCE_INFO_NONE;
 
     // Candidate style. This is not a bit-field.
     // The style is defined in enum |Style|.
-    NumberUtil::NumberString::Style style;
+    NumberUtil::NumberString::Style style =
+        NumberUtil::NumberString::DEFAULT_STYLE;
 
     // Command of this candidate. This is not a bit-field.
     // The style is defined in enum |Command|.
-    Command command;
+    Command command = DEFAULT_COMMAND;
 
     // Boundary information for realtime conversion.  This will be set only for
     // realtime conversion result candidates.  Each element is the encoded
     // lengths of key, value, content key and content value.
-    std::vector<uint32> inner_segment_boundary;
+    std::vector<uint32_t> inner_segment_boundary;
 
 #ifndef NDEBUG
     std::string log;
@@ -198,13 +200,13 @@ class Segment {
 
     static bool EncodeLengths(size_t key_len, size_t value_len,
                               size_t content_key_len, size_t content_value_len,
-                              uint32 *result);
+                              uint32_t *result);
 
     // This function ignores error, so be careful when using this.
-    static uint32 EncodeLengths(size_t key_len, size_t value_len,
-                                size_t content_key_len,
-                                size_t content_value_len) {
-      uint32 result;
+    static uint32_t EncodeLengths(size_t key_len, size_t value_len,
+                                  size_t content_key_len,
+                                  size_t content_value_len) {
+      uint32_t result;
       EncodeLengths(key_len, value_len, content_key_len, content_value_len,
                     &result);
       return result;
@@ -221,7 +223,7 @@ class Segment {
     //   absl::string_view s = iter.GetContentKey();
     //   ...
     // }
-    class InnerSegmentIterator {
+    class InnerSegmentIterator final {
      public:
       explicit InnerSegmentIterator(const Candidate *candidate)
           : candidate_(candidate),
@@ -246,43 +248,7 @@ class Segment {
       size_t index_;
     };
 
-    void Init() {
-      key.clear();
-      value.clear();
-      content_value.clear();
-      content_key.clear();
-      consumed_key_size = 0;
-      prefix.clear();
-      suffix.clear();
-      description.clear();
-      usage_title.clear();
-      usage_description.clear();
-      cost = 0;
-      structure_cost = 0;
-      wcost = 0;
-      lid = 0;
-      rid = 0;
-      usage_id = 0;
-      attributes = 0;
-      source_info = SOURCE_INFO_NONE;
-      style = NumberUtil::NumberString::DEFAULT_STYLE;
-      command = DEFAULT_COMMAND;
-      inner_segment_boundary.clear();
-#ifndef NDEBUG
-      log.clear();
-#endif  // NDEBUG
-    }
-
-    Candidate()
-        : cost(0),
-          wcost(0),
-          structure_cost(0),
-          lid(0),
-          rid(0),
-          attributes(0),
-          source_info(SOURCE_INFO_NONE),
-          style(NumberUtil::NumberString::DEFAULT_STYLE),
-          command(DEFAULT_COMMAND) {}
+    void Init();
 
     // Returns functional key.
     // functional_key =
@@ -294,12 +260,15 @@ class Segment {
     // value.substr(content_value.size(), value.size() - content_value.size());
     absl::string_view functional_value() const;
 
-    void CopyFrom(const Candidate &src);
     bool IsValid() const;
     std::string DebugString() const;
   };
 
   Segment();
+
+  Segment(const Segment &x);
+  Segment &operator=(const Segment &x);
+
   ~Segment();
 
   SegmentType segment_type() const;
@@ -318,15 +287,14 @@ class Segment {
   // setter
   Candidate *mutable_candidate(int i);
 
-  // return the index of candidate
-  // if candidate is not found, return candidates_size()
-  int indexOf(const Candidate *candidate);
-
   // push and insert candidates
   Candidate *push_front_candidate();
   Candidate *push_back_candidate();
   Candidate *add_candidate();  // alias of push_back_candidate()
   Candidate *insert_candidate(int i);
+  void insert_candidate(int i, std::unique_ptr<Candidate> candidate);
+  void insert_candidates(int i,
+                         std::vector<std::unique_ptr<Candidate>> &&candidates);
 
   // get size of candidates
   size_t candidates_size() const;
@@ -355,7 +323,6 @@ class Segment {
   void move_candidate(int old_idx, int new_idx);
 
   void Clear();
-  void CopyFrom(const Segment &src);
 
   // Keep clear() method as other modules are still using the old method
   void clear() { Clear(); }
@@ -377,8 +344,7 @@ class Segment {
   std::string key_;
   std::deque<Candidate *> candidates_;
   std::vector<Candidate> meta_candidates_;
-  std::unique_ptr<ObjectPool<Candidate>> pool_;
-  DISALLOW_COPY_AND_ASSIGN(Segment);
+  std::vector<std::unique_ptr<Candidate>> pool_;
 };
 
 // Segments is basically an array of Segment.
@@ -400,17 +366,8 @@ class Segment {
 // conversion_segment(i) and mutable_conversion_segment(i)
 //  access only Conversion Segment
 //  segment(i + history_segments_size()) == conversion_segment(i)
-class Segments {
+class Segments final {
  public:
-  enum RequestType {
-    CONVERSION,          // normal conversion
-    REVERSE_CONVERSION,  // reverse conversion
-    PREDICTION,          // show prediction with user tab key
-    SUGGESTION,          // show prediction automatically
-    PARTIAL_PREDICTION,  // show prediction using the text before cursor
-    PARTIAL_SUGGESTION,  // show suggestion using the text before cursor
-  };
-
   // Client of segments can remember any string which can be used
   // to revert the last Finish operation.
   // "id" can be used for identifying the purpose of the key;
@@ -419,23 +376,20 @@ class Segments {
       CREATE_ENTRY,
       UPDATE_ENTRY,
     };
-    uint16 revert_entry_type;
+    uint16_t revert_entry_type = 0;
     // UserHitoryPredictor uses '1' for now.
     // Do not use duplicate keys.
-    uint16 id;
-    uint32 timestamp;
+    uint16_t id = 0;
+    uint32_t timestamp = 0;
     std::string key;
-    RevertEntry() : revert_entry_type(0), id(0), timestamp(0) {}
-
-    void CopyFrom(const RevertEntry &src);
   };
 
-  RequestType request_type() const;
-  void set_request_type(RequestType request_type);
+  Segments();
 
-  // enable/disable user history
-  void set_user_history_enabled(bool user_history_enabled);
-  bool user_history_enabled() const;
+  Segments(const Segments &x);
+  Segments &operator=(const Segments &x);
+
+  ~Segments();
 
   // getter
   const Segment &segment(size_t i) const;
@@ -472,28 +426,12 @@ class Segments {
   void set_max_history_segments_size(size_t max_history_segments_size);
   size_t max_history_segments_size() const;
 
-  // Let predictor know the maximum size of
-  // candidates prediction/suggestion can generate.
-  void set_max_prediction_candidates_size(size_t size);
-  size_t max_prediction_candidates_size() const;
-
-  // Let converter know the maximum size of
-  // candidates converter can generate.
-  // NOTE: This field is used as an "optional" field.
-  // Rewriter might insert more than |size| candidates.
-  // Default setting is 200.
-  void set_max_conversion_candidates_size(size_t size);
-  size_t max_conversion_candidates_size() const;
-
   bool resized() const;
   void set_resized(bool resized);
 
   // clear segments
   void Clear();
 
-  // Copy segments from src
-  void CopyFrom(const Segments &src);
-
   // Dump Segments structure
   std::string DebugString() const;
 
@@ -507,23 +445,14 @@ class Segments {
   // setter
   Lattice *mutable_cached_lattice();
 
-  Segments();
-  virtual ~Segments();
-
  private:
   size_t max_history_segments_size_;
-  size_t max_prediction_candidates_size_;
-  size_t max_conversion_candidates_size_;
   bool resized_;
-  bool user_history_enabled_;
 
-  RequestType request_type_;
-  std::unique_ptr<ObjectPool<Segment>> pool_;
+  ObjectPool<Segment> pool_;
   std::deque<Segment *> segments_;
   std::vector<RevertEntry> revert_entries_;
   std::unique_ptr<Lattice> cached_lattice_;
-
-  DISALLOW_COPY_AND_ASSIGN(Segments);
 };
 
 }  // namespace mozc
