@@ -30,22 +30,31 @@
 #include "data_manager/data_manager.h"
 
 #include <algorithm>
+#include <cstdint>
+#include <memory>
 #include <ostream>
 
 #include "base/logging.h"
 #include "base/serialized_string_array.h"
-#include "base/stl_util.h"
-#include "base/util.h"
 #include "base/version.h"
 #include "data_manager/dataset_reader.h"
 #include "data_manager/serialized_dictionary.h"
 #include "protocol/segmenter_data.pb.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_format.h"
+#include "absl/strings/str_split.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
 
-const char *const kDataSetMagicNumber = "\xEFMOZC\r\n";
+#ifdef GOOGLE_JAPANESE_INPUT_BUILD
+constexpr absl::string_view kDataSetMagicNumber = "\xEFMOZC\r\n"
+#else   // GOOGLE_JAPANESE_INPUT_BUILD
+constexpr absl::string_view kDataSetMagicNumber = "\xEFMOZC\r\n";
+#endif  // GOOGLE_JAPANESE_INPUT_BUILD
+
+constexpr absl::string_view kDataSetMagicNumberOss = "\xEFMOZC\r\n";
 
 DataManager::Status InitUserPosManagerDataFromReader(
     const DataSetReader &reader, absl::string_view *pos_matcher_data,
@@ -75,6 +84,7 @@ DataManager::Status InitUserPosManagerDataFromReader(
 
 }  // namespace
 
+// static
 std::string DataManager::StatusCodeToString(Status code) {
   std::string s;
   switch (code) {
@@ -97,10 +107,35 @@ std::string DataManager::StatusCodeToString(Status code) {
       s.assign("Status::UNKNOWN");
       break;
   }
-  s.append(Util::StringPrintf("(%d)", static_cast<int>(code)));
+  s.append(absl::StrFormat("(%d)", static_cast<int>(code)));
   return s;
 }
 
+// static
+absl::string_view DataManager::GetDataSetMagicNumber(absl::string_view type) {
+  if (type == "oss") {
+    return kDataSetMagicNumberOss;
+  }
+  return kDataSetMagicNumber;
+}
+
+absl::StatusOr<std::unique_ptr<DataManager>> DataManager::CreateFromFile(
+    const std::string &path) {
+  return CreateFromFile(path, kDataSetMagicNumber);
+}
+
+absl::StatusOr<std::unique_ptr<DataManager>> DataManager::CreateFromFile(
+    const std::string &path, absl::string_view magic) {
+  auto data_manager = std::make_unique<DataManager>();
+  const Status status = data_manager->InitFromFile(path, magic);
+  if (status != DataManager::Status::OK) {
+    return absl::InternalError(
+        absl::StrFormat("%s: Failed to initialize a data manager from %s",
+                        DataManager::StatusCodeToString(status), path));
+  }
+  return data_manager;
+}
+
 DataManager::DataManager() = default;
 DataManager::~DataManager() = default;
 
@@ -339,21 +374,24 @@ DataManager::Status DataManager::InitFromReader(const DataSetReader &reader) {
   }
 
   for (const auto &kv : reader.name_to_data_map()) {
-    if (!Util::StartsWith(kv.first, "typing_model")) {
+    if (!absl::StartsWith(kv.first, "typing_model")) {
       continue;
     }
     typing_model_data_.push_back(kv);
   }
   std::sort(typing_model_data_.begin(), typing_model_data_.end(),
-            OrderBy<FirstKey, Less>());
+            [](const std::pair<std::string, absl::string_view> &l,
+               const std::pair<std::string, absl::string_view> &r) {
+              return l.first < r.first;
+            });
 
   if (!reader.Get("version", &data_version_)) {
     LOG(ERROR) << "Cannot find data version";
     return Status::DATA_MISSING;
   }
   {
-    std::vector<absl::string_view> components;
-    Util::SplitStringUsing(data_version_, ".", &components);
+    std::vector<absl::string_view> components =
+        absl::StrSplit(data_version_, '.', absl::SkipEmpty());
     if (components.size() != 3) {
       LOG(ERROR) << "Invalid version format: " << data_version_;
       return Status::DATA_BROKEN;
@@ -433,40 +471,40 @@ void DataManager::GetSuggestionFilterData(const char **data,
   *size = suggestion_filter_data_.size();
 }
 
-void DataManager::GetUserPOSData(absl::string_view *token_array_data,
+void DataManager::GetUserPosData(absl::string_view *token_array_data,
                                  absl::string_view *string_array_data) const {
   *token_array_data = user_pos_token_array_data_;
   *string_array_data = user_pos_string_array_data_;
 }
 
-const uint16 *DataManager::GetPOSMatcherData() const {
-  return reinterpret_cast<const uint16 *>(pos_matcher_data_.data());
+const uint16_t *DataManager::GetPosMatcherData() const {
+  return reinterpret_cast<const uint16_t *>(pos_matcher_data_.data());
 }
 
-const uint8 *DataManager::GetPosGroupData() const {
-  return reinterpret_cast<const uint8 *>(pos_group_data_.data());
+const uint8_t *DataManager::GetPosGroupData() const {
+  return reinterpret_cast<const uint8_t *>(pos_group_data_.data());
 }
 
 void DataManager::GetSegmenterData(
-    size_t *l_num_elements, size_t *r_num_elements, const uint16 **l_table,
-    const uint16 **r_table, size_t *bitarray_num_bytes,
-    const char **bitarray_data, const uint16 **boundary_data) const {
+    size_t *l_num_elements, size_t *r_num_elements, const uint16_t **l_table,
+    const uint16_t **r_table, size_t *bitarray_num_bytes,
+    const char **bitarray_data, const uint16_t **boundary_data) const {
   *l_num_elements = segmenter_compressed_lsize_;
   *r_num_elements = segmenter_compressed_rsize_;
-  *l_table = reinterpret_cast<const uint16 *>(segmenter_ltable_.data());
-  *r_table = reinterpret_cast<const uint16 *>(segmenter_rtable_.data());
+  *l_table = reinterpret_cast<const uint16_t *>(segmenter_ltable_.data());
+  *r_table = reinterpret_cast<const uint16_t *>(segmenter_rtable_.data());
   *bitarray_num_bytes = segmenter_bitarray_.size();
   *bitarray_data = segmenter_bitarray_.data();
-  *boundary_data = reinterpret_cast<const uint16 *>(boundary_data_.data());
+  *boundary_data = reinterpret_cast<const uint16_t *>(boundary_data_.data());
 }
 
 void DataManager::GetSuffixDictionaryData(absl::string_view *key_array_data,
                                           absl::string_view *value_array_data,
-                                          const uint32 **token_array) const {
+                                          const uint32_t **token_array) const {
   *key_array_data = suffix_key_array_data_;
   *value_array_data = suffix_value_array_data_;
   *token_array =
-      reinterpret_cast<const uint32 *>(suffix_token_array_data_.data());
+      reinterpret_cast<const uint32_t *>(suffix_token_array_data_.data());
 }
 
 void DataManager::GetReadingCorrectionData(
