@@ -30,6 +30,7 @@
 #ifndef MOZC_DATA_MANAGER_DATA_MANAGER_H_
 #define MOZC_DATA_MANAGER_DATA_MANAGER_H_
 
+#include <cstdint>
 #include <iosfwd>
 #include <string>
 #include <utility>
@@ -38,6 +39,7 @@
 #include "base/mmap.h"
 #include "base/port.h"
 #include "data_manager/data_manager_interface.h"
+#include "absl/status/statusor.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -61,8 +63,20 @@ class DataManager : public DataManagerInterface {
   };
 
   static std::string StatusCodeToString(Status code);
+  static absl::string_view GetDataSetMagicNumber(absl::string_view type);
+
+  // Creates an instance of DataManager from a data set file or returns error
+  // status on failure.
+  static absl::StatusOr<std::unique_ptr<DataManager>> CreateFromFile(
+      const std::string &path);
+  static absl::StatusOr<std::unique_ptr<DataManager>> CreateFromFile(
+      const std::string &path, absl::string_view magic);
 
   DataManager();
+
+  DataManager(const DataManager &) = delete;
+  DataManager &operator=(const DataManager &) = delete;
+
   ~DataManager() override;
 
   // Parses |array| and extracts byte blocks of data set.  The |array| must
@@ -87,8 +101,8 @@ class DataManager : public DataManagerInterface {
                                         absl::string_view magic);
 
   // Implementation of DataManagerInterface.
-  const uint16 *GetPOSMatcherData() const override;
-  void GetUserPOSData(absl::string_view *token_array_data,
+  const uint16_t *GetPosMatcherData() const override;
+  void GetUserPosData(absl::string_view *token_array_data,
                       absl::string_view *string_array_data) const override;
   void GetConnectorData(const char **data, size_t *size) const override;
   void GetSystemDictionaryData(const char **data, int *size) const override;
@@ -96,16 +110,16 @@ class DataManager : public DataManagerInterface {
   void GetCollocationSuppressionData(const char **array,
                                      size_t *size) const override;
   void GetSuggestionFilterData(const char **data, size_t *size) const override;
-  const uint8 *GetPosGroupData() const override;
+  const uint8_t *GetPosGroupData() const override;
   void GetSegmenterData(size_t *l_num_elements, size_t *r_num_elements,
-                        const uint16 **l_table, const uint16 **r_table,
+                        const uint16_t **l_table, const uint16_t **r_table,
                         size_t *bitarray_num_bytes, const char **bitarray_data,
-                        const uint16 **boundary_data) const override;
+                        const uint16_t **boundary_data) const override;
   void GetCounterSuffixSortedArray(const char **array,
                                    size_t *size) const override;
   void GetSuffixDictionaryData(absl::string_view *key_array_data,
                                absl::string_view *value_array_data,
-                               const uint32 **token_array) const override;
+                               const uint32_t **token_array) const override;
   void GetReadingCorrectionData(
       absl::string_view *value_array_data, absl::string_view *error_array_data,
       absl::string_view *correction_array_data) const override;
@@ -193,8 +207,6 @@ class DataManager : public DataManagerInterface {
   absl::string_view usage_string_array_data_;
   std::vector<std::pair<std::string, absl::string_view>> typing_model_data_;
   absl::string_view data_version_;
-
-  DISALLOW_COPY_AND_ASSIGN(DataManager);
 };
 
 // Print helper for DataManager::Status.  Logging, e.g., CHECK_EQ(), requires
