@@ -31,9 +31,10 @@
 
 #include <string>
 
-#include "base/file_stream.h"
+#include "base/file_util.h"
 #include "base/logging.h"
 #include "base/port.h"
+#include "base/status.h"
 #include "base/unverified_sha1.h"
 #include "base/util.h"
 #include "absl/strings/string_view.h"
@@ -50,7 +51,7 @@ DataSetWriter::DataSetWriter(absl::string_view magic)
 
 DataSetWriter::~DataSetWriter() = default;
 
-void DataSetWriter::Add(const string &name, int alignment,
+void DataSetWriter::Add(const std::string &name, int alignment,
                         absl::string_view data) {
   CHECK(seen_names_.insert(name).second) << name << " was already added";
   AppendPadding(alignment);
@@ -61,16 +62,15 @@ void DataSetWriter::Add(const string &name, int alignment,
   image_.append(data.data(), data.size());
 }
 
-void DataSetWriter::AddFile(const string &name, int alignment,
-                            const string &filepath) {
-  mozc::InputFileStream ifs(filepath.c_str(),
-                            std::ios_base::in | std::ios_base::binary);
-  CHECK(ifs.good()) << "Failed to open " << name;
-  Add(name, alignment, ifs.Read());
+void DataSetWriter::AddFile(const std::string &name, int alignment,
+                            const std::string &filepath) {
+  absl::StatusOr<std::string> content = FileUtil::GetContents(filepath);
+  CHECK_OK(content);
+  Add(name, alignment, *content);
 }
 
 void DataSetWriter::Finish(std::ostream *output) {
-  const string s = metadata_.SerializeAsString();
+  const std::string s = metadata_.SerializeAsString();
   image_.append(s);                                // Metadata
   image_.append(Util::SerializeUint64(s.size()));  // Metadata size
 
