@@ -29,6 +29,7 @@
 
 #include "data_manager/serialized_dictionary.h"
 
+#include <cstdint>
 #include <sstream>
 #include <string>
 
@@ -59,8 +60,8 @@ class SerializedDictionaryTest : public ::testing::Test {
   absl::string_view string_array_data_;  // Pointing to a block of buf2_
 
  private:
-  std::unique_ptr<uint32[]> buf1_;
-  std::unique_ptr<uint32[]> buf2_;
+  std::unique_ptr<uint32_t[]> buf1_;
+  std::unique_ptr<uint32_t[]> buf2_;
 };
 
 TEST_F(SerializedDictionaryTest, Compile) {
@@ -81,7 +82,7 @@ TEST_F(SerializedDictionaryTest, Compile) {
   EXPECT_EQ("value3", string_array[9]);
 
   // Recall that entries are sorted first by key then by cost.
-  const char kExpectedTokenArray[] =
+  constexpr char kExpectedTokenArray[] =
       // Entry 2
       "\x05\x00\x00\x00"  // key = "key1", index = 5
       "\x08\x00\x00\x00"  // value = "value2", index = 8
@@ -110,7 +111,7 @@ TEST_F(SerializedDictionaryTest, Compile) {
       "\xd0\x07"          // cost = 2000
       "\x00\x00";         // padding
   ASSERT_EQ(
-      std::string(kExpectedTokenArray, arraysize(kExpectedTokenArray) - 1),
+      std::string(kExpectedTokenArray, std::size(kExpectedTokenArray) - 1),
       token_array_data_);
 }
 
