@@ -44,12 +44,12 @@ namespace {
 #error "MOZC_DATASET_MAGIC_NUMBER is not defined by build system"
 #endif  // MOZC_DATASET_MAGIC_NUMBER
 
-const char kMagicNumber[] = MOZC_DATASET_MAGIC_NUMBER;
+constexpr char kMagicNumber[] = MOZC_DATASET_MAGIC_NUMBER;
 
 }  // namespace
 
 MockDataManager::MockDataManager() {
-  const absl::string_view magic(kMagicNumber, arraysize(kMagicNumber) - 1);
+  const absl::string_view magic(kMagicNumber, std::size(kMagicNumber) - 1);
   CHECK_EQ(Status::OK, InitFromArray(LoadEmbeddedFile(kMockMozcDataSet), magic))
       << "Embedded mock_mozc_data.h is broken";
 }
