@@ -50,7 +50,6 @@
 #include "request/conversion_request.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -60,14 +59,14 @@ namespace {
 struct DictionaryData {
   std::unique_ptr<DictionaryInterface> user_dictionary;
   std::unique_ptr<SuppressionDictionary> suppression_dictionary;
-  POSMatcher pos_matcher;
+  PosMatcher pos_matcher;
   std::unique_ptr<DictionaryInterface> dictionary;
 };
 
 std::unique_ptr<DictionaryData> CreateDictionaryData() {
-  auto ret = absl::make_unique<DictionaryData>();
+  auto ret = std::make_unique<DictionaryData>();
   testing::MockDataManager data_manager;
-  ret->pos_matcher.Set(data_manager.GetPOSMatcherData());
+  ret->pos_matcher.Set(data_manager.GetPosMatcherData());
   const char *dictionary_data = nullptr;
   int dictionary_size = 0;
   data_manager.GetSystemDictionaryData(&dictionary_data, &dictionary_size);
@@ -75,11 +74,11 @@ std::unique_ptr<DictionaryData> CreateDictionaryData() {
       SystemDictionary::Builder(dictionary_data, dictionary_size)
           .Build()
           .value();
-  auto val_dict = absl::make_unique<ValueDictionary>(ret->pos_matcher,
-                                                     &sys_dict->value_trie());
-  ret->user_dictionary = absl::make_unique<UserDictionaryStub>();
-  ret->suppression_dictionary = absl::make_unique<SuppressionDictionary>();
-  ret->dictionary = absl::make_unique<DictionaryImpl>(
+  auto val_dict = std::make_unique<ValueDictionary>(ret->pos_matcher,
+                                                    &sys_dict->value_trie());
+  ret->user_dictionary = std::make_unique<UserDictionaryStub>();
+  ret->suppression_dictionary = std::make_unique<SuppressionDictionary>();
+  ret->dictionary = std::make_unique<DictionaryImpl>(
       std::move(sys_dict), std::move(val_dict), ret->user_dictionary.get(),
       ret->suppression_dictionary.get(), &ret->pos_matcher);
   return ret;
@@ -144,7 +143,7 @@ class DictionaryImplTest : public ::testing::Test {
    public:
     explicit CheckZipCodeExistenceCallback(absl::string_view key,
                                            absl::string_view value,
-                                           const POSMatcher *pos_matcher)
+                                           const PosMatcher *pos_matcher)
         : key_(key), value_(value), pos_matcher_(pos_matcher), found_(false) {}
 
     ResultType OnToken(absl::string_view /* key */,
@@ -162,7 +161,7 @@ class DictionaryImplTest : public ::testing::Test {
 
    private:
     const absl::string_view key_, value_;
-    const POSMatcher *pos_matcher_;
+    const PosMatcher *pos_matcher_;
     bool found_;
   };
 
@@ -206,8 +205,8 @@ TEST_F(DictionaryImplTest, WordSuppressionTest) {
   DictionaryInterface *d = data->dictionary.get();
   SuppressionDictionary *s = data->suppression_dictionary.get();
 
-  const char kKey[] = "ぐーぐる";
-  const char kValue[] = "グーグル";
+  constexpr char kKey[] = "ぐーぐる";
+  constexpr char kValue[] = "グーグル";
 
   const LookupMethodAndQuery kTestPair[] = {
       {&DictionaryInterface::LookupPrefix, "ぐーぐるは"},
@@ -220,7 +219,7 @@ TEST_F(DictionaryImplTest, WordSuppressionTest) {
   s->Clear();
   s->AddEntry(kKey, kValue);
   s->UnLock();
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckKeyValueExistenceCallback callback(kKey, kValue);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_FALSE(callback.found());
@@ -230,7 +229,7 @@ TEST_F(DictionaryImplTest, WordSuppressionTest) {
   s->Lock();
   s->Clear();
   s->UnLock();
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckKeyValueExistenceCallback callback(kKey, kValue);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_TRUE(callback.found());
@@ -242,8 +241,8 @@ TEST_F(DictionaryImplTest, DisableSpellingCorrectionTest) {
   DictionaryInterface *d = data->dictionary.get();
 
   // "あぼがど" -> "アボカド", which is in the test dictionary.
-  const char kKey[] = "あぼがど";
-  const char kValue[] = "アボカド";
+  constexpr char kKey[] = "あぼがど";
+  constexpr char kValue[] = "アボカド";
 
   const LookupMethodAndQuery kTestPair[] = {
       {&DictionaryInterface::LookupPrefix, kKey},
@@ -253,7 +252,7 @@ TEST_F(DictionaryImplTest, DisableSpellingCorrectionTest) {
   // The spelling correction entry (kKey, kValue) should be found if spelling
   // correction flag is set in the config.
   config_.set_use_spelling_correction(true);
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckSpellingExistenceCallback callback(kKey, kValue);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_TRUE(callback.found());
@@ -261,7 +260,7 @@ TEST_F(DictionaryImplTest, DisableSpellingCorrectionTest) {
 
   // Without the flag, it should be suppressed.
   config_.set_use_spelling_correction(false);
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckSpellingExistenceCallback callback(kKey, kValue);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_FALSE(callback.found());
@@ -273,8 +272,8 @@ TEST_F(DictionaryImplTest, DisableZipCodeConversionTest) {
   DictionaryInterface *d = data->dictionary.get();
 
   // "100-0000" -> "東京都千代田区", which is in the test dictionary.
-  const char kKey[] = "100-0000";
-  const char kValue[] = "東京都千代田区";
+  constexpr char kKey[] = "100-0000";
+  constexpr char kValue[] = "東京都千代田区";
 
   const LookupMethodAndQuery kTestPair[] = {
       {&DictionaryInterface::LookupPrefix, kKey},
@@ -284,7 +283,7 @@ TEST_F(DictionaryImplTest, DisableZipCodeConversionTest) {
   // The zip code entry (kKey, kValue) should be found if the flag is set in the
   // config.
   config_.set_use_zip_code_conversion(true);
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckZipCodeExistenceCallback callback(kKey, kValue, &data->pos_matcher);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_TRUE(callback.found());
@@ -292,7 +291,7 @@ TEST_F(DictionaryImplTest, DisableZipCodeConversionTest) {
 
   // Without the flag, it should be suppressed.
   config_.set_use_zip_code_conversion(false);
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckZipCodeExistenceCallback callback(kKey, kValue, &data->pos_matcher);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_FALSE(callback.found());
@@ -304,8 +303,8 @@ TEST_F(DictionaryImplTest, DisableT13nConversionTest) {
   DictionaryInterface *d = data->dictionary.get();
   NodeAllocator allocator;
 
-  const char kKey[] = "ぐーぐる";
-  const char kValue[] = "Google";
+  constexpr char kKey[] = "ぐーぐる";
+  constexpr char kValue[] = "Google";
 
   const LookupMethodAndQuery kTestPair[] = {
       {&DictionaryInterface::LookupPrefix, kKey},
@@ -315,7 +314,7 @@ TEST_F(DictionaryImplTest, DisableT13nConversionTest) {
   // The T13N entry (kKey, kValue) should be found if the flag is set in the
   // config.
   config_.set_use_t13n_conversion(true);
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckEnglishT13nCallback callback(kKey, kValue);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_TRUE(callback.found());
@@ -323,7 +322,7 @@ TEST_F(DictionaryImplTest, DisableT13nConversionTest) {
 
   // Without the flag, it should be suppressed.
   config_.set_use_t13n_conversion(false);
-  for (size_t i = 0; i < arraysize(kTestPair); ++i) {
+  for (size_t i = 0; i < std::size(kTestPair); ++i) {
     CheckEnglishT13nCallback callback(kKey, kValue);
     (d->*kTestPair[i].lookup_method)(kTestPair[i].query, convreq_, &callback);
     EXPECT_FALSE(callback.found());
