@@ -29,6 +29,7 @@
 
 #include "dictionary/dictionary_mock.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <vector>
@@ -39,7 +40,6 @@
 #include "dictionary/dictionary_token.h"
 #include "request/conversion_request.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace dictionary {
@@ -47,14 +47,12 @@ namespace {
 
 class DictionaryMockTest : public ::testing::Test {
  protected:
-  void SetUp() override {
-    mock_ = absl::make_unique<DictionaryMock>();
-  }
+  void SetUp() override { mock_ = std::make_unique<DictionaryMock>(); }
 
   DictionaryMock *GetMock() { return mock_.get(); }
 
   static bool SearchMatchingToken(const std::string &key,
-                                  const std::string &value, uint8 attributes,
+                                  const std::string &value, uint8_t attributes,
                                   const std::vector<Token> &tokens);
 
   std::unique_ptr<DictionaryMock> mock_;
@@ -63,7 +61,7 @@ class DictionaryMockTest : public ::testing::Test {
 
 bool DictionaryMockTest::SearchMatchingToken(const std::string &key,
                                              const std::string &value,
-                                             uint8 attributes,
+                                             uint8_t attributes,
                                              const std::vector<Token> &tokens) {
   for (const Token &token : tokens) {
     if (token.key == key && token.value == value &&
@@ -182,7 +180,7 @@ TEST_F(DictionaryMockTest, LookupPredictive) {
 TEST_F(DictionaryMockTest, LookupExact) {
   DictionaryInterface *dic = GetMock();
 
-  const char kKey[] = "ほげ";
+  constexpr char kKey[] = "ほげ";
 
   std::unique_ptr<Token> t0 = CreateToken(kKey, "value1", Token::NONE);
   std::unique_ptr<Token> t1 = CreateToken(kKey, "value2", Token::NONE);
