@@ -32,6 +32,7 @@
 #ifndef MOZC_DICTIONARY_FILE_CODEC_H_
 #define MOZC_DICTIONARY_FILE_CODEC_H_
 
+#include <cstdint>
 #include <iosfwd>
 #include <string>
 #include <vector>
@@ -39,6 +40,7 @@
 #include "base/port.h"
 #include "dictionary/file/codec_interface.h"
 #include "dictionary/file/section.h"
+#include "absl/status/status.h"
 
 namespace mozc {
 namespace dictionary {
@@ -54,7 +56,7 @@ class DictionaryFileCodec : public DictionaryFileCodecInterface {
 
   void WriteSections(const std::vector<DictionaryFileSection> &sections,
                      std::ostream *ofs) const override;
-  mozc::Status ReadSections(
+  absl::Status ReadSections(
       const char *image, int length,
       std::vector<DictionaryFileSection> *sections) const override;
   std::string GetSectionName(const std::string &name) const override;
@@ -66,9 +68,9 @@ class DictionaryFileCodec : public DictionaryFileCodecInterface {
 
   // Seed value for name string finger print
   // Made it mutable for reading sections.
-  mutable int32 seed_;
+  mutable int32_t seed_;
   // Magic value for simple file validation
-  const int32 filemagic_;
+  const int32_t filemagic_;
 };
 
 }  // namespace dictionary
