@@ -38,10 +38,11 @@
 #include "dictionary/file/codec_factory.h"
 #include "dictionary/file/codec_interface.h"
 #include "dictionary/file/section.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/status/status.h"
 
 namespace mozc {
 namespace dictionary {
@@ -54,13 +55,13 @@ class CodecTest : public ::testing::Test {
  protected:
   void SetUp() override {
     DictionaryFileCodecFactory::SetCodec(nullptr);
-    FileUtil::Unlink(test_file_);
+    EXPECT_OK(FileUtil::UnlinkIfExists(test_file_));
   }
 
   void TearDown() override {
     // Reset to default setting
     DictionaryFileCodecFactory::SetCodec(nullptr);
-    FileUtil::Unlink(test_file_);
+    EXPECT_OK(FileUtil::UnlinkIfExists(test_file_));
   }
 
   void AddSection(const DictionaryFileCodecInterface *codec,
@@ -100,25 +101,25 @@ class CodecMock : public DictionaryFileCodecInterface {
  public:
   void WriteSections(const std::vector<DictionaryFileSection> &sections,
                      std::ostream *ofs) const override {
-    const std::string value = "dummy value";
+    const std::string value = "placeholder value";
     ofs->write(value.data(), value.size());
   }
 
-  mozc::Status ReadSections(
+  absl::Status ReadSections(
       const char *image, int length,
       std::vector<DictionaryFileSection> *sections) const override {
-    sections->emplace_back(nullptr, 0, "dummy name");
-    return mozc::Status();
+    sections->emplace_back(nullptr, 0, "placeholder name");
+    return absl::Status();
   }
 
   std::string GetSectionName(const std::string &name) const override {
-    return "dummy section name";
+    return "placeholder section name";
   }
 };
 
 TEST_F(CodecTest, FactoryTest) {
-  auto codec_mock = absl::make_unique<CodecMock>();
-  DictionaryFileCodecFactory::SetCodec(codec_mock.get());
+  CodecMock codec_mock;
+  DictionaryFileCodecFactory::SetCodec(&codec_mock);
   const DictionaryFileCodecInterface *codec =
       DictionaryFileCodecFactory::GetCodec();
   EXPECT_TRUE(codec != nullptr);
@@ -129,23 +130,17 @@ TEST_F(CodecTest, FactoryTest) {
     codec->WriteSections(sections, &ofs);
   }
   {
-    EXPECT_TRUE(FileUtil::FileExists(test_file_));
-    InputFileStream ifs;
-    ifs.open(test_file_.c_str(), std::ios_base::in | std::ios_base::binary);
-    ifs.seekg(0, std::ios::end);
-    const int len = ifs.tellg();
-    ifs.seekg(0, std::ios::beg);
-    char buf[64];
-    ifs.read(buf, len);
-    EXPECT_EQ("dummy value", std::string(buf, len));
+    absl::StatusOr<std::string> content = FileUtil::GetContents(test_file_);
+    ASSERT_OK(content);
+    EXPECT_EQ("placeholder value", *content);
   }
   {
     EXPECT_EQ(0, sections.size());
     EXPECT_TRUE(codec->ReadSections(nullptr, 0, &sections).ok());
     EXPECT_EQ(1, sections.size());
-    EXPECT_EQ("dummy name", sections[0].name);
+    EXPECT_EQ("placeholder name", sections[0].name);
   }
-  { EXPECT_EQ("dummy section name", codec->GetSectionName("test")); }
+  { EXPECT_EQ("placeholder section name", codec->GetSectionName("test")); }
 }
 
 TEST_F(CodecTest, DefaultTest) {
@@ -166,10 +161,7 @@ TEST_F(CodecTest, DefaultTest) {
   }
   std::string buf;  // sections will reference this buffer.
   std::vector<DictionaryFileSection> sections;
-  ASSERT_TRUE(FileUtil::FileExists(test_file_));
-  buf = InputFileStream(test_file_.c_str(),
-                        std::ios_base::in | std::ios_base::binary)
-            .Read();
+  ASSERT_OK(FileUtil::GetContents(test_file_, &buf));
   ASSERT_TRUE(codec->ReadSections(buf.data(), buf.size(), &sections).ok());
   ASSERT_EQ(2, sections.size());
   int index = -1;
@@ -183,8 +175,8 @@ TEST_F(CodecTest, DefaultTest) {
 }
 
 TEST_F(CodecTest, RandomizedCodecTest) {
-  auto internal_codec = absl::make_unique<DictionaryFileCodec>();
-  DictionaryFileCodecFactory::SetCodec(internal_codec.get());
+  DictionaryFileCodec internal_codec;
+  DictionaryFileCodecFactory::SetCodec(&internal_codec);
   const DictionaryFileCodecInterface *codec =
       DictionaryFileCodecFactory::GetCodec();
   EXPECT_TRUE(codec != nullptr);
@@ -202,10 +194,7 @@ TEST_F(CodecTest, RandomizedCodecTest) {
   }
   std::string buf;  // sections will reference this buffer.
   std::vector<DictionaryFileSection> sections;
-  ASSERT_TRUE(FileUtil::FileExists(test_file_));
-  buf = InputFileStream(test_file_.c_str(),
-                        std::ios_base::in | std::ios_base::binary)
-            .Read();
+  ASSERT_OK(FileUtil::GetContents(test_file_, &buf));
   ASSERT_TRUE(codec->ReadSections(buf.data(), buf.size(), &sections).ok());
   ASSERT_EQ(2, sections.size());
   int index = -1;
