@@ -30,6 +30,8 @@
 #ifndef MOZC_DICTIONARY_SUFFIX_DICTIONARY_H_
 #define MOZC_DICTIONARY_SUFFIX_DICTIONARY_H_
 
+#include <cstdint>
+
 #include "base/port.h"
 #include "base/serialized_string_array.h"
 #include "dictionary/dictionary_interface.h"
@@ -53,7 +55,7 @@ class SuffixDictionary : public DictionaryInterface {
  public:
   SuffixDictionary(absl::string_view key_array_data,
                    absl::string_view value_array_data,
-                   const uint32 *token_array);
+                   const uint32_t *token_array);
   ~SuffixDictionary() override;
 
   bool HasKey(absl::string_view key) const override;
@@ -80,7 +82,7 @@ class SuffixDictionary : public DictionaryInterface {
  private:
   SerializedStringArray key_array_;
   SerializedStringArray value_array_;
-  const uint32 *token_array_;
+  const uint32_t *token_array_;
 
   DISALLOW_COPY_AND_ASSIGN(SuffixDictionary);
 };
