@@ -30,56 +30,80 @@
 #ifndef MOZC_DICTIONARY_SUPPRESSION_DICTIONARY_H_
 #define MOZC_DICTIONARY_SUPPRESSION_DICTIONARY_H_
 
+#include <atomic>
 #include <set>
 #include <string>
 
-#include "base/mutex.h"
-#include "base/port.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 namespace dictionary {
 
-class SuppressionDictionary {
+// Provides a functionality to test if a word should be suppressed in conversion
+// results. This class is not thread safe in general use but is safe under
+// single-producer single-consumer model, provided that the usage is correct. In
+// our usage, the producer is UserDictionary::UserDictionaryReloader thread and
+// the consumer is the main converter thread.
+class SuppressionDictionary final {
  public:
   SuppressionDictionary();
-  virtual ~SuppressionDictionary();
+  ~SuppressionDictionary();
 
-  // Locks dictionary.
-  // Need to lock before calling AddEntry() or Clear().
-  // When the dictionary is locked, Suppress() return false.
+  SuppressionDictionary(const SuppressionDictionary &) = delete;
+  SuppressionDictionary &operator=(const SuppressionDictionary &) = delete;
+
+  // Methods for the producer thread. The thread must obey this edit pattern:
   //
-  // NOTE:
-  // Lock() and SuppressWord() must be called synchronously.
+  // Lock();
+  // Calls of AddEntry() and/or Clear()
+  // Unlock();
+  //
+  // The producer thread must not call the other methods.
+
+  // Locks the dictionary (the producer thread is blocked until it gets the
+  // lock). Should not be called recursively.
   void Lock();
 
-  // Unlocks dictionary.
+  // Unlocks the dictionary.
   void UnLock();
 
-  // Returns true if the dictionary is locked.
-  bool IsLocked() const { return locked_; }
-
-  // Note: this method is thread unsafe.
+  // Adds an entry into the dictionary.
   bool AddEntry(const std::string &key, const std::string &value);
 
-  // Note: this method is thread unsafe.
+  // Clears the dictionary.
   void Clear();
 
+  // Returns true if the dictionary is locked. This method is for debugging.
+  bool IsLocked() const { return locked_.load(std::memory_order_relaxed); }
+
+  // Methods for the consumer thread. If the producer thread is updating the
+  // dictionary contents, the following methods behave as if the dictionary is
+  // empty.
+
   // Returns true if SuppressionDictionary doesn't have any entries.
   bool IsEmpty() const;
 
-  // Returns true if |word| should be suppressed.  If the current dictionary is
-  // "locked" via Lock() method, this function always return false.  Lock() and
-  // SuppressWord() must be called synchronously.
+  // Returns true if a word having `key` and `value` should be suppressed.
   bool SuppressEntry(const std::string &key, const std::string &value) const;
 
  private:
   std::set<std::string> dic_;
-  bool locked_;
   bool has_key_empty_;
   bool has_value_empty_;
-  Mutex mutex_;
+  mutable std::atomic<bool> locked_;
+  // TODO(noriyukit): Check if this mutex is still necessary.
+  absl::Mutex mutex_;
+};
 
-  DISALLOW_COPY_AND_ASSIGN(SuppressionDictionary);
+class SuppressionDictionaryLock final {
+ public:
+  explicit SuppressionDictionaryLock(SuppressionDictionary *dic) : dic_{dic} {
+    dic_->Lock();
+  }
+  ~SuppressionDictionaryLock() { dic_->UnLock(); }
+
+ private:
+  SuppressionDictionary *dic_;
 };
 
 }  // namespace dictionary
