@@ -47,6 +47,7 @@
 #include "dictionary/system/system_dictionary.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <cstring>
 #include <limits>
 #include <map>
@@ -56,6 +57,7 @@
 #include <utility>
 #include <vector>
 
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/mmap.h"
 #include "base/port.h"
@@ -68,7 +70,7 @@
 #include "dictionary/system/words_info.h"
 #include "storage/louds/bit_vector_based_array.h"
 #include "storage/louds/louds_trie.h"
-#include "absl/memory/memory.h"
+#include "absl/container/btree_set.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -79,22 +81,22 @@ using ::mozc::storage::louds::LoudsTrie;
 
 namespace {
 
-const int kMinTokenArrayBlobSize = 4;
+constexpr int kMinTokenArrayBlobSize = 4;
 
 // TODO(noriyukit): The following parameters may not be well optimized.  In our
 // experiments, Select1 is computational burden, so increasing cache size for
 // lb1/select1 may improve performance.
-const size_t kKeyTrieLb0CacheSize = 1 * 1024;
-const size_t kKeyTrieLb1CacheSize = 1 * 1024;
-const size_t kKeyTrieSelect0CacheSize = 4 * 1024;
-const size_t kKeyTrieSelect1CacheSize = 4 * 1024;
-const size_t kKeyTrieTermvecCacheSize = 1 * 1024;
+constexpr size_t kKeyTrieLb0CacheSize = 1 * 1024;
+constexpr size_t kKeyTrieLb1CacheSize = 1 * 1024;
+constexpr size_t kKeyTrieSelect0CacheSize = 4 * 1024;
+constexpr size_t kKeyTrieSelect1CacheSize = 4 * 1024;
+constexpr size_t kKeyTrieTermvecCacheSize = 1 * 1024;
 
-const size_t kValueTrieLb0CacheSize = 1 * 1024;
-const size_t kValueTrieLb1CacheSize = 1 * 1024;
-const size_t kValueTrieSelect0CacheSize = 1 * 1024;
-const size_t kValueTrieSelect1CacheSize = 16 * 1024;
-const size_t kValueTrieTermvecCacheSize = 4 * 1024;
+constexpr size_t kValueTrieLb0CacheSize = 1 * 1024;
+constexpr size_t kValueTrieLb1CacheSize = 1 * 1024;
+constexpr size_t kValueTrieSelect0CacheSize = 1 * 1024;
+constexpr size_t kValueTrieSelect1CacheSize = 16 * 1024;
+constexpr size_t kValueTrieTermvecCacheSize = 4 * 1024;
 
 // Expansion table format:
 // "<Character to expand>[<Expanded character 1><Expanded character 2>...]"
@@ -106,14 +108,14 @@ const size_t kValueTrieTermvecCacheSize = 4 * 1024;
 // be mixed.
 // TODO(hidehiko): Clean up this hacky implementation.
 const char *kHiraganaExpansionTable[] = {
-    "ああぁ",   "いいぃ", "ううぅゔ", "ええぇ",   "おおぉ",   "かかが",
-    "ききぎ",   "くくぐ", "けけげ",   "ここご",   "ささざ",   "ししじ",
-    "すすず",   "せせぜ", "そそぞ",   "たただ",   "ちちぢ",   "つつっづ",
-    "ててで",   "ととど", "ははばぱ", "ひひびぴ", "ふふぶぷ", "へへべぺ",
-    "ほほぼぽ", "ややゃ", "ゆゆゅ",   "よよょ",   "わわゎ",
+    "ああぁ",   "いいぃ",   "ううぅゔ", "ええぇ",   "おおぉ",   "かかが",
+    "ききぎ",   "くくぐ",   "けけげ",   "ここご",   "ささざ",   "ししじ",
+    "すすず",   "せせぜ",   "そそぞ",   "たただ",   "ちちぢ",   "つつっづ",
+    "っっづ",   "ててで",   "ととど",   "ははばぱ", "ひひびぴ", "ふふぶぷ",
+    "へへべぺ", "ほほぼぽ", "ややゃ",   "ゆゆゅ",   "よよょ",   "わわゎ",
 };
 
-const uint32 kAsciiRange = 0x80;
+constexpr uint32_t kAsciiRange = 0x80;
 
 // Confirm that all the characters are within ASCII range.
 bool ContainsAsciiCodeOnly(const std::string &str) {
@@ -132,7 +134,7 @@ void SetKeyExpansion(char key, const std::string &expansion,
 
 void BuildHiraganaExpansionTable(const SystemDictionaryCodecInterface &codec,
                                  KeyExpansionTable *encoded_table) {
-  for (size_t index = 0; index < arraysize(kHiraganaExpansionTable); ++index) {
+  for (size_t index = 0; index < std::size(kHiraganaExpansionTable); ++index) {
     std::string encoded;
     codec.EncodeKey(kHiraganaExpansionTable[index], &encoded);
     DCHECK(ContainsAsciiCodeOnly(encoded))
@@ -148,10 +150,10 @@ void BuildHiraganaExpansionTable(const SystemDictionaryCodecInterface &codec,
   }
 }
 
-inline const uint8 *GetTokenArrayPtr(const BitVectorBasedArray &token_array,
-                                     int key_id) {
+inline const uint8_t *GetTokenArrayPtr(const BitVectorBasedArray &token_array,
+                                       int key_id) {
   size_t length = 0;
-  return reinterpret_cast<const uint8 *>(token_array.Get(key_id, &length));
+  return reinterpret_cast<const uint8_t *>(token_array.Get(key_id, &length));
 }
 
 // Iterator for scanning token array.
@@ -234,8 +236,8 @@ class TokenScanIterator {
   }
 
   const SystemDictionaryCodecInterface *codec_;
-  const uint8 *encoded_tokens_ptr_;
-  const uint8 termination_flag_;
+  const uint8_t *encoded_tokens_ptr_;
+  const uint8_t termination_flag_;
   State state_;
   Result result_;
   int offset_;
@@ -261,8 +263,8 @@ class SystemDictionary::ReverseLookupCache {
  public:
   ReverseLookupCache() {}
 
-  bool IsAvailable(const std::set<int> &id_set) const {
-    for (std::set<int>::const_iterator itr = id_set.begin();
+  bool IsAvailable(const absl::btree_set<int> &id_set) const {
+    for (absl::btree_set<int>::const_iterator itr = id_set.begin();
          itr != id_set.end(); ++itr) {
       if (results.find(*itr) == results.end()) {
         return false;
@@ -291,7 +293,7 @@ class SystemDictionary::ReverseLookupIndex {
 
     CHECK_GE(value_id_max, 0);
     index_size_ = value_id_max + 1;
-    index_ = absl::make_unique<ReverseLookupResultArray[]>(index_size_);
+    index_ = std::make_unique<ReverseLookupResultArray[]>(index_size_);
 
     // Gets result size for each ids.
     for (TokenScanIterator iter(codec, token_array); !iter.Done();
@@ -305,7 +307,7 @@ class SystemDictionary::ReverseLookupIndex {
 
     for (size_t i = 0; i < index_size_; ++i) {
       index_[i].results =
-          absl::make_unique<ReverseLookupResult[]>(index_[i].size);
+          std::make_unique<ReverseLookupResult[]>(index_[i].size);
     }
 
     // Builds index.
@@ -340,9 +342,9 @@ class SystemDictionary::ReverseLookupIndex {
 
   ~ReverseLookupIndex() {}
 
-  void FillResultMap(const std::set<int> &id_set,
+  void FillResultMap(const absl::btree_set<int> &id_set,
                      std::multimap<int, ReverseLookupResult> *result_map) {
-    for (std::set<int>::const_iterator id_itr = id_set.begin();
+    for (absl::btree_set<int>::const_iterator id_itr = id_set.begin();
          id_itr != id_set.end(); ++id_itr) {
       const ReverseLookupResultArray &result_array = index_[*id_itr];
       for (size_t i = 0; i < result_array.size; ++i) {
@@ -369,14 +371,14 @@ class SystemDictionary::ReverseLookupIndex {
 };
 
 struct SystemDictionary::PredictiveLookupSearchState {
-  PredictiveLookupSearchState() : key_pos(0), is_expanded(false) {}
+  PredictiveLookupSearchState() : key_pos(0), num_expanded(0) {}
   PredictiveLookupSearchState(const storage::louds::LoudsTrie::Node &n,
-                              size_t pos, bool expanded)
-      : node(n), key_pos(pos), is_expanded(expanded) {}
+                              size_t pos, int expanded)
+      : node(n), key_pos(pos), num_expanded(expanded) {}
 
   storage::louds::LoudsTrie::Node node;
   size_t key_pos;
-  bool is_expanded;
+  int num_expanded;
 };
 
 struct SystemDictionary::Builder::Specification {
@@ -432,7 +434,7 @@ SystemDictionary::Builder &SystemDictionary::Builder::SetCodec(
   return *this;
 }
 
-mozc::StatusOr<std::unique_ptr<SystemDictionary>>
+absl::StatusOr<std::unique_ptr<SystemDictionary>>
 SystemDictionary::Builder::Build() {
   if (spec_->codec == nullptr) {
     spec_->codec = SystemDictionaryCodecFactory::GetCodec();
@@ -468,12 +470,12 @@ SystemDictionary::Builder::Build() {
       break;
     }
     default:
-      return mozc::InvalidArgumentError("Invalid spec type");
+      return absl::InvalidArgumentError("Invalid spec type");
   }
 
   if (!instance->OpenDictionaryFile(
           (spec_->options & ENABLE_REVERSE_LOOKUP_INDEX) != 0)) {
-    return mozc::UnknownError("Failed to create system dictionary");
+    return absl::UnknownError("Failed to create system dictionary");
   }
 
   return instance;
@@ -491,7 +493,7 @@ SystemDictionary::~SystemDictionary() {}
 bool SystemDictionary::OpenDictionaryFile(bool enable_reverse_lookup_index) {
   int len;
 
-  const uint8 *key_image = reinterpret_cast<const uint8 *>(
+  const uint8_t *key_image = reinterpret_cast<const uint8_t *>(
       dictionary_file_->GetSection(codec_->GetSectionNameForKey(), &len));
   if (!key_trie_.Open(key_image, kKeyTrieLb0CacheSize, kKeyTrieLb1CacheSize,
                       kKeyTrieSelect0CacheSize, kKeyTrieSelect1CacheSize,
@@ -502,7 +504,7 @@ bool SystemDictionary::OpenDictionaryFile(bool enable_reverse_lookup_index) {
 
   BuildHiraganaExpansionTable(*codec_, &hiragana_expansion_table_);
 
-  const uint8 *value_image = reinterpret_cast<const uint8 *>(
+  const uint8_t *value_image = reinterpret_cast<const uint8_t *>(
       dictionary_file_->GetSection(codec_->GetSectionNameForValue(), &len));
   if (!value_trie_.Open(value_image, kValueTrieLb0CacheSize,
                         kValueTrieLb1CacheSize, kValueTrieSelect0CacheSize,
@@ -516,7 +518,7 @@ bool SystemDictionary::OpenDictionaryFile(bool enable_reverse_lookup_index) {
       dictionary_file_->GetSection(codec_->GetSectionNameForTokens(), &len));
   token_array_.Open(token_image);
 
-  frequent_pos_ = reinterpret_cast<const uint32 *>(
+  frequent_pos_ = reinterpret_cast<const uint32_t *>(
       dictionary_file_->GetSection(codec_->GetSectionNameForPos(), &len));
   if (frequent_pos_ == nullptr) {
     LOG(ERROR) << "can not find frequent pos section";
@@ -535,7 +537,7 @@ void SystemDictionary::InitReverseLookupIndex() {
     return;
   }
   reverse_lookup_index_ =
-      absl::make_unique<ReverseLookupIndex>(codec_, token_array_);
+      std::make_unique<ReverseLookupIndex>(codec_, token_array_);
 }
 
 bool SystemDictionary::HasKey(absl::string_view key) const {
@@ -559,7 +561,7 @@ bool SystemDictionary::HasValue(absl::string_view value) const {
   // Normalize the value as the key.  This process depends on the
   // implementation of SystemDictionaryBuilder::BuildValueTrie.
   std::string key;
-  Util::KatakanaToHiragana(value, &key);
+  japanese_util::KatakanaToHiragana(value, &key);
 
   std::string encoded_key;
   codec_->EncodeKey(key, &encoded_key);
@@ -581,7 +583,7 @@ bool SystemDictionary::HasValue(absl::string_view value) const {
   // true.
 
   // Get the block of tokens for this key.
-  const uint8 *encoded_tokens_ptr = GetTokenArrayPtr(token_array_, key_id);
+  const uint8_t *encoded_tokens_ptr = GetTokenArrayPtr(token_array_, key_id);
 
   // Check tokens.
   for (TokenDecodeIterator iter(codec_, value_trie_, frequent_pos_, key,
@@ -616,9 +618,10 @@ void SystemDictionary::CollectPredictiveNodesInBfsOrder(
         if (!chars.IsHit(c)) {
           continue;
         }
-        const bool is_expanded = state.is_expanded || c != target_char;
+        const int num_expanded =
+            state.num_expanded + static_cast<int>(c != target_char);
         queue.push(PredictiveLookupSearchState(state.node, state.key_pos + 1,
-                                               is_expanded));
+                                               num_expanded));
       }
       continue;
     }
@@ -654,7 +657,7 @@ void SystemDictionary::CollectPredictiveNodesInBfsOrder(
          key_trie_.IsValidNode(state.node);
          key_trie_.MoveToNextSibling(&state.node)) {
       queue.push(PredictiveLookupSearchState(state.node, state.key_pos + 1,
-                                             state.is_expanded));
+                                             state.num_expanded));
     }
   } while (!queue.empty());
 }
@@ -683,7 +686,7 @@ void SystemDictionary::LookupPredictive(
   // callback mechanism.  This hard-coding limits the capability and generality
   // of dictionary module.  CollectPredictiveNodesInBfsOrder() and the following
   // loop for callback should be integrated for this purpose.
-  const size_t kLookupLimit = 64;
+  constexpr size_t kLookupLimit = 64;
   std::vector<PredictiveLookupSearchState> result;
   result.reserve(kLookupLimit);
   CollectPredictiveNodesInBfsOrder(encoded_key, table, kLookupLimit, &result);
@@ -723,14 +726,15 @@ void SystemDictionary::LookupPredictive(
     }
 
     absl::string_view actual_key;
-    if (state.is_expanded) {
+    if (state.num_expanded > 0) {
       actual_key_str.clear();
       codec_->DecodeKey(encoded_actual_key, &actual_key_str);
       actual_key = actual_key_str;
     } else {
       actual_key = decoded_key;
     }
-    switch (callback->OnActualKey(decoded_key, actual_key, state.is_expanded)) {
+    switch (
+        callback->OnActualKey(decoded_key, actual_key, state.num_expanded)) {
       case Callback::TRAVERSE_DONE:
         return;
       case Callback::TRAVERSE_NEXT_KEY:
@@ -782,7 +786,7 @@ void RunCallbackOnEachPrefix(const LoudsTrie &key_trie,
                              const LoudsTrie &value_trie,
                              const BitVectorBasedArray &token_array,
                              const SystemDictionaryCodecInterface *codec,
-                             const uint32 *frequent_pos, const char *key,
+                             const uint32_t *frequent_pos, const char *key,
                              absl::string_view encoded_key,
                              DictionaryInterface::Callback *callback,
                              Func token_filter) {
@@ -878,8 +882,8 @@ class ReverseLookupCallbackWrapper : public DictionaryInterface::Callback {
 //   key_pos:
 //     Depth of node, i.e., encoded_key.substr(0, key_pos) is the current prefix
 //     for search.
-//   is_expanded:
-//     true is stored if the current node is reached by key expansion.
+//   num_expanded:
+//     the number of chharacters expanded. if non zero, characters are expanded.
 //   actual_key_buffer:
 //     Buffer for storing actually used characters to reach this node, i.e.,
 //     absl::string_view(actual_key_buffer, key_pos) is the matched prefix using
@@ -891,7 +895,7 @@ DictionaryInterface::Callback::ResultType
 SystemDictionary::LookupPrefixWithKeyExpansionImpl(
     const char *key, absl::string_view encoded_key,
     const KeyExpansionTable &table, Callback *callback, LoudsTrie::Node node,
-    absl::string_view::size_type key_pos, bool is_expanded,
+    absl::string_view::size_type key_pos, int num_expanded,
     char *actual_key_buffer, std::string *actual_prefix) const {
   // This do-block handles a terminal node and callback.  do-block is used to
   // break the block and continue to the subsequent traversal phase.
@@ -915,7 +919,7 @@ SystemDictionary::LookupPrefixWithKeyExpansionImpl(
     const absl::string_view encoded_actual_prefix(actual_key_buffer, key_pos);
     actual_prefix->clear();
     codec_->DecodeKey(encoded_actual_prefix, actual_prefix);
-    result = callback->OnActualKey(prefix, *actual_prefix, is_expanded);
+    result = callback->OnActualKey(prefix, *actual_prefix, num_expanded);
     if (result == Callback::TRAVERSE_DONE ||
         result == Callback::TRAVERSE_CULL) {
       return result;
@@ -956,7 +960,8 @@ SystemDictionary::LookupPrefixWithKeyExpansionImpl(
     actual_key_buffer[key_pos] = c;
     const Callback::ResultType result = LookupPrefixWithKeyExpansionImpl(
         key, encoded_key, table, callback, node, key_pos + 1,
-        is_expanded || c != current_char, actual_key_buffer, actual_prefix);
+        num_expanded + static_cast<int>(c != current_char), actual_key_buffer,
+        actual_prefix);
     if (result == Callback::TRAVERSE_DONE) {
       return Callback::TRAVERSE_DONE;
     }
@@ -1025,7 +1030,7 @@ namespace {
 
 class AddKeyIdsToSet {
  public:
-  explicit AddKeyIdsToSet(std::set<int> *output) : output_(output) {}
+  explicit AddKeyIdsToSet(absl::btree_set<int> *output) : output_(output) {}
 
   void operator()(absl::string_view key, size_t prefix_len,
                   const LoudsTrie &trie, LoudsTrie::Node node) {
@@ -1033,11 +1038,11 @@ class AddKeyIdsToSet {
   }
 
  private:
-  std::set<int> *output_;
+  absl::btree_set<int> *output_;
 };
 
 inline void AddKeyIdsOfAllPrefixes(const LoudsTrie &trie, absl::string_view key,
-                                   std::set<int> *key_ids) {
+                                   absl::btree_set<int> *key_ids) {
   trie.PrefixSearch(key, AddKeyIdsToSet(key_ids));
 }
 
@@ -1049,11 +1054,11 @@ void SystemDictionary::PopulateReverseLookupCache(absl::string_view str) const {
     // as we have already built the index for reverse lookup.
     return;
   }
-  reverse_lookup_cache_ = absl::make_unique<ReverseLookupCache>();
+  reverse_lookup_cache_ = std::make_unique<ReverseLookupCache>();
   DCHECK(reverse_lookup_cache_.get());
 
   // Iterate each suffix and collect IDs of all substrings.
-  std::set<int> id_set;
+  absl::btree_set<int> id_set;
   int pos = 0;
   std::string lookup_key;
   lookup_key.reserve(str.size());
@@ -1089,7 +1094,7 @@ class FilterTokenForRegisterReverseLookupTokensForT13N {
         token_info.value_type != TokenInfo::AS_IS_KATAKANA) {
       // SAME_AS_PREV_VALUE may be t13n token.
       tmp_str_.clear();
-      Util::KatakanaToHiragana(token_info.token->value, &tmp_str_);
+      japanese_util::KatakanaToHiragana(token_info.token->value, &tmp_str_);
       if (token_info.token->key != tmp_str_) {
         return false;
       }
@@ -1106,7 +1111,7 @@ class FilterTokenForRegisterReverseLookupTokensForT13N {
 void SystemDictionary::RegisterReverseLookupTokensForT13N(
     absl::string_view value, Callback *callback) const {
   std::string hiragana_value, encoded_key;
-  Util::KatakanaToHiragana(value, &hiragana_value);
+  japanese_util::KatakanaToHiragana(value, &hiragana_value);
   codec_->EncodeKey(hiragana_value, &encoded_key);
   RunCallbackOnEachPrefix(key_trie_, value_trie_, token_array_, codec_,
                           frequent_pos_, hiragana_value.data(), encoded_key,
@@ -1119,7 +1124,7 @@ void SystemDictionary::RegisterReverseLookupTokensForValue(
   std::string lookup_key;
   codec_->EncodeValue(value, &lookup_key);
 
-  std::set<int> id_set;
+  absl::btree_set<int> id_set;
   AddKeyIdsOfAllPrefixes(value_trie_, lookup_key, &id_set);
 
   ReverseLookupCache *results = nullptr;
@@ -1140,7 +1145,7 @@ void SystemDictionary::RegisterReverseLookupTokensForValue(
   RegisterReverseLookupResults(id_set, *results, callback);
 }
 
-void SystemDictionary::ScanTokens(const std::set<int> &id_set,
+void SystemDictionary::ScanTokens(const absl::btree_set<int> &id_set,
                                   ReverseLookupCache *cache) const {
   for (TokenScanIterator iter(codec_, token_array_); !iter.Done();
        iter.Next()) {
@@ -1155,11 +1160,11 @@ void SystemDictionary::ScanTokens(const std::set<int> &id_set,
 }
 
 void SystemDictionary::RegisterReverseLookupResults(
-    const std::set<int> &id_set, const ReverseLookupCache &cache,
+    const absl::btree_set<int> &id_set, const ReverseLookupCache &cache,
     Callback *callback) const {
-  const uint8 *encoded_tokens_ptr = GetTokenArrayPtr(token_array_, 0);
+  const uint8_t *encoded_tokens_ptr = GetTokenArrayPtr(token_array_, 0);
   char buffer[LoudsTrie::kMaxDepth + 1];
-  for (std::set<int>::const_iterator set_itr = id_set.begin();
+  for (absl::btree_set<int>::const_iterator set_itr = id_set.begin();
        set_itr != id_set.end(); ++set_itr) {
     const int value_id = *set_itr;
     typedef std::multimap<int, ReverseLookupResult>::const_iterator ResultItr;
