@@ -30,12 +30,12 @@
 #ifndef MOZC_DICTIONARY_SYSTEM_SYSTEM_DICTIONARY_H_
 #define MOZC_DICTIONARY_SYSTEM_SYSTEM_DICTIONARY_H_
 
+#include <cstdint>
 #include <memory>
 #include <set>
 #include <string>
 #include <vector>
 
-#include "base/statusor.h"
 #include "dictionary/dictionary_interface.h"
 #include "dictionary/file/codec_interface.h"
 #include "dictionary/system/codec_interface.h"
@@ -43,6 +43,8 @@
 #include "dictionary/system/words_info.h"
 #include "storage/louds/bit_vector_based_array.h"
 #include "storage/louds/louds_trie.h"
+#include "absl/container/btree_set.h"
+#include "absl/status/statusor.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -90,7 +92,7 @@ class SystemDictionary : public DictionaryInterface {
     Builder &SetCodec(const SystemDictionaryCodecInterface *codec);
 
     // Builds and returns system dictionary.
-    mozc::StatusOr<std::unique_ptr<SystemDictionary>> Build();
+    absl::StatusOr<std::unique_ptr<SystemDictionary>> Build();
 
    private:
     struct Specification;
@@ -141,8 +143,9 @@ class SystemDictionary : public DictionaryInterface {
                                           Callback *callback) const;
   void RegisterReverseLookupTokensForValue(absl::string_view value,
                                            Callback *callback) const;
-  void ScanTokens(const std::set<int> &id_set, ReverseLookupCache *cache) const;
-  void RegisterReverseLookupResults(const std::set<int> &id_set,
+  void ScanTokens(const absl::btree_set<int> &id_set,
+                  ReverseLookupCache *cache) const;
+  void RegisterReverseLookupResults(const absl::btree_set<int> &id_set,
                                     const ReverseLookupCache &cache,
                                     Callback *callback) const;
   void InitReverseLookupIndex();
@@ -151,7 +154,7 @@ class SystemDictionary : public DictionaryInterface {
       const char *key, absl::string_view encoded_key,
       const KeyExpansionTable &table, Callback *callback,
       storage::louds::LoudsTrie::Node node,
-      absl::string_view::size_type key_pos, bool is_expanded,
+      absl::string_view::size_type key_pos, int num_expanded,
       char *actual_key_buffer, std::string *actual_prefix) const;
 
   void CollectPredictiveNodesInBfsOrder(
@@ -161,7 +164,7 @@ class SystemDictionary : public DictionaryInterface {
   storage::louds::LoudsTrie key_trie_;
   storage::louds::LoudsTrie value_trie_;
   storage::louds::BitVectorBasedArray token_array_;
-  const uint32 *frequent_pos_;
+  const uint32_t *frequent_pos_;
   const SystemDictionaryCodecInterface *codec_;
   KeyExpansionTable hiragana_expansion_table_;
   std::unique_ptr<DictionaryFile> dictionary_file_;
