@@ -29,6 +29,7 @@
 
 #include "dictionary/system/value_dictionary.h"
 
+#include <cstdint>
 #include <limits>
 #include <memory>
 #include <queue>
@@ -37,6 +38,7 @@
 #include "base/logging.h"
 #include "base/mmap.h"
 #include "base/port.h"
+#include "base/util.h"
 #include "dictionary/dictionary_token.h"
 #include "dictionary/file/codec_factory.h"
 #include "dictionary/file/dictionary_file.h"
@@ -50,7 +52,7 @@ using mozc::storage::louds::LoudsTrie;
 namespace mozc {
 namespace dictionary {
 
-ValueDictionary::ValueDictionary(const POSMatcher &pos_matcher,
+ValueDictionary::ValueDictionary(const PosMatcher &pos_matcher,
                                  const LoudsTrie *value_trie)
     : value_trie_(value_trie),
       codec_(SystemDictionaryCodecFactory::GetCodec()),
@@ -73,7 +75,7 @@ bool ValueDictionary::HasValue(absl::string_view value) const { return false; }
 namespace {
 
 // A version of the above function for Token.
-inline void FillToken(const uint16 suggestion_only_word_id,
+inline void FillToken(const uint16_t suggestion_only_word_id,
                       absl::string_view key, Token *token) {
   token->key.assign(key.data(), key.size());
   token->value = token->key;
@@ -82,9 +84,24 @@ inline void FillToken(const uint16 suggestion_only_word_id,
   token->attributes = Token::NONE;
 }
 
+inline bool IsValidKey(absl::string_view key) {
+  // Do nothing for empty key, although looking up all the entries with empty
+  // string seems natural.
+  if (key.empty()) {
+    return false;
+  }
+  // Value dictionary is used to suggest English words from literal ASCII
+  // query.
+  const Util::ScriptType type = Util::GetFirstScriptType(key);
+  if (type == Util::HIRAGANA || type == Util::KANJI || type == Util::KATAKANA) {
+    return false;
+  }
+  return true;
+}
+
 inline DictionaryInterface::Callback::ResultType HandleTerminalNode(
     const LoudsTrie &value_trie, const SystemDictionaryCodecInterface &codec,
-    const uint16 suggestion_only_word_id, const LoudsTrie::Node &node,
+    const uint16_t suggestion_only_word_id, const LoudsTrie::Node &node,
     DictionaryInterface::Callback *callback, char *encoded_value_buffer,
     std::string *value, Token *token) {
   const absl::string_view encoded_value =
@@ -107,11 +124,10 @@ inline DictionaryInterface::Callback::ResultType HandleTerminalNode(
 void ValueDictionary::LookupPredictive(
     absl::string_view key, const ConversionRequest &conversion_request,
     Callback *callback) const {
-  // Do nothing for empty key, although looking up all the entries with empty
-  // string seems natural.
-  if (key.empty()) {
+  if (!IsValidKey(key)) {
     return;
   }
+
   std::string encoded_key;
   codec_->EncodeValue(key, &encoded_key);
 
@@ -159,9 +175,7 @@ void ValueDictionary::LookupPrefix(absl::string_view key,
 void ValueDictionary::LookupExact(absl::string_view key,
                                   const ConversionRequest &conversion_request,
                                   Callback *callback) const {
-  if (key.empty()) {
-    // For empty string, return nothing for compatibility reason; see the
-    // comment above.
+  if (!IsValidKey(key)) {
     return;
   }
 
