@@ -29,7 +29,9 @@
 
 #include "dictionary/system/value_dictionary.h"
 
+#include <cstdint>
 #include <memory>
+#include <string>
 
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/dictionary_test_util.h"
@@ -39,7 +41,6 @@
 #include "request/conversion_request.h"
 #include "storage/louds/louds_trie_builder.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 
 using mozc::storage::louds::LoudsTrie;
 using mozc::storage::louds::LoudsTrieBuilder;
@@ -50,9 +51,9 @@ namespace dictionary {
 class ValueDictionaryTest : public ::testing::Test {
  protected:
   void SetUp() override {
-    pos_matcher_.Set(mock_data_manager_.GetPOSMatcherData());
-    louds_trie_builder_ = absl::make_unique<LoudsTrieBuilder>();
-    louds_trie_ = absl::make_unique<LoudsTrie>();
+    pos_matcher_.Set(mock_data_manager_.GetPosMatcherData());
+    louds_trie_builder_ = std::make_unique<LoudsTrieBuilder>();
+    louds_trie_ = std::make_unique<LoudsTrie>();
   }
 
   void TearDown() override {
@@ -69,7 +70,7 @@ class ValueDictionaryTest : public ::testing::Test {
   ValueDictionary *BuildValueDictionary() {
     louds_trie_builder_->Build();
     louds_trie_->Open(
-        reinterpret_cast<const uint8 *>(louds_trie_builder_->image().data()));
+        reinterpret_cast<const uint8_t *>(louds_trie_builder_->image().data()));
     return new ValueDictionary(pos_matcher_, louds_trie_.get());
   }
 
@@ -81,7 +82,7 @@ class ValueDictionaryTest : public ::testing::Test {
   }
 
   const testing::MockDataManager mock_data_manager_;
-  POSMatcher pos_matcher_;
+  PosMatcher pos_matcher_;
   ConversionRequest convreq_;
   std::unique_ptr<LoudsTrieBuilder> louds_trie_builder_;
   std::unique_ptr<LoudsTrie> louds_trie_;
@@ -113,6 +114,11 @@ TEST_F(ValueDictionaryTest, LookupPredictive) {
   AddValue("war");
   AddValue("word");
   AddValue("world");
+
+  // These values are not fetched.
+  AddValue("あいう");
+  AddValue("東京");
+  AddValue("アイウ");
   std::unique_ptr<ValueDictionary> dictionary(BuildValueDictionary());
 
   // Reading fields are irrelevant to value dictionary.  Prepare actual tokens
@@ -151,6 +157,17 @@ TEST_F(ValueDictionaryTest, LookupPredictive) {
     dictionary->LookupPredictive("ho", convreq_, &callback);
     EXPECT_TRUE(callback.tokens().empty());
   }
+  {
+    CollectTokenCallback callback;
+    dictionary->LookupPredictive("あ", convreq_, &callback);
+    EXPECT_TRUE(callback.tokens().empty());
+
+    dictionary->LookupPredictive("東", convreq_, &callback);
+    EXPECT_TRUE(callback.tokens().empty());
+
+    dictionary->LookupPredictive("ア", convreq_, &callback);
+    EXPECT_TRUE(callback.tokens().empty());
+  }
 }
 
 TEST_F(ValueDictionaryTest, LookupExact) {
