@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,18 +41,20 @@
 #include "dictionary/user_pos_interface.h"
 #include "protocol/user_dictionary_storage.pb.h"
 #include "absl/strings/string_view.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
-
-class ReaderWriterMutex;
-
 namespace dictionary {
 
 class UserDictionary : public DictionaryInterface {
  public:
-  UserDictionary(std::unique_ptr<const UserPOSInterface> user_pos,
-                 POSMatcher pos_matcher,
+  UserDictionary(std::unique_ptr<const UserPosInterface> user_pos,
+                 PosMatcher pos_matcher,
                  SuppressionDictionary *suppression_dictionary);
+
+  UserDictionary(const UserDictionary &) = delete;
+  UserDictionary &operator=(const UserDictionary &) = delete;
+
   ~UserDictionary() override;
 
   bool HasKey(absl::string_view key) const override;
@@ -90,9 +92,21 @@ class UserDictionary : public DictionaryInterface {
   // Waits until reloader finishes
   void WaitForReloader();
 
+  // Gets the user POS list.
+  std::vector<std::string> GetPosList() const;
+
   // Sets user dicitonary filename for unittesting
   static void SetUserDictionaryName(const std::string &filename);
 
+  enum RequestType { PREFIX, PREDICTIVE, EXACT };
+
+  // Populates Token from UserToken.
+  // This method sets the actual cost and rewrites POS id depending
+  // on the POS and attribute.
+  void PopulateTokenFromUserPosToken(
+      const UserPosInterface::Token &user_pos_token, RequestType request_type,
+      Token *token) const;
+
  private:
   class TokensIndex;
   class UserDictionaryReloader;
@@ -101,14 +115,13 @@ class UserDictionary : public DictionaryInterface {
   void Swap(TokensIndex *new_tokens);
 
   std::unique_ptr<UserDictionaryReloader> reloader_;
-  std::unique_ptr<const UserPOSInterface> user_pos_;
-  const POSMatcher pos_matcher_;
+  std::unique_ptr<const UserPosInterface> user_pos_;
+  const PosMatcher pos_matcher_;
   SuppressionDictionary *suppression_dictionary_;
   TokensIndex *tokens_;
-  mutable std::unique_ptr<ReaderWriterMutex> mutex_;
+  mutable absl::Mutex mutex_;
 
   friend class UserDictionaryTest;
-  DISALLOW_COPY_AND_ASSIGN(UserDictionary);
 };
 
 }  // namespace dictionary
