@@ -27,13 +27,15 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include "dictionary/user_dictionary_importer.h"
+
 #include <algorithm>
+#include <cstdint>
 #include <sstream>
 #include <string>
 #include <vector>
 
 #include "base/util.h"
-#include "dictionary/user_dictionary_importer.h"
 #include "dictionary/user_dictionary_storage.h"
 #include "dictionary/user_dictionary_util.h"
 #include "testing/base/public/googletest.h"
@@ -81,7 +83,7 @@ class TestInputIterator
 }  // namespace
 
 TEST(UserDictionaryImporter, ImportFromNormalTextTest) {
-  const char kInput[] =
+  constexpr char kInput[] =
       "きょうと\t京都\t名詞\n"
       "おおさか\t大阪\t地名\n"
       "とうきょう\t東京\t地名\tコメント\n"
@@ -133,7 +135,7 @@ TEST(UserDictionaryImporter, ImportFromNormalTextTest) {
 }
 
 TEST(UserDictionaryImporter, ImportFromKotoeriTextTest) {
-  const char kInput[] =
+  constexpr char kInput[] =
       "\"きょうと\","
       "\"京都\",\"名詞\"\n"
       "\"おおさか\","
@@ -171,7 +173,7 @@ TEST(UserDictionaryImporter, ImportFromKotoeriTextTest) {
 }
 
 TEST(UserDictionaryImporter, ImportFromCommentTextTest) {
-  const char kInput[] =
+  constexpr char kInput[] =
       "きょうと\t京都\t名詞\n"
       "!おおさか\t大阪\t地名\n"
       "\n"
@@ -229,7 +231,7 @@ TEST(UserDictionaryImporter, ImportFromCommentTextTest) {
 }
 
 TEST(UserDictionaryImporter, ImportFromInvalidTextTest) {
-  const char kInput[] =
+  constexpr char kInput[] =
       "a"
       "\n"
       "東京\t\t地名\tコメント\n"
@@ -292,13 +294,14 @@ TEST(UserDictionaryImporter, ImportFromIteratorNormalTest) {
   TestInputIterator iter;
   UserDictionaryStorage::UserDictionary user_dic;
 
-  static const size_t kSize[] = {10, 100, 1000, 5000, 12000};
-  for (size_t i = 0; i < arraysize(kSize); ++i) {
+  static constexpr size_t kSize[] = {10, 100, 1000, 5000, 12000};
+  for (size_t i = 0; i < std::size(kSize); ++i) {
     std::vector<UserDictionaryImporter::RawEntry> entries;
     for (size_t j = 0; j < kSize[i]; ++j) {
       UserDictionaryImporter::RawEntry entry;
-      const std::string key("key" + std::to_string(static_cast<uint32>(j)));
-      const std::string value("value" + std::to_string(static_cast<uint32>(j)));
+      const std::string key("key" + std::to_string(static_cast<uint32_t>(j)));
+      const std::string value("value" +
+                              std::to_string(static_cast<uint32_t>(j)));
       entry.key = key;
       entry.value = value;
       entry.pos = "名詞";
@@ -332,13 +335,14 @@ TEST(UserDictionaryImporter, ImportFromIteratorInvalidEntriesTest) {
   TestInputIterator iter;
   UserDictionaryStorage::UserDictionary user_dic;
 
-  static const size_t kSize[] = {10, 100, 1000};
-  for (size_t i = 0; i < arraysize(kSize); ++i) {
+  static constexpr size_t kSize[] = {10, 100, 1000};
+  for (size_t i = 0; i < std::size(kSize); ++i) {
     std::vector<UserDictionaryImporter::RawEntry> entries;
     for (size_t j = 0; j < kSize[i]; ++j) {
       UserDictionaryImporter::RawEntry entry;
-      const std::string key("key" + std::to_string(static_cast<uint32>(j)));
-      const std::string value("value" + std::to_string(static_cast<uint32>(j)));
+      const std::string key("key" + std::to_string(static_cast<uint32_t>(j)));
+      const std::string value("value" +
+                              std::to_string(static_cast<uint32_t>(j)));
       entry.key = key;
       entry.value = value;
       if (j % 2 == 0) {
@@ -573,7 +577,7 @@ TEST(UserDictionaryImporter, StringTextLineIterator) {
       "klmno",
   };
 
-  for (size_t i = 0; i < arraysize(kTestData); ++i) {
+  for (size_t i = 0; i < std::size(kTestData); ++i) {
     UserDictionaryImporter::StringTextLineIterator iter(kTestData[i]);
     ASSERT_TRUE(iter.IsAvailable());
     ASSERT_TRUE(iter.Next(&line));
@@ -589,7 +593,7 @@ TEST(UserDictionaryImporter, StringTextLineIterator) {
 
   // Test empty line with CR.
   {
-    const char kInput[] = "\r\rabcde";
+    constexpr char kInput[] = "\r\rabcde";
     UserDictionaryImporter::StringTextLineIterator iter(kInput);
     ASSERT_TRUE(iter.IsAvailable());
     ASSERT_TRUE(iter.Next(&line));
@@ -605,7 +609,7 @@ TEST(UserDictionaryImporter, StringTextLineIterator) {
 
   // Test empty line with LF.
   {
-    const char kInput[] = "\n\nabcde";
+    constexpr char kInput[] = "\n\nabcde";
     UserDictionaryImporter::StringTextLineIterator iter(kInput);
     ASSERT_TRUE(iter.IsAvailable());
     ASSERT_TRUE(iter.Next(&line));
@@ -621,7 +625,7 @@ TEST(UserDictionaryImporter, StringTextLineIterator) {
 
   // Test empty line with CRLF.
   {
-    const char kInput[] = "\r\n\r\nabcde";
+    constexpr char kInput[] = "\r\n\r\nabcde";
     UserDictionaryImporter::StringTextLineIterator iter(kInput);
     ASSERT_TRUE(iter.IsAvailable());
     ASSERT_TRUE(iter.Next(&line));
@@ -638,7 +642,7 @@ TEST(UserDictionaryImporter, StringTextLineIterator) {
   // Invalid empty line.
   // At the moment, \n\r is processed as two empty lines.
   {
-    const char kInput[] = "\n\rabcde";
+    constexpr char kInput[] = "\n\rabcde";
     UserDictionaryImporter::StringTextLineIterator iter(kInput);
     ASSERT_TRUE(iter.IsAvailable());
     ASSERT_TRUE(iter.Next(&line));
