@@ -30,7 +30,10 @@
 #include "dictionary/user_dictionary_session.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <memory>
+#include <string>
+#include <utility>
 
 #include "base/logging.h"
 #include "base/port.h"
@@ -40,6 +43,7 @@
 #include "dictionary/user_dictionary_storage.h"
 #include "dictionary/user_dictionary_util.h"
 #include "protocol/user_dictionary_storage.pb.h"
+#include "absl/container/fixed_array.h"
 
 namespace mozc {
 namespace user_dictionary {
@@ -131,14 +135,14 @@ class UndoDeleteDictionaryWithEnsuringNonEmptyStorageCommand
 
 class UndoRenameDictionaryCommand : public UserDictionarySession::UndoCommand {
  public:
-  UndoRenameDictionaryCommand(uint64 dictionary_id,
+  UndoRenameDictionaryCommand(uint64_t dictionary_id,
                               const std::string &original_name)
       : dictionary_id_(dictionary_id), original_name_(original_name) {}
 
   bool RunUndo(mozc::UserDictionaryStorage *storage) override {
     UserDictionary *dictionary =
-        UserDictionaryUtil::GetMutableUserDictionaryById(
-            &storage->GetProto(), dictionary_id_);
+        UserDictionaryUtil::GetMutableUserDictionaryById(&storage->GetProto(),
+                                                         dictionary_id_);
     if (dictionary == nullptr) {
       return false;
     }
@@ -148,7 +152,7 @@ class UndoRenameDictionaryCommand : public UserDictionarySession::UndoCommand {
   }
 
  private:
-  uint64 dictionary_id_;
+  uint64_t dictionary_id_;
   std::string original_name_;
 
   DISALLOW_COPY_AND_ASSIGN(UndoRenameDictionaryCommand);
@@ -156,13 +160,13 @@ class UndoRenameDictionaryCommand : public UserDictionarySession::UndoCommand {
 
 class UndoAddEntryCommand : public UserDictionarySession::UndoCommand {
  public:
-  explicit UndoAddEntryCommand(uint64 dictionary_id)
+  explicit UndoAddEntryCommand(uint64_t dictionary_id)
       : dictionary_id_(dictionary_id) {}
 
   bool RunUndo(mozc::UserDictionaryStorage *storage) override {
     UserDictionary *dictionary =
-        UserDictionaryUtil::GetMutableUserDictionaryById(
-            &storage->GetProto(), dictionary_id_);
+        UserDictionaryUtil::GetMutableUserDictionaryById(&storage->GetProto(),
+                                                         dictionary_id_);
     if (dictionary == nullptr || dictionary->entries_size() == 0) {
       return false;
     }
@@ -172,14 +176,14 @@ class UndoAddEntryCommand : public UserDictionarySession::UndoCommand {
   }
 
  private:
-  uint64 dictionary_id_;
+  uint64_t dictionary_id_;
 
   DISALLOW_COPY_AND_ASSIGN(UndoAddEntryCommand);
 };
 
 class UndoEditEntryCommand : public UserDictionarySession::UndoCommand {
  public:
-  UndoEditEntryCommand(uint64 dictionary_id, int index,
+  UndoEditEntryCommand(uint64_t dictionary_id, int index,
                        const UserDictionary::Entry &original_entry)
       : dictionary_id_(dictionary_id),
         index_(index),
@@ -187,19 +191,19 @@ class UndoEditEntryCommand : public UserDictionarySession::UndoCommand {
 
   bool RunUndo(mozc::UserDictionaryStorage *storage) override {
     UserDictionary *dictionary =
-        UserDictionaryUtil::GetMutableUserDictionaryById(
-            &storage->GetProto(), dictionary_id_);
+        UserDictionaryUtil::GetMutableUserDictionaryById(&storage->GetProto(),
+                                                         dictionary_id_);
     if (dictionary == nullptr || index_ < 0 ||
         dictionary->entries_size() <= index_) {
       return false;
     }
 
-    dictionary->mutable_entries(index_)->CopyFrom(original_entry_);
+    *dictionary->mutable_entries(index_) = original_entry_;
     return true;
   }
 
  private:
-  uint64 dictionary_id_;
+  uint64_t dictionary_id_;
   int index_;
   UserDictionary::Entry original_entry_;
 
@@ -217,10 +221,10 @@ class UndoDeleteEntryCommand : public UserDictionarySession::UndoCommand {
  public:
   // This instance takes the ownership of the given entries.
   UndoDeleteEntryCommand(
-      uint64 dictionary_id,
-      const std::vector<std::pair<int, UserDictionary::Entry *> >
-          deleted_entries)
-      : dictionary_id_(dictionary_id), deleted_entries_(deleted_entries) {
+      uint64_t dictionary_id,
+      std::vector<std::pair<int, UserDictionary::Entry *>> deleted_entries)
+      : dictionary_id_(dictionary_id),
+        deleted_entries_(std::move(deleted_entries)) {
     std::sort(deleted_entries_.begin(), deleted_entries_.end(),
               DeleteEntryComparator());
   }
@@ -232,8 +236,8 @@ class UndoDeleteEntryCommand : public UserDictionarySession::UndoCommand {
 
   bool RunUndo(mozc::UserDictionaryStorage *storage) override {
     UserDictionary *dictionary =
-        UserDictionaryUtil::GetMutableUserDictionaryById(
-            &storage->GetProto(), dictionary_id_);
+        UserDictionaryUtil::GetMutableUserDictionaryById(&storage->GetProto(),
+                                                         dictionary_id_);
     if (dictionary == nullptr) {
       return false;
     }
@@ -252,11 +256,8 @@ class UndoDeleteEntryCommand : public UserDictionarySession::UndoCommand {
         dictionary->mutable_entries();
 
     // Move instances to backup vector.
-    std::vector<UserDictionary::Entry *> backup(entries->pointer_begin(),
-                                                entries->pointer_end());
-    while (!entries->empty()) {
-      entries->ReleaseLast();
-    }
+    absl::FixedArray<UserDictionary::Entry *> backup(entries->size());
+    entries->ExtractSubrange(0, entries->size(), backup.data());
 
     // Merge two vectors into entries.
     int backup_index = 0;
@@ -283,22 +284,22 @@ class UndoDeleteEntryCommand : public UserDictionarySession::UndoCommand {
   }
 
  private:
-  uint64 dictionary_id_;
-  std::vector<std::pair<int, UserDictionary::Entry *> > deleted_entries_;
+  uint64_t dictionary_id_;
+  std::vector<std::pair<int, UserDictionary::Entry *>> deleted_entries_;
 
   DISALLOW_COPY_AND_ASSIGN(UndoDeleteEntryCommand);
 };
 
 class UndoImportFromStringCommand : public UserDictionarySession::UndoCommand {
  public:
-  UndoImportFromStringCommand(uint64 dictionary_id, int original_num_entries)
+  UndoImportFromStringCommand(uint64_t dictionary_id, int original_num_entries)
       : dictionary_id_(dictionary_id),
         original_num_entries_(original_num_entries) {}
 
   bool RunUndo(mozc::UserDictionaryStorage *storage) override {
     UserDictionary *dictionary =
-        UserDictionaryUtil::GetMutableUserDictionaryById(
-            &storage->GetProto(), dictionary_id_);
+        UserDictionaryUtil::GetMutableUserDictionaryById(&storage->GetProto(),
+                                                         dictionary_id_);
     if (dictionary == nullptr) {
       return false;
     }
@@ -312,18 +313,18 @@ class UndoImportFromStringCommand : public UserDictionarySession::UndoCommand {
   }
 
  private:
-  uint64 dictionary_id_;
+  uint64_t dictionary_id_;
   int original_num_entries_;
 
   DISALLOW_COPY_AND_ASSIGN(UndoImportFromStringCommand);
 };
 
 // The limit of the number of commands remembered by the session for undo.
-const int kMaxUndoHistory = 30;
+constexpr int kMaxUndoHistory = 30;
 
 // The default name of a dictionary, which is created to ensure "non-empty"
 // storage.
-const char kDefaultDictionaryName[] = "user dictionary";
+constexpr char kDefaultDictionaryName[] = "user dictionary";
 
 }  // namespace
 
@@ -367,9 +368,11 @@ UserDictionarySession::LoadWithEnsuringNonEmptyStorage() {
 UserDictionaryCommandStatus::Status UserDictionarySession::LoadInternal(
     bool ensure_non_empty_storage) {
   UserDictionaryCommandStatus::Status status;
-  if (storage_->Load()) {
+  if (absl::Status s = storage_->Load(); s.ok()) {
     status = UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS;
   } else {
+    LOG(ERROR) << "Load failed: " << s
+               << ": last error=" << storage_->GetLastError();
     switch (storage_->GetLastError()) {
       case mozc::UserDictionaryStorage::FILE_NOT_EXISTS:
         status = UserDictionaryCommandStatus::FILE_NOT_FOUND;
@@ -378,7 +381,6 @@ UserDictionaryCommandStatus::Status UserDictionarySession::LoadInternal(
         status = UserDictionaryCommandStatus::INVALID_FILE_FORMAT;
         break;
       default:
-        LOG(ERROR) << "Unknown error code: " << storage_->GetLastError();
         status = UserDictionaryCommandStatus::UNKNOWN_ERROR;
         break;
     }
@@ -423,13 +425,13 @@ UserDictionaryCommandStatus::Status UserDictionarySession::Save() {
     return UserDictionaryCommandStatus::UNKNOWN_ERROR;
   }
 
-  if (!storage_->Save()) {
+  if (absl::Status s = storage_->Save(); !s.ok()) {
+    LOG(ERROR) << "Failed to save to storage: " << s;
     switch (storage_->GetLastError()) {
       case mozc::UserDictionaryStorage::TOO_BIG_FILE_BYTES:
         return UserDictionaryCommandStatus::FILE_SIZE_LIMIT_EXCEEDED;
         // TODO(hidehiko): Handle SYNC_FAILURE.
       default:
-        LOG(ERROR) << "Unknown error code: " << storage_->GetLastError();
         return UserDictionaryCommandStatus::UNKNOWN_ERROR;
     }
     // Should never reach here.
@@ -451,10 +453,10 @@ UserDictionaryCommandStatus::Status UserDictionarySession::Undo() {
 }
 
 UserDictionaryCommandStatus::Status UserDictionarySession::CreateDictionary(
-    const std::string &dictionary_name, uint64 *new_dictionary_id) {
+    const std::string &dictionary_name, uint64_t *new_dictionary_id) {
   UserDictionaryCommandStatus::Status status =
-      UserDictionaryUtil::CreateDictionary(
-          &storage_->GetProto(), dictionary_name, new_dictionary_id);
+      UserDictionaryUtil::CreateDictionary(&storage_->GetProto(),
+                                           dictionary_name, new_dictionary_id);
   if (status == UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS) {
     AddUndoCommand(new UndoCreateDictionaryCommand);
   }
@@ -462,24 +464,24 @@ UserDictionaryCommandStatus::Status UserDictionarySession::CreateDictionary(
 }
 
 UserDictionaryCommandStatus::Status UserDictionarySession::DeleteDictionary(
-    uint64 dictionary_id) {
+    uint64_t dictionary_id) {
   return DeleteDictionaryInternal(dictionary_id, false);
 }
 
 UserDictionaryCommandStatus::Status
 UserDictionarySession::DeleteDictionaryWithEnsuringNonEmptyStorage(
-    uint64 dictionary_id) {
+    uint64_t dictionary_id) {
   return DeleteDictionaryInternal(dictionary_id, true);
 }
 
 UserDictionaryCommandStatus::Status
-UserDictionarySession::DeleteDictionaryInternal(uint64 dictionary_id,
+UserDictionarySession::DeleteDictionaryInternal(uint64_t dictionary_id,
                                                 bool ensure_non_empty_storage) {
   int original_index;
   UserDictionary *deleted_dictionary;
-  if (!UserDictionaryUtil::DeleteDictionary(
-      &storage_->GetProto(), dictionary_id, &original_index,
-      &deleted_dictionary)) {
+  if (!UserDictionaryUtil::DeleteDictionary(&storage_->GetProto(),
+                                            dictionary_id, &original_index,
+                                            &deleted_dictionary)) {
     // Failed to delete the dictionary.
     return UserDictionaryCommandStatus::UNKNOWN_DICTIONARY_ID;
   }
@@ -497,11 +499,10 @@ UserDictionarySession::DeleteDictionaryInternal(uint64 dictionary_id,
 }
 
 UserDictionaryCommandStatus::Status UserDictionarySession::RenameDictionary(
-    uint64 dictionary_id, const std::string &dictionary_name) {
+    uint64_t dictionary_id, const std::string &dictionary_name) {
   std::string original_name;
-  const UserDictionary *dictionary =
-      UserDictionaryUtil::GetUserDictionaryById(
-          storage_->GetProto(), dictionary_id);
+  const UserDictionary *dictionary = UserDictionaryUtil::GetUserDictionaryById(
+      storage_->GetProto(), dictionary_id);
   if (dictionary != nullptr) {
     // Note that if dictionary is null, it means the dictionary_id is invalid
     // so following RenameDictionary will fail, and error handling is done
@@ -534,7 +535,7 @@ UserDictionaryCommandStatus::Status UserDictionarySession::RenameDictionary(
 }
 
 UserDictionaryCommandStatus::Status UserDictionarySession::AddEntry(
-    uint64 dictionary_id, const UserDictionary::Entry &entry) {
+    uint64_t dictionary_id, const UserDictionary::Entry &entry) {
   UserDictionary *dictionary = UserDictionaryUtil::GetMutableUserDictionaryById(
       &storage_->GetProto(), dictionary_id);
   if (dictionary == nullptr) {
@@ -553,7 +554,7 @@ UserDictionaryCommandStatus::Status UserDictionarySession::AddEntry(
   }
 
   UserDictionary::Entry *new_entry = dictionary->add_entries();
-  new_entry->CopyFrom(entry);
+  *new_entry = entry;
   UserDictionaryUtil::SanitizeEntry(new_entry);
 
   AddUndoCommand(new UndoAddEntryCommand(dictionary_id));
@@ -561,7 +562,7 @@ UserDictionaryCommandStatus::Status UserDictionarySession::AddEntry(
 }
 
 UserDictionaryCommandStatus::Status UserDictionarySession::EditEntry(
-    uint64 dictionary_id, int index, const UserDictionary::Entry &entry) {
+    uint64_t dictionary_id, int index, const UserDictionary::Entry &entry) {
   UserDictionary *dictionary = UserDictionaryUtil::GetMutableUserDictionaryById(
       &storage_->GetProto(), dictionary_id);
   if (dictionary == nullptr) {
@@ -582,13 +583,13 @@ UserDictionaryCommandStatus::Status UserDictionarySession::EditEntry(
   UserDictionary::Entry *target_entry = dictionary->mutable_entries(index);
   AddUndoCommand(new UndoEditEntryCommand(dictionary_id, index, *target_entry));
 
-  target_entry->CopyFrom(entry);
+  *target_entry = entry;
   UserDictionaryUtil::SanitizeEntry(target_entry);
   return UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS;
 }
 
 UserDictionaryCommandStatus::Status UserDictionarySession::DeleteEntry(
-    uint64 dictionary_id, const std::vector<int> &index_list) {
+    uint64_t dictionary_id, std::vector<int> index_list) {
   UserDictionary *dictionary = UserDictionaryUtil::GetMutableUserDictionaryById(
       &storage_->GetProto(), dictionary_id);
   if (dictionary == nullptr) {
@@ -602,25 +603,21 @@ UserDictionaryCommandStatus::Status UserDictionarySession::DeleteEntry(
     }
   }
 
-  std::vector<std::pair<int, UserDictionary::Entry *> > deleted_entries;
+  std::vector<std::pair<int, UserDictionary::Entry *>> deleted_entries;
   deleted_entries.reserve(index_list.size());
 
+  // Sort these in descending order so the indices don't change as we remove
+  // elements.
+  std::sort(index_list.begin(), index_list.end(), std::greater<int>());
+
   RepeatedPtrField<UserDictionary::Entry> *entries =
       dictionary->mutable_entries();
-  UserDictionary::Entry **data = entries->mutable_data();
   for (size_t i = 0; i < index_list.size(); ++i) {
     const int index = index_list[i];
 
-    deleted_entries.push_back(std::make_pair(index, data[index]));
-    data[index] = nullptr;
-  }
-
-  UserDictionary::Entry **tail =
-      std::remove(data, data + entries->size(),
-                  static_cast<UserDictionary::Entry *>(nullptr));
-  const int remaining_size = tail - data;
-  while (entries->size() > remaining_size) {
-    entries->ReleaseLast();
+    std::rotate(entries->pointer_begin() + index,
+                entries->pointer_begin() + index + 1, entries->pointer_end());
+    deleted_entries.push_back(std::make_pair(index, entries->ReleaseLast()));
   }
 
   AddUndoCommand(new UndoDeleteEntryCommand(dictionary_id, deleted_entries));
@@ -628,7 +625,7 @@ UserDictionaryCommandStatus::Status UserDictionarySession::DeleteEntry(
 }
 
 UserDictionaryCommandStatus::Status UserDictionarySession::ImportFromString(
-    uint64 dictionary_id, const std::string &data) {
+    uint64_t dictionary_id, const std::string &data) {
   UserDictionary *dictionary = UserDictionaryUtil::GetMutableUserDictionaryById(
       &storage_->GetProto(), dictionary_id);
   if (dictionary == nullptr) {
@@ -681,10 +678,10 @@ UserDictionarySession::ImportFromStringInternal(UserDictionary *dictionary,
 UserDictionaryCommandStatus::Status
 UserDictionarySession::ImportToNewDictionaryFromString(
     const std::string &dictionary_name, const std::string &data,
-    uint64 *new_dictionary_id) {
+    uint64_t *new_dictionary_id) {
   UserDictionaryCommandStatus::Status status =
-      UserDictionaryUtil::CreateDictionary(
-          &storage_->GetProto(), dictionary_name, new_dictionary_id);
+      UserDictionaryUtil::CreateDictionary(&storage_->GetProto(),
+                                           dictionary_name, new_dictionary_id);
   if (status != UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS) {
     return status;
   }
@@ -709,7 +706,7 @@ bool UserDictionarySession::EnsureNonEmptyStorage() {
   }
 
   // Creates a dictionary with the default name. Should never fail.
-  uint64 new_dictionary_id;
+  uint64_t new_dictionary_id;
   UserDictionaryCommandStatus::Status status =
       UserDictionaryUtil::CreateDictionary(
           &storage_->GetProto(), default_dictionary_name_, &new_dictionary_id);
