@@ -29,6 +29,9 @@
 
 #include "dictionary/user_dictionary_session_handler.h"
 
+#include <cstdint>
+#include <memory>
+
 #include "base/file_util.h"
 #include "base/logging.h"
 #include "base/port.h"
@@ -38,7 +41,6 @@
 #include "dictionary/user_dictionary_session.h"
 #include "dictionary/user_dictionary_util.h"
 #include "protocol/user_dictionary_storage.pb.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace user_dictionary {
@@ -151,10 +153,10 @@ void UserDictionarySessionHandler::ClearStorage(
 
 void UserDictionarySessionHandler::CreateSession(
     const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
-  uint64 new_id = CreateNewSessionId();
+  uint64_t new_id = CreateNewSessionId();
 
   session_id_ = new_id;
-  session_ = absl::make_unique<UserDictionarySession>(dictionary_path_);
+  session_ = std::make_unique<UserDictionarySession>(dictionary_path_);
 
   status->set_status(
       UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS);
@@ -320,7 +322,7 @@ void UserDictionarySessionHandler::GetEntries(
   mutable_entries->Reserve(entry_index_size);
   for (int i = 0; i < entry_index_size; ++i) {
     const int entry_index = command.entry_index(i);
-    mutable_entries->Add()->CopyFrom(dictionary->entries(entry_index));
+    *mutable_entries->Add() = dictionary->entries(entry_index);
   }
   status->set_status(
       UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS);
@@ -355,7 +357,7 @@ void UserDictionarySessionHandler::CreateDictionary(
     return;
   }
 
-  uint64 new_dictionary_id;
+  uint64_t new_dictionary_id;
   status->set_status(
       session->CreateDictionary(command.dictionary_name(), &new_dictionary_id));
   if (status->status() ==
@@ -473,9 +475,9 @@ void UserDictionarySessionHandler::DeleteEntry(
     return;
   }
 
-  const std::vector<int> index_list(command.entry_index().begin(),
-                                    command.entry_index().end());
-  status->set_status(session->DeleteEntry(command.dictionary_id(), index_list));
+  status->set_status(session->DeleteEntry(
+      command.dictionary_id(),
+      {command.entry_index().begin(), command.entry_index().end()}));
 }
 
 void UserDictionarySessionHandler::ImportData(
@@ -491,7 +493,7 @@ void UserDictionarySessionHandler::ImportData(
     return;
   }
 
-  uint64 dictionary_id = 0;
+  uint64_t dictionary_id = 0;
   UserDictionaryCommandStatus::Status result_status;
   if (command.has_dictionary_id()) {
     result_status =
@@ -522,7 +524,7 @@ void UserDictionarySessionHandler::GetStorage(
   if (session == nullptr) {
     return;
   }
-  status->mutable_storage()->CopyFrom(session->storage());
+  *status->mutable_storage() = session->storage();
   status->set_status(
       UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS);
 }
@@ -542,8 +544,8 @@ UserDictionarySession *UserDictionarySessionHandler::GetSession(
   return session_.get();
 }
 
-uint64 UserDictionarySessionHandler::CreateNewSessionId() const {
-  uint64 id = kInvalidSessionId;
+uint64_t UserDictionarySessionHandler::CreateNewSessionId() const {
+  uint64_t id = kInvalidSessionId;
   while (true) {
     Util::GetRandomSequence(reinterpret_cast<char *>(&id), sizeof(id));
 
