@@ -29,6 +29,9 @@
 
 #include "dictionary/user_dictionary_session.h"
 
+#include <cstdint>
+#include <string>
+
 #ifndef OS_WIN
 #include <sys/stat.h>
 #endif  // OS_WIN
@@ -37,6 +40,7 @@
 #include "base/system_util.h"
 #include "dictionary/user_dictionary_storage.h"
 #include "protocol/user_dictionary_storage.pb.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/testing_util.h"
@@ -44,7 +48,7 @@
 
 namespace {
 
-const char kDictionaryData[] =
+constexpr char kDictionaryData[] =
     "きょうと\t京都\t名詞\n"
     "おおさか\t大阪\t地名\n"
     "とうきょう\t東京\t地名\tコメント\n"
@@ -62,11 +66,11 @@ class UserDictionarySessionTest : public ::testing::Test {
   void SetUp() override {
     original_user_profile_directory_ = SystemUtil::GetUserProfileDirectory();
     SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
-    FileUtil::Unlink(GetUserDictionaryFile());
+    EXPECT_OK(FileUtil::UnlinkIfExists(GetUserDictionaryFile()));
   }
 
   void TearDown() override {
-    FileUtil::Unlink(GetUserDictionaryFile());
+    EXPECT_OK(FileUtil::UnlinkIfExists(GetUserDictionaryFile()));
     SystemUtil::SetUserProfileDirectory(original_user_profile_directory_);
   }
 
@@ -159,7 +163,7 @@ TEST_F(UserDictionarySessionTest, UndoWithoutHistory) {
 TEST_F(UserDictionarySessionTest, CreateDictionary) {
   UserDictionarySession session(GetUserDictionaryFile());
 
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("user dictionary", &dictionary_id));
   {
@@ -169,7 +173,7 @@ TEST_F(UserDictionarySessionTest, CreateDictionary) {
     EXPECT_EQ(dictionary_id, storage.dictionaries(0).id());
   }
 
-  uint64 dummy_dictionary_id;
+  uint64_t dummy_dictionary_id;
   EXPECT_EQ(UserDictionaryCommandStatus::DICTIONARY_NAME_EMPTY,
             session.CreateDictionary("", &dummy_dictionary_id));
   EXPECT_EQ(
@@ -198,7 +202,7 @@ TEST_F(UserDictionarySessionTest, DeleteDictionary) {
   UserDictionarySession session(GetUserDictionaryFile());
 
   // Add dummy dictionary.
-  const uint64 kDummyId = 10;
+  constexpr uint64_t kDummyId = 10;
   {
     UserDictionary *user_dictionary =
         session.mutable_storage()->GetProto().add_dictionaries();
@@ -222,7 +226,7 @@ TEST_F(UserDictionarySessionTest, DeleteDictionaryWithEnsuringNonEmptyStorage) {
   session.SetDefaultDictionaryName("abcde");
 
   // Add dummy dictionary.
-  const uint64 kDummyId = 10;
+  constexpr uint64_t kDummyId = 10;
   {
     UserDictionary *user_dictionary =
         session.mutable_storage()->GetProto().add_dictionaries();
@@ -249,7 +253,7 @@ TEST_F(UserDictionarySessionTest, RenameDictionary) {
   UserDictionarySession session(GetUserDictionaryFile());
 
   // Prepare the targeet dictionary.
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("user dictionary", &dictionary_id));
 
@@ -269,7 +273,7 @@ TEST_F(UserDictionarySessionTest, RenameDictionary) {
   EXPECT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.RenameDictionary(dictionary_id, "new name"));
 
-  uint64 dummy_dictionary_id;
+  uint64_t dummy_dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("another name", &dummy_dictionary_id));
   // NG to rename to the name of another dictionary.
@@ -296,7 +300,7 @@ TEST_F(UserDictionarySessionTest, AddEntry) {
   UserDictionarySession session(GetUserDictionaryFile());
   UserDictionary::Entry entry;
 
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("user dictionary", &dictionary_id));
 
@@ -358,7 +362,7 @@ TEST_F(UserDictionarySessionTest, AddEntryLimitExceeded) {
   UserDictionarySession session(GetUserDictionaryFile());
   UserDictionary::Entry entry;
 
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("user dictionary", &dictionary_id));
   ResetEntry("reading", "word", UserDictionary::NOUN, &entry);
@@ -376,7 +380,7 @@ TEST_F(UserDictionarySessionTest, EditEntry) {
   UserDictionarySession session(GetUserDictionaryFile());
   UserDictionary::Entry entry;
 
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("user dictionary", &dictionary_id));
 
@@ -457,7 +461,7 @@ TEST_F(UserDictionarySessionTest, DeleteEntry) {
   UserDictionarySession session(GetUserDictionaryFile());
   UserDictionary::Entry entry;
 
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("user dictionary", &dictionary_id));
 
@@ -511,7 +515,7 @@ TEST_F(UserDictionarySessionTest, DeleteEntry) {
   index_list.push_back(1);
   index_list.push_back(3);
   EXPECT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
-            session.DeleteEntry(dictionary_id, index_list));
+            session.DeleteEntry(dictionary_id, std::move(index_list)));
 
   EXPECT_PROTO_PEQ(
       "dictionaries: <\n"
@@ -538,7 +542,7 @@ TEST_F(UserDictionarySessionTest, DeleteEntry) {
   index_list.push_back(0);
   index_list.push_back(100);
   EXPECT_EQ(UserDictionaryCommandStatus::ENTRY_INDEX_OUT_OF_RANGE,
-            session.DeleteEntry(dictionary_id, index_list));
+            session.DeleteEntry(dictionary_id, std::move(index_list)));
 
   // The contents shouldn't be changed.
   EXPECT_PROTO_PEQ(
@@ -565,7 +569,7 @@ TEST_F(UserDictionarySessionTest, DeleteEntry) {
   index_list.clear();
   index_list.push_back(0);
   EXPECT_EQ(UserDictionaryCommandStatus::UNKNOWN_DICTIONARY_ID,
-            session.DeleteEntry(0, index_list));
+            session.DeleteEntry(0, std::move(index_list)));
 
   // Test undo for delete entries.
   EXPECT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
@@ -604,7 +608,7 @@ TEST_F(UserDictionarySessionTest, DeleteEntry) {
 TEST_F(UserDictionarySessionTest, ImportFromString) {
   UserDictionarySession session(GetUserDictionaryFile());
 
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("user dictionary", &dictionary_id));
 
@@ -652,7 +656,7 @@ TEST_F(UserDictionarySessionTest, ImportFromString) {
 TEST_F(UserDictionarySessionTest, ImportToNewDictionaryFromString) {
   UserDictionarySession session(GetUserDictionaryFile());
 
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.ImportToNewDictionaryFromString(
                 "user dictionary", kDictionaryData, &dictionary_id));
@@ -695,7 +699,7 @@ TEST_F(UserDictionarySessionTest, ImportToNewDictionaryFromStringFailure) {
 
   // Try to create a new dictionary with a name containing
   // an invalid character.
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
   ASSERT_EQ(
       UserDictionaryCommandStatus ::DICTIONARY_NAME_CONTAINS_INVALID_CHARACTER,
       session.ImportToNewDictionaryFromString("a\nb", kDictionaryData,
@@ -707,7 +711,7 @@ TEST_F(UserDictionarySessionTest, ImportToNewDictionaryFromStringFailure) {
 TEST_F(UserDictionarySessionTest, ClearDictionariesAndUndoHistory) {
   UserDictionarySession session(GetUserDictionaryFile());
 
-  uint64 dic_id;
+  uint64_t dic_id;
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             session.CreateDictionary("dic1", &dic_id));
 
