@@ -61,15 +61,17 @@
 #ifndef MOZC_DICTIONARY_USER_DICTIONARY_STORAGE_H_
 #define MOZC_DICTIONARY_USER_DICTIONARY_STORAGE_H_
 
+#include <cstdint>
 #include <memory>
 #include <string>
 
 #include "base/port.h"
 #include "protocol/user_dictionary_storage.pb.h"
+#include "absl/status/status.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 
-class Mutex;
 class ProcessMutex;
 
 class UserDictionaryStorage {
@@ -95,7 +97,7 @@ class UserDictionaryStorage {
     ERROR_TYPE_SIZE
   };
 
-  explicit UserDictionaryStorage(const std::string &filename);
+  explicit UserDictionaryStorage(const std::string &file_name);
   virtual ~UserDictionaryStorage();
 
   // return the filename of user dictionary
@@ -104,18 +106,18 @@ class UserDictionaryStorage {
   // Return true if data tied with this object already
   // exists. Otherwise, it means that the space for the data is used
   // for the first time.
-  bool Exists() const;
+  absl::Status Exists() const;
 
-  // Load user dictionary from the file.
+  // Loads a user dictionary from the file.
   // NOTE: If the file is not existent, nothing is updated.
   //       Therefore if the file is deleted after first load(),
   //       second load() does nothing so the content loaded by first load()
   //       is kept as is.
-  bool Load();
+  absl::Status Load();
 
   // Serialize user dictionary to local file.
   // Need to call Lock() the dictionary before calling Save().
-  bool Save();
+  absl::Status Save();
 
   // Lock the dictionary so that other processes/threads cannot
   // execute mutable operations on this dictionary.
@@ -125,30 +127,30 @@ class UserDictionaryStorage {
   bool UnLock();
 
   // Export a dictionary to a file in TSV format.
-  bool ExportDictionary(uint64 dic_id, const std::string &file_name);
+  bool ExportDictionary(uint64_t dic_id, const std::string &file_name);
 
   // Create a new dictionary with a specified name. Returns the id of
   // the new instance via new_dic_id.
 
-  bool CreateDictionary(const std::string &dic_name, uint64 *new_dic_id);
+  bool CreateDictionary(const std::string &dic_name, uint64_t *new_dic_id);
 
   // Delete a dictionary.
-  bool DeleteDictionary(uint64 dic_id);
+  bool DeleteDictionary(uint64_t dic_id);
 
   // Rename a dictionary.
-  bool RenameDictionary(uint64 dic_id, const std::string &dic_name);
+  bool RenameDictionary(uint64_t dic_id, const std::string &dic_name);
 
   // return the index of "dic_id"
   // return -1 if no dictionary is found.
-  int GetUserDictionaryIndex(uint64 dic_id) const;
+  int GetUserDictionaryIndex(uint64_t dic_id) const;
 
   // return mutable UserDictionary corresponding to dic_id
-  UserDictionary *GetUserDictionary(uint64 dic_id);
+  UserDictionary *GetUserDictionary(uint64_t dic_id);
 
   // Searches a dictionary from a dictionary name, and the dictionary id is
   // stored in "dic_id".
   // Returns false if the name is not found.
-  bool GetUserDictionaryId(const std::string &dic_name, uint64 *dic_id);
+  bool GetUserDictionaryId(const std::string &dic_name, uint64_t *dic_id);
 
   // return last error type.
   // You can obtain the reason of the error of dictionary operation.
@@ -192,13 +194,14 @@ class UserDictionaryStorage {
   bool IsValidDictionaryName(const std::string &name);
 
   // Load the data from file_name actually.
-  bool LoadInternal();
+  absl::Status LoadInternal();
 
   user_dictionary::UserDictionaryStorage proto_;
   std::string file_name_;
-  bool locked_;
-  UserDictionaryStorageErrorType last_error_type_;
-  std::unique_ptr<Mutex> local_mutex_;
+  bool locked_ = false;
+  UserDictionaryStorageErrorType last_error_type_ =
+      USER_DICTIONARY_STORAGE_NO_ERROR;
+  absl::Mutex local_mutex_;
   std::unique_ptr<ProcessMutex> process_mutex_;
 };
 
