@@ -30,11 +30,13 @@
 #include "dictionary/user_dictionary.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <cstring>
 #include <memory>
 #include <random>
 #include <sstream>
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "base/file_util.h"
@@ -53,22 +55,22 @@
 #include "dictionary/user_pos_interface.h"
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/str_join.h"
+#include "absl/strings/str_split.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace dictionary {
 namespace {
 
-using std::unique_ptr;
-
-const char kUserDictionary0[] =
+constexpr char kUserDictionary0[] =
     "start\tstart\tverb\n"
     "star\tstar\tnoun\n"
     "starting\tstarting\tnoun\n"
@@ -100,33 +102,32 @@ const char kUserDictionary0[] =
     // White spaces comment
     "comment_key4\tcomment_value4\tverb\t     \n";
 
-const char kUserDictionary1[] = "end\tend\tverb\n";
+constexpr char kUserDictionary1[] = "end\tend\tverb\n";
 
-void PushBackToken(const std::string &key, const std::string &value, uint16 id,
-                   std::vector<UserPOS::Token> *tokens) {
+void PushBackToken(absl::string_view key, absl::string_view value, uint16_t id,
+                   std::vector<UserPos::Token> *tokens) {
   tokens->resize(tokens->size() + 1);
-  UserPOS::Token *t = &tokens->back();
-  t->key = key;
-  t->value = value;
+  UserPos::Token *t = &tokens->back();
+  t->key = std::string(key);
+  t->value = std::string(value);
   t->id = id;
-  t->cost = 0;
 }
 
 // This class is a mock class for writing unit tests of a class that
 // depends on POS. It accepts only two values for part-of-speech:
 // "noun" as words without inflection and "verb" as words with
 // inflection.
-class UserPOSMock : public UserPOSInterface {
+class UserPosMock : public UserPosInterface {
  public:
-  UserPOSMock() = default;
+  UserPosMock() = default;
 
-  UserPOSMock(const UserPOSMock &) = delete;
-  UserPOSMock &operator=(const UserPOSMock &) = delete;
+  UserPosMock(const UserPosMock &) = delete;
+  UserPosMock &operator=(const UserPosMock &) = delete;
 
-  ~UserPOSMock() override = default;
+  ~UserPosMock() override = default;
 
   // This method returns true if the given pos is "noun" or "verb".
-  bool IsValidPOS(const std::string &pos) const override { return true; }
+  bool IsValidPos(absl::string_view pos) const override { return true; }
 
   static const char *kNoun;
   static const char *kVerb;
@@ -143,9 +144,9 @@ class UserPOSMock : public UserPOSInterface {
   //  verb (base form) | 200 | 200
   //  verb (-ed form)  | 210 | 210
   //  verb (-ing form) | 220 | 220
-  bool GetTokens(const std::string &key, const std::string &value,
-                 const std::string &pos, const std::string &locale,
-                 std::vector<UserPOS::Token> *tokens) const override {
+  bool GetTokens(absl::string_view key, absl::string_view value,
+                 absl::string_view pos, absl::string_view locale,
+                 std::vector<UserPos::Token> *tokens) const override {
     if (key.empty() || value.empty() || pos.empty() || tokens == nullptr) {
       return false;
     }
@@ -156,30 +157,32 @@ class UserPOSMock : public UserPOSInterface {
       return true;
     } else if (pos == kVerb) {
       PushBackToken(key, value, 200, tokens);
-      PushBackToken(key + "ed", value + "ed", 210, tokens);
-      PushBackToken(key + "ing", value + "ing", 220, tokens);
+      PushBackToken(absl::StrCat(key, "ed"), absl::StrCat(value, "ed"), 210,
+                    tokens);
+      PushBackToken(absl::StrCat(key, "ing"), absl::StrCat(value, "ing"), 220,
+                    tokens);
       return true;
     } else {
       return false;
     }
   }
 
-  void GetPOSList(std::vector<std::string> *pos_list) const override {}
+  void GetPosList(std::vector<std::string> *pos_list) const override {}
 
-  bool GetPOSIDs(const std::string &pos, uint16 *id) const override {
+  bool GetPosIds(absl::string_view pos, uint16_t *id) const override {
     return false;
   }
 };
 
-const char *UserPOSMock::kNoun = "名詞";
-const char *UserPOSMock::kVerb = "動詞ワ行五段";
+const char *UserPosMock::kNoun = "名詞";
+const char *UserPosMock::kVerb = "動詞ワ行五段";
 
 std::string GenRandomAlphabet(int size) {
   std::string result;
   const size_t len = Util::Random(size) + 1;
   for (int i = 0; i < len; ++i) {
     const char32 l = Util::Random(static_cast<int>('z' - 'a')) + 'a';
-    Util::UCS4ToUTF8Append(l, &result);
+    Util::Ucs4ToUtf8Append(l, &result);
   }
   return result;
 }
@@ -189,7 +192,7 @@ class UserDictionaryTest : public ::testing::Test {
   UserDictionaryTest() { convreq_.set_config(&config_); }
 
   void SetUp() override {
-    suppression_dictionary_ = absl::make_unique<SuppressionDictionary>();
+    suppression_dictionary_ = std::make_unique<SuppressionDictionary>();
 
     mozc::usage_stats::UsageStats::ClearAllStatsForTest();
     config::ConfigHandler::GetDefaultConfig(&config_);
@@ -209,24 +212,24 @@ class UserDictionaryTest : public ::testing::Test {
   // Creates a user dictionary with mock pos data.
   UserDictionary *CreateDictionaryWithMockPos() {
     return new UserDictionary(
-        absl::make_unique<UserPOSMock>(),
-        dictionary::POSMatcher(mock_data_manager_.GetPOSMatcherData()),
+        std::make_unique<UserPosMock>(),
+        dictionary::PosMatcher(mock_data_manager_.GetPosMatcherData()),
         suppression_dictionary_.get());
   }
 
   // Creates a user dictionary with actual pos data.
   UserDictionary *CreateDictionary() {
     return new UserDictionary(
-        UserPOS::CreateFromDataManager(mock_data_manager_),
-        dictionary::POSMatcher(mock_data_manager_.GetPOSMatcherData()),
+        UserPos::CreateFromDataManager(mock_data_manager_),
+        dictionary::PosMatcher(mock_data_manager_.GetPosMatcherData()),
         Singleton<SuppressionDictionary>::get());
   }
 
   struct Entry {
     std::string key;
     std::string value;
-    uint16 lid;
-    uint16 rid;
+    uint16_t lid;
+    uint16_t rid;
   };
 
   class EntryCollector : public DictionaryInterface::Callback {
@@ -304,9 +307,7 @@ class UserDictionaryTest : public ::testing::Test {
       encoded_items.push_back(EncodeEntry(array[i]));
     }
     std::sort(encoded_items.begin(), encoded_items.end());
-    std::string result;
-    Util::JoinStrings(encoded_items, "", &result);
-    return result;
+    return absl::StrJoin(encoded_items, "");
   }
 
   static void CompareEntries(const Entry *expected, size_t expected_size,
@@ -331,20 +332,20 @@ class UserDictionaryTest : public ::testing::Test {
       if (line.empty() || line[0] == '#') {
         continue;
       }
-      std::vector<std::string> fields;
-      Util::SplitStringAllowEmpty(line, "\t", &fields);
+      std::vector<std::string> fields =
+          absl::StrSplit(line, '\t', absl::AllowEmpty());
       EXPECT_GE(fields.size(), 3) << line;
       UserDictionaryStorage::UserDictionaryEntry *entry = dic->add_entries();
       CHECK(entry);
-      entry->set_key(fields[0]);
-      entry->set_value(fields[1]);
+      entry->set_key(std::move(fields[0]));
+      entry->set_value(std::move(fields[1]));
       if (fields[2] == "verb") {
         entry->set_pos(user_dictionary::UserDictionary::WA_GROUP1_VERB);
       } else if (fields[2] == "noun") {
         entry->set_pos(user_dictionary::UserDictionary::NOUN);
       }
       if (fields.size() >= 4 && !fields[3].empty()) {
-        entry->set_comment(fields[3]);
+        entry->set_comment(std::move(fields[3]));
       }
     }
   }
@@ -357,7 +358,7 @@ class UserDictionaryTest : public ::testing::Test {
     return comment;
   }
 
-  unique_ptr<SuppressionDictionary> suppression_dictionary_;
+  std::unique_ptr<SuppressionDictionary> suppression_dictionary_;
   ConversionRequest convreq_;
   config::Config config_;
 
@@ -368,7 +369,7 @@ class UserDictionaryTest : public ::testing::Test {
 };
 
 TEST_F(UserDictionaryTest, TestLookupPredictive) {
-  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  std::unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -385,7 +386,7 @@ TEST_F(UserDictionaryTest, TestLookupPredictive) {
       {"starting", "starting", 100, 100},
       {"starting", "starting", 220, 220},
   };
-  TestLookupPredictiveHelper(kExpected0, arraysize(kExpected0), "start", *dic);
+  TestLookupPredictiveHelper(kExpected0, std::size(kExpected0), "start", *dic);
 
   // Another normal lookup operation.
   const Entry kExpected1[] = {
@@ -395,7 +396,7 @@ TEST_F(UserDictionaryTest, TestLookupPredictive) {
       {"started", "started", 210, 210},   {"starting", "starting", 100, 100},
       {"starting", "starting", 220, 220},
   };
-  TestLookupPredictiveHelper(kExpected1, arraysize(kExpected1), "st", *dic);
+  TestLookupPredictiveHelper(kExpected1, std::size(kExpected1), "st", *dic);
 
   // Invalid input values should be just ignored.
   TestLookupPredictiveHelper(nullptr, 0, "", *dic);
@@ -414,7 +415,7 @@ TEST_F(UserDictionaryTest, TestLookupPredictive) {
       {"ended", "ended", 210, 210},
       {"ending", "ending", 220, 220},
   };
-  TestLookupPredictiveHelper(kExpected2, arraysize(kExpected2), "end", *dic);
+  TestLookupPredictiveHelper(kExpected2, std::size(kExpected2), "end", *dic);
 
   // Entries in the dictionary before reloading cannot be looked up.
   TestLookupPredictiveHelper(nullptr, 0, "start", *dic);
@@ -422,7 +423,7 @@ TEST_F(UserDictionaryTest, TestLookupPredictive) {
 }
 
 TEST_F(UserDictionaryTest, TestLookupPrefix) {
-  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  std::unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -438,7 +439,7 @@ TEST_F(UserDictionaryTest, TestLookupPrefix) {
       {"start", "start", 200, 200},
       {"started", "started", 210, 210},
   };
-  TestLookupPrefixHelper(kExpected0, arraysize(kExpected0), "started", 7, *dic);
+  TestLookupPrefixHelper(kExpected0, std::size(kExpected0), "started", 7, *dic);
 
   // Another normal lookup operation.
   const Entry kExpected1[] = {
@@ -447,7 +448,7 @@ TEST_F(UserDictionaryTest, TestLookupPrefix) {
       {"starting", "starting", 100, 100},
       {"starting", "starting", 220, 220},
   };
-  TestLookupPrefixHelper(kExpected1, arraysize(kExpected1), "starting", 8,
+  TestLookupPrefixHelper(kExpected1, std::size(kExpected1), "starting", 8,
                          *dic);
 
   // Invalid input values should be just ignored.
@@ -466,7 +467,7 @@ TEST_F(UserDictionaryTest, TestLookupPrefix) {
       {"end", "end", 200, 200},
       {"ending", "ending", 220, 220},
   };
-  TestLookupPrefixHelper(kExpected2, arraysize(kExpected2), "ending", 6, *dic);
+  TestLookupPrefixHelper(kExpected2, std::size(kExpected2), "ending", 6, *dic);
 
   // Lookup for entries which are gone should returns empty result.
   TestLookupPrefixHelper(nullptr, 0, "started", 7, *dic);
@@ -474,7 +475,7 @@ TEST_F(UserDictionaryTest, TestLookupPrefix) {
 }
 
 TEST_F(UserDictionaryTest, TestLookupExact) {
-  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  std::unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -488,14 +489,14 @@ TEST_F(UserDictionaryTest, TestLookupExact) {
   const Entry kExpected0[] = {
       {"start", "start", 200, 200},
   };
-  TestLookupExactHelper(kExpected0, arraysize(kExpected0), "start", 5, *dic);
+  TestLookupExactHelper(kExpected0, std::size(kExpected0), "start", 5, *dic);
 
   // Another normal lookup operation.
   const Entry kExpected1[] = {
       {"starting", "starting", 100, 100},
       {"starting", "starting", 220, 220},
   };
-  TestLookupExactHelper(kExpected1, arraysize(kExpected1), "starting", 8, *dic);
+  TestLookupExactHelper(kExpected1, std::size(kExpected1), "starting", 8, *dic);
 
   // Invalid input values should be just ignored.
   TestLookupPrefixHelper(nullptr, 0, "", 0, *dic);
@@ -503,16 +504,16 @@ TEST_F(UserDictionaryTest, TestLookupExact) {
 }
 
 TEST_F(UserDictionaryTest, TestLookupExactWithSuggestionOnlyWords) {
-  unique_ptr<UserDictionary> user_dic(CreateDictionary());
+  std::unique_ptr<UserDictionary> user_dic(CreateDictionary());
   user_dic->WaitForReloader();
 
   // Create dictionary
   const std::string filename = FileUtil::JoinPath(
       absl::GetFlag(FLAGS_test_tmpdir), "suggestion_only_test.db");
-  FileUtil::Unlink(filename);
+  EXPECT_OK(FileUtil::UnlinkIfExists(filename));
   UserDictionaryStorage storage(filename);
   {
-    uint64 id = 0;
+    uint64_t id = 0;
     EXPECT_TRUE(storage.CreateDictionary("test", &id));
     UserDictionaryStorage::UserDictionary *dic =
         storage.GetProto().mutable_dictionaries(0);
@@ -534,16 +535,65 @@ TEST_F(UserDictionaryTest, TestLookupExactWithSuggestionOnlyWords) {
 
   // "suggestion_only" should not be looked up.
   const testing::MockDataManager mock_data_manager;
-  const dictionary::POSMatcher pos_matcher(
-      mock_data_manager.GetPOSMatcherData());
-  const uint16 kNounId = pos_matcher.GetGeneralNounId();
+  const dictionary::PosMatcher pos_matcher(
+      mock_data_manager.GetPosMatcherData());
+  const uint16_t kNounId = pos_matcher.GetGeneralNounId();
   const Entry kExpected1[] = {{"key", "noun", kNounId, kNounId}};
-  TestLookupExactHelper(kExpected1, arraysize(kExpected1), "key", 3, *user_dic);
+  TestLookupExactHelper(kExpected1, std::size(kExpected1), "key", 3, *user_dic);
+}
+
+TEST_F(UserDictionaryTest, TestLookupWighShortCut) {
+  std::unique_ptr<UserDictionary> user_dic(CreateDictionary());
+  user_dic->WaitForReloader();
+
+  // Create dictionary
+  const std::string filename =
+      FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "shortcut_test.db");
+  EXPECT_OK(FileUtil::UnlinkIfExists(filename));
+  UserDictionaryStorage storage(filename);
+  {
+    uint64_t id = 0;
+    // Creates the shortcut dictionary.
+    EXPECT_TRUE(storage.CreateDictionary(
+        "__auto_imported_android_shortcuts_dictionary", &id));
+    UserDictionaryStorage::UserDictionary *dic =
+        storage.GetProto().mutable_dictionaries(0);
+
+    // "名詞"
+    UserDictionaryStorage::UserDictionaryEntry *entry = dic->add_entries();
+    entry->set_key("key");
+    entry->set_value("noun");
+    entry->set_pos(user_dictionary::UserDictionary::NOUN);
+
+    // SUGGESTION ONLY word is handled as SHORTCUT word.
+    entry = dic->add_entries();
+    entry->set_key("key");
+    entry->set_value("suggest_only");
+    entry->set_pos(user_dictionary::UserDictionary::SUGGESTION_ONLY);
+
+    user_dic->Load(storage.GetProto());
+  }
+
+  // shortcut words are looked up.
+  const testing::MockDataManager mock_data_manager;
+  const dictionary::PosMatcher pos_matcher(
+      mock_data_manager.GetPosMatcherData());
+  const uint16_t kNounId = pos_matcher.GetGeneralNounId();
+  const uint16_t kUnknownId = pos_matcher.GetUnknownId();
+  const Entry kExpected2[] = {
+      {"key", "noun", kNounId, kNounId},
+      {"key", "suggest_only", kUnknownId, kUnknownId},
+  };
+  TestLookupExactHelper(kExpected2, std::size(kExpected2), "key", 3, *user_dic);
+  TestLookupPredictiveHelper(kExpected2, std::size(kExpected2), "ke",
+                             *user_dic);
+  TestLookupPrefixHelper(kExpected2, std::size(kExpected2), "keykey", 3,
+                         *user_dic);
 }
 
 TEST_F(UserDictionaryTest, IncognitoModeTest) {
   config_.set_incognito_mode(true);
-  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  std::unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -572,17 +622,17 @@ TEST_F(UserDictionaryTest, IncognitoModeTest) {
 TEST_F(UserDictionaryTest, AsyncLoadTest) {
   const std::string filename = FileUtil::JoinPath(
       absl::GetFlag(FLAGS_test_tmpdir), "async_load_test.db");
-  FileUtil::Unlink(filename);
+  EXPECT_OK(FileUtil::UnlinkIfExists(filename));
 
   // Create dictionary
   std::vector<std::string> keys;
   {
     UserDictionaryStorage storage(filename);
 
-    EXPECT_FALSE(storage.Load());
+    EXPECT_FALSE(storage.Load().ok());
     EXPECT_TRUE(storage.Lock());
 
-    uint64 id = 0;
+    uint64_t id = 0;
     EXPECT_TRUE(storage.CreateDictionary("test", &id));
     UserDictionaryStorage::UserDictionary *dic =
         storage.GetProto().mutable_dictionaries(0);
@@ -594,12 +644,12 @@ TEST_F(UserDictionaryTest, AsyncLoadTest) {
       entry->set_comment(GenRandomAlphabet(10));
       keys.push_back(entry->key());
     }
-    EXPECT_TRUE(storage.Save());
+    EXPECT_OK(storage.Save());
     EXPECT_TRUE(storage.UnLock());
   }
 
   {
-    unique_ptr<UserDictionary> dic(CreateDictionary());
+    std::unique_ptr<UserDictionary> dic(CreateDictionary());
     // Wait for async reload called from the constructor.
     dic->WaitForReloader();
     dic->SetUserDictionaryName(filename);
@@ -616,104 +666,99 @@ TEST_F(UserDictionaryTest, AsyncLoadTest) {
     }
     dic->WaitForReloader();
   }
-  FileUtil::Unlink(filename);
+  EXPECT_OK(FileUtil::UnlinkIfExists(filename));
 }
 
 TEST_F(UserDictionaryTest, TestSuppressionDictionary) {
-  unique_ptr<UserDictionary> user_dic(CreateDictionaryWithMockPos());
+  std::unique_ptr<UserDictionary> user_dic(CreateDictionaryWithMockPos());
   user_dic->WaitForReloader();
 
   const std::string filename = FileUtil::JoinPath(
       absl::GetFlag(FLAGS_test_tmpdir), "suppression_test.db");
-  FileUtil::Unlink(filename);
+  ASSERT_OK(FileUtil::UnlinkIfExists(filename));
 
   UserDictionaryStorage storage(filename);
 
   // Create dictionary
   {
-    uint64 id = 0;
+    uint64_t id = 0;
     EXPECT_TRUE(storage.CreateDictionary("test", &id));
     UserDictionaryStorage::UserDictionary *dic =
         storage.GetProto().mutable_dictionaries(0);
     for (size_t j = 0; j < 10000; ++j) {
       UserDictionaryStorage::UserDictionaryEntry *entry = dic->add_entries();
       entry->set_key("no_suppress_key" +
-                     std::to_string(static_cast<uint32>(j)));
+                     std::to_string(static_cast<uint32_t>(j)));
       entry->set_value("no_suppress_value" +
-                       std::to_string(static_cast<uint32>(j)));
+                       std::to_string(static_cast<uint32_t>(j)));
       entry->set_pos(user_dictionary::UserDictionary::NOUN);
     }
 
     for (size_t j = 0; j < 10; ++j) {
       UserDictionaryStorage::UserDictionaryEntry *entry = dic->add_entries();
-      entry->set_key("suppress_key" + std::to_string(static_cast<uint32>(j)));
+      entry->set_key("suppress_key" + std::to_string(static_cast<uint32_t>(j)));
       entry->set_value("suppress_value" +
-                       std::to_string(static_cast<uint32>(j)));
+                       std::to_string(static_cast<uint32_t>(j)));
       // entry->set_pos("抑制単語");
       entry->set_pos(user_dictionary::UserDictionary::SUPPRESSION_WORD);
     }
 
-    suppression_dictionary_->Lock();
-    EXPECT_TRUE(suppression_dictionary_->IsLocked());
     user_dic->Load(storage.GetProto());
-    EXPECT_FALSE(suppression_dictionary_->IsLocked());
 
     for (size_t j = 0; j < 10; ++j) {
       EXPECT_TRUE(suppression_dictionary_->SuppressEntry(
-          "suppress_key" + std::to_string(static_cast<uint32>(j)),
-          "suppress_value" + std::to_string(static_cast<uint32>(j))));
+          "suppress_key" + std::to_string(static_cast<uint32_t>(j)),
+          "suppress_value" + std::to_string(static_cast<uint32_t>(j))));
     }
   }
 
   // Remove suppression entry
   {
     storage.GetProto().Clear();
-    uint64 id = 0;
+    uint64_t id = 0;
     EXPECT_TRUE(storage.CreateDictionary("test", &id));
     UserDictionaryStorage::UserDictionary *dic =
         storage.GetProto().mutable_dictionaries(0);
     for (size_t j = 0; j < 10000; ++j) {
       UserDictionaryStorage::UserDictionaryEntry *entry = dic->add_entries();
       entry->set_key("no_suppress_key" +
-                     std::to_string(static_cast<uint32>(j)));
+                     std::to_string(static_cast<uint32_t>(j)));
       entry->set_value("no_suppress_value" +
-                       std::to_string(static_cast<uint32>(j)));
+                       std::to_string(static_cast<uint32_t>(j)));
       entry->set_pos(user_dictionary::UserDictionary::NOUN);
     }
 
-    suppression_dictionary_->Lock();
     user_dic->Load(storage.GetProto());
-    EXPECT_FALSE(suppression_dictionary_->IsLocked());
 
     for (size_t j = 0; j < 10; ++j) {
       EXPECT_FALSE(suppression_dictionary_->SuppressEntry(
-          "suppress_key" + std::to_string(static_cast<uint32>(j)),
-          "suppress_value" + std::to_string(static_cast<uint32>(j))));
+          "suppress_key" + std::to_string(static_cast<uint32_t>(j)),
+          "suppress_value" + std::to_string(static_cast<uint32_t>(j))));
     }
   }
-  FileUtil::Unlink(filename);
+  EXPECT_OK(FileUtil::UnlinkIfExists(filename));
 }
 
 TEST_F(UserDictionaryTest, TestSuggestionOnlyWord) {
-  unique_ptr<UserDictionary> user_dic(CreateDictionary());
+  std::unique_ptr<UserDictionary> user_dic(CreateDictionary());
   user_dic->WaitForReloader();
 
   const std::string filename = FileUtil::JoinPath(
       absl::GetFlag(FLAGS_test_tmpdir), "suggestion_only_test.db");
-  FileUtil::Unlink(filename);
+  ASSERT_OK(FileUtil::UnlinkIfExists(filename));
 
   UserDictionaryStorage storage(filename);
 
   // Create dictionary
   {
-    uint64 id = 0;
+    uint64_t id = 0;
     EXPECT_TRUE(storage.CreateDictionary("test", &id));
     UserDictionaryStorage::UserDictionary *dic =
         storage.GetProto().mutable_dictionaries(0);
 
     for (size_t j = 0; j < 10; ++j) {
       UserDictionaryStorage::UserDictionaryEntry *entry = dic->add_entries();
-      entry->set_key("key" + std::to_string(static_cast<uint32>(j)));
+      entry->set_key("key" + std::to_string(static_cast<uint32_t>(j)));
       entry->set_value("default");
       // "名詞"
       entry->set_pos(user_dictionary::UserDictionary::NOUN);
@@ -721,7 +766,7 @@ TEST_F(UserDictionaryTest, TestSuggestionOnlyWord) {
 
     for (size_t j = 0; j < 10; ++j) {
       UserDictionaryStorage::UserDictionaryEntry *entry = dic->add_entries();
-      entry->set_key("key" + std::to_string(static_cast<uint32>(j)));
+      entry->set_key("key" + std::to_string(static_cast<uint32_t>(j)));
       entry->set_value("suggest_only");
       // "サジェストのみ"
       entry->set_pos(user_dictionary::UserDictionary::SUGGESTION_ONLY);
@@ -731,7 +776,7 @@ TEST_F(UserDictionaryTest, TestSuggestionOnlyWord) {
   }
 
   {
-    const char kKey[] = "key0123";
+    constexpr char kKey[] = "key0123";
     CollectTokenCallback callback;
     user_dic->LookupPrefix(kKey, convreq_, &callback);
     const std::vector<Token> &tokens = callback.tokens();
@@ -740,7 +785,7 @@ TEST_F(UserDictionaryTest, TestSuggestionOnlyWord) {
     }
   }
   {
-    const char kKey[] = "key";
+    constexpr char kKey[] = "key";
     CollectTokenCallback callback;
     user_dic->LookupPredictive(kKey, convreq_, &callback);
     const std::vector<Token> &tokens = callback.tokens();
@@ -750,11 +795,11 @@ TEST_F(UserDictionaryTest, TestSuggestionOnlyWord) {
     }
   }
 
-  FileUtil::Unlink(filename);
+  EXPECT_OK(FileUtil::UnlinkIfExists(filename));
 }
 
 TEST_F(UserDictionaryTest, TestUsageStats) {
-  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  std::unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
   UserDictionaryStorage storage("");
@@ -802,7 +847,7 @@ TEST_F(UserDictionaryTest, TestUsageStats) {
 }
 
 TEST_F(UserDictionaryTest, LookupComment) {
-  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  std::unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -849,6 +894,89 @@ TEST_F(UserDictionaryTest, LookupComment) {
   EXPECT_TRUE(LookupComment(*dic, "mismatching_key", "comment_value4").empty());
 }
 
+TEST_F(UserDictionaryTest, TestPopulateTokenFromUserPosToken) {
+  std::unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  dic->WaitForReloader();
+
+  const testing::MockDataManager mock_data_manager;
+  const dictionary::PosMatcher pos_matcher(
+      mock_data_manager.GetPosMatcherData());
+
+  UserPosInterface::Token user_token;
+  user_token.key = "key";
+  user_token.value = "value";
+  user_token.id = 10;
+
+  Token token;
+
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.key, "key");
+  EXPECT_EQ(token.value, "value");
+  EXPECT_EQ(token.lid, 10);
+  EXPECT_EQ(token.rid, 10);
+  EXPECT_EQ(token.cost, 5000);
+  EXPECT_EQ(token.attributes, Token::USER_DICTIONARY);
+
+  user_token.add_attribute(UserPos::Token::NON_JA_LOCALE);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.cost, 10000);
+
+  user_token.attributes = 0;
+  user_token.add_attribute(UserPos::Token::ISOLATED_WORD);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.cost, 200);
+
+  user_token.attributes = 0;
+  user_token.add_attribute(UserPos::Token::SUGGESTION_ONLY);
+  dic->PopulateTokenFromUserPosToken(
+      user_token, UserDictionary::UserDictionary::PREFIX, &token);
+  EXPECT_EQ(token.lid, pos_matcher.GetUnknownId());
+  EXPECT_EQ(token.rid, pos_matcher.GetUnknownId());
+  EXPECT_EQ(token.cost, 5000);
+
+  user_token.attributes = 0;
+  user_token.add_attribute(UserPos::Token::SHORTCUT);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREDICTIVE,
+                                     &token);
+  EXPECT_EQ(token.lid, pos_matcher.GetUnknownId());
+  EXPECT_EQ(token.rid, pos_matcher.GetUnknownId());
+  EXPECT_EQ(token.cost, 5000);
+
+  user_token.attributes = 0;
+
+  user_token.key = "a";  // one char
+  user_token.add_attribute(UserPos::Token::SHORTCUT);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.cost, 5000 + 2000 * 3);
+
+  user_token.key = "aa";
+  user_token.add_attribute(UserPos::Token::SHORTCUT);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.cost, 5000 + 2000 * 2);
+
+  user_token.key = "aaa";
+  user_token.add_attribute(UserPos::Token::SHORTCUT);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.cost, 5000 + 2000);
+
+  user_token.key = "aaaa";
+  user_token.add_attribute(UserPos::Token::SHORTCUT);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.cost, 5000);
+
+  user_token.key = "aaaaaaa";
+  user_token.add_attribute(UserPos::Token::SHORTCUT);
+  dic->PopulateTokenFromUserPosToken(user_token, UserDictionary::PREFIX,
+                                     &token);
+  EXPECT_EQ(token.cost, 5000);
+}
 }  // namespace
 }  // namespace dictionary
 }  // namespace mozc
