@@ -30,10 +30,14 @@
 #include "dictionary/user_dictionary_util.h"
 
 #include <string.h>
+
 #include <algorithm>
+#include <cstdint>
+#include <string>
 
 #include "base/config_file_stream.h"
 #include "base/file_stream.h"
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/protobuf/protobuf.h"
 #include "base/util.h"
@@ -46,18 +50,18 @@ using ::mozc::user_dictionary::UserDictionaryCommandStatus;
 
 namespace {
 // Maximum string length in UserDictionaryEntry's field
-const size_t kMaxKeySize = 300;
-const size_t kMaxValueSize = 300;
-const size_t kMaxCommentSize = 300;
-const char kInvalidChars[] = "\n\r\t";
-const char kUserDictionaryFile[] = "user://user_dictionary.db";
+constexpr size_t kMaxKeySize = 300;
+constexpr size_t kMaxValueSize = 300;
+constexpr size_t kMaxCommentSize = 300;
+constexpr char kInvalidChars[] = "\n\r\t";
+constexpr char kUserDictionaryFile[] = "user://user_dictionary.db";
 
 // Maximum string length for dictionary name.
-const size_t kMaxDictionaryNameSize = 300;
+constexpr size_t kMaxDictionaryNameSize = 300;
 
 // The limits of dictionary/entry size.
-const size_t kMaxDictionarySize = 100;
-const size_t kMaxEntrySize = 1000000;
+constexpr size_t kMaxDictionarySize = 100;
+constexpr size_t kMaxEntrySize = 1000000;
 }  // namespace
 
 size_t UserDictionaryUtil::max_dictionary_size() { return kMaxDictionarySize; }
@@ -65,7 +69,7 @@ size_t UserDictionaryUtil::max_dictionary_size() { return kMaxDictionarySize; }
 size_t UserDictionaryUtil::max_entry_size() { return kMaxEntrySize; }
 
 bool UserDictionaryUtil::IsValidEntry(
-    const UserPOSInterface &user_pos,
+    const UserPosInterface &user_pos,
     const user_dictionary::UserDictionary::Entry &entry) {
   return ValidateEntry(entry) ==
          UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS;
@@ -107,9 +111,9 @@ void UserDictionaryUtil::NormalizeReading(const std::string &input,
                                           std::string *output) {
   output->clear();
   std::string tmp1, tmp2;
-  Util::FullWidthAsciiToHalfWidthAscii(input, &tmp1);
-  Util::HalfWidthKatakanaToFullWidthKatakana(tmp1, &tmp2);
-  Util::KatakanaToHiragana(tmp2, output);
+  japanese_util::FullWidthAsciiToHalfWidthAscii(input, &tmp1);
+  japanese_util::HalfWidthKatakanaToFullWidthKatakana(tmp1, &tmp2);
+  japanese_util::KatakanaToHiragana(tmp2, output);
 }
 
 UserDictionaryCommandStatus::Status UserDictionaryUtil::ValidateEntry(
@@ -177,21 +181,21 @@ bool UserDictionaryUtil::IsDictionaryFull(
 const user_dictionary::UserDictionary *
 UserDictionaryUtil::GetUserDictionaryById(
     const user_dictionary::UserDictionaryStorage &storage,
-    uint64 dictionary_id) {
+    uint64_t dictionary_id) {
   int index = GetUserDictionaryIndexById(storage, dictionary_id);
   return index >= 0 ? &storage.dictionaries(index) : nullptr;
 }
 
 user_dictionary::UserDictionary *
 UserDictionaryUtil::GetMutableUserDictionaryById(
-    user_dictionary::UserDictionaryStorage *storage, uint64 dictionary_id) {
+    user_dictionary::UserDictionaryStorage *storage, uint64_t dictionary_id) {
   int index = GetUserDictionaryIndexById(*storage, dictionary_id);
   return index >= 0 ? storage->mutable_dictionaries(index) : nullptr;
 }
 
 int UserDictionaryUtil::GetUserDictionaryIndexById(
     const user_dictionary::UserDictionaryStorage &storage,
-    uint64 dictionary_id) {
+    uint64_t dictionary_id) {
   for (int i = 0; i < storage.dictionaries_size(); ++i) {
     const user_dictionary::UserDictionary &dictionary = storage.dictionaries(i);
     if (dictionary.id() == dictionary_id) {
@@ -321,7 +325,7 @@ const char *UserDictionaryUtil::GetStringPosType(
 user_dictionary::UserDictionary::PosType UserDictionaryUtil::ToPosType(
     const char *string_pos_type) {
   // Skip the element at 0.
-  for (int i = 1; i < arraysize(kPosTypeStringTable); ++i) {
+  for (int i = 1; i < std::size(kPosTypeStringTable); ++i) {
     if (strcmp(kPosTypeStringTable[i], string_pos_type) == 0) {
       return static_cast<user_dictionary::UserDictionary::PosType>(i);
     }
@@ -331,11 +335,11 @@ user_dictionary::UserDictionary::PosType UserDictionaryUtil::ToPosType(
   return static_cast<user_dictionary::UserDictionary::PosType>(-1);
 }
 
-uint64 UserDictionaryUtil::CreateNewDictionaryId(
+uint64_t UserDictionaryUtil::CreateNewDictionaryId(
     const user_dictionary::UserDictionaryStorage &storage) {
-  static const uint64 kInvalidDictionaryId = 0;
+  static constexpr uint64_t kInvalidDictionaryId = 0;
 
-  uint64 id = kInvalidDictionaryId;
+  uint64_t id = kInvalidDictionaryId;
   while (id == kInvalidDictionaryId) {
     Util::GetRandomSequence(reinterpret_cast<char *>(&id), sizeof(id));
 
@@ -354,7 +358,7 @@ uint64 UserDictionaryUtil::CreateNewDictionaryId(
 
 UserDictionaryCommandStatus::Status UserDictionaryUtil::CreateDictionary(
     user_dictionary::UserDictionaryStorage *storage,
-    const std::string &dictionary_name, uint64 *new_dictionary_id) {
+    const std::string &dictionary_name, uint64_t *new_dictionary_id) {
   UserDictionaryCommandStatus::Status status =
       ValidateDictionaryName(*storage, dictionary_name);
   if (status != UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS) {
@@ -385,7 +389,7 @@ UserDictionaryCommandStatus::Status UserDictionaryUtil::CreateDictionary(
 }
 
 bool UserDictionaryUtil::DeleteDictionary(
-    user_dictionary::UserDictionaryStorage *storage, uint64 dictionary_id,
+    user_dictionary::UserDictionaryStorage *storage, uint64_t dictionary_id,
     int *original_index, user_dictionary::UserDictionary **deleted_dictionary) {
   const int index = GetUserDictionaryIndexById(*storage, dictionary_id);
   if (original_index != nullptr) {
