@@ -29,6 +29,9 @@
 
 #include "dictionary/user_dictionary_util.h"
 
+#include <cstdint>
+#include <string>
+
 #include "base/util.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
@@ -172,57 +175,56 @@ TEST(UserDictionaryUtilTest, ValidateEntry) {
   base_entry.set_pos(UserDictionary::NOUN);
   base_entry.set_comment("コメント");
 
-  UserDictionary::Entry entry;
-  entry.CopyFrom(base_entry);
+  UserDictionary::Entry entry = base_entry;
   EXPECT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.clear_key();
   EXPECT_EQ(UserDictionaryCommandStatus::READING_EMPTY,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.set_key(std::string(500, 'a'));
   EXPECT_EQ(UserDictionaryCommandStatus::READING_TOO_LONG,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.set_key("a\nb");
   EXPECT_EQ(UserDictionaryCommandStatus::READING_CONTAINS_INVALID_CHARACTER,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.clear_value();
   EXPECT_EQ(UserDictionaryCommandStatus::WORD_EMPTY,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.set_value(std::string(500, 'a'));
   EXPECT_EQ(UserDictionaryCommandStatus::WORD_TOO_LONG,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.set_value("a\nb");
   EXPECT_EQ(UserDictionaryCommandStatus::WORD_CONTAINS_INVALID_CHARACTER,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.clear_comment();
   EXPECT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.set_comment(std::string(500, 'a'));
   EXPECT_EQ(UserDictionaryCommandStatus::COMMENT_TOO_LONG,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.set_comment("a\nb");
   EXPECT_EQ(UserDictionaryCommandStatus::COMMENT_CONTAINS_INVALID_CHARACTER,
             UserDictionaryUtil::ValidateEntry(entry));
 
-  entry.CopyFrom(base_entry);
+  entry = base_entry;
   entry.clear_pos();
   EXPECT_EQ(UserDictionaryCommandStatus::INVALID_POS_TYPE,
             UserDictionaryUtil::ValidateEntry(entry));
@@ -310,7 +312,7 @@ TEST(UserDictionaryUtilTest, GetUserDictionaryIndexById) {
 
 TEST(UserDictionaryUtilTest, CreateDictionary) {
   user_dictionary::UserDictionaryStorage storage;
-  uint64 dictionary_id;
+  uint64_t dictionary_id;
 
   // Check dictionary validity.
   EXPECT_EQ(UserDictionaryCommandStatus::DICTIONARY_NAME_EMPTY,
@@ -367,16 +369,15 @@ TEST(UserDictionaryUtilTest, DeleteDictionary) {
   storage.Clear();
   storage.add_dictionaries()->set_id(1);
   storage.add_dictionaries()->set_id(2);
-  UserDictionary *expected_deleted_dictionary = storage.mutable_dictionaries(0);
   UserDictionary *deleted_dictionary;
   EXPECT_TRUE(UserDictionaryUtil::DeleteDictionary(&storage, 1, nullptr,
                                                    &deleted_dictionary));
   ASSERT_EQ(1, storage.dictionaries_size());
   EXPECT_EQ(2, storage.dictionaries(0).id());
-  EXPECT_TRUE(expected_deleted_dictionary == deleted_dictionary);
+  EXPECT_EQ(1, deleted_dictionary->id());
 
   // Delete to avoid memoary leaking.
-  delete expected_deleted_dictionary;
+  delete deleted_dictionary;
 }
 
 }  // namespace mozc
