@@ -30,66 +30,95 @@
 #ifndef MOZC_DICTIONARY_USER_POS_INTERFACE_H_
 #define MOZC_DICTIONARY_USER_POS_INTERFACE_H_
 
+#include <cstdint>
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "base/port.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 
 // Provides a list of part-of-speech (POS) used by Mozc.  This minimal interface
 // is used by GUI tools so that we can minimize the data embedded in
 // executables.
-class POSListProviderInterface {
+class PosListProviderInterface {
  public:
-  virtual ~POSListProviderInterface() = default;
+  virtual ~PosListProviderInterface() = default;
 
   // Sets posssible list of POS which Mozc can handle.
-  virtual void GetPOSList(std::vector<std::string> *pos_list) const = 0;
+  virtual void GetPosList(std::vector<std::string> *pos_list) const = 0;
 
  protected:
-  POSListProviderInterface() = default;
+  PosListProviderInterface() = default;
 
  private:
-  DISALLOW_COPY_AND_ASSIGN(POSListProviderInterface);
+  DISALLOW_COPY_AND_ASSIGN(PosListProviderInterface);
 };
 
 // Interface of the helper class used by POS.
-class UserPOSInterface : public POSListProviderInterface {
+class UserPosInterface : public PosListProviderInterface {
  public:
   struct Token {
     std::string key;
     std::string value;
-    uint16 id;
-    int16 cost;
+    uint16_t id = 0;
+    uint16_t attributes = 0;
+    // The actual cost of user dictionary entries are populated
+    // in the dictionary lookup time via PopulateTokenFromUserPosToken.
     std::string comment;  // This field comes from user dictionary.
+
+    // Attribute is used to dynamically assign cost, and is independent from the
+    // POS.
+    enum Attribute {
+      SHORTCUT = 1,  // Added via android shortcut, which has no explicit POS.
+      ISOLATED_WORD = 2,    // 短縮よみ
+      SUGGESTION_ONLY = 4,  //  SUGGESTION only.
+      NON_JA_LOCALE = 8     // Locale is not Japanese.
+    };
+
+    inline void add_attribute(Attribute attr) { attributes |= attr; }
+    inline bool has_attribute(Attribute attr) const {
+      return attributes & attr;
+    }
+    inline void remove_attribute(Attribute attr) { attributes &= ~attr; }
+
+    friend void swap(Token &l, Token &r) {
+      using std::swap;
+      swap(l.key, r.key);
+      swap(l.value, r.value);
+      swap(l.id, r.id);
+      swap(l.attributes, r.attributes);
+      swap(l.comment, r.comment);
+    }
   };
 
-  ~UserPOSInterface() override = default;
+  ~UserPosInterface() override = default;
 
   // Returns true if the given string is one of the POSes Mozc can handle.
-  virtual bool IsValidPOS(const std::string &pos) const = 0;
+  virtual bool IsValidPos(absl::string_view pos) const = 0;
 
   // Returns iid from Mozc POS. If the pos has inflection, this method only
   // returns the ids of base form.
-  virtual bool GetPOSIDs(const std::string &pos, uint16 *id) const = 0;
+  virtual bool GetPosIds(absl::string_view pos, uint16_t *id) const = 0;
 
   // Converts the given tuple (key, value, pos, locale) to Token.  If the pos
   // has inflection, this function expands possible inflections automatically.
-  virtual bool GetTokens(const std::string &key, const std::string &value,
-                         const std::string &pos, const std::string &locale,
+  virtual bool GetTokens(absl::string_view key, absl::string_view value,
+                         absl::string_view pos, absl::string_view locale,
                          std::vector<Token> *tokens) const = 0;
 
-  bool GetTokens(const std::string &key, const std::string &value,
-                 const std::string &pos, std::vector<Token> *tokens) const {
+  bool GetTokens(absl::string_view key, absl::string_view value,
+                 absl::string_view pos, std::vector<Token> *tokens) const {
     return GetTokens(key, value, pos, "", tokens);
   }
 
  protected:
-  UserPOSInterface() = default;
+  UserPosInterface() = default;
 
  private:
-  DISALLOW_COPY_AND_ASSIGN(UserPOSInterface);
+  DISALLOW_COPY_AND_ASSIGN(UserPosInterface);
 };
 
 }  // namespace mozc
