@@ -29,6 +29,7 @@
 
 #include "engine/engine_builder.h"
 
+#include <filesystem>
 #include <memory>
 #include <utility>
 
@@ -38,7 +39,7 @@
 #include "data_manager/data_manager.h"
 #include "engine/engine.h"
 #include "protocol/engine_builder.pb.h"
-#include "absl/memory/memory.h"
+#include "absl/status/status.h"
 
 namespace mozc {
 namespace {
@@ -60,7 +61,6 @@ EngineReloadResponse::Status ConvertStatus(DataManager::Status status) {
   }
   return EngineReloadResponse::UNKNOWN_ERROR;
 }
-
 }  // namespace
 
 class EngineBuilder::Preparator : public Thread {
@@ -74,7 +74,7 @@ class EngineBuilder::Preparator : public Thread {
   void Run() override {
     const EngineReloadRequest &request = response_.request();
 
-    std::unique_ptr<DataManager> tmp_data_manager(new DataManager());
+    auto tmp_data_manager = std::make_unique<DataManager>();
     const DataManager::Status status =
         InitDataManager(request, tmp_data_manager.get());
     if (status != DataManager::Status::OK) {
@@ -84,12 +84,14 @@ class EngineBuilder::Preparator : public Thread {
       return;
     }
 
-    if (request.has_install_location() &&
-        !FileUtil::AtomicRename(request.file_path(),
-                                request.install_location())) {
-      LOG(ERROR) << "Atomic rename faild: " << request.Utf8DebugString();
-      response_.set_status(EngineReloadResponse::INSTALL_FAILURE);
-      return;
+    if (request.has_install_location()) {
+      if (absl::Status s = FileUtil::LinkOrCopyFile(request.file_path(),
+                                                    request.install_location());
+          !s.ok()) {
+        LOG(ERROR) << "Copy faild: " << request.Utf8DebugString() << ": " << s;
+        response_.set_status(EngineReloadResponse::INSTALL_FAILURE);
+        return;
+      }
     }
 
     response_.set_status(EngineReloadResponse::RELOAD_READY);
@@ -125,7 +127,7 @@ void EngineBuilder::PrepareAsync(const EngineReloadRequest &request,
     preparator_->Join();
     VLOG(1) << "Previously loaded data is discarded";
   }
-  preparator_ = absl::make_unique<Preparator>(request);
+  preparator_ = std::make_unique<Preparator>(request);
   preparator_->SetJoinable(true);
   preparator_->Start("EngineBuilder::Preparator");
   response->set_status(EngineReloadResponse::ACCEPTED);
@@ -154,7 +156,7 @@ std::unique_ptr<EngineInterface> EngineBuilder::BuildFromPreparedData() {
     LOG(ERROR) << "Build() is called in invalid state";
     return nullptr;
   }
-  mozc::StatusOr<std::unique_ptr<Engine>> engine;
+  absl::StatusOr<std::unique_ptr<Engine>> engine;
   switch (preparator_->response_.request().engine_type()) {
     case EngineReloadRequest::DESKTOP:
       engine =
