@@ -33,6 +33,7 @@
 
 #include "base/file_util.h"
 #include "prediction/predictor_interface.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
@@ -41,7 +42,7 @@
 namespace mozc {
 namespace {
 
-const char kMockMagicNumber[] = "MOCK";
+constexpr char kMockMagicNumber[] = "MOCK";
 
 class EngineBuilderTest : public ::testing::Test {
  protected:
@@ -80,11 +81,11 @@ TEST_F(EngineBuilderTest, PrepareAsync) {
   }
   Clear();
   {
-    // Test request with install.  Since the requested file is moved,
+    // Test request with install.  Since the requested file is copied,
     // |mock_data_path_| is copied to a temporary file.
     const std::string src_path =
         FileUtil::JoinPath({absl::GetFlag(FLAGS_test_tmpdir), "src.data"});
-    ASSERT_TRUE(FileUtil::CopyFile(mock_data_path_, src_path));
+    ASSERT_OK(FileUtil::CopyFile(mock_data_path_, src_path));
 
     const std::string install_path =
         FileUtil::JoinPath({absl::GetFlag(FLAGS_test_tmpdir), "dst.data"});
@@ -99,9 +100,9 @@ TEST_F(EngineBuilderTest, PrepareAsync) {
     ASSERT_TRUE(builder_.HasResponse());
     builder_.GetResponse(&response_);
     EXPECT_EQ(EngineReloadResponse::RELOAD_READY, response_.status());
-    // Verify |src_path| was renamed.
-    EXPECT_FALSE(FileUtil::FileExists(src_path));
-    EXPECT_TRUE(FileUtil::FileExists(install_path));
+    // Verify |src_path| was copied.
+    EXPECT_OK(FileUtil::FileExists(src_path));
+    EXPECT_OK(FileUtil::FileExists(install_path));
   }
 }
 
@@ -159,9 +160,9 @@ TEST_F(EngineBuilderTest, AsyncBuildWithInstall) {
   for (const auto &test_case : kTestCases) {
     Clear();
 
-    // Since requested file is renamed, copy |mock_data_path_| to a temporary
+    // Since requested file is copied, copy |mock_data_path_| to a temporary
     // file.
-    ASSERT_TRUE(FileUtil::CopyFile(mock_data_path_, tmp_src));
+    ASSERT_OK(FileUtil::CopyFile(mock_data_path_, tmp_src));
 
     // Request preparation with install.
     request_.set_engine_type(test_case.type);
@@ -178,9 +179,9 @@ TEST_F(EngineBuilderTest, AsyncBuildWithInstall) {
     builder_.GetResponse(&response_);
     ASSERT_EQ(EngineReloadResponse::RELOAD_READY, response_.status());
 
-    // |tmp_src| should be renamed to |install_path|.
-    ASSERT_FALSE(FileUtil::FileExists(tmp_src));
-    ASSERT_TRUE(FileUtil::FileExists(install_path));
+    // |tmp_src| should be copied to |install_path|.
+    ASSERT_OK(FileUtil::FileExists(tmp_src));
+    ASSERT_OK(FileUtil::FileExists(install_path));
 
     // Build an engine and verify its predictor type (desktop or mobile).
     auto engine = builder_.BuildFromPreparedData();
@@ -194,7 +195,7 @@ TEST_F(EngineBuilderTest, AsyncBuildWithInstall) {
   }
 }
 
-TEST_F(EngineBuilderTest, FailureCase_DataBroken) {
+TEST_F(EngineBuilderTest, FailureCaseDataBroken) {
   // Test the case where input file is invalid.
   request_.set_engine_type(EngineReloadRequest::MOBILE);
   request_.set_file_path(
@@ -210,7 +211,7 @@ TEST_F(EngineBuilderTest, FailureCase_DataBroken) {
   ASSERT_EQ(EngineReloadResponse::DATA_BROKEN, response_.status());
 }
 
-TEST_F(EngineBuilderTest, FailureCase_FileDoesNotExist) {
+TEST_F(EngineBuilderTest, FailureCaseFileDoesNotExist) {
   // Test the case where input file doesn't exist.
   request_.set_engine_type(EngineReloadRequest::MOBILE);
   request_.set_file_path("file_does_not_exist");
