@@ -30,9 +30,11 @@
 #ifndef MOZC_ENGINE_OSS_ENGINE_FACTORY_H_
 #define MOZC_ENGINE_OSS_ENGINE_FACTORY_H_
 
-#include "base/logging.h"
+#include <memory>
+
 #include "data_manager/oss/oss_data_manager.h"
 #include "engine/engine.h"
+#include "absl/status/statusor.h"
 
 namespace mozc {
 
@@ -40,15 +42,12 @@ namespace mozc {
 // equipped with the data set for OSS (i.e., mozc/data/dictionary_oss).
 class OssEngineFactory {
  public:
-  // Creates an instance of Engine class. The caller is responsible for deleting
-  // the returned object.
-  static Engine *Create() {
-    auto engine = Engine::CreateMobileEngineHelper<oss::OssDataManager>();
-    if (!engine.ok()) {
-      LOG(ERROR) << engine.status();
-      return nullptr;
-    }
-    return engine->release();
+  static absl::StatusOr<std::unique_ptr<Engine>> Create() {
+#ifdef OS_ANDROID
+    return Engine::CreateMobileEngineHelper<oss::OssDataManager>();
+#else
+    return Engine::CreateDesktopEngineHelper<oss::OssDataManager>();
+#endif  // OS_ANDROID
   }
 };
 
