@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,7 @@
 #ifndef MOZC_GUI_BASE_DEBUG_UTIL_H_
 #define MOZC_GUI_BASE_DEBUG_UTIL_H_
 
-#include <QtGui/QGuiApplication>
+#include <QGuiApplication>
 
 namespace mozc {
 namespace gui {
