@@ -91,7 +91,7 @@ using user_dictionary::UserDictionaryCommandStatus;
 
 namespace {
 
-const size_t kBufferSize = 256;
+constexpr size_t kBufferSize = 256;
 
 // ProgID of MS-IME Japanese.
 const wchar_t kVersionIndependentProgIdForMSIME[] = L"MSIME.Japan";
@@ -174,9 +174,9 @@ class MSIMEImportIterator
       return;
     }
 
-    string name;
+    std::string name;
     for (int i = 0; i < pos_size; ++i) {
-      EncodingUtil::SJISToUTF8(reinterpret_cast<char *>(pos_table->szName),
+      EncodingUtil::SjisToUtf8(reinterpret_cast<char *>(pos_table->szName),
                                &name);
       pos_map_.insert(std::make_pair(pos_table->nPos, name));
       ++pos_table;
@@ -220,11 +220,11 @@ class MSIMEImportIterator
       }
 
       // set key/value
-      Util::WideToUTF8(buf_[index_].pwchReading, &entry->key);
-      Util::WideToUTF8(buf_[index_].pwchDisplay, &entry->value);
+      Util::WideToUtf8(buf_[index_].pwchReading, &entry->key);
+      Util::WideToUtf8(buf_[index_].pwchDisplay, &entry->value);
 
       // set POS
-      std::map<int, string>::const_iterator it =
+      std::map<int, std::string>::const_iterator it =
           pos_map_.find(buf_[index_].nPos1);
       if (it == pos_map_.end()) {
         ++index_;
@@ -237,11 +237,11 @@ class MSIMEImportIterator
       // set comment
       if (buf_[index_].pvComment != nullptr) {
         if (buf_[index_].uct == IFED_UCT_STRING_SJIS) {
-          EncodingUtil::SJISToUTF8(
+          EncodingUtil::SjisToUtf8(
               reinterpret_cast<const char *>(buf_[index_].pvComment),
               &entry->comment);
         } else if (buf_[index_].uct == IFED_UCT_STRING_UNICODE) {
-          Util::WideToUTF8(
+          Util::WideToUtf8(
               reinterpret_cast<const wchar_t *>(buf_[index_].pvComment),
               &entry->comment);
         }
@@ -270,7 +270,7 @@ class MSIMEImportIterator
  private:
   std::vector<IMEWRD> buf_;
   ScopedIFEDictionary dic_;
-  std::map<int, string> pos_map_;
+  std::map<int, std::string> pos_map_;
   HRESULT result_;
   ULONG size_;
   ULONG index_;
