@@ -29,6 +29,8 @@
 
 #include "gui/base/setup_util.h"
 
+#include <cstdint>
+
 #ifdef OS_WIN
 #include <algorithm>
 #endif  // OS_WIN
@@ -63,7 +65,7 @@ bool SetupUtil::IsUserDictionaryLocked() const {
   return is_userdictionary_locked_;
 }
 
-void SetupUtil::SetDefaultProperty(uint32 flags) {
+void SetupUtil::SetDefaultProperty(uint32_t flags) {
 #ifdef OS_WIN
   if (flags & IME_DEFAULT) {
     mozc::usage_stats::UsageStats::IncrementCount("PostInstallSetDefault");
@@ -83,7 +85,7 @@ void SetupUtil::SetDefaultProperty(uint32 flags) {
       LOG(ERROR) << "Failed to migrate dictionary";
     }
   }
-#else
+#else   // OS_WIN
   // not supported on Mac and Linux
 #endif  // OS_WIN
 }
@@ -94,13 +96,13 @@ bool SetupUtil::MigrateDictionaryFromMSIME() {
   if (!is_userdictionary_locked_ && !storage_->Lock()) {
     return false;
   }
-  if (!storage_->Load()) {
+  if (!storage_->Load().ok()) {
     return false;
   }
 
   // create UserDictionary if the current user dictionary is empty
-  if (!storage_->Exists()) {
-    const string kUserdictionaryName = "User Dictionary 1";
+  if (!storage_->Exists().ok()) {
+    const std::string kUserdictionaryName = "User Dictionary 1";
     uint64 dic_id = 0;
     if (!storage_->CreateDictionary(kUserdictionaryName, &dic_id)) {
       LOG(ERROR) << "Failed to create a new dictionary.";
@@ -111,7 +113,7 @@ bool SetupUtil::MigrateDictionaryFromMSIME() {
   // Import MS-IME's dictionary to a unique dictionary labeled
   // as "MS-IME"
   uint64 dic_id = 0;
-  const string kMsimeUserdictionaryName = "MS-IME User Dictionary";
+  const std::string kMsimeUserdictionaryName = "MS-IME User Dictionary";
   for (size_t i = 0; i < storage_->dictionaries_size(); ++i) {
     if (storage_->dictionaries(i).name() == kMsimeUserdictionaryName) {
       dic_id = storage_->dictionaries(i).id();
@@ -146,9 +148,12 @@ bool SetupUtil::MigrateDictionaryFromMSIME() {
     return false;
   }
 
-  storage_->Save();
+  if (!storage_->Save().ok()) {
+    LOG(ERROR) << "Failed to save the dictionary.";
+    return false;
+  }
   return true;
-#else
+#else   // OS_WIN
   return false;
 #endif  // OS_WIN
 }
