@@ -29,25 +29,24 @@
 
 #include "gui/base/singleton_window_helper.h"
 
-#ifdef OS_WIN
-#include <windows.h>
-#else
-#include <unistd.h>  // for getpid()
-#endif
+#include <cstdint>
 
 #ifdef OS_WIN
-#include <memory>  // for std::unique_ptr
-#endif             // OS_WIN
+#include <windows.h>
+#else  // OS_WIN
+#include <unistd.h>
+#endif  // OS_WIN
+
+#include <memory>
+#include <string>
 
 #include "base/file_stream.h"
 #include "base/logging.h"
-#include "base/mutex.h"
 #include "base/process_mutex.h"
 #include "base/scoped_handle.h"
 #include "base/util.h"
 #include "gui/base/win_util.h"
 #include "ipc/window_info.pb.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace gui {
@@ -56,7 +55,7 @@ bool ReadWindowInfo(const std::string &lock_name,
                     ipc::WindowInfo *window_info) {
 #ifdef OS_WIN
   std::wstring wfilename;
-  mozc::Util::UTF8ToWide(lock_name, &wfilename);
+  mozc::Util::Utf8ToWide(lock_name, &wfilename);
   {
     mozc::ScopedHandle handle(
         ::CreateFileW(wfilename.c_str(), GENERIC_READ,
@@ -73,7 +72,7 @@ bool ReadWindowInfo(const std::string &lock_name,
       return false;
     }
 
-    const DWORD kMaxFileSize = 2096;
+    constexpr DWORD kMaxFileSize = 2096;
     if (size == 0 || size >= kMaxFileSize) {
       LOG(ERROR) << "Invalid file size: " << kMaxFileSize;
       return false;
@@ -97,7 +96,7 @@ bool ReadWindowInfo(const std::string &lock_name,
       return false;
     }
   }
-#else
+#else   // OS_WIN
   InputFileStream is(lock_name.c_str(), std::ios::binary | std::ios::in);
   if (!is) {
     LOG(ERROR) << "cannot open: " << lock_name;
@@ -108,13 +107,13 @@ bool ReadWindowInfo(const std::string &lock_name,
     LOG(ERROR) << "ParseFromStream failed";
     return false;
   }
-#endif
+#endif  // OS_WIN
   return true;
 }
 }  // namespace
 
 SingletonWindowHelper::SingletonWindowHelper(const std::string &name) {
-  mutex_ = absl::make_unique<mozc::ProcessMutex>(name.c_str());
+  mutex_ = std::make_unique<mozc::ProcessMutex>(name.c_str());
 }
 
 SingletonWindowHelper::~SingletonWindowHelper() {}
@@ -123,9 +122,9 @@ bool SingletonWindowHelper::FindPreviousWindow() {
   ipc::WindowInfo window_info;
 #ifdef OS_WIN
   window_info.set_process_id(static_cast<uint32>(::GetCurrentProcessId()));
-#else
-  window_info.set_process_id(static_cast<uint32>(getpid()));
-#endif
+#else   // OS_WIN
+  window_info.set_process_id(static_cast<uint32_t>(getpid()));
+#endif  // OS_WIN
 
   std::string window_info_str;
   if (!window_info.SerializeToString(&window_info_str)) {
@@ -153,10 +152,10 @@ bool SingletonWindowHelper::ActivatePreviousWindow() {
 #ifdef OS_WIN
   WinUtil::ActivateWindow(window_info.process_id());
   return true;
-#else
+#else   // OS_WIN
   // not implemented
   return false;
-#endif
+#endif  // OS_WIN
 }
 
 }  // namespace gui
