@@ -35,18 +35,18 @@
 #define MOZC_SHOW_BUILD_NUMBER_ON_TITLE
 #endif  // CHANNEL_DEV && GOOGLE_JAPANESE_INPUT_BUILD
 
-
-#include <QtCore/QObject>
-#include <QtGui/QFont>
-#include <QtGui/QGuiApplication>
-#include <QtGui/QtGui>
-#include <QtWidgets/QAbstractButton>
-#include <QtWidgets/QApplication>
-#include <QtWidgets/QStyleFactory>
+#include <QAbstractButton>
+#include <QApplication>
+#include <QFont>
+#include <QGuiApplication>
+#include <QObject>
+#include <QStyleFactory>
+#include <QtGui>
 #include <memory>
+#include <string>
+#include <utility>
 
 #include "base/logging.h"
-#include "absl/memory/memory.h"
 
 #ifdef MOZC_SHOW_BUILD_NUMBER_ON_TITLE
 #include "gui/base/window_title_modifier.h"
@@ -92,10 +92,10 @@ std::unique_ptr<QApplication> GuiUtil::InitQt(int &argc, char *argv[]) {
   QApplication::setStyle(QStyleFactory::create(QLatin1String("fusion")));
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
   QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
+#endif  // QT_VERSION
 
   // QApplication takes argc as a reference.
-  auto app = absl::make_unique<QApplication>(argc, argv);
+  auto app = std::make_unique<QApplication>(argc, argv);
 #ifdef __APPLE__
   app->setFont(QFont("Hiragino Sans"));
 #endif  // __APPLE__
@@ -128,7 +128,7 @@ void GuiUtil::InstallTranslator(const char *resource_name) {
 // static
 const QString GuiUtil::ProductName() {
 #ifdef GOOGLE_JAPANESE_INPUT_BUILD
-  const QString name = QObject::tr("Mozc");
+  const QString name = QObject::tr("Google Japanese Input");
 #else  // GOOGLE_JAPANESE_INPUT_BUILD
   const QString name = QObject::tr("Mozc");
 #endif  // GOOGLE_JAPANESE_INPUT_BUILD
