@@ -30,6 +30,8 @@
 // Qt component of configure dialog for Mozc
 #include "gui/config_dialog/config_dialog.h"
 
+#include <cstdint>
+
 #if defined(OS_ANDROID) || defined(OS_WASM)
 #error "This platform is not supported."
 #endif  // OS_ANDROID || OS_WASM
@@ -37,16 +39,16 @@
 #ifdef OS_WIN
 // clang-format off
 #include <windows.h>
-#include <QtGui/QGuiApplication>
+#include <QGuiApplication>
 // clang-format on
-#endif
-
-#include <QtWidgets/QMessageBox>
+#endif  // OS_WIN
 
+#include <QMessageBox>
 #include <algorithm>
 #include <cstdlib>
 #include <memory>
 #include <sstream>
+#include <string>
 
 #include "base/config_file_stream.h"
 #include "base/logging.h"
@@ -116,7 +118,7 @@ ConfigDialog::ConfigDialog()
 
 #if defined(OS_LINUX)
   // The last "misc" tab has no valid configs on Linux
-  const int kMiscTabIndex = 6;
+  constexpr int kMiscTabIndex = 6;
   configDialogTabWidget->removeTab(kMiscTabIndex);
 #endif  // OS_LINUX
 #endif  // MOZC_NO_LOGGING
@@ -270,7 +272,7 @@ ConfigDialog::ConfigDialog()
   usageStatsCheckBox->setVisible(false);
   usageStatsMessage->setDisabled(true);
   usageStatsMessage->setVisible(false);
-#else
+#else   // OS_WIN
   launchAdministrationDialogButton->setEnabled(false);
   launchAdministrationDialogButton->setVisible(false);
   launchAdministrationDialogButtonForUsageStats->setEnabled(false);
@@ -298,9 +300,9 @@ ConfigDialog::ConfigDialog()
 
 #ifdef OS_WIN
   IMEHotKeyDisabledCheckBox->setChecked(WinUtil::GetIMEHotKeyDisabled());
-#else
+#else   // OS_WIN
   IMEHotKeyDisabledCheckBox->setVisible(false);
-#endif
+#endif  // OS_WIN
 
 #ifdef CHANNEL_DEV
   usageStatsCheckBox->setEnabled(false);
@@ -456,7 +458,7 @@ void ConfigDialog::GetSendStatsCheckBox() const {
   } while (0)
 
 namespace {
-static const int kPreeditMethodSize = 2;
+static constexpr int kPreeditMethodSize = 2;
 
 void SetComboboxForPreeditMethod(const config::Config &config,
                                  QComboBox *combobox) {
@@ -523,7 +525,7 @@ void ConfigDialog::ConvertFromProto(const config::Config &config) {
   // InfoListConfig
   localUsageDictionaryCheckBox->setChecked(
       config.information_list_config().use_local_usage_dictionary());
-  information_list_config_.CopyFrom(config.information_list_config());
+  information_list_config_ = config.information_list_config();
 
   // tab3
   SET_CHECKBOX(useAutoImeTurnOff, use_auto_ime_turn_off);
@@ -553,7 +555,7 @@ void ConfigDialog::ConvertFromProto(const config::Config &config) {
   SET_CHECKBOX(realtimeConversionCheckBox, use_realtime_conversion);
 
   suggestionsSizeSpinBox->setValue(
-      std::max(1, std::min(9, static_cast<int>(config.suggestions_size()))));
+      std::max(1, std::min<int>(9, config.suggestions_size())));
 
   // tab5
   SetSendStatsCheckBox();
@@ -621,7 +623,7 @@ void ConfigDialog::ConvertToProto(config::Config *config) const {
 
   GET_CHECKBOX(useModeIndicator, use_mode_indicator);
 
-  uint32 auto_conversion_key = 0;
+  uint32_t auto_conversion_key = 0;
   if (kutenCheckBox->isChecked()) {
     auto_conversion_key |= config::Config::AUTO_CONVERSION_KUTEN;
   }
@@ -645,7 +647,7 @@ void ConfigDialog::ConvertToProto(config::Config *config) const {
   GET_CHECKBOX(realtimeConversionCheckBox, use_realtime_conversion);
 
   config->set_suggestions_size(
-      static_cast<uint32>(suggestionsSizeSpinBox->value()));
+      static_cast<uint32_t>(suggestionsSizeSpinBox->value()));
 
   // tab5
   GetSendStatsCheckBox();
@@ -837,7 +839,7 @@ bool ConfigDialog::eventFilter(QObject *obj, QEvent *event) {
     if (obj == usageStatsMessage) {
 #ifndef CHANNEL_DEV
       usageStatsCheckBox->toggle();
-#endif
+#endif  // CHANNEL_DEV
     } else if (obj == incognitoModeMessage) {
       incognitoModeCheckBox->toggle();
     }
