@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,16 +29,15 @@
 
 #include "gui/config_dialog/generic_table_editor.h"
 
-#include <QtCore/QFile>
-#include <QtGui/QtGui>
-#include <QtWidgets/QFileDialog>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QMessageBox>
-
+#include <QFile>
+#include <QFileDialog>
+#include <QMenu>
+#include <QMessageBox>
+#include <QtGui>
 #include <algorithm>  // for unique
 #include <cctype>
-#include <sstream>
 #include <set>
+#include <sstream>
 #include <string>
 
 #include "base/file_stream.h"
@@ -50,7 +49,7 @@
 namespace mozc {
 namespace gui {
 namespace {
-const size_t kMaxEntrySize = 10000;
+constexpr size_t kMaxEntrySize = 10000;
 
 int GetTableHeight(QTableWidget *widget) {
   // Dragon Hack:
@@ -59,7 +58,7 @@ int GetTableHeight(QTableWidget *widget) {
       QFontMetrics(widget->font()).boundingRect(QString::fromUtf8("龍"));
 #ifdef OS_WIN
   return static_cast<int>(rect.height() * 1.3);
-#else
+#else  // OS_WIN
   return static_cast<int>(rect.height() * 1.4);
 #endif  // OS_WIN
 }
@@ -121,13 +120,13 @@ QTableWidget *GenericTableEditorDialog::mutable_table_widget() {
   return editorTableWidget;
 }
 
-const string &GenericTableEditorDialog::table() const { return table_; }
+const std::string &GenericTableEditorDialog::table() const { return table_; }
 
-string *GenericTableEditorDialog::mutable_table() { return &table_; }
+std::string *GenericTableEditorDialog::mutable_table() { return &table_; }
 
 QMenu *GenericTableEditorDialog::mutable_edit_menu() { return edit_menu_; }
 
-bool GenericTableEditorDialog::LoadFromString(const string &str) {
+bool GenericTableEditorDialog::LoadFromString(const std::string &str) {
   std::istringstream istr(str);
   return LoadFromStream(&istr);
 }
