@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
 #ifndef MOZC_GUI_CONFIG_DIALOG_GENERIC_TABLE_EDITOR_H_
 #define MOZC_GUI_CONFIG_DIALOG_GENERIC_TABLE_EDITOR_H_
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 #include <string>
 
 #include "gui/config_dialog/ui_generic_table_editor.h"
@@ -70,7 +70,7 @@ class GenericTableEditorDialog : public QDialog,
   QTableWidget *mutable_table_widget();
   QMenu *mutable_edit_menu();
 
-  // impliments a method which returns default fileame
+  // implements a method which returns default fileame
   virtual std::string GetDefaultFilename() const = 0;
 
   // implements a method which loads
