@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,9 +29,9 @@
 
 #include "gui/config_dialog/keybinding_editor.h"
 
-#if defined(OS_ANDROID) || defined(OS_NACL)
+#if defined(OS_ANDROID) || defined(OS_WASM)
 #error "This platform is not supported."
-#endif  // OS_ANDROID || OS_NACL
+#endif  // OS_ANDROID || OS_WASM
 
 #ifdef OS_WIN
 // clang-format off
@@ -39,82 +39,78 @@
 #include <imm.h>
 #include <ime.h>
 // clang-format on
-#endif
+#endif  // OS_WIN
 
-#include <QtCore/QString>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QMessageBox>
-#include <QtWidgets/QPushButton>
-#include <QtWidgets/QTableWidget>
+#include <QMenu>
+#include <QMessageBox>
+#include <QPushButton>
+#include <QString>
+#include <QTableWidget>
+#include <map>
+#include <memory>
 
 #include "base/logging.h"
 #include "base/util.h"
 #include "gui/base/util.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace gui {
 
 namespace {
-struct QtKeyEntry {
-  Qt::Key qt_key;
-  const char *mozc_key_name;
-};
+static const auto *kQtKeyModifierNonRequiredTable =
+    new std::map<const int, const char *>({
+        {Qt::Key_Escape, "Escape"},
+        {Qt::Key_Tab, "Tab"},
+        {Qt::Key_Backtab, "Tab"},  // Qt handles Tab + Shift as a special key
+        {Qt::Key_Backspace, "Backspace"},
+        {Qt::Key_Return, "Enter"},
+        {Qt::Key_Enter, "Enter"},
+        {Qt::Key_Insert, "Insert"},
+        {Qt::Key_Delete, "Delete"},
+        {Qt::Key_Home, "Home"},
+        {Qt::Key_End, "End"},
+        {Qt::Key_Left, "Left"},
+        {Qt::Key_Up, "Up"},
+        {Qt::Key_Right, "Right"},
+        {Qt::Key_Down, "Down"},
+        {Qt::Key_PageUp, "PageUp"},
+        {Qt::Key_PageDown, "PageDown"},
+        {Qt::Key_Space, "Space"},
+        {Qt::Key_F1, "F1"},
+        {Qt::Key_F2, "F2"},
+        {Qt::Key_F3, "F3"},
+        {Qt::Key_F4, "F4"},
+        {Qt::Key_F5, "F5"},
+        {Qt::Key_F6, "F6"},
+        {Qt::Key_F7, "F7"},
+        {Qt::Key_F8, "F8"},
+        {Qt::Key_F9, "F9"},
+        {Qt::Key_F10, "F10"},
+        {Qt::Key_F11, "F11"},
+        {Qt::Key_F12, "F12"},
+        {Qt::Key_F13, "F13"},
+        {Qt::Key_F14, "F14"},
+        {Qt::Key_F15, "F15"},
+        {Qt::Key_F16, "F16"},
+        {Qt::Key_F17, "F17"},
+        {Qt::Key_F18, "F18"},
+        {Qt::Key_F19, "F19"},
+        {Qt::Key_F20, "F20"},
+        {Qt::Key_F21, "F21"},
+        {Qt::Key_F22, "F22"},
+        {Qt::Key_F23, "F23"},
+        {Qt::Key_F24, "F24"},
 
-// TODO(taku): check it these mappings are correct.
-const QtKeyEntry kQtKeyModifierNonRequiredTable[] = {
-    {Qt::Key_Escape, "Escape"},
-    {Qt::Key_Tab, "Tab"},
-    {Qt::Key_Backtab, "Tab"},  // Qt handles Tab + Shift as a special key
-    {Qt::Key_Backspace, "Backspace"},
-    {Qt::Key_Return, "Enter"},
-    {Qt::Key_Enter, "Enter"},
-    {Qt::Key_Insert, "Insert"},
-    {Qt::Key_Delete, "Delete"},
-    {Qt::Key_Home, "Home"},
-    {Qt::Key_End, "End"},
-    {Qt::Key_Left, "Left"},
-    {Qt::Key_Up, "Up"},
-    {Qt::Key_Right, "Right"},
-    {Qt::Key_Down, "Down"},
-    {Qt::Key_PageUp, "PageUp"},
-    {Qt::Key_PageDown, "PageDown"},
-    {Qt::Key_Space, "Space"},
-    {Qt::Key_F1, "F1"},
-    {Qt::Key_F2, "F2"},
-    {Qt::Key_F3, "F3"},
-    {Qt::Key_F4, "F4"},
-    {Qt::Key_F5, "F5"},
-    {Qt::Key_F6, "F6"},
-    {Qt::Key_F7, "F7"},
-    {Qt::Key_F8, "F8"},
-    {Qt::Key_F9, "F9"},
-    {Qt::Key_F10, "F10"},
-    {Qt::Key_F11, "F11"},
-    {Qt::Key_F12, "F12"},
-    {Qt::Key_F13, "F13"},
-    {Qt::Key_F14, "F14"},
-    {Qt::Key_F15, "F15"},
-    {Qt::Key_F16, "F16"},
-    {Qt::Key_F17, "F17"},
-    {Qt::Key_F18, "F18"},
-    {Qt::Key_F19, "F19"},
-    {Qt::Key_F20, "F20"},
-    {Qt::Key_F21, "F21"},
-    {Qt::Key_F22, "F22"},
-    {Qt::Key_F23, "F23"},
-    {Qt::Key_F24, "F24"},
-
-    {Qt::Key_Muhenkan, "Muhenkan"},
-    {Qt::Key_Henkan, "Henkan"},
-    {Qt::Key_Hiragana, "Hiragana"},
-    {Qt::Key_Katakana, "Katakana"},
-    // We need special hack for Hiragana_Katakana key. For the detail, please
-    // see KeyBindingFilter::AddKey implementation.
-    {Qt::Key_Hiragana_Katakana, "Hiragana"},
-    {Qt::Key_Eisu_toggle, "Eisu"},
-    {Qt::Key_Zenkaku_Hankaku, "Hankaku/Zenkaku"},
-};
+        {Qt::Key_Muhenkan, "Muhenkan"},
+        {Qt::Key_Henkan, "Henkan"},
+        {Qt::Key_Hiragana, "Hiragana"},
+        {Qt::Key_Katakana, "Katakana"},
+        // We need special hack for Hiragana_Katakana key. For the detail,
+        // please see KeyBindingFilter::AddKey implementation.
+        {Qt::Key_Hiragana_Katakana, "Hiragana"},
+        {Qt::Key_Eisu_toggle, "Eisu"},
+        {Qt::Key_Zenkaku_Hankaku, "Hankaku/Zenkaku"},
+    });
 
 #ifdef OS_WIN
 struct WinVirtualKeyEntry {
@@ -138,17 +134,23 @@ const WinVirtualKeyEntry kWinVirtualKeyModifierNonRequiredTable[] = {
     {VK_DBE_SBCSCHAR, "Hankaku/Zenkaku"},  // Zenkaku/hankaku
     {VK_DBE_DBCSCHAR, "Hankaku/Zenkaku"},  // Zenkaku/hankaku
     // { VK_KANJI, "Kanji" },  // Do not support Kanji
+
+    // VK_IME_ON and VK_IME_OFF
+    // https://docs.microsoft.com/en-us/windows-hardware/design/component-guidelines/keyboard-japan-ime
+    // Those variables may not be declared yet in sone build environments.
+    {0x16, "ON"},   // 0x16 = VK_IME_ON
+    {0x1A, "OFF"},  // 0x1A = VK_IME_OFF
 };
-#endif
+#endif  // OS_WIN
 
 // On Windows Hiragana/Eisu keys only emits KEY_DOWN event.
-// for these keys we don't hanlde auto-key repeat.
+// for these keys we don't handle auto-key repeat.
 bool IsDownOnlyKey(const QKeyEvent &key_event) {
 #ifdef OS_WIN
   const DWORD virtual_key = key_event.nativeVirtualKey();
   return (virtual_key == VK_DBE_ALPHANUMERIC ||
           virtual_key == VK_DBE_HIRAGANA || virtual_key == VK_DBE_KATAKANA);
-#else
+#else  // OS_WIN
   return false;
 #endif  // OS_WIN
 }
@@ -241,10 +243,10 @@ KeyBindingFilter::KeyState KeyBindingFilter::Encode(QString *result) const {
   if (alt_pressed_) {
 #ifdef __APPLE__
     results << QLatin1String("Option");
-#else
+#else  // __APPLE__
     // Do not support and show keybindings with alt for Windows
     // results << "Alt";
-#endif
+#endif  // __APPLE__
   }
 
   const bool has_modifier = !results.isEmpty();
@@ -262,7 +264,7 @@ KeyBindingFilter::KeyState KeyBindingFilter::Encode(QString *result) const {
   if (!unknown_key_.isEmpty()) {
     results << unknown_key_;
   }
-#endif
+#endif  // MOZC_NO_LOGGING
 
   KeyBindingFilter::KeyState result_state = KeyBindingFilter::ACCEPT_KEY;
 
@@ -345,7 +347,7 @@ KeyBindingFilter::KeyState KeyBindingFilter::AddKey(const QKeyEvent &key_event,
                        //    case Qt::Key_Control:  Command key
       alt_pressed_ = true;
       return Encode(result);
-#else
+#else  // __APPLE__
     case Qt::Key_Control:
       ctrl_pressed_ = true;
       return Encode(result);
@@ -353,7 +355,7 @@ KeyBindingFilter::KeyState KeyBindingFilter::AddKey(const QKeyEvent &key_event,
     case Qt::Key_Alt:
       alt_pressed_ = true;
       return Encode(result);
-#endif
+#endif  // __APPLE__
     case Qt::Key_Shift:
       shift_pressed_ = true;
       return Encode(result);
@@ -362,18 +364,16 @@ KeyBindingFilter::KeyState KeyBindingFilter::AddKey(const QKeyEvent &key_event,
   }
 
   // non-printable command, which doesn't require modifier keys
-  for (size_t i = 0; i < arraysize(kQtKeyModifierNonRequiredTable); ++i) {
-    if (kQtKeyModifierNonRequiredTable[i].qt_key == qt_key) {
-      modifier_non_required_key_ =
-          QLatin1String(kQtKeyModifierNonRequiredTable[i].mozc_key_name);
-      return Encode(result);
-    }
+  const auto it = kQtKeyModifierNonRequiredTable->find(qt_key);
+  if (it != kQtKeyModifierNonRequiredTable->end()) {
+    modifier_non_required_key_ = QLatin1String(it->second);
+    return Encode(result);
   }
 
 #ifdef OS_WIN
   // Handle JP109's Muhenkan/Henkan/katakana-hiragana and Zenkaku/Hankaku
   const DWORD virtual_key = key_event.nativeVirtualKey();
-  for (size_t i = 0; i < arraysize(kWinVirtualKeyModifierNonRequiredTable);
+  for (size_t i = 0; i < std::size(kWinVirtualKeyModifierNonRequiredTable);
        ++i) {
     if (kWinVirtualKeyModifierNonRequiredTable[i].virtual_key == virtual_key) {
       modifier_non_required_key_ = QLatin1String(
@@ -405,7 +405,7 @@ KeyBindingFilter::KeyState KeyBindingFilter::AddKey(const QKeyEvent &key_event,
     modifier_non_required_key_ = QLatin1String("Katakana");
     return Encode(result);
   }
-#endif
+#endif  // OS_WIN, OS_LINUX
 
   if (qt_key == Qt::Key_yen) {
     // Japanese Yen mark, treat it as backslash for compatibility
@@ -425,9 +425,9 @@ KeyBindingFilter::KeyState KeyBindingFilter::AddKey(const QKeyEvent &key_event,
     return Encode(result);
   }
 
-  unknown_key_.sprintf("<UNK:0x%x 0x%x 0x%x>", key_event.key(),
-                       key_event.nativeScanCode(),
-                       key_event.nativeVirtualKey());
+  unknown_key_.asprintf("<UNK:0x%x 0x%x 0x%x>", key_event.key(),
+                        key_event.nativeScanCode(),
+                        key_event.nativeVirtualKey());
 
   return Encode(result);
 }
@@ -484,16 +484,16 @@ KeyBindingEditor::KeyBindingEditor(QWidget *parent, QWidget *trigger_parent)
   // the edit is not raised. This might be a bug of setFocusProxy.
   setWindowFlags(Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint |
                  Qt::Tool | Qt::WindowStaysOnTopHint);
-#else
+#else  // OS_LINUX
   setWindowFlags(Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint |
                  Qt::Tool);
-#endif
+#endif  // OS_LINUX
 
   QPushButton *ok_button =
       KeyBindingEditorbuttonBox->button(QDialogButtonBox::Ok);
   CHECK(ok_button != nullptr);
 
-  filter_ = absl::make_unique<KeyBindingFilter>(KeyBindingLineEdit, ok_button);
+  filter_ = std::make_unique<KeyBindingFilter>(KeyBindingLineEdit, ok_button);
   KeyBindingLineEdit->installEventFilter(filter_.get());
 
   // no right click
@@ -503,7 +503,7 @@ KeyBindingEditor::KeyBindingEditor(QWidget *parent, QWidget *trigger_parent)
 
 #ifdef OS_WIN
   ::ImmAssociateContext(reinterpret_cast<HWND>(KeyBindingLineEdit->winId()), 0);
-#endif
+#endif  // OS_WIN
 
   QObject::connect(KeyBindingEditorbuttonBox,
                    SIGNAL(clicked(QAbstractButton *)), this,
