@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,8 +29,8 @@
 
 #include "gui/config_dialog/keybinding_editor_delegate.h"
 
-#include <QtGui/QtGui>
-#include <QtWidgets/QPushButton>
+#include <QPushButton>
+#include <QtGui>
 #include <memory>
 
 #include "base/logging.h"
