@@ -29,15 +29,17 @@
 
 #include "gui/config_dialog/keymap_editor.h"
 
+#include <cstdint>
+
 #if defined(OS_ANDROID) || defined(OS_WASM)
 #error "This platform is not supported."
 #endif  // OS_ANDROID || OS_WASM
 
-#include <QtCore/QFile>
-#include <QtGui/QtGui>
-#include <QtWidgets/QFileDialog>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QMessageBox>
+#include <QFile>
+#include <QFileDialog>
+#include <QMenu>
+#include <QMessageBox>
+#include <QtGui>
 #include <algorithm>  // for unique
 #include <cctype>
 #include <memory>
@@ -57,6 +59,8 @@
 #include "gui/config_dialog/keybinding_editor_delegate.h"
 #include "protocol/commands.pb.h"
 #include "session/internal/keymap.h"
+#include "absl/container/btree_set.h"
+#include "absl/strings/str_split.h"
 // TODO(komatsu): internal files should not be used from external modules.
 
 namespace mozc {
@@ -74,15 +78,15 @@ const char *kKeyMapStatus[] = {
     "Conversion",  "Suggestion",     "Prediction",
 };
 
-const char kInsertCharacterCommand[] = "InsertCharacter";
-const char kDirectMode[] = "DirectInput";
-const char kReportBugCommand[] = "ReportBug";
+constexpr char kInsertCharacterCommand[] = "InsertCharacter";
+constexpr char kDirectMode[] = "DirectInput";
+constexpr char kReportBugCommand[] = "ReportBug";
 // Old command name
-const char kEditInsertCommand[] = "EditInsert";
+constexpr char kEditInsertCommand[] = "EditInsert";
 
 #if defined(__APPLE__)
-const char kIMEOnCommand[] = "IMEOn";
-const char kIMEOffCommand[] = "IMEOff";
+constexpr char kIMEOnCommand[] = "IMEOn";
+constexpr char kIMEOffCommand[] = "IMEOff";
 #endif  // __APPLE__
 
 enum {
@@ -165,7 +169,7 @@ class KeyMapValidator {
     if (fields[2] == kReportBugCommand) {
       return false;
     }
-#endif
+#endif  // MOZC_NO_LOGGING
     return true;
   }
 
@@ -188,8 +192,8 @@ class KeyMapValidator {
   }
 
  private:
-  std::set<uint32> invisible_modifiers_;
-  std::set<uint32> invisible_key_events_;
+  std::set<uint32_t> invisible_modifiers_;
+  std::set<uint32_t> invisible_key_events_;
   std::set<std::string> invisible_commands_;
 };
 
@@ -203,7 +207,7 @@ class KeyMapTableLoader {
     KeyMapValidator *validator = mozc::Singleton<KeyMapValidator>::get();
 
     // get all command names
-    std::set<std::string> command_names;
+    absl::btree_set<std::string> command_names;
     mozc::keymap::KeyMapManager manager;
     manager.GetAvailableCommandNameDirect(&command_names);
     manager.GetAvailableCommandNamePrecomposition(&command_names);
@@ -212,14 +216,15 @@ class KeyMapTableLoader {
     manager.GetAvailableCommandNameZeroQuerySuggestion(&command_names);
     manager.GetAvailableCommandNameSuggestion(&command_names);
     manager.GetAvailableCommandNamePrediction(&command_names);
-    for (std::set<std::string>::const_iterator itr = command_names.begin();
+    for (absl::btree_set<std::string>::const_iterator itr =
+             command_names.begin();
          itr != command_names.end(); ++itr) {
       if (validator->IsVisibleCommand(*itr)) {
         commands.insert(*itr);
       }
     }
 
-    for (size_t i = 0; i < arraysize(kKeyMapStatus); ++i) {
+    for (size_t i = 0; i < std::size(kKeyMapStatus); ++i) {
       status_ << QString::fromUtf8(kKeyMapStatus[i]);
     }
 
@@ -244,7 +249,7 @@ KeyMapEditorDialog::KeyMapEditorDialog(QWidget *parent)
       commands_delegate_(new ComboBoxDelegate),
       keybinding_delegate_(new KeyBindingEditorDelegate) {
   actions_.reset(new QAction *[MENU_SIZE]);
-  import_actions_.reset(new QAction *[arraysize(kKeyMaps)]);
+  import_actions_.reset(new QAction *[std::size(kKeyMaps)]);
 
   actions_[NEW_INDEX] = mutable_edit_menu()->addAction(tr("New entry"));
   actions_[REMOVE_INDEX] =
@@ -329,7 +334,6 @@ bool KeyMapEditorDialog::LoadFromStream(std::istream *is) {
     return false;
   }
 
-  std::vector<std::string> fields;
   int row = 0;
   mutable_table_widget()->setRowCount(0);
   mutable_table_widget()->verticalHeader()->hide();
@@ -342,8 +346,8 @@ bool KeyMapEditorDialog::LoadFromStream(std::istream *is) {
     }
     Util::ChopReturns(&line);
 
-    fields.clear();
-    Util::SplitStringUsing(line, "\t", &fields);
+    std::vector<std::string> fields =
+        absl::StrSplit(line, '\t', absl::SkipEmpty());
     if (fields.size() < 3) {
       VLOG(3) << "field size < 3";
       continue;
@@ -471,7 +475,7 @@ void KeyMapEditorDialog::UpdateMenuStatus() {
 
 void KeyMapEditorDialog::OnEditMenuAction(QAction *action) {
   int import_index = -1;
-  for (size_t i = 0; i < arraysize(kKeyMaps); ++i) {
+  for (size_t i = 0; i < std::size(kKeyMaps); ++i) {
     if (import_actions_[i] == action) {
       import_index = i;
       break;
@@ -496,7 +500,7 @@ void KeyMapEditorDialog::OnEditMenuAction(QAction *action) {
     if (action == actions_[IMPORT_FROM_FILE_INDEX]) {
       Import();
       // otherwise, load from predefined tables
-    } else if (import_index >= 0 && import_index < arraysize(kKeyMaps)) {
+    } else if (import_index >= 0 && import_index < std::size(kKeyMaps)) {
       const char *keymap_file =
           keymap::KeyMapManager::GetKeyMapFileName(kKeyMaps[import_index]);
       std::unique_ptr<std::istream> ifs(
