@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,10 +29,9 @@
 
 #include "gui/config_dialog/roman_table_editor.h"
 
-#include <QtGui/QtGui>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QMessageBox>
-
+#include <QMenu>
+#include <QMessageBox>
+#include <QtGui>
 #include <cctype>
 #include <memory>
 #include <sstream>
@@ -45,6 +44,7 @@
 #include "gui/base/table_util.h"
 #include "gui/base/util.h"
 #include "protocol/commands.pb.h"
+#include "absl/strings/str_split.h"
 
 namespace mozc {
 namespace gui {
@@ -57,7 +57,7 @@ enum {
   RESET_INDEX = 4,
   MENU_SIZE = 5
 };
-const char kRomanTableFile[] = "system://romanji-hiragana.tsv";
+constexpr char kRomanTableFile[] = "system://romanji-hiragana.tsv";
 }  // namespace
 
 RomanTableEditorDialog::RomanTableEditorDialog(QWidget *parent)
@@ -96,14 +96,13 @@ std::string RomanTableEditorDialog::GetDefaultRomanTable() {
       ConfigFileStream::LegacyOpen(kRomanTableFile));
   CHECK(ifs.get() != nullptr);  // should never happen
   std::string line, result;
-  std::vector<std::string> fields;
   while (std::getline(*ifs, line)) {
     if (line.empty()) {
       continue;
     }
     Util::ChopReturns(&line);
-    fields.clear();
-    Util::SplitStringAllowEmpty(line, "\t", &fields);
+    std::vector<std::string> fields =
+        absl::StrSplit(line, '\t', absl::AllowEmpty());
     if (fields.size() < 2) {
       VLOG(3) << "field size < 2";
       continue;
@@ -123,7 +122,6 @@ std::string RomanTableEditorDialog::GetDefaultRomanTable() {
 bool RomanTableEditorDialog::LoadFromStream(std::istream *is) {
   CHECK(is);
   std::string line;
-  std::vector<std::string> fields;
   mutable_table_widget()->setRowCount(0);
   mutable_table_widget()->verticalHeader()->hide();
 
@@ -134,8 +132,8 @@ bool RomanTableEditorDialog::LoadFromStream(std::istream *is) {
     }
     Util::ChopReturns(&line);
 
-    fields.clear();
-    Util::SplitStringAllowEmpty(line, "\t", &fields);
+    std::vector<std::string> fields =
+        absl::StrSplit(line, '\t', absl::AllowEmpty());
     if (fields.size() < 2) {
       VLOG(3) << "field size < 2";
       continue;
