@@ -29,18 +29,20 @@
 
 #include "gui/dictionary_tool/dictionary_tool.h"
 
+#include <cstdint>
+
 #if defined(OS_ANDROID) || defined(OS_WASM)
 #error "This platform is not supported."
 #endif  // OS_ANDROID || OS_WASM
 
-#include <QtCore/QTimer>
-#include <QtGui/QtGui>
-#include <QtWidgets/QFileDialog>
-#include <QtWidgets/QInputDialog>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QMessageBox>
-#include <QtWidgets/QProgressDialog>
-#include <QtWidgets/QShortcut>
+#include <QFileDialog>
+#include <QInputDialog>
+#include <QMenu>
+#include <QMessageBox>
+#include <QProgressDialog>
+#include <QShortcut>
+#include <QTimer>
+#include <QtGui>
 
 #ifdef OS_WIN
 #include <Windows.h>
@@ -69,7 +71,6 @@
 #include "gui/dictionary_tool/find_dialog.h"
 #include "gui/dictionary_tool/import_dialog.h"
 #include "protocol/user_dictionary_storage.pb.h"
-#include "absl/memory/memory.h"
 
 #ifdef OS_WIN
 #include "gui/base/win_util.h"
@@ -84,9 +85,7 @@ using ::mozc::user_dictionary::UserDictionaryCommandStatus;
 using ::mozc::user_dictionary::UserDictionarySession;
 using ::mozc::user_dictionary::UserDictionaryStorage;
 
-inline QString QUtf8(const char str[]) {
-  return QString::fromUtf8(str);
-}
+inline QString QUtf8(const char str[]) { return QString::fromUtf8(str); }
 
 inline QString QUtf8(const std::string &str) {
   return QString::fromUtf8(str.c_str());
@@ -94,7 +93,7 @@ inline QString QUtf8(const std::string &str) {
 
 // set longer timeout because it takes longer time
 // to reload all user dictionary.
-const int kSessionTimeout = 100000;
+constexpr int kSessionTimeout = 100000;
 
 int GetTableHeight(QTableWidget *widget) {
   // Dragon Hack:
@@ -153,7 +152,7 @@ class UTF16TextLineIterator
     QChar ch;
     QString output_line;
     while (!stream_->atEnd()) {
-      *(stream_.get()) >> ch;
+      *stream_ >> ch;
       if (output_line.isEmpty() && ch == QLatin1Char('\n')) {
         // no harm to skip empty line
         continue;
@@ -173,7 +172,7 @@ class UTF16TextLineIterator
 
   void Reset() override {
     file_.seek(0);
-    stream_ = absl::make_unique<QTextStream>();
+    stream_ = std::make_unique<QTextStream>();
     stream_->setDevice(&file_);
     stream_->setCodec("UTF-16");
   }
@@ -236,12 +235,12 @@ class MultiByteTextLineIterator
     // We won't enable it as it increases the binary size.
     if (encoding_type_ == UserDictionaryImporter::SHIFT_JIS) {
       const std::string input = *line;
-      EncodingUtil::SJISToUTF8(input, line);
+      EncodingUtil::SjisToUtf8(input, line);
     }
 
     // strip UTF8 BOM
     if (first_line_ && encoding_type_ == UserDictionaryImporter::UTF8) {
-      mozc::Util::StripUTF8BOM(line);
+      mozc::Util::StripUtf8Bom(line);
     }
 
     mozc::Util::ChopReturns(line);
@@ -276,9 +275,9 @@ UserDictionaryImporter::TextLineIteratorInterface *CreateTextLineIterator(
     // set default encoding
 #ifdef OS_WIN
     encoding_type = UserDictionaryImporter::SHIFT_JIS;
-#else
+#else   // OS_WIN
     encoding_type = UserDictionaryImporter::UTF16;
-#endif
+#endif  // OS_WIN
   }
 
   VLOG(1) << "Setting Encoding to: " << static_cast<int>(encoding_type);
@@ -310,8 +309,6 @@ DictionaryTool::DictionaryTool(QWidget *parent)
       session_(new UserDictionarySession(
           UserDictionaryUtil::GetUserDictionaryFileName())),
       current_dic_id_(0),
-      modified_(false),
-      monitoring_user_edit_(false),
       window_title_(GuiUtil::ProductName()),
       dic_menu_(new QMenu),
       new_action_(nullptr),
@@ -323,9 +320,11 @@ DictionaryTool::DictionaryTool(QWidget *parent)
       export_action_(nullptr),
       import_default_ime_action_(nullptr),
       client_(client::ClientFactory::NewClient()),
-      is_available_(true),
       max_entry_size_(mozc::UserDictionaryStorage::max_entry_size()),
-      pos_list_provider_(new POSListProvider()) {
+      pos_list_provider_(new PosListProvider()),
+      modified_(false),
+      monitoring_user_edit_(false),
+      is_available_(true) {
   setupUi(this);
 
   // Create and set up ImportDialog object.
@@ -353,7 +352,9 @@ DictionaryTool::DictionaryTool(QWidget *parent)
   if (session_->mutable_storage()
           ->ConvertSyncDictionariesToNormalDictionaries()) {
     LOG(INFO) << "Syncable dictionaries are converted to normal dictionaries";
-    session_->mutable_storage()->Save();
+    if (absl::Status s = session_->mutable_storage()->Save(); !s.ok()) {
+      LOG(ERROR) << "Failed to save the storage: " << s;
+    }
   }
 #endif  // !ENABLE_CLOUD_SYNC
 
@@ -362,7 +363,7 @@ DictionaryTool::DictionaryTool(QWidget *parent)
   // For some reason setCentralWidget crashes the dictionary_tool on Linux
   // TODO(taku): investigate the cause of the crashes
   setCentralWidget(splitter_);
-#endif
+#endif  // OS_LINUX
 
   setContextMenuPolicy(Qt::NoContextMenu);
 
@@ -387,7 +388,7 @@ DictionaryTool::DictionaryTool(QWidget *parent)
 
   dic_content_->setFrameStyle(QFrame::NoFrame);
   dic_content_->setShowGrid(false);
-#endif
+#endif  // __APPLE__
 
   dic_content_->setWordWrap(false);
   dic_content_->verticalHeader()->hide();
@@ -404,7 +405,7 @@ DictionaryTool::DictionaryTool(QWidget *parent)
 
   // Get a list of POS and set a custom delagate that holds the list.
   std::vector<std::string> tmp_pos_vec;
-  pos_list_provider_->GetPOSList(&tmp_pos_vec);
+  pos_list_provider_->GetPosList(&tmp_pos_vec);
   QStringList pos_list;
   for (size_t i = 0; i < tmp_pos_vec.size(); ++i) {
     pos_list.append(QUtf8(tmp_pos_vec[i]));
@@ -437,11 +438,11 @@ DictionaryTool::DictionaryTool(QWidget *parent)
       new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Backspace), dic_content_);
   connect(shortcut1, SIGNAL(activated()), this, SLOT(DeleteWord()));
   connect(shortcut2, SIGNAL(activated()), this, SLOT(DeleteWord()));
-#else
+#else   // __APPLE__
   QShortcut *shortcut =
       new QShortcut(QKeySequence(QKeySequence::Delete), dic_content_);
   connect(shortcut, SIGNAL(activated()), this, SLOT(DeleteWord()));
-#endif
+#endif  // __APPLE__
 
   dic_content_->setContextMenuPolicy(Qt::CustomContextMenu);
   connect(dic_content_, SIGNAL(customContextMenuRequested(const QPoint &)),
@@ -524,14 +525,16 @@ DictionaryTool::DictionaryTool(QWidget *parent)
 
   // If this is the first time for the user dictionary is used, create
   // a default dictionary.
-  if (!session_->mutable_storage()->Exists()) {
+  if (absl::Status s = session_->mutable_storage()->Exists(); !s.ok()) {
+    LOG_IF(ERROR, !absl::IsNotFound(s))
+        << "Cannot check if the storage file exists: " << s;
     CreateDictionaryHelper(tr("User Dictionary 1"));
   }
 
   // for Mac-like style
 #ifdef __APPLE__
   setUnifiedTitleAndToolBarOnMac(true);
-#endif
+#endif  // __APPLE__
 
   StartMonitoringUserEdit();
   UpdateUIStatus();
@@ -581,7 +584,7 @@ bool DictionaryTool::eventFilter(QObject *obj, QEvent *event) {
   // This is an workaround for http://b/2190275.
   // TODO(taku): Find out a better way.
   if (event->type() == QEvent::ApplicationDeactivate) {
-    const int kDelayOnDeactivateTime = 200;
+    constexpr int kDelayOnDeactivateTime = 200;
     QTimer::singleShot(kDelayOnDeactivateTime, this, SLOT(OnDeactivate()));
   }
   return QWidget::eventFilter(obj, event);
@@ -807,7 +810,8 @@ void DictionaryTool::ReportImportError(UserDictionaryImporter::ErrorType error,
                                   "unsupported file format.\n\n"
                                   "Please check the file format. "
                                   "ATOK11 or older format is not supported by "
-                                  "%1.").arg(GuiUtil::ProductName()));
+                                  "%1.")
+                                   .arg(GuiUtil::ProductName()));
       break;
     case UserDictionaryImporter::IMPORT_TOO_MANY_WORDS:
       QMessageBox::information(
@@ -838,7 +842,7 @@ void DictionaryTool::ReportImportError(UserDictionaryImporter::ErrorType error,
 }
 
 void DictionaryTool::ImportHelper(
-    uint64 dic_id, const std::string &dic_name, const std::string &file_name,
+    uint64_t dic_id, const std::string &dic_name, const std::string &file_name,
     UserDictionaryImporter::IMEType ime_type,
     UserDictionaryImporter::EncodingType encoding_type) {
   if (!IsReadableToImport(file_name)) {
@@ -940,7 +944,7 @@ void DictionaryTool::ImportFromDefaultIME() {
   DCHECK(dic);
 
   const int old_size = dic->entries_size();
-  const string dic_name = dic_info.item->text().toStdString();
+  const std::string dic_name = dic_info.item->text().toStdString();
 
   UserDictionaryImporter::ErrorType error =
       UserDictionaryImporter::IMPORT_NOT_SUPPORTED;
@@ -958,7 +962,7 @@ void DictionaryTool::ImportFromDefaultIME() {
   UpdateUIStatus();
 
   ReportImportError(error, dic_name, added_entries_size);
-#endif
+#endif  // OS_WIN
 }
 
 void DictionaryTool::ExportDictionary() {
@@ -1101,7 +1105,7 @@ void DictionaryTool::DeleteWord() {
   modified_ = true;
 }
 
-void DictionaryTool::EditPOS(const std::string &pos) {
+void DictionaryTool::EditPos(const std::string &pos) {
   const QList<QTableWidgetItem *> items = dic_content_->selectedItems();
   if (items.empty()) {
     return;
@@ -1308,7 +1312,7 @@ void DictionaryTool::OnContextMenuRequestedForContent(const QPoint &pos) {
   menu->addSeparator();
   QMenu *change_category_to = menu->addMenu(tr("Change category to"));
   std::vector<std::string> pos_list;
-  pos_list_provider_->GetPOSList(&pos_list);
+  pos_list_provider_->GetPosList(&pos_list);
   std::vector<QAction *> change_pos_actions(pos_list.size());
   for (size_t i = 0; i < pos_list.size(); ++i) {
     change_pos_actions[i] =
@@ -1328,7 +1332,7 @@ void DictionaryTool::OnContextMenuRequestedForContent(const QPoint &pos) {
     bool found = false;
     for (int i = 0; i < change_pos_actions.size(); ++i) {
       if (selected_action == change_pos_actions[i]) {
-        EditPOS(pos_list[i]);
+        EditPos(pos_list[i]);
         found = true;
         break;
       }
@@ -1413,7 +1417,7 @@ void DictionaryTool::SyncToStorage() {
 }
 
 void DictionaryTool::CreateDictionaryHelper(const QString &dic_name) {
-  uint64 new_dic_id = 0;
+  uint64_t new_dic_id = 0;
   if (!session_->mutable_storage()->CreateDictionary(dic_name.toStdString(),
                                                      &new_dic_id)) {
     LOG(ERROR) << "Failed to create a new dictionary.";
@@ -1517,10 +1521,10 @@ void DictionaryTool::StopMonitoringUserEdit() {
 }
 
 void DictionaryTool::SaveAndReloadServer() {
-  if (!session_->mutable_storage()->Save() &&
-      session_->mutable_storage()->GetLastError() ==
-          mozc::UserDictionaryStorage::SYNC_FAILURE) {
-    LOG(ERROR) << "Cannot save dictionary";
+  if (absl::Status s = session_->mutable_storage()->Save();
+      !s.ok() && session_->mutable_storage()->GetLastError() ==
+                     mozc::UserDictionaryStorage::SYNC_FAILURE) {
+    LOG(ERROR) << "Cannot save dictionary: " << s;
     return;
   }
 
@@ -1559,9 +1563,9 @@ bool DictionaryTool::IsWritableToExport(const std::string &file_name) {
     // that export fails on Windows.
 #ifdef OS_WIN
     return dir_info.isExecutable();
-#else
+#else   // OS_WIN
     return dir_info.isExecutable() && dir_info.isWritable();
-#endif
+#endif  // OS_WIN
   }
 }
 
@@ -1575,7 +1579,7 @@ void DictionaryTool::UpdateUIStatus() {
   import_append_action_->setEnabled(dic_list_->count() > 0);
 #ifdef OS_WIN
   import_default_ime_action_->setEnabled(dic_list_->count() > 0);
-#endif
+#endif  // OS_WIN
 
   const bool is_enable_new_word =
       dic_list_->count() > 0 && dic_content_->rowCount() < max_entry_size_;
