@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,18 +27,21 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <QtCore/QTextCodec>
-#include <QtCore/QTranslator>
-#include <QtGui/QGuiApplication>
-
+#include <QGuiApplication>
+#include <QTextCodec>
+#include <QTranslator>
 #include <string>
+
 #include "base/logging.h"
 #include "base/system_util.h"
-#include "base/win_util.h"
-#include "gui/base/locale_util.h"
 #include "gui/base/singleton_window_helper.h"
+#include "gui/base/util.h"
 #include "gui/dictionary_tool/dictionary_tool.h"
 
+#ifdef OS_WIN
+#include "base/win_util.h"
+#endif  // OS_WIN
+
 int RunDictionaryTool(int argc, char *argv[]) {
 #ifdef OS_WIN
   // For MSIMEImportIterator.
@@ -46,9 +49,9 @@ int RunDictionaryTool(int argc, char *argv[]) {
 #endif  // OS_WIN
 
   Q_INIT_RESOURCE(qrc_dictionary_tool);
-  QApplication app(argc, argv);
+  auto app = mozc::gui::GuiUtil::InitQt(argc, argv);
 
-  string name = "dictionary_tool.";
+  std::string name = "dictionary_tool.";
   name += mozc::SystemUtil::GetDesktopNameAsString();
   mozc::gui::SingletonWindowHelper window_helper(name);
   if (window_helper.FindPreviousWindow()) {
@@ -57,7 +60,7 @@ int RunDictionaryTool(int argc, char *argv[]) {
     return -1;
   }
 
-  mozc::gui::LocaleUtil::InstallTranslationMessageAndFont("dictionary_tool");
+  mozc::gui::GuiUtil::InstallTranslator("dictionary_tool");
   mozc::gui::DictionaryTool window;
 
   if (!window.IsAvailable()) {
@@ -68,5 +71,5 @@ int RunDictionaryTool(int argc, char *argv[]) {
   window.show();
   window.raise();
 
-  return app.exec();
+  return app->exec();
 }
