@@ -31,8 +31,9 @@
 #include <windows.h>
 #endif  // OS_WIN
 
-#include <QtGui/QGuiApplication>
-#include <QtGui/QtGui>
+#include <QGuiApplication>
+#include <QtGui>
+#include <string>
 
 #include "base/logging.h"
 #include "base/process_mutex.h"
@@ -61,7 +62,7 @@ int RunSetDefaultDialog(int argc, char *argv[]) {
 #ifdef OS_WIN
   // For ImeUtil::SetDefault.
   mozc::ScopedCOMInitializer com_initializer;
-#endif
+#endif  // OS_WIN
 
   auto app = mozc::gui::GuiUtil::InitQt(argc, argv);
 
