@@ -31,9 +31,9 @@
 
 #ifdef OS_WIN
 #include <windows.h>
-#endif
+#endif  // OS_WIN
 
-#include <QtGui/QtGui>
+#include <QtGui>
 
 #ifdef __APPLE__
 #include <cstdlib>
@@ -62,7 +62,7 @@
 #endif  // OS_WIN
 
 ABSL_FLAG(std::string, mode, "about_dialog", "mozc_tool mode");
-ABSL_DECLARE_FLAG(string, error_type);
+ABSL_DECLARE_FLAG(std::string, error_type);
 
 // Run* are defiend in each qt module
 int RunAboutDialog(int argc, char *argv[]);
@@ -114,7 +114,7 @@ int RunMozcTool(int argc, char *argv[]) {
 #ifdef __APPLE__
   // In Mac, we shares the same binary but changes the application
   // name.
-  string binary_name = mozc::FileUtil::Basename(argv[0]);
+  std::string binary_name = mozc::FileUtil::Basename(argv[0]);
   if (binary_name == "AboutDialog") {
     absl::SetFlag(&FLAGS_mode, "about_dialog");
   } else if (binary_name == "ConfigDialog") {
@@ -131,7 +131,7 @@ int RunMozcTool(int argc, char *argv[]) {
     // So we set kProductPrefix to the binary name.
     absl::SetFlag(&FLAGS_mode, "prelauncher");
   }
-#endif
+#endif  // __APPLE__
 
   if (absl::GetFlag(FLAGS_mode) != "administration_dialog" &&
       !mozc::RunLevel::IsValidClientRunLevel()) {
