@@ -29,6 +29,8 @@
 
 #include "gui/word_register_dialog/word_register_dialog.h"
 
+#include <cstdint>
+
 #if defined(OS_ANDROID) || defined(OS_WASM)
 #error "This platform is not supported."
 #endif  // OS_ANDROID || OS_WASM
@@ -40,8 +42,8 @@
 // clang-format on
 #endif  // OS_WIN
 
-#include <QtGui/QtGui>
-#include <QtWidgets/QMessageBox>
+#include <QMessageBox>
+#include <QtGui>
 #include <cstdlib>
 #ifdef OS_WIN
 #include <memory>  // for std::unique_ptr
@@ -69,14 +71,14 @@ using mozc::user_dictionary::UserDictionarySession;
 using mozc::user_dictionary::UserDictionaryStorage;
 
 namespace {
-const int kSessionTimeout = 100000;
-const int kMaxEditLength = 100;
-const int kMaxReverseConversionLength = 30;
+constexpr int kSessionTimeout = 100000;
+constexpr int kMaxEditLength = 100;
+constexpr int kMaxReverseConversionLength = 30;
 
 QString GetEnv(const char *envname) {
 #if defined(OS_WIN)
   std::wstring wenvname;
-  mozc::Util::UTF8ToWide(envname, &wenvname);
+  mozc::Util::Utf8ToWide(envname, &wenvname);
   const DWORD buffer_size =
       ::GetEnvironmentVariable(wenvname.c_str(), nullptr, 0);
   if (buffer_size == 0) {
@@ -111,7 +113,7 @@ WordRegisterDialog::WordRegisterDialog()
           UserDictionaryUtil::GetUserDictionaryFileName())),
       client_(client::ClientFactory::NewClient()),
       window_title_(GuiUtil::ProductName()),
-      pos_list_provider_(new POSListProvider()) {
+      pos_list_provider_(new PosListProvider()) {
   setupUi(this);
   setWindowFlags(Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint |
                  Qt::WindowStaysOnTopHint);
@@ -146,13 +148,15 @@ WordRegisterDialog::WordRegisterDialog()
   if (session_->mutable_storage()
           ->ConvertSyncDictionariesToNormalDictionaries()) {
     LOG(INFO) << "Syncable dictionaries are converted to normal dictionaries";
-    session_->mutable_storage()->Save();
+    if (absl::Status s = session_->mutable_storage()->Save(); !s.ok()) {
+      LOG(ERROR) << "Failed to save the storage: " << s;
+    }
   }
 #endif  // !ENABLE_CLOUD_SYNC
 
   // Initialize ComboBox
   std::vector<std::string> pos_set;
-  pos_list_provider_->GetPOSList(&pos_set);
+  pos_list_provider_->GetPosList(&pos_set);
   CHECK(!pos_set.empty());
 
   for (const std::string &pos : pos_set) {
@@ -161,10 +165,10 @@ WordRegisterDialog::WordRegisterDialog()
   }
 
   // Create new dictionary if empty
-  if (!session_->mutable_storage()->Exists() ||
+  if (!session_->mutable_storage()->Exists().ok() ||
       session_->storage().dictionaries_size() == 0) {
     const QString name = tr("User Dictionary 1");
-    uint64 dic_id = 0;
+    uint64_t dic_id = 0;
     if (!session_->mutable_storage()->CreateDictionary(name.toStdString(),
                                                        &dic_id)) {
       LOG(ERROR) << "Failed to create a new dictionary.";
@@ -315,10 +319,10 @@ WordRegisterDialog::ErrorCode WordRegisterDialog::SaveEntry() {
   entry->set_value(value);
   entry->set_pos(pos);
 
-  if (!session_->mutable_storage()->Save() &&
-      session_->mutable_storage()->GetLastError() ==
-          mozc::UserDictionaryStorage::SYNC_FAILURE) {
-    LOG(ERROR) << "Cannot save dictionary";
+  if (absl::Status s = session_->mutable_storage()->Save();
+      !s.ok() && session_->mutable_storage()->GetLastError() ==
+                     mozc::UserDictionaryStorage::SYNC_FAILURE) {
+    LOG(ERROR) << "Cannot save dictionary: " << s;
     return SAVE_FAILURE;
   }
 
@@ -445,7 +449,7 @@ void WordRegisterDialog::CopyCurrentSelectionToClipboard() {
   }
 
   DWORD message_response = 0;
-  const DWORD kSendMessageTimeout = 10 * 1000;  // 10sec.
+  constexpr DWORD kSendMessageTimeout = 10 * 1000;  // 10sec.
   const LRESULT send_result =
       ::SendMessageTimeout(focus_window, WM_COPY, 0, 0, SMTO_NORMAL,
                            kSendMessageTimeout, &message_response);
