@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,9 +30,9 @@
 #ifndef MOZC_GUI_WORD_REGISTER_DIALOG_WORD_REGISTER_DIALOG_H_
 #define MOZC_GUI_WORD_REGISTER_DIALOG_WORD_REGISTER_DIALOG_H_
 
-#include <QtCore/QString>
-#include <QtGui/QtGui>
-#include <QtWidgets/QDialog>
+#include <QDialog>
+#include <QString>
+#include <QtGui>
 #include <memory>
 
 #include "base/port.h"
@@ -40,7 +40,7 @@
 
 namespace mozc {
 
-class POSListProviderInterface;
+class PosListProviderInterface;
 
 namespace client {
 class ClientInterface;
@@ -114,7 +114,7 @@ class WordRegisterDialog : public QDialog, private Ui::WordRegisterDialog {
   std::unique_ptr<mozc::user_dictionary::UserDictionarySession> session_;
   std::unique_ptr<client::ClientInterface> client_;
   QString window_title_;
-  std::unique_ptr<const POSListProviderInterface> pos_list_provider_;
+  std::unique_ptr<const PosListProviderInterface> pos_list_provider_;
 };
 
 }  // namespace gui
