@@ -27,9 +27,10 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <QtGui/QGuiApplication>
-#include <QtGui/QtGui>
-#include <QtWidgets/QDialog>
+#include <QDialog>
+#include <QGuiApplication>
+#include <QtGui>
+#include <string>
 
 #include "base/system_util.h"
 #include "gui/base/singleton_window_helper.h"
