@@ -29,22 +29,24 @@
 
 #include "ipc/ipc.h"
 
+#include <cstdint>
+
 #ifdef OS_WIN
 #include <windows.h>
-#else
+#else  // OS_WIN
 #include <errno.h>
 #include <signal.h>
 #include <sys/types.h>
-#endif
+#endif  // OS_WIN
 
 #include <cstdlib>
+#include <memory>
 
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/singleton.h"
 #include "base/thread.h"
 #include "ipc/ipc_path_manager.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 
@@ -70,7 +72,7 @@ class IPCServerThread : public Thread {
 
 void IPCServer::LoopAndReturn() {
   if (server_thread_ == nullptr) {
-    server_thread_ = absl::make_unique<IPCServerThread>(this);
+    server_thread_ = std::make_unique<IPCServerThread>(this);
     server_thread_->SetJoinable(true);
     server_thread_->Start("IPCServer");
   } else {
@@ -105,7 +107,7 @@ IPCClientFactory *IPCClientFactory::GetIPCClientFactory() {
   return Singleton<IPCClientFactory>::get();
 }
 
-uint32 IPCClient::GetServerProtocolVersion() const {
+uint32_t IPCClient::GetServerProtocolVersion() const {
   DCHECK(ipc_path_manager_);
   return ipc_path_manager_->GetServerProtocolVersion();
 }
@@ -115,7 +117,7 @@ const std::string &IPCClient::GetServerProductVersion() const {
   return ipc_path_manager_->GetServerProductVersion();
 }
 
-uint32 IPCClient::GetServerProcessId() const {
+uint32_t IPCClient::GetServerProcessId() const {
   DCHECK(ipc_path_manager_);
   return ipc_path_manager_->GetServerProcessId();
 }
@@ -129,7 +131,7 @@ bool IPCClient::TerminateServer(const std::string &name) {
     return true;
   }
 
-  const uint32 pid = client.GetServerProcessId();
+  const uint32_t pid = client.GetServerProcessId();
   if (pid == 0) {
     LOG(ERROR) << "pid is not a valid value: " << pid;
     return false;
@@ -154,13 +156,13 @@ bool IPCClient::TerminateServer(const std::string &name) {
   ::CloseHandle(handle);
 
   return true;
-#else
+#else   // OS_WIN
   if (-1 == ::kill(static_cast<pid_t>(pid), 9)) {
     LOG(ERROR) << "kill failed: " << errno;
     return false;
   }
 
   return true;
-#endif
+#endif  // OS_WIN
 }
 }  // namespace mozc
