@@ -29,7 +29,8 @@
 
 #include "ipc/ipc_path_manager.h"
 
-#include "absl/memory/memory.h"
+#include <cstdint>
+
 #include "absl/strings/str_format.h"
 
 #if defined(OS_ANDROID) || defined(OS_WASM)
@@ -43,7 +44,7 @@
 #include <windows.h>
 #include <psapi.h>  // GetModuleFileNameExW
 // clang-format on
-#else
+#else  // OS_WIN
 // For stat system call
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -55,9 +56,7 @@
 
 #include <cstdlib>
 #include <map>
-#ifdef OS_WIN
-#include <memory>  // for std::unique_ptr
-#endif
+#include <memory>
 
 #include "base/const.h"
 #include "base/file_stream.h"
@@ -69,7 +68,6 @@
 #if defined(__APPLE__) || defined(OS_IOS)
 #include "base/mac_util.h"
 #endif  // __APPLE__ || OS_IOS
-#include "base/mutex.h"
 #include "base/port.h"
 #include "base/process_mutex.h"
 #include "base/scoped_handle.h"
@@ -82,21 +80,22 @@
 #endif  // OS_WIN
 #include "ipc/ipc.h"
 #include "ipc/ipc.pb.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 namespace {
 
 // size of key
-const size_t kKeySize = 32;
+constexpr size_t kKeySize = 32;
 
 // Do not use ConfigFileStream, since client won't link
 // to the embedded resource files
 std::string GetIPCKeyFileName(const std::string &name) {
 #ifdef OS_WIN
-  string basename;
-#else
+  std::string basename;
+#else   // OS_WIN
   std::string basename = ".";  // hidden file
-#endif
+#endif  // OS_WIN
   basename += name + ".ipc";
   return FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(), basename);
 }
@@ -125,15 +124,15 @@ std::string CreateIPCKey() {
   char value[kKeySize + 1] = {};
 
 #ifdef OS_WIN
-  const string sid = SystemUtil::GetUserSidAsString();
-  const string sha1 = internal::UnverifiedSHA1::MakeDigest(sid);
+  const std::string sid = SystemUtil::GetUserSidAsString();
+  const std::string sha1 = internal::UnverifiedSHA1::MakeDigest(sid);
   for (int i = 0; i < sizeof(buf) && i < sha1.size(); ++i) {
     buf[i] = sha1.at(i);
   }
-#else
+#else   // OS_WIN
   // get 128 bit key: Note that collision will happen.
   Util::GetRandomSequence(buf, sizeof(buf));
-#endif
+#endif  // OS_WIN
 
   // escape
   for (size_t i = 0; i < sizeof(buf); ++i) {
@@ -150,7 +149,7 @@ std::string CreateIPCKey() {
 class IPCPathManagerMap {
  public:
   IPCPathManager *GetIPCPathManager(const std::string &name) {
-    scoped_lock l(&mutex_);
+    absl::MutexLock l(&mutex_);
     std::map<std::string, IPCPathManager *>::const_iterator it =
         manager_map_.find(name);
     if (it != manager_map_.end()) {
@@ -164,7 +163,7 @@ class IPCPathManagerMap {
   IPCPathManagerMap() {}
 
   ~IPCPathManagerMap() {
-    scoped_lock l(&mutex_);
+    absl::MutexLock l(&mutex_);
     for (std::map<std::string, IPCPathManager *>::iterator it =
              manager_map_.begin();
          it != manager_map_.end(); ++it) {
@@ -175,14 +174,13 @@ class IPCPathManagerMap {
 
  private:
   std::map<std::string, IPCPathManager *> manager_map_;
-  Mutex mutex_;
+  absl::Mutex mutex_;
 };
 
 }  // namespace
 
 IPCPathManager::IPCPathManager(const std::string &name)
-    : mutex_(new Mutex),
-      ipc_path_info_(new ipc::IPCPathInfo),
+    : ipc_path_info_(new ipc::IPCPathInfo),
       name_(name),
       server_pid_(0),
       last_modified_(-1) {}
@@ -196,7 +194,11 @@ IPCPathManager *IPCPathManager::GetIPCPathManager(const std::string &name) {
 }
 
 bool IPCPathManager::CreateNewPathName() {
-  scoped_lock l(mutex_.get());
+  absl::MutexLock l(&mutex_);
+  return CreateNewPathNameUnlocked();
+}
+
+bool IPCPathManager::CreateNewPathNameUnlocked() {
   if (ipc_path_info_->key().empty()) {
     ipc_path_info_->set_key(CreateIPCKey());
   }
@@ -204,17 +206,15 @@ bool IPCPathManager::CreateNewPathName() {
 }
 
 bool IPCPathManager::SavePathName() {
-  scoped_lock l(mutex_.get());
+  absl::MutexLock l(&mutex_);
   if (path_mutex_ != nullptr) {
     return true;
   }
 
-  path_mutex_ = absl::make_unique<ProcessMutex>("ipc");
-
+  path_mutex_ = std::make_unique<ProcessMutex>("ipc");
   path_mutex_->set_lock_filename(GetIPCKeyFileName(name_));
 
-  // a little tricky as CreateNewPathName() tries mutex lock
-  CreateNewPathName();
+  CreateNewPathNameUnlocked();
 
   // set the server version
   ipc_path_info_->set_protocol_version(IPC_PROTOCOL_VERSION);
@@ -223,10 +223,10 @@ bool IPCPathManager::SavePathName() {
 #ifdef OS_WIN
   ipc_path_info_->set_process_id(static_cast<uint32>(::GetCurrentProcessId()));
   ipc_path_info_->set_thread_id(static_cast<uint32>(::GetCurrentThreadId()));
-#else
-  ipc_path_info_->set_process_id(static_cast<uint32>(getpid()));
+#else   // OS_WIN
+  ipc_path_info_->set_process_id(static_cast<uint32_t>(getpid()));
   ipc_path_info_->set_thread_id(0);
-#endif
+#endif  // OS_WIN
 
   std::string buf;
   if (!ipc_path_info_->SerializeToString(&buf)) {
@@ -269,10 +269,10 @@ bool IPCPathManager::LoadPathName() {
   ipc_path_info_->set_protocol_version(IPC_PROTOCOL_VERSION);
   ipc_path_info_->set_product_version(Version::GetMozcVersion());
   return true;
-#else
+#else   // defined(OS_WIN)
   LOG(ERROR) << "LoadPathName failed";
   return false;
-#endif
+#endif  // defined(OS_WIN)
 }
 
 bool IPCPathManager::GetPathName(std::string *ipc_name) const {
@@ -292,14 +292,14 @@ bool IPCPathManager::GetPathName(std::string *ipc_name) const {
   ipc_name->assign(MacUtil::GetLabelForSuffix(""));
 #else   // not OS_WIN nor __APPLE__
   // GetUserIPCName("<name>") => "/tmp/.mozc.<key>.<name>"
-  const char kIPCPrefix[] = "/tmp/.mozc.";
+  constexpr char kIPCPrefix[] = "/tmp/.mozc.";
   *ipc_name = kIPCPrefix;
 #endif  // OS_WIN
 
 #ifdef OS_LINUX
   // On Linux, use abstract namespace which is independent of the file system.
   (*ipc_name)[0] = '\0';
-#endif
+#endif  // OS_LINUX
 
   ipc_name->append(ipc_path_info_->key());
   ipc_name->append(".");
@@ -308,7 +308,7 @@ bool IPCPathManager::GetPathName(std::string *ipc_name) const {
   return true;
 }
 
-uint32 IPCPathManager::GetServerProtocolVersion() const {
+uint32_t IPCPathManager::GetServerProtocolVersion() const {
   return ipc_path_info_->protocol_version();
 }
 
@@ -316,17 +316,18 @@ const std::string &IPCPathManager::GetServerProductVersion() const {
   return ipc_path_info_->product_version();
 }
 
-uint32 IPCPathManager::GetServerProcessId() const {
+uint32_t IPCPathManager::GetServerProcessId() const {
   return ipc_path_info_->process_id();
 }
 
 void IPCPathManager::Clear() {
-  scoped_lock l(mutex_.get());
+  absl::MutexLock l(&mutex_);
   ipc_path_info_->Clear();
 }
 
-bool IPCPathManager::IsValidServer(uint32 pid, const std::string &server_path) {
-  scoped_lock l(mutex_.get());
+bool IPCPathManager::IsValidServer(uint32_t pid,
+                                   const std::string &server_path) {
+  absl::MutexLock l(&mutex_);
   if (pid == 0) {
     // For backward compatibility.
     return true;
@@ -336,7 +337,7 @@ bool IPCPathManager::IsValidServer(uint32 pid, const std::string &server_path) {
     return true;
   }
 
-  if (pid == static_cast<uint32>(-1)) {
+  if (pid == static_cast<uint32_t>(-1)) {
     VLOG(1) << "pid is -1. so assume that it is an invalid program";
     return false;
   }
@@ -352,13 +353,13 @@ bool IPCPathManager::IsValidServer(uint32 pid, const std::string &server_path) {
 #ifdef OS_WIN
   {
     std::wstring expected_server_ntpath;
-    const std::map<string, std::wstring>::const_iterator it =
+    const std::map<std::string, std::wstring>::const_iterator it =
         expected_server_ntpath_cache_.find(server_path);
     if (it != expected_server_ntpath_cache_.end()) {
       expected_server_ntpath = it->second;
     } else {
       std::wstring wide_server_path;
-      Util::UTF8ToWide(server_path, &wide_server_path);
+      Util::Utf8ToWide(server_path, &wide_server_path);
       if (WinUtil::GetNtPath(wide_server_path, &expected_server_ntpath)) {
         // Caches the relationship from |server_path| to
         // |expected_server_ntpath| in case |server_path| is renamed later.
@@ -390,13 +391,13 @@ bool IPCPathManager::IsValidServer(uint32 pid, const std::string &server_path) {
 #ifdef __APPLE__
   int name[] = {CTL_KERN, KERN_PROCARGS, static_cast<int>(pid)};
   size_t data_len = 0;
-  if (sysctl(name, arraysize(name), nullptr, &data_len, nullptr, 0) < 0) {
+  if (sysctl(name, std::size(name), nullptr, &data_len, nullptr, 0) < 0) {
     LOG(ERROR) << "sysctl KERN_PROCARGS failed";
     return false;
   }
 
   server_path_.resize(data_len);
-  if (sysctl(name, arraysize(name), &server_path_[0], &data_len, nullptr, 0) <
+  if (sysctl(name, std::size(name), &server_path_[0], &data_len, nullptr, 0) <
       0) {
     LOG(ERROR) << "sysctl KERN_PROCARGS failed";
     return false;
@@ -444,8 +445,8 @@ bool IPCPathManager::ShouldReload() const {
   // In windows, no reloading mechanism is necessary because IPC files
   // are automatically removed.
   return false;
-#else
-  scoped_lock l(mutex_.get());
+#else   // OS_WIN
+  absl::MutexLock l(&mutex_);
 
   time_t last_modified = GetIPCFileTimeStamp();
   if (last_modified == last_modified_) {
@@ -461,7 +462,7 @@ time_t IPCPathManager::GetIPCFileTimeStamp() const {
   // In windows, we don't need to get the exact file timestamp, so
   // just returns -1 at this time.
   return static_cast<time_t>(-1);
-#else
+#else   // OS_WIN
   const std::string filename = GetIPCKeyFileName(name_);
   struct stat filestat;
   if (::stat(filename.c_str(), &filestat) == -1) {
@@ -473,7 +474,7 @@ time_t IPCPathManager::GetIPCFileTimeStamp() const {
 }
 
 bool IPCPathManager::LoadPathNameInternal() {
-  scoped_lock l(mutex_.get());
+  absl::MutexLock l(&mutex_);
 
   // try the new file name first.
   const std::string filename = GetIPCKeyFileName(name_);
@@ -482,7 +483,7 @@ bool IPCPathManager::LoadPathNameInternal() {
   // we want to pass FILE_SHRED_DELETE flag for CreateFile.
 #ifdef OS_WIN
   std::wstring wfilename;
-  Util::UTF8ToWide(filename, &wfilename);
+  Util::Utf8ToWide(filename, &wfilename);
 
   {
     ScopedHandle handle(
@@ -503,7 +504,7 @@ bool IPCPathManager::LoadPathNameInternal() {
       return false;
     }
 
-    const DWORD kMaxFileSize = 2096;
+    constexpr DWORD kMaxFileSize = 2096;
     if (size == 0 || size >= kMaxFileSize) {
       LOG(ERROR) << "Invalid file size: " << kMaxFileSize;
       return false;
@@ -528,7 +529,7 @@ bool IPCPathManager::LoadPathNameInternal() {
     }
   }
 
-#else
+#else   // OS_WIN
 
   InputFileStream is(filename.c_str(), std::ios::binary | std::ios::in);
   if (!is) {
@@ -540,7 +541,7 @@ bool IPCPathManager::LoadPathNameInternal() {
     LOG(ERROR) << "ParseFromStream failed";
     return false;
   }
-#endif
+#endif  // OS_WIN
 
   if (!IsValidKey(ipc_path_info_->key())) {
     LOG(ERROR) << "IPCServer::key is invalid";
