@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,14 +29,13 @@
 
 #include "ipc/ipc_path_manager.h"
 
-#if defined(OS_ANDROID) || defined(OS_NACL)
+#if defined(OS_ANDROID) || defined(OS_WASM)
 #error "This platform is not supported."
-#endif  // OS_ANDROID || OS_NACL
+#endif  // OS_ANDROID || OS_WASM
 
 #include <string>
 #include <vector>
 
-#include "base/file_stream.h"
 #include "base/file_util.h"
 #include "base/port.h"
 #include "base/process_mutex.h"
@@ -46,8 +45,10 @@
 #include "base/version.h"
 #include "ipc/ipc.h"
 #include "ipc/ipc.pb.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/flags/flag.h"
 
 namespace mozc {
 namespace {
@@ -72,7 +73,7 @@ class CreateThread : public Thread {
 
 class BatchGetPathNameThread : public Thread {
  public:
-  virtual void Run() {
+  void Run() override {
     for (int i = 0; i < 100; ++i) {
       IPCPathManager *manager = IPCPathManager::GetIPCPathManager("test2");
       std::string path;
@@ -85,8 +86,8 @@ class BatchGetPathNameThread : public Thread {
 
 class IPCPathManagerTest : public ::testing::Test {
  protected:
-  virtual void SetUp() {
-    SystemUtil::SetUserProfileDirectory(FLAGS_test_tmpdir);
+  void SetUp() override {
+    SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
   }
 };
 
@@ -107,7 +108,7 @@ TEST_F(IPCPathManagerTest, IPCPathManagerTest) {
   // On Linux, |path| should be abstract (see man unix(7) for details.)
   ASSERT_FALSE(path.empty());
   EXPECT_EQ('\0', path[0]);
-#endif
+#endif  // OS_LINUX
 }
 
 // Test the thread-safeness of GetPathName() and
@@ -143,10 +144,7 @@ TEST_F(IPCPathManagerTest, ReloadTest) {
   Util::Sleep(1000);  // msec
   std::string filename = FileUtil::JoinPath(
       SystemUtil::GetUserProfileDirectory(), ".reload_test.ipc");
-  OutputFileStream outf(filename.c_str());
-  outf << "foobar";
-  outf.close();
-
+  ASSERT_OK(FileUtil::SetContents(filename, "foobar"));
   EXPECT_TRUE(manager->ShouldReload());
 #endif  // OS_WIN
 }
