@@ -30,6 +30,7 @@
 #include "ipc/named_event.h"
 
 #include <atomic>
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -41,17 +42,16 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace {
 
-const char kName[] = "named_event_test";
+constexpr char kName[] = "named_event_test";
 
 class NamedEventListenerThread : public Thread {
  public:
-  NamedEventListenerThread(const std::string &name, uint32 initial_wait_msec,
-                           uint32 wait_msec, size_t max_num_wait)
+  NamedEventListenerThread(const std::string &name, uint32_t initial_wait_msec,
+                           uint32_t wait_msec, size_t max_num_wait)
       : listener_(name.c_str()),
         initial_wait_msec_(initial_wait_msec),
         wait_msec_(wait_msec),
@@ -64,7 +64,7 @@ class NamedEventListenerThread : public Thread {
     Util::Sleep(initial_wait_msec_);
     for (size_t i = 0; i < max_num_wait_; ++i) {
       const bool result = listener_.Wait(wait_msec_);
-      const uint64 ticks = Clock::GetTicks();
+      const uint64_t ticks = Clock::GetTicks();
       if (result) {
         first_triggered_ticks_ = ticks;
         return;
@@ -72,16 +72,16 @@ class NamedEventListenerThread : public Thread {
     }
   }
 
-  uint64 first_triggered_ticks() const { return first_triggered_ticks_; }
+  uint64_t first_triggered_ticks() const { return first_triggered_ticks_; }
 
   bool IsTriggered() const { return first_triggered_ticks() > 0; }
 
  private:
   NamedEventListener listener_;
-  const uint32 initial_wait_msec_;
-  const uint32 wait_msec_;
+  const uint32_t initial_wait_msec_;
+  const uint32_t wait_msec_;
   const size_t max_num_wait_;
-  std::atomic<uint64> first_triggered_ticks_;
+  std::atomic<uint64_t> first_triggered_ticks_;
 };
 
 class NamedEventTest : public testing::Test {
@@ -104,7 +104,7 @@ TEST_F(NamedEventTest, NamedEventBasicTest) {
   Util::Sleep(200);
   NamedEventNotifier notifier(kName);
   ASSERT_TRUE(notifier.IsAvailable());
-  const uint64 notify_ticks = Clock::GetTicks();
+  const uint64_t notify_ticks = Clock::GetTicks();
   notifier.Notify();
   listener.Join();
 
@@ -139,7 +139,7 @@ TEST_F(NamedEventTest, IsOwnerTest) {
 }
 
 TEST_F(NamedEventTest, NamedEventMultipleListenerTest) {
-  const size_t kNumRequests = 4;
+  constexpr size_t kNumRequests = 4;
 
   // mozc::Thread is not designed as value-semantics.
   // So here we use pointers to maintain these instances.
@@ -147,7 +147,7 @@ TEST_F(NamedEventTest, NamedEventMultipleListenerTest) {
       kNumRequests);
   for (size_t i = 0; i < kNumRequests; ++i) {
     listeners[i] =
-        absl::make_unique<NamedEventListenerThread>(kName, 33 * i, 50, 100);
+        std::make_unique<NamedEventListenerThread>(kName, 33 * i, 50, 100);
     listeners[i]->Start("NamedEventMultipleListenerTest");
   }
 
@@ -157,7 +157,7 @@ TEST_F(NamedEventTest, NamedEventMultipleListenerTest) {
   // at once with single notifier event
   NamedEventNotifier notifier(kName);
   ASSERT_TRUE(notifier.IsAvailable());
-  const uint64 notify_ticks = Clock::GetTicks();
+  const uint64_t notify_ticks = Clock::GetTicks();
   ASSERT_TRUE(notifier.Notify());
 
   for (size_t i = 0; i < kNumRequests; ++i) {
