@@ -28,6 +28,7 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // OS_LINUX only. Note that OS_ANDROID/OS_WASM don't reach here.
+#include <cstdint>
 #if defined(OS_LINUX)
 
 #include <arpa/inet.h>
@@ -51,24 +52,26 @@
 #include "base/thread.h"
 #include "ipc/ipc.h"
 #include "ipc/ipc_path_manager.h"
+#include "absl/status/status.h"
 
 #ifndef UNIX_PATH_MAX
 #define UNIX_PATH_MAX 108
 #endif  // UNIX_PATH_MAX
 
 namespace mozc {
-
 namespace {
 
-const int kInvalidSocket = -1;
+constexpr int kInvalidSocket = -1;
 
-void mkdir_p(const std::string &dirname) {
+absl::Status mkdir_p(const std::string &dirname) {
   const std::string parent_dir = FileUtil::Dirname(dirname);
   struct stat st;
   if (!parent_dir.empty() && ::stat(parent_dir.c_str(), &st) < 0) {
-    mkdir_p(parent_dir);
+    if (absl::Status s = mkdir_p(parent_dir); !s.ok()) {
+      return s;
+    }
   }
-  FileUtil::CreateDirectory(dirname);
+  return FileUtil::CreateDirectory(dirname);
 }
 
 bool IsReadTimeout(int socket, int timeout) {
@@ -289,7 +292,7 @@ void IPCClient::Init(const std::string &name, const std::string &server_path) {
       manager->Clear();
       continue;
     } else {
-      if (!manager->IsValidServer(static_cast<uint32>(pid), server_path)) {
+      if (!manager->IsValidServer(static_cast<uint32_t>(pid), server_path)) {
         LOG(ERROR) << "Connecting to invalid server";
         last_ipc_error_ = IPC_INVALID_SERVER;
         break;
@@ -314,7 +317,7 @@ IPCClient::~IPCClient() {
 
 // RPC call
 bool IPCClient::Call(const char *request_, size_t input_length, char *response_,
-                     size_t *response_size, int32 timeout) {
+                     size_t *response_size, int32_t timeout) {
   last_ipc_error_ = IPC_NO_ERROR;
   if (!SendMessage(socket_, request_, input_length, timeout,
                    &last_ipc_error_)) {
@@ -342,8 +345,8 @@ bool IPCClient::Call(const char *request_, size_t input_length, char *response_,
 bool IPCClient::Connected() const { return connected_; }
 
 // Server
-IPCServer::IPCServer(const std::string &name, int32 num_connections,
-                     int32 timeout)
+IPCServer::IPCServer(const std::string &name, int32_t num_connections,
+                     int32_t timeout)
     : connected_(false), socket_(kInvalidSocket), timeout_(timeout) {
   IPCPathManager *manager = IPCPathManager::GetIPCPathManager(name);
   if (!manager->CreateNewPathName() && !manager->LoadPathName()) {
@@ -356,9 +359,19 @@ IPCServer::IPCServer(const std::string &name, int32 num_connections,
     return;
   }
   DCHECK(!server_address_.empty());
+  if (server_address_.size() >= UNIX_PATH_MAX) {
+    LOG(WARNING) << "server address is too long";
+    return;
+  }
 
-  const std::string dirname = FileUtil::Dirname(server_address_);
-  mkdir_p(dirname);
+  const bool is_file_socket = !IsAbstractSocket(server_address_);
+  if (is_file_socket) {
+    // Linux does not use files for IPC.
+    const std::string dirname = FileUtil::Dirname(server_address_);
+    if (absl::Status s = mkdir_p(dirname); !s.ok()) {
+      LOG(ERROR) << s << ": Cannot create " << dirname;
+    }
+  }
 
   sockaddr_un addr;
   ::memset(&addr, 0, sizeof(addr));
@@ -369,11 +382,6 @@ IPCServer::IPCServer(const std::string &name, int32 num_connections,
   }
   SetCloseOnExecFlag(socket_);
 
-  if (server_address_.size() >= UNIX_PATH_MAX) {
-    LOG(WARNING) << "server address is too long";
-    return;
-  }
-
   addr.sun_family = AF_UNIX;
   ::memcpy(addr.sun_path, server_address_.data(), server_address_.size());
   addr.sun_path[server_address_.size()] = '\0';
@@ -382,7 +390,7 @@ IPCServer::IPCServer(const std::string &name, int32 num_connections,
   ::setsockopt(socket_, SOL_SOCKET, SO_REUSEADDR, reinterpret_cast<char *>(&on),
                sizeof(on));
   const size_t sun_len = sizeof(addr.sun_family) + server_address_.size();
-  if (!IsAbstractSocket(server_address_)) {
+  if (is_file_socket) {
     // Linux does not use files for IPC.
     ::chmod(server_address_.c_str(), 0600);
   }
