@@ -30,8 +30,6 @@
 // skip all unless OS_WIN
 #ifdef OS_WIN
 
-#include "ipc/ipc.h"
-
 #include <Sddl.h>
 #include <Windows.h>
 
@@ -48,20 +46,22 @@
 #include "base/util.h"
 #include "base/win_sandbox.h"
 #include "base/win_util.h"
+#include "ipc/ipc.h"
 #include "ipc/ipc_path_manager.h"
+#include "absl/strings/match.h"
 
 namespace mozc {
 namespace {
 
-const bool kReadTypeACK = true;
-const bool kReadTypeData = false;
-const bool kSendTypeData = false;
-const int kMaxSuccessiveConnectionFailureCount = 5;
+constexpr bool kReadTypeACK = true;
+constexpr bool kReadTypeData = false;
+constexpr bool kSendTypeData = false;
+constexpr int kMaxSuccessiveConnectionFailureCount = 5;
 
 size_t GetNumberOfProcessors() {
   // thread-safety is not required.
   static size_t num = CPUStats().GetNumberOfProcessors();
-  return std::max(num, static_cast<size_t>(1));
+  return std::max<size_t>(num, 1);
 }
 
 // Least significant bit of OVERLAPPED::hEvent can be used for special
@@ -92,7 +92,7 @@ bool InitOverlapped(OVERLAPPED *overlapped, HANDLE wait_handle) {
 
 class IPCClientMutexBase {
  public:
-  explicit IPCClientMutexBase(const string &ipc_channel_name) {
+  explicit IPCClientMutexBase(const std::string &ipc_channel_name) {
     // Make a kernel mutex object so that multiple ipc connections are
     // serialized here. In Windows, there is no useful way to serialize
     // the multiple connections to the single-thread named pipe server.
@@ -102,13 +102,13 @@ class IPCClientMutexBase {
     // thread. The "available" notification is sent to all waiting ipc
     // clients at the same time and only one client gets the connection.
     // This causes redundant and wasteful CreateFile calles.
-    string mutex_name = kMutexPathPrefix;
+    std::string mutex_name = kMutexPathPrefix;
     mutex_name += SystemUtil::GetUserSidAsString();
     mutex_name += ".";
     mutex_name += ipc_channel_name;
     mutex_name += ".ipc";
     std::wstring wmutex_name;
-    Util::UTF8ToWide(mutex_name, &wmutex_name);
+    Util::Utf8ToWide(mutex_name, &wmutex_name);
 
     LPSECURITY_ATTRIBUTES security_attributes_ptr = nullptr;
     SECURITY_ATTRIBUTES security_attributes;
@@ -178,11 +178,11 @@ class FallbackClientMutex : public IPCClientMutexBase {
 // and client-renderer) so we need to have different global mutexes to
 // serialize each client. Currently |ipc_name| starts with "session" and
 // "renderer" are expected.
-HANDLE GetClientMutex(const string &ipc_name) {
-  if (Util::StartsWith(ipc_name, "session")) {
+HANDLE GetClientMutex(const std::string &ipc_name) {
+  if (absl::StartsWith(ipc_name, "session")) {
     return Singleton<ConverterClientMutex>::get()->get();
   }
-  if (Util::StartsWith(ipc_name, "renderer")) {
+  if (absl::StartsWith(ipc_name, "renderer")) {
     return Singleton<RendererClientMutex>::get()->get();
   }
   LOG(WARNING) << "unexpected IPC name: " << ipc_name;
@@ -444,13 +444,14 @@ void MaybeDisableFileCompletionNotification(HANDLE device_handle) {
 
 }  // namespace
 
-IPCServer::IPCServer(const string &name, int32 num_connections, int32 timeout)
+IPCServer::IPCServer(const std::string &name, int32 num_connections,
+                     int32 timeout)
     : connected_(false),
       pipe_event_(CreateManualResetEvent()),
       quit_event_(CreateManualResetEvent()),
       timeout_(timeout) {
   IPCPathManager *manager = IPCPathManager::GetIPCPathManager(name);
-  string server_address;
+  std::string server_address;
 
   if (!manager->CreateNewPathName() && !manager->LoadPathName()) {
     LOG(ERROR) << "Cannot prepare IPC path name";
@@ -472,7 +473,7 @@ IPCServer::IPCServer(const string &name, int32 num_connections, int32 timeout)
 
   // Create a named pipe.
   std::wstring wserver_address;
-  Util::UTF8ToWide(server_address, &wserver_address);
+  Util::Utf8ToWide(server_address, &wserver_address);
   HANDLE handle = ::CreateNamedPipe(
       wserver_address.c_str(),
       PIPE_ACCESS_DUPLEX | FILE_FLAG_OVERLAPPED | FILE_FLAG_FIRST_PIPE_INSTANCE,
@@ -610,7 +611,7 @@ void IPCServer::Loop() {
     // is an ACK signal (the IPC client of Mozc 1.5.x or earlier does this).
     char ack_request[1] = {0};
     size_t ack_request_size = 1;
-    static const int kAckTimeout = 100;
+    static constexpr int kAckTimeout = 100;
     if (!RecvIPCMessage(pipe_handle_.get(), pipe_event_.get(), ack_request,
                         &ack_request_size, kAckTimeout, kReadTypeACK,
                         &last_ipc_error)) {
@@ -627,7 +628,7 @@ void IPCServer::Loop() {
 }
 
 // old interface
-IPCClient::IPCClient(const string &name)
+IPCClient::IPCClient(const std::string &name)
     : pipe_event_(CreateManualResetEvent()),
       connected_(false),
       ipc_path_manager_(nullptr),
@@ -635,7 +636,7 @@ IPCClient::IPCClient(const string &name)
   Init(name, "");
 }
 
-IPCClient::IPCClient(const string &name, const string &server_path)
+IPCClient::IPCClient(const std::string &name, const std::string &server_path)
     : pipe_event_(CreateManualResetEvent()),
       connected_(false),
       ipc_path_manager_(nullptr),
@@ -643,7 +644,7 @@ IPCClient::IPCClient(const string &name, const string &server_path)
   Init(name, server_path);
 }
 
-void IPCClient::Init(const string &name, const string &server_path) {
+void IPCClient::Init(const std::string &name, const std::string &server_path) {
   last_ipc_error_ = IPC_NO_CONNECTION;
 
   // We should change the mutex based on which IPC server we will talk with.
@@ -652,7 +653,7 @@ void IPCClient::Init(const string &name, const string &server_path) {
   if (ipc_mutex.get() == nullptr) {
     LOG(ERROR) << "IPC mutex is not available";
   } else {
-    const int kMutexTimeout = 10 * 1000;  // wait at most 10sec.
+    constexpr int kMutexTimeout = 10 * 1000;  // wait at most 10sec.
     switch (::WaitForSingleObject(ipc_mutex.get(), kMutexTimeout)) {
       case WAIT_TIMEOUT:
         // TODO(taku): with suspend/resume, WaitForSingleObject may
@@ -681,18 +682,18 @@ void IPCClient::Init(const string &name, const string &server_path) {
 
   // TODO(taku): enable them on Mac/Linux
 #ifdef DEBUG
-  const size_t kMaxTrial = 256;
-#else
-  const size_t kMaxTrial = 2;
-#endif
+  constexpr size_t kMaxTrial = 256;
+#else   // DEBUG
+  constexpr size_t kMaxTrial = 2;
+#endif  // DEBUG
 
   for (size_t trial = 0; trial < kMaxTrial; ++trial) {
-    string server_address;
+    std::string server_address;
     if (!manager->LoadPathName() || !manager->GetPathName(&server_address)) {
       continue;
     }
     std::wstring wserver_address;
-    Util::UTF8ToWide(server_address, &wserver_address);
+    Util::Utf8ToWide(server_address, &wserver_address);
 
     if (GetNumberOfProcessors() == 1) {
       // When the code is running in single processor environment, sometimes
@@ -701,7 +702,7 @@ void IPCClient::Init(const string &name, const string &server_path) {
       // server has a chance to complete clean-up tasks if necessary.
       // NOTE: We cannot set 0 for the wait time because 0 has a special meaning
       // as |NMPWAIT_USE_DEFAULT_WAIT|.
-      const DWORD kMinWaitTimeForWaitNamedPipe = 1;
+      constexpr DWORD kMinWaitTimeForWaitNamedPipe = 1;
       ::WaitNamedPipe(wserver_address.c_str(), kMinWaitTimeForWaitNamedPipe);
     }
 
@@ -737,10 +738,10 @@ void IPCClient::Init(const string &name, const string &server_path) {
     // wait for 10 second until server is ready
     // TODO(taku): control the timeout via flag.
 #ifdef DEBUG
-    const int kNamedPipeTimeout = 100000;  // 100 sec
-#else
-    const int kNamedPipeTimeout = 10000;  // 10 sec
-#endif
+    constexpr int kNamedPipeTimeout = 100000;  // 100 sec
+#else                                          // DEBUG
+    constexpr int kNamedPipeTimeout = 10000;  // 10 sec
+#endif                                         // DEBUG
     DLOG(ERROR) << "Server is busy. waiting for " << kNamedPipeTimeout
                 << " msec";
     if (!::WaitNamedPipe(wserver_address.c_str(), kNamedPipeTimeout)) {
