@@ -30,6 +30,7 @@
 #ifndef MOZC_PREDICTION_DICTIONARY_PREDICTOR_H_
 #define MOZC_PREDICTION_DICTIONARY_PREDICTOR_H_
 
+#include <cstdint>
 #include <functional>
 #include <string>
 #include <vector>
@@ -64,7 +65,7 @@ class DictionaryPredictor : public PredictorInterface {
                       const dictionary::DictionaryInterface *dictionary,
                       const dictionary::DictionaryInterface *suffix_dictionary,
                       const Connector *connector, const Segmenter *segmenter,
-                      const dictionary::POSMatcher *pos_matcher,
+                      const dictionary::PosMatcher *pos_matcher,
                       const SuggestionFilter *suggestion_filter);
   ~DictionaryPredictor() override;
 
@@ -104,7 +105,7 @@ class DictionaryPredictor : public PredictorInterface {
     REALTIME_TOP = 65536,
   };
   // Bitfield to store a set of PredictionType.
-  typedef int32 PredictionTypes;
+  typedef int32_t PredictionTypes;
 
   struct Result {
     Result()
@@ -139,17 +140,17 @@ class DictionaryPredictor : public PredictorInterface {
     int cost;
     int lid;
     int rid;
+    uint32_t candidate_attributes;
     // Boundary information for realtime conversion.
     // This will be set only for realtime conversion result candidates.
     // This contains inner segment size for key and value.
     // If the candidate key and value are
     // "わたしの|なまえは|なかのです", " 私の|名前は|中野です",
     // |inner_segment_boundary| have [(4,2), (4, 3), (5, 4)].
-    std::vector<uint32> inner_segment_boundary;
-    uint32 candidate_attributes;
+    std::vector<uint32_t> inner_segment_boundary;
     // Segment::Candidate::SourceInfo.
     // Will be used for usage stats.
-    uint32 source_info;
+    uint32_t source_info;
     size_t consumed_key_size;
     // If removed is true, this result is not used for a candidate.
     bool removed;
@@ -177,6 +178,8 @@ class DictionaryPredictor : public PredictorInterface {
   class ResultWCostLess;
   class ResultCostLess;
 
+  // Aggregate* methods aggregate the candidates with different resources
+  // and algorithms.
   void AggregateRealtimeConversion(const ConversionRequest &request,
                                    size_t realtime_candidates_size,
                                    Segments *segments,
@@ -247,11 +250,11 @@ class DictionaryPredictor : public PredictorInterface {
   FRIEND_TEST(DictionaryPredictorTest, AggregateSuffixPrediction);
   FRIEND_TEST(DictionaryPredictorTest, AggregateZeroQuerySuffixPrediction);
   FRIEND_TEST(DictionaryPredictorTest,
-              AggregateZeroQueryPrediction_LatinInputMode);
+              AggregateZeroQueryPredictionLatinInputMode);
   FRIEND_TEST(DictionaryPredictorTest,
               AggregateUnigramCandidateForMixedConversion);
   FRIEND_TEST(DictionaryPredictorTest,
-              AggregateUnigramCandidateForMixedConversion_EnglishWords);
+              AggregateUnigramCandidateForMixedConversionEnglishWords);
   FRIEND_TEST(DictionaryPredictorTest, ZeroQuerySuggestionAfterNumbers);
   FRIEND_TEST(DictionaryPredictorTest, TriggerNumberZeroQuerySuggestion);
   FRIEND_TEST(DictionaryPredictorTest, TriggerZeroQuerySuggestion);
@@ -263,14 +266,15 @@ class DictionaryPredictor : public PredictorInterface {
   FRIEND_TEST(DictionaryPredictorTest, GetMissSpelledPosition);
   FRIEND_TEST(DictionaryPredictorTest, RemoveMissSpelledCandidates);
   FRIEND_TEST(DictionaryPredictorTest, ConformCharacterWidthToPreference);
-  FRIEND_TEST(DictionaryPredictorTest, SetLMCost);
+  FRIEND_TEST(DictionaryPredictorTest, SetPredictionCostForMixedConversion);
   FRIEND_TEST(DictionaryPredictorTest, SetLMCostForUserDictionaryWord);
   FRIEND_TEST(DictionaryPredictorTest, SetDescription);
   FRIEND_TEST(DictionaryPredictorTest, SetDebugDescription);
   FRIEND_TEST(DictionaryPredictorTest, GetZeroQueryCandidates);
   FRIEND_TEST(DictionaryPredictorTest, TriggerConditions);
-  FRIEND_TEST(DictionaryPredictorTest, TriggerConditions_Mobile);
-  FRIEND_TEST(DictionaryPredictorTest, TriggerConditions_LatinInputMode);
+  FRIEND_TEST(DictionaryPredictorTest, TriggerConditionsMobile);
+  FRIEND_TEST(DictionaryPredictorTest, TriggerConditionsLatinInputMode);
+  FRIEND_TEST(DictionaryPredictorTest, GetLMCost);
   FRIEND_TEST(TriggerConditionsTest, TriggerConditions);
 
   typedef std::pair<std::string, ZeroQueryType> ZeroQueryResult;
@@ -283,8 +287,8 @@ class DictionaryPredictor : public PredictorInterface {
       const ZeroQueryDict &dict, std::vector<ZeroQueryResult> *results);
 
   static void AppendZeroQueryToResults(
-      const std::vector<ZeroQueryResult> &candidates, uint16 lid, uint16 rid,
-      std::vector<Result> *results);
+      const std::vector<ZeroQueryResult> &candidates, uint16_t lid,
+      uint16_t rid, std::vector<Result> *results);
 
   // Returns the bitfield that indicates what prediction subroutines
   // were used.  NO_PREDICTION means that no prediction was made.
@@ -421,12 +425,15 @@ class DictionaryPredictor : public PredictorInterface {
   // Scoring function which takes prediction bounus into account.
   // It basically reranks the candidate by lang_prob * (1 + remain_len).
   // This algorithm is mainly used for desktop.
-  void SetPredictionCost(const Segments &segments,
+  void SetPredictionCost(ConversionRequest::RequestType request_type,
+                         const Segments &segments,
                          std::vector<Result> *results) const;
 
-  // Language model-based scoring function.
-  // This algorithm is mainly used for mobile.
-  void SetLMCost(const Segments &segments, std::vector<Result> *results) const;
+  // Scoring function for mixed conversion.
+  // In the mixed conversion we basically use the pure language model-based
+  // scoring function. This algorithm is mainly used for mobile.
+  void SetPredictionCostForMixedConversion(const Segments &segments,
+                                           std::vector<Result> *results) const;
 
   // Returns true if the suggestion is classified
   // as "aggressive".
@@ -450,7 +457,8 @@ class DictionaryPredictor : public PredictorInterface {
   static bool IsZipCodeRequest(const std::string &key);
 
   // Returns max size of realtime candidates.
-  size_t GetRealtimeCandidateMaxSize(const Segments &segments,
+  size_t GetRealtimeCandidateMaxSize(const ConversionRequest &request,
+                                     const Segments &segments,
                                      bool mixed_conversion) const;
 
   // Returns config to gather unigram candidates.
@@ -462,7 +470,8 @@ class DictionaryPredictor : public PredictorInterface {
   // if there are too many (>= cutoff threshold) eligible candidates.
   // This behavior prevents a user from seeing too many prefix-match
   // candidates.
-  size_t GetCandidateCutoffThreshold(const Segments &segments) const;
+  size_t GetCandidateCutoffThreshold(
+      ConversionRequest::RequestType request_type) const;
 
   // Generates a top conversion result from |converter_| and adds its result to
   // |results|.
@@ -473,7 +482,7 @@ class DictionaryPredictor : public PredictorInterface {
   void MaybeRecordUsageStats(const Segment::Candidate &candidate) const;
 
   // Sets candidate description.
-  static void SetDescription(PredictionTypes types, uint32 attributes,
+  static void SetDescription(PredictionTypes types, uint32_t attributes,
                              std::string *description);
   // Description for DEBUG mode.
   static void SetDebugDescription(PredictionTypes types,
@@ -486,9 +495,9 @@ class DictionaryPredictor : public PredictorInterface {
   const Connector *connector_;
   const Segmenter *segmenter_;
   const SuggestionFilter *suggestion_filter_;
-  const uint16 counter_suffix_word_id_;
-  const uint16 general_symbol_id_;
-  const uint16 unknown_id_;
+  const uint16_t counter_suffix_word_id_;
+  const uint16_t general_symbol_id_;
+  const uint16_t unknown_id_;
   const std::string predictor_name_;
   ZeroQueryDict zero_query_dict_;
   ZeroQueryDict zero_query_number_dict_;
