@@ -32,6 +32,7 @@
 #include <algorithm>
 #include <cctype>
 #include <climits>
+#include <cstdint>
 #include <limits>
 #include <memory>
 #include <string>
@@ -39,8 +40,8 @@
 #include "base/clock.h"
 #include "base/config_file_stream.h"
 #include "base/hash.h"
+#include "base/japanese_util.h"
 #include "base/logging.h"
-#include "base/mozc_hash_set.h"
 #include "base/thread.h"
 #include "base/trie.h"
 #include "base/util.h"
@@ -58,68 +59,68 @@
 #include "storage/encrypted_string_storage.h"
 #include "storage/lru_cache.h"
 #include "usage_stats/usage_stats.h"
+#include "absl/container/flat_hash_set.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_join.h"
 
 namespace mozc {
 namespace {
 
-using std::unique_ptr;
-
 using commands::Request;
 using dictionary::DictionaryInterface;
-using dictionary::POSMatcher;
+using dictionary::PosMatcher;
 using dictionary::SuppressionDictionary;
 using usage_stats::UsageStats;
 
 // Finds suggestion candidates from the most recent 3000 history in LRU.
 // We don't check all history, since suggestion is called every key event
-const size_t kMaxSuggestionTrial = 3000;
+constexpr size_t kMaxSuggestionTrial = 3000;
 
 // Finds suffix matches of history_segments from the most recent 500 histories
 // in LRU.
-const size_t kMaxPrevValueTrial = 500;
+constexpr size_t kMaxPrevValueTrial = 500;
 
 // Cache size
-// Typically memory/storage footprint becomes kLRUCacheSize * 70 bytes.
+// Typically memory/storage footprint becomes kLruCacheSize * 70 bytes.
 #ifdef OS_ANDROID
-const size_t kLRUCacheSize = 4000;
+constexpr size_t kLruCacheSize = 4000;
 #else   // OS_ANDROID
-const size_t kLRUCacheSize = 10000;
+constexpr size_t kLruCacheSize = 10000;
 #endif  // OS_ANDROID
 
 // Don't save key/value that are
 // longer than kMaxCandidateSize to avoid memory explosion
-const size_t kMaxStringLength = 256;
+constexpr size_t kMaxStringLength = 256;
 
 // Maximum size of next_entries
-const size_t kMaxNextEntriesSize = 4;
+constexpr size_t kMaxNextEntriesSize = 4;
 
 // Revert id for user_history_predictor
-const uint16 kRevertId = 1;
+const uint16_t kRevertId = 1;
 
 // Default object pool size for EntryPriorityQueue
-const size_t kEntryPoolSize = 16;
+constexpr size_t kEntryPoolSize = 16;
 
 // File name for the history
 #ifdef OS_WIN
-const char kFileName[] = "user://history.db";
-#else
-const char kFileName[] = "user://.history.db";
-#endif
+constexpr char kFileName[] = "user://history.db";
+#else   // OS_WIN
+constexpr char kFileName[] = "user://.history.db";
+#endif  // OS_WIN
 
 // Uses '\t' as a key/value delimiter
-const char kDelimiter[] = "\t";
-const char kEmojiDescription[] = "絵文字";
+constexpr char kDelimiter[] = "\t";
+constexpr char kEmojiDescription[] = "絵文字";
 
-const uint64 k62DaysInSec = 62 * 24 * 60 * 60;
+const uint64_t k62DaysInSec = 62 * 24 * 60 * 60;
 
 // TODO(peria, hidehiko): Unify this checker and IsEmojiCandidate in
 //     EmojiRewriter.  If you make similar functions before the merging in
 //     case, put a similar note to avoid twisted dependency.
 bool IsEmojiEntry(const UserHistoryPredictor::Entry &entry) {
   return (entry.has_description() &&
-          entry.description().find(kEmojiDescription) != std::string::npos);
+          absl::StrContains(entry.description(), kEmojiDescription));
 }
 
 bool IsPunctuation(absl::string_view value) {
@@ -144,7 +145,7 @@ bool IsSentenceLikeCandidate(const Segment::Candidate &candidate) {
 // Returns romanaized string.
 std::string ToRoman(const std::string &str) {
   std::string result;
-  Util::HiraganaToRomanji(str, &result);
+  japanese_util::HiraganaToRomanji(str, &result);
   return result;
 }
 
@@ -174,8 +175,8 @@ std::string GetDescription(const Segment::Candidate &candidate) {
 // Returns true if the input first candidate seems to be a privacy sensitive
 // such like password.
 bool UserHistoryPredictor::IsPrivacySensitive(const Segments *segments) const {
-  const bool kNonSensitive = false;
-  const bool kSensitive = true;
+  constexpr bool kNonSensitive = false;
+  constexpr bool kSensitive = true;
 
   // Skips privacy sensitive check if |segments| consists of multiple conversion
   // segment. That is, segments like "パスワードは|x7LAGhaR" where '|'
@@ -200,7 +201,7 @@ bool UserHistoryPredictor::IsPrivacySensitive(const Segments *segments) const {
   //     because of this rule. When a user commits his password in
   //     full-width form by mistake, like "ｘ７ＬＡＧｈａＲ", it is not
   //     treated as privacy sensitive too.
-  if (Util::GetCharacterSet(candidate_value) != Util::ASCII) {
+  if (!Util::IsAscii(candidate_value)) {
     return kNonSensitive;
   }
 
@@ -269,7 +270,7 @@ bool UserHistoryStorage::Save() {
   return true;
 }
 
-int UserHistoryStorage::DeleteEntriesBefore(uint64 timestamp) {
+int UserHistoryStorage::DeleteEntriesBefore(uint64_t timestamp) {
   // Partition entries so that [0, new_size) is kept and [new_size, size) is
   // deleted.
   int i = 0;
@@ -297,8 +298,8 @@ int UserHistoryStorage::DeleteEntriesBefore(uint64 timestamp) {
 }
 
 int UserHistoryStorage::DeleteEntriesUntouchedFor62Days() {
-  const uint64 now = Clock::GetTime();
-  const uint64 timestamp = (now > k62DaysInSec) ? now - k62DaysInSec : 0;
+  const uint64_t now = Clock::GetTime();
+  const uint64_t timestamp = (now > k62DaysInSec) ? now - k62DaysInSec : 0;
   return DeleteEntriesBefore(timestamp);
 }
 
@@ -313,7 +314,7 @@ bool UserHistoryPredictor::EntryPriorityQueue::Push(Entry *entry) {
     VLOG(2) << "found dups";
     return false;
   }
-  const uint32 score = UserHistoryPredictor::GetScore(*entry);
+  const uint32_t score = UserHistoryPredictor::GetScore(*entry);
   agenda_.push(std::make_pair(score, entry));
   return true;
 }
@@ -365,7 +366,7 @@ class UserHistoryPredictorSyncer : public Thread {
 };
 
 UserHistoryPredictor::UserHistoryPredictor(
-    const DictionaryInterface *dictionary, const POSMatcher *pos_matcher,
+    const DictionaryInterface *dictionary, const PosMatcher *pos_matcher,
     const SuppressionDictionary *suppression_dictionary,
     bool enable_content_word_learning)
     : dictionary_(dictionary),
@@ -391,7 +392,7 @@ std::string UserHistoryPredictor::GetUserHistoryFileName() {
 
 // Returns revert id
 // static
-uint16 UserHistoryPredictor::revert_id() { return kRevertId; }
+uint16_t UserHistoryPredictor::revert_id() { return kRevertId; }
 
 void UserHistoryPredictor::WaitForSyncer() {
   if (syncer_ != nullptr) {
@@ -432,7 +433,7 @@ bool UserHistoryPredictor::AsyncLoad() {
     return true;
   }
 
-  syncer_ = absl::make_unique<UserHistoryPredictorSyncer>(
+  syncer_ = std::make_unique<UserHistoryPredictorSyncer>(
       this, UserHistoryPredictorSyncer::LOAD);
   syncer_->Start("UserHistoryPredictor:Load");
 
@@ -448,7 +449,7 @@ bool UserHistoryPredictor::AsyncSave() {
     return true;
   }
 
-  syncer_ = absl::make_unique<UserHistoryPredictorSyncer>(
+  syncer_ = std::make_unique<UserHistoryPredictorSyncer>(
       this, UserHistoryPredictorSyncer::SAVE);
   syncer_->Start("UserHistoryPredictor:Save");
 
@@ -518,9 +519,9 @@ bool UserHistoryPredictor::ClearAllHistory() {
   WaitForSyncer();
 
   VLOG(1) << "Clearing user prediction";
-  // Renews DicCache as LRUCache tries to reuse the internal value by
+  // Renews DicCache as LruCache tries to reuse the internal value by
   // using FreeList
-  dic_ = absl::make_unique<DicCache>(UserHistoryPredictor::cache_size());
+  dic_ = std::make_unique<DicCache>(UserHistoryPredictor::cache_size());
 
   // insert a dummy event entry.
   InsertEvent(Entry::CLEAN_ALL_EVENT);
@@ -543,7 +544,7 @@ bool UserHistoryPredictor::ClearUnusedHistory() {
     return false;
   }
 
-  std::vector<uint32> keys;
+  std::vector<uint32_t> keys;
   for (const DicElement *elm = head; elm != nullptr; elm = elm->next) {
     VLOG(3) << elm->key << " " << elm->value.suggestion_freq();
     if (elm->value.suggestion_freq() == 0) {
@@ -571,7 +572,7 @@ bool UserHistoryPredictor::ClearUnusedHistory() {
 }
 
 // Erases all the next_entries whose entry_fp field equals |fp|.
-void UserHistoryPredictor::EraseNextEntries(uint32 fp, Entry *entry) {
+void UserHistoryPredictor::EraseNextEntries(uint32_t fp, Entry *entry) {
   const size_t orig_size = entry->next_entries_size();
   size_t new_size = orig_size;
   for (size_t pos = 0; pos < new_size;) {
@@ -618,7 +619,7 @@ UserHistoryPredictor::RemoveNgramChain(
     key_ngrams->push_back(entry->key());
     value_ngrams->push_back(entry->value());
     for (size_t i = 0; i < entry->next_entries().size(); ++i) {
-      const uint32 fp = entry->next_entries(i).entry_fp();
+      const uint32_t fp = entry->next_entries(i).entry_fp();
       Entry *e = dic_->MutableLookupWithoutInsert(fp);
       if (e == nullptr) {
         continue;
@@ -650,8 +651,8 @@ UserHistoryPredictor::RemoveNgramChain(
       value_ngrams_len == target_value.size()) {
     key_ngrams->push_back(entry->key());
     value_ngrams->push_back(entry->value());
-    const std::string ngram_key = Util::JoinStrings(*key_ngrams, "");
-    const std::string ngram_value = Util::JoinStrings(*value_ngrams, "");
+    const std::string ngram_key = absl::StrJoin(*key_ngrams, "");
+    const std::string ngram_value = absl::StrJoin(*value_ngrams, "");
     if (ngram_key == target_key && ngram_value == target_value) {
       // |entry| is the last node. So return TAIL to tell the caller so
       // that it can remove the link to this last node.
@@ -688,8 +689,8 @@ bool UserHistoryPredictor::ClearHistoryEntry(const std::string &key,
     for (DicElement *elm = dic_->MutableHead(); elm != nullptr;
          elm = elm->next) {
       Entry *entry = &elm->value;
-      if (!Util::StartsWith(key, entry->key()) ||
-          !Util::StartsWith(value, entry->value())) {
+      if (!absl::StartsWith(key, entry->key()) ||
+          !absl::StartsWith(value, entry->value())) {
         continue;
       }
       std::vector<absl::string_view> key_ngrams, value_ngrams;
@@ -709,7 +710,7 @@ bool UserHistoryPredictor::ClearHistoryEntry(const std::string &key,
 // static
 bool UserHistoryPredictor::HasBigramEntry(const Entry &entry,
                                           const Entry &prev_entry) {
-  const uint32 fp = EntryFingerprint(entry);
+  const uint32_t fp = EntryFingerprint(entry);
   for (int i = 0; i < prev_entry.next_entries_size(); ++i) {
     if (fp == prev_entry.next_entries(i).entry_fp()) {
       return true;
@@ -784,7 +785,7 @@ bool UserHistoryPredictor::RomanFuzzyPrefixMatch(const std::string &str,
       if (!isalnum(prefix[i])) {
         std::string replaced_prefix = prefix;
         replaced_prefix[i] = str[i];
-        if (Util::StartsWith(str, replaced_prefix)) {
+        if (absl::StartsWith(str, replaced_prefix)) {
           return true;
         }
       }
@@ -792,7 +793,7 @@ bool UserHistoryPredictor::RomanFuzzyPrefixMatch(const std::string &str,
       // deletion.
       std::string inserted_prefix = prefix;
       inserted_prefix.insert(i, 1, str[i]);
-      if (Util::StartsWith(str, inserted_prefix)) {
+      if (absl::StartsWith(str, inserted_prefix)) {
         return true;
       }
 
@@ -801,7 +802,7 @@ bool UserHistoryPredictor::RomanFuzzyPrefixMatch(const std::string &str,
         std::string swapped_prefix = prefix;
         using std::swap;
         swap(swapped_prefix[i], swapped_prefix[i + 1]);
-        if (Util::StartsWith(str, swapped_prefix)) {
+        if (absl::StartsWith(str, swapped_prefix)) {
           return true;
         }
       }
@@ -830,8 +831,7 @@ bool UserHistoryPredictor::RomanFuzzyLookupEntry(
 
   Entry *result = results->NewEntry();
   DCHECK(result);
-  result->Clear();
-  result->CopyFrom(*entry);
+  *result = *entry;
   result->set_spelling_correction(true);
   results->Push(result);
 
@@ -844,8 +844,7 @@ UserHistoryPredictor::Entry *UserHistoryPredictor::AddEntry(
   // generate prediction by entry chaining. The deleted entry itself is never
   // shown in the final prediction result as it is filtered finally.
   Entry *new_entry = results->NewEntry();
-  new_entry->Clear();
-  new_entry->CopyFrom(entry);
+  *new_entry = entry;
   return new_entry;
 }
 
@@ -856,8 +855,7 @@ UserHistoryPredictor::Entry *UserHistoryPredictor::AddEntryWithNewKeyValue(
   // generate prediction by entry chaining. The deleted entry itself is never
   // shown in the final prediction result as it is filtered finally.
   Entry *new_entry = results->NewEntry();
-  new_entry->Clear();
-  new_entry->CopyFrom(entry);
+  *new_entry = entry;
   new_entry->set_key(key);
   new_entry->set_value(value);
 
@@ -870,13 +868,13 @@ UserHistoryPredictor::Entry *UserHistoryPredictor::AddEntryWithNewKeyValue(
 
 bool UserHistoryPredictor::GetKeyValueForExactAndRightPrefixMatch(
     const std::string &input_key, const Entry *entry,
-    const Entry **result_last_entry, uint64 *left_last_access_time,
-    uint64 *left_most_last_access_time, std::string *result_key,
+    const Entry **result_last_entry, uint64_t *left_last_access_time,
+    uint64_t *left_most_last_access_time, std::string *result_key,
     std::string *result_value) const {
   std::string key = entry->key();
   std::string value = entry->value();
   const Entry *current_entry = entry;
-  mozc_hash_set<uint32> seen;
+  absl::flat_hash_set<uint32_t> seen;
   seen.insert(EntryFingerprint(*current_entry));
   // Until target entry gets longer than input_key.
   while (key.size() <= input_key.size()) {
@@ -983,10 +981,10 @@ bool UserHistoryPredictor::LookupEntry(RequestType request_type,
   const Entry *last_entry = nullptr;
 
   // last_access_time of the left-closest content word.
-  uint64 left_last_access_time = 0;
+  uint64_t left_last_access_time = 0;
 
   // last_access_time of the left-most content word.
-  uint64 left_most_last_access_time = 0;
+  uint64_t left_most_last_access_time = 0;
 
   // Example: [a|B|c|D]
   // a,c: functional word
@@ -1116,8 +1114,8 @@ bool UserHistoryPredictor::LookupEntry(RequestType request_type,
     // The new entry was input within 10 seconds.
     // TODO(taku): This is a simple heuristics.
     if (next_entry != nullptr && !next_entry->key().empty() &&
-        abs(static_cast<int32>(next_entry->last_access_time() -
-                               last_entry->last_access_time())) <= 10 &&
+        abs(static_cast<int32_t>(next_entry->last_access_time() -
+                                 last_entry->last_access_time())) <= 10 &&
         IsContentWord(next_entry->value())) {
       Entry *result2 = AddEntryWithNewKeyValue(
           result->key() + next_entry->key(),
@@ -1133,11 +1131,50 @@ bool UserHistoryPredictor::LookupEntry(RequestType request_type,
 
 bool UserHistoryPredictor::Predict(Segments *segments) const {
   ConversionRequest default_request;
+  default_request.set_request_type(ConversionRequest::PREDICTION);
   return PredictForRequest(default_request, segments);
 }
 
 bool UserHistoryPredictor::PredictForRequest(const ConversionRequest &request,
                                              Segments *segments) const {
+  const RequestType request_type = request.request().zero_query_suggestion()
+                                       ? ZERO_QUERY_SUGGESTION
+                                       : DEFAULT;
+  if (!ShouldPredict(request_type, request, *segments)) {
+    return false;
+  }
+
+  const size_t input_key_len =
+      Util::CharsLen(segments->conversion_segment(0).key());
+  const Entry *prev_entry =
+      LookupPrevEntry(*segments, request.request().available_emoji_carrier());
+  if (input_key_len == 0 && prev_entry == nullptr) {
+    VLOG(1) << "If input_key_len is 0, prev_entry must be set";
+    return false;
+  }
+
+  const bool is_zero_query =
+      ((request_type == ZERO_QUERY_SUGGESTION) && (input_key_len == 0));
+  const size_t max_prediction_size =
+      is_zero_query
+          ? request.max_user_history_prediction_candidates_size_for_zero_query()
+          : request.max_user_history_prediction_candidates_size();
+
+  EntryPriorityQueue results;
+  GetResultsFromHistoryDictionary(request_type, request, *segments, prev_entry,
+                                  max_prediction_size * 5, &results);
+  if (results.size() == 0) {
+    VLOG(2) << "no prefix match candidate is found.";
+    return false;
+  }
+
+  return InsertCandidates(request_type, request, max_prediction_size, segments,
+                          &results);
+}
+
+bool UserHistoryPredictor::ShouldPredict(RequestType request_type,
+                                         const ConversionRequest &request,
+                                         const Segments &segments) const {
   if (!CheckSyncerAndDelete()) {
     LOG(WARNING) << "Syncer is running";
     return false;
@@ -1153,18 +1190,18 @@ bool UserHistoryPredictor::PredictForRequest(const ConversionRequest &request,
     return false;
   }
 
-  if (segments->request_type() == Segments::CONVERSION) {
+  if (request.request_type() == ConversionRequest::CONVERSION) {
     VLOG(2) << "request type is CONVERSION";
     return false;
   }
 
   if (!request.config().use_history_suggest() &&
-      segments->request_type() == Segments::SUGGESTION) {
+      request.request_type() == ConversionRequest::SUGGESTION) {
     VLOG(2) << "no history suggest";
     return false;
   }
 
-  if (segments->conversion_segments_size() < 1) {
+  if (segments.conversion_segments_size() < 1) {
     VLOG(2) << "segment size < 1";
     return false;
   }
@@ -1174,10 +1211,7 @@ bool UserHistoryPredictor::PredictForRequest(const ConversionRequest &request,
     return false;
   }
 
-  const RequestType request_type = request.request().zero_query_suggestion()
-                                       ? ZERO_QUERY_SUGGESTION
-                                       : DEFAULT;
-  const std::string &input_key = segments->conversion_segment(0).key();
+  const std::string &input_key = segments.conversion_segment(0).key();
   if (IsPunctuation(Util::Utf8SubString(input_key, 0, 1))) {
     VLOG(2) << "input_key starts with punctuations";
     return false;
@@ -1189,26 +1223,11 @@ bool UserHistoryPredictor::PredictForRequest(const ConversionRequest &request,
     return false;
   }
 
-  const Entry *prev_entry =
-      LookupPrevEntry(*segments, request.request().available_emoji_carrier());
-  if (input_key_len == 0 && prev_entry == nullptr) {
-    VLOG(1) << "If input_key_len is 0, prev_entry must be set";
-    return false;
-  }
-
-  EntryPriorityQueue results;
-  GetResultsFromHistoryDictionary(request_type, request, *segments, prev_entry,
-                                  &results);
-  if (results.size() == 0) {
-    VLOG(2) << "no prefix match candidate is found.";
-    return false;
-  }
-
-  return InsertCandidates(request_type, request, segments, &results);
+  return true;
 }
 
 const UserHistoryPredictor::Entry *UserHistoryPredictor::LookupPrevEntry(
-    const Segments &segments, uint32 available_emoji_carrier) const {
+    const Segments &segments, uint32_t available_emoji_carrier) const {
   const size_t history_segments_size = segments.history_segments_size();
   const Entry *prev_entry = nullptr;
   // When there are non-zero history segments, lookup an entry
@@ -1225,7 +1244,7 @@ const UserHistoryPredictor::Entry *UserHistoryPredictor::LookupPrevEntry(
   prev_entry = dic_->LookupWithoutInsert(SegmentFingerprint(history_segment));
 
   // Check the timestamp of prev_entry.
-  const uint64 now = Clock::GetTime();
+  const uint64_t now = Clock::GetTime();
   if (prev_entry != nullptr &&
       prev_entry->last_access_time() + k62DaysInSec < now) {
     updated_ = true;  // We found an entry to be deleted at next save.
@@ -1251,7 +1270,7 @@ const UserHistoryPredictor::Entry *UserHistoryPredictor::LookupPrevEntry(
           entry != prev_entry && entry->next_entries_size() > 0 &&
           Util::CharsLen(entry->value()) >= 2 &&
           (entry->value() == prev_value ||
-           Util::EndsWith(prev_value, entry->value()))) {
+           absl::EndsWith(prev_value, entry->value()))) {
         prev_entry = entry;
         break;
       }
@@ -1262,11 +1281,9 @@ const UserHistoryPredictor::Entry *UserHistoryPredictor::LookupPrevEntry(
 
 void UserHistoryPredictor::GetResultsFromHistoryDictionary(
     RequestType request_type, const ConversionRequest &request,
-    const Segments &segments, const Entry *prev_entry,
+    const Segments &segments, const Entry *prev_entry, size_t max_results_size,
     EntryPriorityQueue *results) const {
   DCHECK(results);
-  const size_t max_results_size = 5 * segments.max_prediction_candidates_size();
-
   // Gets romanized input key if the given preedit looks misspelled.
   const std::string roman_input_key = GetRomanMisspelledKey(request, segments);
 
@@ -1292,10 +1309,10 @@ void UserHistoryPredictor::GetResultsFromHistoryDictionary(
   // |input_key| is "あｋ" and |base_key| is "あ"
   std::string input_key;
   std::string base_key;
-  unique_ptr<Trie<std::string>> expanded;
+  std::unique_ptr<Trie<std::string>> expanded;
   GetInputKeyFromSegments(request, segments, &input_key, &base_key, &expanded);
 
-  const uint64 now = Clock::GetTime();
+  const uint64_t now = Clock::GetTime();
   int trial = 0;
   for (const DicElement *elm = dic_->Head(); elm != nullptr; elm = elm->next) {
     if (!IsValidEntryIgnoringRemovedField(
@@ -1306,7 +1323,7 @@ void UserHistoryPredictor::GetResultsFromHistoryDictionary(
       updated_ = true;  // We found an entry to be deleted at next save.
       continue;
     }
-    if (segments.request_type() == Segments::SUGGESTION &&
+    if (request.request_type() == ConversionRequest::SUGGESTION &&
         trial++ >= kMaxSuggestionTrial) {
       VLOG(2) << "too many trials";
       break;
@@ -1332,7 +1349,7 @@ void UserHistoryPredictor::GetResultsFromHistoryDictionary(
 void UserHistoryPredictor::GetInputKeyFromSegments(
     const ConversionRequest &request, const Segments &segments,
     std::string *input_key, std::string *base,
-    unique_ptr<Trie<std::string>> *expanded) {
+    std::unique_ptr<Trie<std::string>> *expanded) {
   DCHECK(input_key);
   DCHECK(base);
 
@@ -1346,7 +1363,7 @@ void UserHistoryPredictor::GetInputKeyFromSegments(
   std::set<std::string> expanded_set;
   request.composer().GetQueriesForPrediction(base, &expanded_set);
   if (!expanded_set.empty()) {
-    *expanded = absl::make_unique<Trie<std::string>>();
+    *expanded = std::make_unique<Trie<std::string>>();
     for (std::set<std::string>::const_iterator itr = expanded_set.begin();
          itr != expanded_set.end(); ++itr) {
       // For getting matched key, insert values
@@ -1357,6 +1374,7 @@ void UserHistoryPredictor::GetInputKeyFromSegments(
 
 bool UserHistoryPredictor::InsertCandidates(RequestType request_type,
                                             const ConversionRequest &request,
+                                            size_t max_prediction_size,
                                             Segments *segments,
                                             EntryPriorityQueue *results) const {
   DCHECK(results);
@@ -1365,9 +1383,10 @@ bool UserHistoryPredictor::InsertCandidates(RequestType request_type,
     LOG(ERROR) << "segment is nullptr";
     return false;
   }
-  const uint32 input_key_len = Util::CharsLen(segment->key());
-  while (segment->candidates_size() <
-         segments->max_prediction_candidates_size()) {
+  const uint32_t input_key_len = Util::CharsLen(segment->key());
+
+  size_t inserted_num = 0;
+  while (inserted_num < max_prediction_size) {
     // |results| is a priority queue where the elemtnt
     // in the queue is sorted by the score defined in GetScore().
     const Entry *result_entry = results->Pop();
@@ -1376,9 +1395,9 @@ bool UserHistoryPredictor::InsertCandidates(RequestType request_type,
       break;
     }
     bool is_valid_candidate = false;
-    if (segments->request_type() == Segments::PREDICTION) {
+    if (request.request_type() == ConversionRequest::PREDICTION) {
       is_valid_candidate = true;
-    } else if (segments->request_type() == Segments::SUGGESTION) {
+    } else if (request.request_type() == ConversionRequest::SUGGESTION) {
       // The top result of suggestion should be a VALID suggestion candidate.
       // i.e., SuggestionTrigerFunc should return true for the first
       // candidate.
@@ -1434,13 +1453,14 @@ bool UserHistoryPredictor::InsertCandidates(RequestType request_type,
       VariantsRewriter::SetDescriptionForPrediction(*pos_matcher_, candidate);
     }
 #if DEBUG
-    if (candidate->description.find("History") == string::npos) {
+    if (!absl::StrContains(candidate->description, "History")) {
       candidate->description += " History";
     }
 #endif  // DEBUG
+    ++inserted_num;
   }
 
-  return (segment->candidates_size() > 0);
+  return inserted_num > 0;
 }
 
 void UserHistoryPredictor::InsertNextEntry(const NextEntry &next_entry,
@@ -1457,7 +1477,7 @@ void UserHistoryPredictor::InsertNextEntry(const NextEntry &next_entry,
     target_next_entry = entry->add_next_entries();
   } else {
     // Otherwise, find the oldest next_entry.
-    uint64 last_access_time = std::numeric_limits<uint64>::max();
+    uint64_t last_access_time = std::numeric_limits<uint64_t>::max();
     for (int i = 0; i < entry->next_entries_size(); ++i) {
       // Already has the same id
       if (next_entry.entry_fp() == entry->next_entries(i).entry_fp()) {
@@ -1485,11 +1505,11 @@ void UserHistoryPredictor::InsertNextEntry(const NextEntry &next_entry,
     return;
   }
 
-  target_next_entry->CopyFrom(next_entry);
+  *target_next_entry = next_entry;
 }
 
-bool UserHistoryPredictor::IsValidEntry(const Entry &entry,
-                                        uint32 available_emoji_carrier) const {
+bool UserHistoryPredictor::IsValidEntry(
+    const Entry &entry, uint32_t available_emoji_carrier) const {
   if (entry.removed() ||
       !IsValidEntryIgnoringRemovedField(entry, available_emoji_carrier)) {
     return false;
@@ -1498,7 +1518,7 @@ bool UserHistoryPredictor::IsValidEntry(const Entry &entry,
 }
 
 bool UserHistoryPredictor::IsValidEntryIgnoringRemovedField(
-    const Entry &entry, uint32 available_emoji_carrier) const {
+    const Entry &entry, uint32_t available_emoji_carrier) const {
   if (entry.entry_type() != Entry::DEFAULT_ENTRY ||
       suppression_dictionary_->SuppressEntry(entry.key(), entry.value())) {
     return false;
@@ -1507,7 +1527,7 @@ bool UserHistoryPredictor::IsValidEntryIgnoringRemovedField(
   if (IsEmojiEntry(entry)) {
     if (Util::IsAndroidPuaEmoji(entry.value())) {
       // Android carrier dependent emoji.
-      const uint32 kAndroidCarrier =
+      constexpr uint32_t kAndroidCarrier =
           Request::DOCOMO_EMOJI | Request::SOFTBANK_EMOJI | Request::KDDI_EMOJI;
       if (!(available_emoji_carrier & kAndroidCarrier)) {
         return false;
@@ -1536,8 +1556,8 @@ void UserHistoryPredictor::InsertEvent(EntryType type) {
     return;
   }
 
-  const uint64 last_access_time = Clock::GetTime();
-  const uint32 dic_key = Fingerprint("", "", type);
+  const uint64_t last_access_time = Clock::GetTime();
+  const uint32_t dic_key = Fingerprint("", "", type);
 
   CHECK(dic_.get());
   DicElement *e = dic_->Insert(dic_key);
@@ -1555,8 +1575,8 @@ void UserHistoryPredictor::InsertEvent(EntryType type) {
 
 void UserHistoryPredictor::TryInsert(
     RequestType request_type, const std::string &key, const std::string &value,
-    const std::string &description, bool is_suggestion_selected, uint32 next_fp,
-    uint64 last_access_time, Segments *segments) {
+    const std::string &description, bool is_suggestion_selected,
+    uint32_t next_fp, uint64_t last_access_time, Segments *segments) {
   if (key.empty() || value.empty() || key.size() > kMaxStringLength ||
       value.size() > kMaxStringLength ||
       description.size() > kMaxStringLength) {
@@ -1576,9 +1596,10 @@ void UserHistoryPredictor::TryInsert(
 void UserHistoryPredictor::Insert(const std::string &key,
                                   const std::string &value,
                                   const std::string &description,
-                                  bool is_suggestion_selected, uint32 next_fp,
-                                  uint64 last_access_time, Segments *segments) {
-  const uint32 dic_key = Fingerprint(key, value);
+                                  bool is_suggestion_selected, uint32_t next_fp,
+                                  uint64_t last_access_time,
+                                  Segments *segments) {
+  const uint32_t dic_key = Fingerprint(key, value);
 
   if (!dic_->HasKey(dic_key)) {
     // The key is a new key inserted in the last Finish method.
@@ -1662,7 +1683,7 @@ void UserHistoryPredictor::MaybeRecordUsageStats(
 
 void UserHistoryPredictor::Finish(const ConversionRequest &request,
                                   Segments *segments) {
-  if (segments->request_type() == Segments::REVERSE_CONVERSION) {
+  if (request.request_type() == ConversionRequest::REVERSE_CONVERSION) {
     // Do nothing for REVERSE_CONVERSION.
     return;
   }
@@ -1694,8 +1715,9 @@ void UserHistoryPredictor::Finish(const ConversionRequest &request,
   const RequestType request_type = request.request().zero_query_suggestion()
                                        ? ZERO_QUERY_SUGGESTION
                                        : DEFAULT;
-  const bool is_suggestion = segments->request_type() != Segments::CONVERSION;
-  const uint64 last_access_time = Clock::GetTime();
+  const bool is_suggestion =
+      request.request_type() != ConversionRequest::CONVERSION;
+  const uint64_t last_access_time = Clock::GetTime();
 
   // If user inputs a punctuation just after some long sentence,
   // we make a new candidate by concatenating the top element in LRU and
@@ -1725,7 +1747,7 @@ void UserHistoryPredictor::Finish(const ConversionRequest &request,
             .value;
     // Check if the head value in LRU ends with the candidate value in history
     // segments.
-    if (Util::EndsWith(entry->value(), last_value)) {
+    if (absl::EndsWith(entry->value(), last_value)) {
       const Segment::Candidate &candidate =
           segments->conversion_segment(0).candidate(0);
       const std::string key = entry->key() + candidate.key;
@@ -1810,13 +1832,13 @@ void UserHistoryPredictor::MakeLearningSegments(
 
 void UserHistoryPredictor::InsertHistory(RequestType request_type,
                                          bool is_suggestion_selected,
-                                         uint64 last_access_time,
+                                         uint64_t last_access_time,
                                          Segments *segments) {
   SegmentsForLearning learning_segments;
   MakeLearningSegments(*segments, &learning_segments);
 
   std::string all_key, all_value;
-  mozc_hash_set<uint32> seen;
+  absl::flat_hash_set<uint32_t> seen;
   bool this_was_seen = false;
   const size_t history_segments_size =
       learning_segments.history_segments_size();
@@ -1826,7 +1848,7 @@ void UserHistoryPredictor::InsertHistory(RequestType request_type,
     const SegmentForLearning &segment = learning_segments.all_segment(i);
     all_key += segment.key;
     all_value += segment.value;
-    uint32 next_fp =
+    uint32_t next_fp =
         (i == learning_segments.all_segments_size() - 1)
             ? 0
             : LearningSegmentFingerprint(learning_segments.all_segment(i + 1));
@@ -1834,7 +1856,7 @@ void UserHistoryPredictor::InsertHistory(RequestType request_type,
     if (i == history_segments_size) {
       seen.insert(LearningSegmentFingerprint(segment));
     }
-    uint32 next_fp_to_set = next_fp;
+    uint32_t next_fp_to_set = next_fp;
     // If two duplicate segments exist, kills the link
     // TO/FROM the second one to prevent loops.
     // Only killing "TO" link caused bug #2982886:
@@ -1904,13 +1926,13 @@ void UserHistoryPredictor::InsertHistory(RequestType request_type,
         LearningSegmentFingerprint(history_segment));
     if (history_entry) {
       NextEntry next_entry;
-      if (segments->request_type() == Segments::CONVERSION) {
+      if (!is_suggestion_selected) {
         next_entry.set_entry_fp(LearningSegmentFingerprint(conversion_segment));
         InsertNextEntry(next_entry, history_entry);
       }
 
       // Entire user input or SUGGESTION
-      if (segments->request_type() != Segments::CONVERSION ||
+      if (is_suggestion_selected ||
           learning_segments.conversion_segments_size() > 1) {
         next_entry.set_entry_fp(Fingerprint(all_key, all_value));
         InsertNextEntry(next_entry, history_entry);
@@ -2018,31 +2040,31 @@ UserHistoryPredictor::MatchType UserHistoryPredictor::GetMatchTypeFromInput(
 }
 
 // static
-uint32 UserHistoryPredictor::Fingerprint(const std::string &key,
-                                         const std::string &value,
-                                         EntryType type) {
+uint32_t UserHistoryPredictor::Fingerprint(const std::string &key,
+                                           const std::string &value,
+                                           EntryType type) {
   if (type == Entry::DEFAULT_ENTRY) {
     // Since we have already used the fingerprint function for next entries and
     // next entries are saved in user's local machine, we are not able
     // to change the Fingerprint function for the old key/value type.
     return Hash::Fingerprint32(key + kDelimiter + value);
   } else {
-    return Hash::Fingerprint32(static_cast<uint8>(type));
+    return Hash::Fingerprint32(static_cast<uint8_t>(type));
   }
 }
 
 // static
-uint32 UserHistoryPredictor::Fingerprint(const std::string &key,
-                                         const std::string &value) {
+uint32_t UserHistoryPredictor::Fingerprint(const std::string &key,
+                                           const std::string &value) {
   return Fingerprint(key, value, Entry::DEFAULT_ENTRY);
 }
 
-uint32 UserHistoryPredictor::EntryFingerprint(const Entry &entry) {
+uint32_t UserHistoryPredictor::EntryFingerprint(const Entry &entry) {
   return Fingerprint(entry.key(), entry.value());
 }
 
 // static
-uint32 UserHistoryPredictor::SegmentFingerprint(const Segment &segment) {
+uint32_t UserHistoryPredictor::SegmentFingerprint(const Segment &segment) {
   if (segment.candidates_size() > 0) {
     return Fingerprint(segment.candidate(0).key, segment.candidate(0).value);
   }
@@ -2050,20 +2072,20 @@ uint32 UserHistoryPredictor::SegmentFingerprint(const Segment &segment) {
 }
 
 // static
-uint32 UserHistoryPredictor::LearningSegmentFingerprint(
+uint32_t UserHistoryPredictor::LearningSegmentFingerprint(
     const SegmentForLearning &segment) {
   return Fingerprint(segment.key, segment.value);
 }
 
 // static
-std::string UserHistoryPredictor::Uint32ToString(uint32 fp) {
+std::string UserHistoryPredictor::Uint32ToString(uint32_t fp) {
   std::string buf(reinterpret_cast<const char *>(&fp), sizeof(fp));
   return buf;
 }
 
 // static
-uint32 UserHistoryPredictor::StringToUint32(const std::string &input) {
-  uint32 result = 0;
+uint32_t UserHistoryPredictor::StringToUint32(const std::string &input) {
+  uint32_t result = 0;
   if (input.size() == sizeof(result)) {
     memcpy(reinterpret_cast<char *>(&result), input.data(), input.size());
   }
@@ -2072,7 +2094,7 @@ uint32 UserHistoryPredictor::StringToUint32(const std::string &input) {
 
 // static
 bool UserHistoryPredictor::IsValidSuggestion(RequestType request_type,
-                                             uint32 prefix_len,
+                                             uint32_t prefix_len,
                                              const Entry &entry) {
   // When bigram_boost is true, that means that previous user input
   // and current input have bigram relation.
@@ -2087,11 +2109,10 @@ bool UserHistoryPredictor::IsValidSuggestion(RequestType request_type,
   }
   // Handles suggestion_freq and conversion_freq differently.
   // conversion_freq is less aggressively affecting to the final decision.
-  const uint32 freq =
+  const uint32_t freq =
       std::max(entry.suggestion_freq(), entry.conversion_freq() / 4);
-
   // TODO(taku,komatsu): better to make it simpler and easier to be understood.
-  const uint32 base_prefix_len = 3 - std::min(static_cast<uint32>(2), freq);
+  const uint32_t base_prefix_len = 3 - std::min<uint32_t>(2, freq);
   return (prefix_len >= base_prefix_len);
 }
 
@@ -2100,19 +2121,19 @@ bool UserHistoryPredictor::IsValidSuggestion(RequestType request_type,
 // 2) boost shorter candidate, if having the same last_access_time.
 // 3) add a bigram boost as a special bonus.
 // TODO(taku): better to take "frequency" into consideration
-uint32 UserHistoryPredictor::GetScore(const Entry &entry) {
-  const uint32 kBigramBoostAsTime = 7 * 24 * 60 * 60;  // 1 week.
+uint32_t UserHistoryPredictor::GetScore(const Entry &entry) {
+  constexpr uint32_t kBigramBoostAsTime = 7 * 24 * 60 * 60;  // 1 week.
   return entry.last_access_time() - Util::CharsLen(entry.value()) +
          (entry.bigram_boost() ? kBigramBoostAsTime : 0);
 }
 
 // Returns the size of cache.
 // static
-uint32 UserHistoryPredictor::cache_size() { return kLRUCacheSize; }
+uint32_t UserHistoryPredictor::cache_size() { return kLruCacheSize; }
 
 // Returns the size of next entries.
 // static
-uint32 UserHistoryPredictor::max_next_entries_size() {
+uint32_t UserHistoryPredictor::max_next_entries_size() {
   return kMaxNextEntriesSize;
 }
 
