@@ -31,12 +31,12 @@
 
 #include <climits>
 #include <cstddef>
+#include <cstdint>
 #include <memory>
 #include <string>
 
 #include "base/clock.h"
 #include "base/logging.h"
-#include "base/mutex.h"
 #include "base/process.h"
 #include "base/run_level.h"
 #include "base/system_util.h"
@@ -46,11 +46,11 @@
 #include "ipc/ipc.h"
 #include "ipc/named_event.h"
 #include "protocol/renderer_command.pb.h"
-#include "absl/memory/memory.h"
+#include "absl/synchronization/mutex.h"
 
 #ifdef __APPLE__
 #include "base/mac_util.h"
-#endif
+#endif  // __APPLE__
 
 #ifdef OS_WIN
 #include "base/win_sandbox.h"
@@ -60,12 +60,12 @@ namespace mozc {
 namespace renderer {
 namespace {
 
-const int kIPCTimeout = 100;                   // 100 msec
-const int kRendererWaitTimeout = 30 * 1000;    // 30 sec
-const int kRendererWaitSleepTime = 10 * 1000;  // 10 sec
-const size_t kMaxErrorTimes = 5;
-const uint64 kRetryIntervalTime = 30;  // 30 sec
-const char kServiceName[] = "renderer";
+constexpr int kIPCTimeout = 100;                   // 100 msec
+constexpr int kRendererWaitTimeout = 30 * 1000;    // 30 sec
+constexpr int kRendererWaitSleepTime = 10 * 1000;  // 10 sec
+constexpr size_t kMaxErrorTimes = 5;
+constexpr uint64_t kRetryIntervalTime = 30;  // 30 sec
+constexpr char kServiceName[] = "renderer";
 
 inline void CallCommand(IPCClientInterface *client,
                         const commands::RendererCommand &command) {
@@ -137,7 +137,7 @@ class RendererLauncher : public RendererLauncherInterface, public Thread {
 #ifdef OS_WIN
     DWORD pid = 0;
     const bool process_in_job = RunLevel::IsProcessInJob();
-    const string arg = process_in_job ? "--restricted" : "";
+    const std::string arg = process_in_job ? "--restricted" : "";
 
     WinSandbox::SecurityInfo info;
     info.primary_level = WinSandbox::USER_INTERACTIVE;
@@ -157,11 +157,11 @@ class RendererLauncher : public RendererLauncherInterface, public Thread {
     // Start renderer process by using launch_msg API.
     pid_t pid = 0;
     const bool result = MacUtil::StartLaunchdService("Renderer", &pid);
-#else
+#else                     // OS_WIN, __APPLE__
     size_t tmp = 0;
     const bool result = Process::SpawnProcess(path_, "", &tmp);
-    uint32 pid = static_cast<uint32>(tmp);
-#endif  // OS_WIN, __APPLE__
+    uint32_t pid = static_cast<uint32_t>(tmp);
+#endif                    // OS_WIN, __APPLE__
 
     if (!result) {
       LOG(ERROR) << "Can't start process";
@@ -236,9 +236,9 @@ class RendererLauncher : public RendererLauncherInterface, public Thread {
   void SetPendingCommand(const commands::RendererCommand &command) override {
     // ignore NOOP|SHUTDOWN
     if (command.type() == commands::RendererCommand::UPDATE) {
-      scoped_lock l(&pending_command_mutex_);
+      absl::MutexLock l(&pending_command_mutex_);
       if (!pending_command_) {
-        pending_command_ = absl::make_unique<commands::RendererCommand>();
+        pending_command_ = std::make_unique<commands::RendererCommand>();
       }
       *pending_command_ = command;
     }
@@ -249,12 +249,12 @@ class RendererLauncher : public RendererLauncherInterface, public Thread {
   }
 
   RendererLauncher()
-      : renderer_status_(RendererLauncher::RENDERER_UNKNOWN),
-        last_launch_time_(0),
+      : last_launch_time_(0),
         error_times_(0),
+        ipc_client_factory_interface_(nullptr),
+        renderer_status_(RendererLauncher::RENDERER_UNKNOWN),
         disable_renderer_path_check_(false),
-        suppress_error_dialog_(false),
-        ipc_client_factory_interface_(nullptr) {}
+        suppress_error_dialog_(false) {}
 
   ~RendererLauncher() override {
     if (!IsRunning()) {
@@ -276,11 +276,11 @@ class RendererLauncher : public RendererLauncherInterface, public Thread {
   };
 
   void FlushPendingCommand() {
-    scoped_lock l(&pending_command_mutex_);
+    absl::MutexLock l(&pending_command_mutex_);
     if (ipc_client_factory_interface_ != nullptr && pending_command_) {
       std::unique_ptr<IPCClientInterface> client(CreateIPCClient());
       if (!client) {
-        CallCommand(client.get(), *(pending_command_.get()));
+        CallCommand(client.get(), *pending_command_);
       }
     }
     pending_command_.reset();
@@ -304,14 +304,14 @@ class RendererLauncher : public RendererLauncherInterface, public Thread {
 
   std::string name_;
   std::string path_;
-  volatile RendererStatus renderer_status_;
-  volatile uint64 last_launch_time_;
+  volatile uint64_t last_launch_time_;
   volatile size_t error_times_;
-  bool disable_renderer_path_check_;
-  bool suppress_error_dialog_;
   IPCClientFactoryInterface *ipc_client_factory_interface_;
   std::unique_ptr<commands::RendererCommand> pending_command_;
-  Mutex pending_command_mutex_;
+  absl::Mutex pending_command_mutex_;
+  volatile RendererStatus renderer_status_;
+  bool disable_renderer_path_check_;
+  bool suppress_error_dialog_;
 };
 
 RendererClient::RendererClient()
@@ -431,7 +431,7 @@ bool RendererClient::ExecCommand(const commands::RendererCommand &command) {
   }
 
   // Drop the current request if version mismatch happens.
-  const int kMaxVersionMismatchNums = 3;
+  constexpr int kMaxVersionMismatchNums = 3;
   if (version_mismatch_nums_ >= kMaxVersionMismatchNums) {
     return true;
   }
