@@ -29,40 +29,40 @@
 
 #include "renderer/renderer_client.h"
 
+#include <cstdint>
 #include <string>
 
 #include "base/logging.h"
 #include "base/number_util.h"
 #include "base/port.h"
-#include "base/util.h"
 #include "base/version.h"
 #include "ipc/ipc.h"
+#include "protocol/commands.pb.h"
 #include "protocol/renderer_command.pb.h"
 #include "renderer/renderer_interface.h"
 #include "testing/base/public/gunit.h"
 #include "absl/strings/str_format.h"
+#include "absl/strings/str_join.h"
+#include "absl/strings/str_split.h"
 
 namespace mozc {
-
 namespace renderer {
-
 namespace {
+
 const std::string UpdateVersion(int diff) {
-  std::vector<std::string> tokens;
-  Util::SplitStringUsing(Version::GetMozcVersion(), ".", &tokens);
+  std::vector<std::string> tokens =
+      absl::StrSplit(Version::GetMozcVersion(), '.', absl::SkipEmpty());
   EXPECT_EQ(tokens.size(), 4);
   char buf[64];
   absl::SNPrintF(buf, sizeof(buf), "%d",
                  NumberUtil::SimpleAtoi(tokens[3]) + diff);
   tokens[3] = buf;
-  std::string output;
-  Util::JoinStrings(tokens, ".", &output);
-  return output;
+  return absl::StrJoin(tokens, ".");
 }
 
 int g_counter = 0;
 bool g_connected = false;
-uint32 g_server_protocol_version = IPC_PROTOCOL_VERSION;
+uint32_t g_server_protocol_version = IPC_PROTOCOL_VERSION;
 std::string g_server_product_version;
 
 class TestIPCClient : public IPCClientInterface {
@@ -72,7 +72,7 @@ class TestIPCClient : public IPCClientInterface {
 
   bool Connected() const override { return g_connected; }
 
-  uint32 GetServerProtocolVersion() const override {
+  uint32_t GetServerProtocolVersion() const override {
     return g_server_protocol_version;
   }
 
@@ -80,11 +80,11 @@ class TestIPCClient : public IPCClientInterface {
     return g_server_product_version;
   }
 
-  uint32 GetServerProcessId() const override { return 0; }
+  uint32_t GetServerProcessId() const override { return 0; }
 
   // just count up how many times Call is called.
   bool Call(const char *request, size_t request_size, char *response,
-            size_t *response_size, int32 timeout) override {
+            size_t *response_size, int32_t timeout) override {
     g_counter++;
     return true;
   }
@@ -95,7 +95,7 @@ class TestIPCClient : public IPCClientInterface {
 
   static int counter() { return g_counter; }
 
-  static void set_server_protocol_version(uint32 version) {
+  static void set_server_protocol_version(uint32_t version) {
     g_server_protocol_version = version;
   }
 
