@@ -75,7 +75,7 @@ class FontSpecTest : public testing::Test {
   }
 
   void ExpectFontDescription(const TestableFontSpec &font_spec,
-                             const string &expected,
+                             const std::string &expected,
                              FontSpecInterface::FONT_TYPE font_type) {
     EXPECT_EQ(expected, pango_font_description_to_string(
                             font_spec.GetFontDescription(font_type)));
@@ -163,7 +163,7 @@ TEST_F(FontSpecTest, FontDescriptionTest) {
   ExpectFontDescription(font_spec, kDefaultFontDescription,
                         FontSpecInterface::FONTSET_INFOLIST_DESCRIPTION);
 
-  const char kDummyFontDescription[] = "Foo,Bar,Baz";
+  constexpr char kDummyFontDescription[] = "Foo,Bar,Baz";
   font_spec.Reload(kDummyFontDescription);
   ExpectFontDescription(font_spec, kDummyFontDescription,
                         FontSpecInterface::FONTSET_CANDIDATE);
