@@ -62,7 +62,7 @@ class GtkWindowInterface {
   virtual void Resize(const Size &size) = 0;
   virtual void Initialize() = 0;
   virtual void Redraw() = 0;
-  virtual void ReloadFontConfig(const string &font_description) = 0;
+  virtual void ReloadFontConfig(const std::string &font_description) = 0;
 
   virtual Size Update(const commands::Candidates &candidates) = 0;
 
