@@ -30,7 +30,6 @@
 #include "renderer/unix/infolist_window.h"
 
 #include "base/logging.h"
-#include "base/mutex.h"
 #include "protocol/renderer_command.pb.h"
 #include "protocol/renderer_style.pb.h"
 #include "renderer/renderer_style_handler.h"
@@ -74,7 +73,7 @@ InfolistWindow::InfolistWindow(TextRendererInterface *text_renderer,
 }
 
 Size InfolistWindow::Update(const commands::Candidates &candidates) {
-  candidates_.CopyFrom(candidates);
+  candidates_ = candidates;
 
   const RendererStyle::InfolistStyle &infostyle = style_->infolist_style();
   const InformationList &usages = candidates_.usages();
@@ -151,7 +150,7 @@ void InfolistWindow::Draw() {
 }
 
 void InfolistWindow::GetRenderingRects(
-    const renderer::RendererStyle::TextStyle &style, const string &text,
+    const renderer::RendererStyle::TextStyle &style, const std::string &text,
     FontSpec::FONT_TYPE font_type, int top, Rect *background_rect,
     Rect *textarea_rect) {
   const RendererStyle::InfolistStyle &infostyle = style_->infolist_style();
@@ -241,7 +240,7 @@ void InfolistWindow::Initialize() {
   text_renderer_->Initialize(GetCanvasWidget()->window);
 }
 
-void InfolistWindow::ReloadFontConfig(const string &font_description) {
+void InfolistWindow::ReloadFontConfig(const std::string &font_description) {
   text_renderer_->ReloadFontConfig(font_description);
 }
 
