@@ -54,27 +54,27 @@ namespace {
 GtkWidget *kDummyWindow = reinterpret_cast<GtkWidget *>(0x12345678);
 GtkWidget *kDummyCanvas = reinterpret_cast<GtkWidget *>(0x87654321);
 
-const char kSampleTitle[] = "TITLE";
-const char kSampleDescription[] = "DESCRIPTION";
+constexpr char kSampleTitle[] = "TITLE";
+constexpr char kSampleDescription[] = "DESCRIPTION";
 
 void SetInformations(int count, commands::InformationList *usages) {
   usages->Clear();
   for (int i = 0; i < count; ++i) {
     commands::Information *info = usages->add_information();
 
-    const string id_str = std::to_string(i);
+    const std::string id_str = std::to_string(i);
     info->set_title(kSampleTitle + id_str);
     info->set_description(kSampleDescription + id_str);
   }
 }
 
-string GetExpectedTitle(int row) {
-  const string id_str = std::to_string(row);
+std::string GetExpectedTitle(int row) {
+  const std::string id_str = std::to_string(row);
   return kSampleTitle + id_str;
 }
 
-string GetExpectedDescription(int row) {
-  const string id_str = std::to_string(row);
+std::string GetExpectedDescription(int row) {
+  const std::string id_str = std::to_string(row);
   return kSampleDescription + id_str;
 }
 
@@ -468,7 +468,7 @@ TEST_F(InfolistWindowTest, GetRenderingRectsTest) {
 
 TEST_F(InfolistWindowTest, ReloadFontConfigTest) {
   InfolistWindowTestKit testkit = SetUpInfolistWindow();
-  const char kDummyFontDescription[] = "Foo,Bar,Baz";
+  constexpr char kDummyFontDescription[] = "Foo,Bar,Baz";
   EXPECT_CALL(*testkit.text_renderer_mock,
               ReloadFontConfig(StrEq(kDummyFontDescription)));
   testkit.window->ReloadFontConfig(kDummyFontDescription);
