@@ -34,7 +34,6 @@
 #include <memory>
 #include <string>
 
-#include "base/mutex.h"
 #include "base/port.h"
 #include "client/client_interface.h"
 #include "protocol/renderer_command.pb.h"
@@ -98,7 +97,7 @@ class WindowManager : public WindowManagerInterface {
   std::unique_ptr<GtkWindowInterface> infolist_window_;
   std::unique_ptr<GtkWrapperInterface> gtk_;
   client::SendCommandInterface *send_command_interface_;
-  string previous_font_description_;
+  std::string previous_font_description_;
   DISALLOW_COPY_AND_ASSIGN(WindowManager);
 };
 
