@@ -32,6 +32,7 @@
 #include <windows.h>
 
 #include <sstream>
+#include <string>
 
 #include "base/coordinates.h"
 #include "base/logging.h"
@@ -60,15 +61,15 @@ using WTL::CSize;
 namespace {
 
 // 96 DPI is the default DPI in Windows.
-const int kDefaultDPI = 96;
+constexpr int kDefaultDPI = 96;
 
 // layout size constants in pixel unit in the default DPI.
-const int kIndicatorWidthInDefaultDPI = 4;
+constexpr int kIndicatorWidthInDefaultDPI = 4;
 
 // DPI-invariant layout size constants in pixel unit.
-const int kWindowBorder = 1;
-const int kFooterSeparatorHeight = 1;
-const int kRowRectPadding = 1;
+constexpr int kWindowBorder = 1;
+constexpr int kFooterSeparatorHeight = 1;
+constexpr int kRowRectPadding = 1;
 
 // usage type for each column.
 enum COLUMN_TYPE {
@@ -80,7 +81,8 @@ enum COLUMN_TYPE {
   NUMBER_OF_COLUMNS,    // number of columns. (this item should be last)
 };
 
-const char kMinimumCandidateAndDescriptionWidthAsString[] = "そのほかの文字種";
+constexpr char kMinimumCandidateAndDescriptionWidthAsString[] =
+    "そのほかの文字種";
 
 // Color scheme
 const COLORREF kFrameColor = RGB(0x96, 0x96, 0x96);
@@ -122,7 +124,7 @@ int GetCandidateArrayIndexByCandidateIndex(
 // the selected index is "13" (in 1-origin) and the number of
 // candidates is "123"
 // Returns an empty string if index string should not be displayed.
-string GetIndexGuideString(const commands::Candidates &candidates) {
+std::string GetIndexGuideString(const commands::Candidates &candidates) {
   if (!candidates.has_footer() || !candidates.footer().index_visible()) {
     return "";
   }
@@ -142,10 +144,10 @@ string GetIndexGuideString(const commands::Candidates &candidates) {
 // This function returns the size of the given candidate list when there
 // aren't any candidates satisfying the above condition.
 int GetFocusedArrayIndex(const commands::Candidates &candidates) {
-  const int kInvalidIndex = candidates.candidate_size();
+  const int invalid_index = candidates.candidate_size();
 
   if (!candidates.has_focused_index()) {
-    return kInvalidIndex;
+    return invalid_index;
   }
 
   const int focused_index = candidates.focused_index();
@@ -164,24 +166,24 @@ std::wstring GetDisplayStringByColumn(
       if (candidate.has_annotation()) {
         const commands::Annotation &annotation = candidate.annotation();
         if (annotation.has_shortcut()) {
-          mozc::Util::UTF8ToWide(annotation.shortcut(), &display_string);
+          mozc::Util::Utf8ToWide(annotation.shortcut(), &display_string);
         }
       }
       break;
     case COLUMN_CANDIDATE:
       if (candidate.has_value()) {
-        mozc::Util::UTF8ToWide(candidate.value(), &display_string);
+        mozc::Util::Utf8ToWide(candidate.value(), &display_string);
       }
       if (candidate.has_annotation()) {
         const commands::Annotation &annotation = candidate.annotation();
         if (annotation.has_prefix()) {
           std::wstring annotation_prefix;
-          mozc::Util::UTF8ToWide(annotation.prefix(), &annotation_prefix);
+          mozc::Util::Utf8ToWide(annotation.prefix(), &annotation_prefix);
           display_string = annotation_prefix + display_string;
         }
         if (annotation.has_suffix()) {
           std::wstring annotation_suffix;
-          mozc::Util::UTF8ToWide(annotation.suffix(), &annotation_suffix);
+          mozc::Util::Utf8ToWide(annotation.suffix(), &annotation_suffix);
           display_string += annotation_suffix;
         }
       }
@@ -190,7 +192,7 @@ std::wstring GetDisplayStringByColumn(
       if (candidate.has_annotation()) {
         const commands::Annotation &annotation = candidate.annotation();
         if (annotation.has_description()) {
-          mozc::Util::UTF8ToWide(annotation.description(), &display_string);
+          mozc::Util::Utf8ToWide(annotation.description(), &display_string);
         }
       }
       break;
@@ -433,7 +435,7 @@ void CandidateWindow::OnSettingChange(UINT uFlags, LPCTSTR /*lpszSection*/) {
 }
 
 void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
-  candidates_->CopyFrom(candidates);
+  *candidates_ = candidates;
 
   // If we detect any change of font parameters, update text renderer
   if (metrics_changed_) {
@@ -469,7 +471,7 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
     // Calculate the size to display a label string.
     if (candidates_->footer().has_label()) {
       std::wstring footer_label;
-      mozc::Util::UTF8ToWide(candidates_->footer().label(), &footer_label);
+      mozc::Util::Utf8ToWide(candidates_->footer().label(), &footer_label);
       const Size label_string_size = text_renderer_->MeasureString(
           TextRenderer::FONTSET_FOOTER_LABEL, L" " + footer_label + L" ");
       footer_size.width += label_string_size.width;
@@ -480,7 +482,7 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
       // absent.
       // TODO(yukawa): Refactor the layout system for the footer.
       std::wstring footer_sub_label;
-      mozc::Util::UTF8ToWide(candidates_->footer().sub_label(),
+      mozc::Util::Utf8ToWide(candidates_->footer().sub_label(),
                              &footer_sub_label);
       const Size label_string_size =
           text_renderer_->MeasureString(TextRenderer::FONTSET_FOOTER_SUBLABEL,
@@ -493,7 +495,7 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
     // Calculate the size to display a index string.
     if (candidates_->footer().index_visible()) {
       std::wstring index_guide_string;
-      mozc::Util::UTF8ToWide(GetIndexGuideString(*candidates_),
+      mozc::Util::Utf8ToWide(GetIndexGuideString(*candidates_),
                              &index_guide_string);
       const Size index_guide_size = text_renderer_->MeasureString(
           TextRenderer::FONTSET_FOOTER_INDEX, index_guide_string);
@@ -522,7 +524,7 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
     if (candidates_->candidate_size() < candidates_->size()) {
       // We use FONTSET_CANDIDATE for calculating the minimum width.
       std::wstring minimum_width_as_wstring;
-      mozc::Util::UTF8ToWide(kMinimumCandidateAndDescriptionWidthAsString,
+      mozc::Util::Utf8ToWide(kMinimumCandidateAndDescriptionWidthAsString,
                              &minimum_width_as_wstring);
       const Size minimum_size = text_renderer_->MeasureString(
           TextRenderer::FONTSET_CANDIDATE, minimum_width_as_wstring.c_str());
@@ -645,8 +647,8 @@ void CandidateWindow::DrawCells(CDCHandle dc) {
                                           TextRenderer::FONTSET_CANDIDATE,
                                           TextRenderer::FONTSET_DESCRIPTION};
 
-  DCHECK_EQ(arraysize(kColumnTypes), arraysize(kFontTypes));
-  for (size_t type_index = 0; type_index < arraysize(kColumnTypes);
+  DCHECK_EQ(std::size(kColumnTypes), std::size(kFontTypes));
+  for (size_t type_index = 0; type_index < std::size(kColumnTypes);
        ++type_index) {
     const COLUMN_TYPE column_type = kColumnTypes[type_index];
     const TextRenderer::FONT_TYPE font_type = kFontTypes[type_index];
@@ -768,7 +770,7 @@ void CandidateWindow::DrawFooter(CDCHandle dc) {
   int right_used = 0;
   if (candidates_->footer().index_visible()) {
     std::wstring index_guide_string;
-    mozc::Util::UTF8ToWide(GetIndexGuideString(*candidates_),
+    mozc::Util::Utf8ToWide(GetIndexGuideString(*candidates_),
                            &index_guide_string);
     const Size index_guide_size = text_renderer_->MeasureString(
         TextRenderer::FONTSET_FOOTER_INDEX, index_guide_string);
@@ -785,12 +787,12 @@ void CandidateWindow::DrawFooter(CDCHandle dc) {
                           footer_content_rect.Width() - left_used - right_used,
                           footer_content_rect.Height());
     std::wstring footer_label;
-    mozc::Util::UTF8ToWide(candidates_->footer().label(), &footer_label);
+    mozc::Util::Utf8ToWide(candidates_->footer().label(), &footer_label);
     text_renderer_->RenderText(dc, L" " + footer_label + L" ", label_rect,
                                TextRenderer::FONTSET_FOOTER_LABEL);
   } else if (candidates_->footer().has_sub_label()) {
     std::wstring footer_sub_label;
-    mozc::Util::UTF8ToWide(candidates_->footer().sub_label(),
+    mozc::Util::Utf8ToWide(candidates_->footer().sub_label(),
                            &footer_sub_label);
     const Rect label_rect(left_used, footer_content_rect.Top(),
                           footer_content_rect.Width() - left_used - right_used,
