@@ -56,7 +56,7 @@ TEST(FontUtilTest, ToLOGFONTWithTooLongFaceName) {
                       L""};
 
   // make a string which is not null-terminated.
-  for (size_t i = 0; i < arraysize(log_font.lfFaceName); ++i) {
+  for (size_t i = 0; i < std::size(log_font.lfFaceName); ++i) {
     log_font.lfFaceName[i] = L' ';
   }
 
@@ -82,9 +82,9 @@ TEST(FontUtilTest, ToWinLogFontWithTooLongFaceName) {
   win_log_font.set_pitch_and_family(FF_SCRIPT);
 
   LOGFONT log_font = {};
-  std::wstring too_long_face_name(L' ', arraysize(log_font.lfFaceName));
-  string face_name;
-  mozc::Util::WideToUTF8(too_long_face_name, &face_name);
+  std::wstring too_long_face_name(L' ', std::size(log_font.lfFaceName));
+  std::string face_name;
+  mozc::Util::WideToUtf8(too_long_face_name, &face_name);
   win_log_font.set_face_name(face_name);
 
   // Conversion should fail.
@@ -144,8 +144,8 @@ TEST(FontUtilTest, RoundtripToLOGFONT) {
   original.set_clip_precision(CLIP_DEFAULT_PRECIS);
   original.set_quality(ANTIALIASED_QUALITY);
   original.set_pitch_and_family(FF_SCRIPT);
-  string face_name;
-  mozc::Util::WideToUTF8(L"MS Sans Serif", &face_name);
+  std::string face_name;
+  mozc::Util::WideToUtf8(L"MS Sans Serif", &face_name);
   original.set_face_name(face_name);
 
   LOGFONT log_font = {};
