@@ -40,10 +40,10 @@
 
 #include <algorithm>
 #include <bitset>
+#include <memory>
 #include <vector>
 
 #include "base/logging.h"
-#include "base/stl_util.h"
 #include "base/util.h"
 
 namespace mozc {
@@ -366,17 +366,17 @@ Rect GetBoundingRect(double left, double top, double width, double height) {
 
 // Core logic to render 1-bit text glyphs for sub-pixel rendering. Caller takes
 // the ownerships of the returned pointers.
-std::vector<TextLabel::BinarySubdivisionalPixel *> Get1bitGlyph(
-    double left, double top, double width, double height, const string &text,
-    const string &fontname, size_t font_point) {
-  const size_t kDivision = SubdivisionalPixel::kDivision;
+std::vector<std::unique_ptr<TextLabel::BinarySubdivisionalPixel>> Get1bitGlyph(
+    double left, double top, double width, double height,
+    const std::string &text, const std::string &fontname, size_t font_point) {
+  constexpr size_t kDivision = SubdivisionalPixel::kDivision;
 
   const Rect &bounding_rect = GetBoundingRect(left, top, width, height);
   const int pix_width = bounding_rect.Width();
   const int pix_height = bounding_rect.Height();
 
-  std::vector<TextLabel::BinarySubdivisionalPixel *> pixels;
-  pixels.resize(pix_width * pix_height, nullptr);
+  std::vector<std::unique_ptr<TextLabel::BinarySubdivisionalPixel>> pixels(
+      pix_width * pix_height);
   if (text.empty()) {
     return pixels;
   }
@@ -414,7 +414,7 @@ std::vector<TextLabel::BinarySubdivisionalPixel *> Get1bitGlyph(
   CBitmapHandle old_bitmap = dc.SelectBitmap(dib);
 
   std::wstring wide_fontname;
-  Util::UTF8ToWide(fontname, &wide_fontname);
+  Util::Utf8ToWide(fontname, &wide_fontname);
   CLogFont logfont;
   logfont.lfWeight = FW_NORMAL;
   logfont.lfCharSet = DEFAULT_CHARSET;
@@ -439,7 +439,7 @@ std::vector<TextLabel::BinarySubdivisionalPixel *> Get1bitGlyph(
   dc.SetBkMode(TRANSPARENT);
   dc.SetTextColor(RGB(255, 255, 255));
   std::wstring wide_text;
-  Util::UTF8ToWide(text, &wide_text);
+  Util::Utf8ToWide(text, &wide_text);
   dc.DrawTextW(wide_text.c_str(), wide_text.size(), &rect,
                DT_VCENTER | DT_SINGLELINE | DT_NOPREFIX | DT_CENTER);
   dc.SelectFont(old_font);
@@ -464,8 +464,9 @@ std::vector<TextLabel::BinarySubdivisionalPixel *> Get1bitGlyph(
             continue;
           }
           if (sub_pixels == nullptr) {
-            sub_pixels = new TextLabel::BinarySubdivisionalPixel();
-            pixels[pix_index] = sub_pixels;
+            auto ptr = std::make_unique<TextLabel::BinarySubdivisionalPixel>();
+            sub_pixels = ptr.get();
+            pixels[pix_index] = std::move(ptr);
           }
           sub_pixels->set(subpix_y * kDivision + subpix_x);
         }
@@ -477,7 +478,7 @@ std::vector<TextLabel::BinarySubdivisionalPixel *> Get1bitGlyph(
 
 double Gauss(double sigma, double x, double y) {
   const double sigma_coef = 0.5 / (sigma * sigma);
-  const double kInvPi = 0.31830988618379067153776752674503;
+  constexpr double kInvPi = 0.31830988618379067153776752674503;
   return kInvPi * sigma_coef * exp(-(x * x + y * y) * sigma_coef);
 }
 
@@ -546,8 +547,8 @@ HBITMAP BalloonImage::CreateInternal(const BalloonImageInfo &info,
                                      POINT *tail_offset, SIZE *size,
                                      std::vector<ARGBColor> *arbg_buffer) {
   // Base point. You can set arbitrary position.
-  const double kLeft = 10.0;
-  const double kTop = 10.0;
+  constexpr double kLeft = 10.0;
+  constexpr double kTop = 10.0;
 
   const Balloon balloon(
       kLeft, kTop, std::max(info.rect_width, 0.0),
@@ -949,15 +950,13 @@ size_t SafeFrameBuffer::GetIndex(int x, int y) const {
 }
 
 TextLabel::TextLabel(double left, double top, double width, double height,
-                     const string &text, const string &font, size_t font_point,
-                     const RGBColor text_color)
+                     const std::string &text, const std::string &font,
+                     size_t font_point, const RGBColor text_color)
     : bounding_rect_(GetBoundingRect(left, top, width, height)),
       pixels_(Get1bitGlyph(left, top, width, height, text, font, font_point)),
       text_color_(text_color) {}
 
-TextLabel::~TextLabel() {
-  STLDeleteContainerPointers(pixels_.begin(), pixels_.end());
-}
+TextLabel::~TextLabel() = default;
 
 void TextLabel::RenderPixel(int x, int y, SubdivisionalPixel *dest) const {
   if (x < bounding_rect_.Left() || bounding_rect_.Right() <= x ||
@@ -967,7 +966,7 @@ void TextLabel::RenderPixel(int x, int y, SubdivisionalPixel *dest) const {
   const int pix_width = bounding_rect_.Width();
   const size_t index =
       (y - bounding_rect_.Top()) * pix_width + (x - bounding_rect_.Left());
-  const BinarySubdivisionalPixel *sub_pixels = pixels_[index];
+  const BinarySubdivisionalPixel *sub_pixels = pixels_[index].get();
   if (sub_pixels == nullptr) {
     return;
   }
