@@ -50,6 +50,7 @@
 #include "base/util.h"
 #include "base/win_font_test_helper.h"
 #include "net/jsoncpp.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
 
@@ -65,7 +66,6 @@ using ::mozc::renderer::win32::internal::GaussianBlur;
 using ::mozc::renderer::win32::internal::SafeFrameBuffer;
 using ::mozc::renderer::win32::internal::SubdivisionalPixel;
 using ::mozc::renderer::win32::internal::TextLabel;
-using ::std::unique_ptr;
 
 using ::WTL::CBitmap;
 using ::WTL::CDC;
@@ -132,8 +132,8 @@ class BalloonImageTest : public ::testing::Test,
 
     bitmap.Save(filename.c_str(), &clsid_png_);
 
-    string utf8_filename;
-    Util::WideToUTF8(filename + L".json", &utf8_filename);
+    std::string utf8_filename;
+    Util::WideToUtf8(filename + L".json", &utf8_filename);
     OutputFileStream os(utf8_filename.c_str());
     Json::StyledWriter writer;
     os << writer.write(tail);
@@ -284,10 +284,10 @@ INSTANTIATE_TEST_CASE_P(BalloonImageParameters, BalloonImageTest,
                         ::testing::ValuesIn(kRenderingResultList));
 
 TEST_P(BalloonImageTest, TestImpl) {
-  const string &expected_image_path =
+  const std::string &expected_image_path =
       mozc::testing::GetSourceFileOrDie({GetParam()});
-  const string json_path = expected_image_path + ".json";
-  ASSERT_TRUE(FileUtil::FileExists(json_path))
+  const std::string json_path = expected_image_path + ".json";
+  ASSERT_OK(FileUtil::FileExists(json_path))
       << "Manifest file is not found: " << json_path;
 
   Json::Value tail;
@@ -309,7 +309,7 @@ TEST_P(BalloonImageTest, TestImpl) {
   EXPECT_EQ(tail["output"]["tail_offset_y"].asInt(), actual_tail_offset.y);
 
   std::wstring wide_path;
-  Util::UTF8ToWide(expected_image_path, &wide_path);
+  Util::Utf8ToWide(expected_image_path, &wide_path);
 
   Gdiplus::Bitmap bitmap(wide_path.c_str());
 
@@ -457,10 +457,10 @@ TEST(GaussianBlurTest, NormalBlurTest) {
 
 TEST(SafeFrameBufferTest, BasicTest) {
   const ARGBColor kTransparent(0, 0, 0, 0);
-  const int kLeft = -10;
-  const int kTop = -20;
-  const int kWidth = 50;
-  const int kHeight = 100;
+  constexpr int kLeft = -10;
+  constexpr int kTop = -20;
+  constexpr int kWidth = 50;
+  constexpr int kHeight = 100;
   SafeFrameBuffer buffer(Rect(kLeft, kTop, kWidth, kHeight));
 
   EXPECT_EQ(kTransparent, buffer.GetPixel(kLeft, kTop))
