@@ -56,7 +56,6 @@ namespace mozc {
 namespace renderer {
 namespace win32 {
 using ATL::CWindow;
-using std::unique_ptr;
 using WTL::CDC;
 using WTL::CDCHandle;
 using WTL::CFont;
@@ -414,7 +413,7 @@ bool CanUseExcludeRegionInCandidateFrom(
 }
 
 std::wstring ComposePreeditText(const commands::Preedit &preedit,
-                                string *preedit_utf8,
+                                std::string *preedit_utf8,
                                 std::vector<int> *segment_indices,
                                 std::vector<CharacterRange> *segment_ranges) {
   if (preedit_utf8 != nullptr) {
@@ -432,7 +431,7 @@ std::wstring ComposePreeditText(const commands::Preedit &preedit,
        ++segment_index) {
     const commands::Preedit::Segment &segment = preedit.segment(segment_index);
     std::wstring segment_value;
-    mozc::Util::UTF8ToWide(segment.value(), &segment_value);
+    mozc::Util::Utf8ToWide(segment.value(), &segment_value);
     value.append(segment_value);
     if (preedit_utf8 != nullptr) {
       preedit_utf8->append(segment.value());
@@ -1724,7 +1723,7 @@ bool LayoutManager::LayoutCompositionWindow(
 
   CompositionForm composition_form;
   if (command.application_info().has_composition_form()) {
-    composition_form.CopyFrom(command.application_info().composition_form());
+    composition_form = command.application_info().composition_form();
   } else {
     // No composition form is available.  Use client rect instead.
     CRect client_rect;
@@ -1836,7 +1835,7 @@ bool LayoutManager::LayoutCompositionWindow(
     logfont.lfOrientation = 0;
   }
 
-  string preedit_utf8;
+  std::string preedit_utf8;
   std::vector<int> segment_indices;
   std::vector<CharacterRange> segment_lengths;
   const std::wstring composition_text = ComposePreeditText(
@@ -2246,7 +2245,7 @@ bool LayoutManager::GetClientRect(HWND window_handle, RECT *client_rect) const {
 }
 
 double LayoutManager::GetScalingFactor(HWND window_handle) const {
-  const double kDefaultValue = 1.0;
+  constexpr double kDefaultValue = 1.0;
   CRect window_rect_in_logical_coord;
   if (!window_position_->GetWindowRect(window_handle,
                                        &window_rect_in_logical_coord)) {
@@ -2437,64 +2436,64 @@ int LayoutManager::GetCompatibilityMode(
   }
 
   int mode = COMPATIBILITY_MODE_NONE;
-  {{const wchar_t * kUseCandidateFormForSuggest[] = {
+  {
+    const wchar_t *kUseCandidateFormForSuggest[] = {
         L"Chrome_RenderWidgetHostHWND",
         L"JsTaroCtrl",
         L"MozillaWindowClass",
         L"OperaWindowClass",
         L"QWidget",
     };
-  for (size_t i = 0; i < ARRAYSIZE(kUseCandidateFormForSuggest); ++i) {
-    if (kUseCandidateFormForSuggest[i] == class_name) {
-      mode |= CAN_USE_CANDIDATE_FORM_FOR_SUGGEST;
-      break;
+    for (size_t i = 0; i < ARRAYSIZE(kUseCandidateFormForSuggest); ++i) {
+      if (kUseCandidateFormForSuggest[i] == class_name) {
+        mode |= CAN_USE_CANDIDATE_FORM_FOR_SUGGEST;
+        break;
+      }
     }
   }
-}
-}  // namespace win32
 
-{
-  const wchar_t *kUseLocalCoord[] = {
-      L"gdkWindowToplevel",
-      L"SunAwtDialog",
-      L"SunAwtFrame",
-  };
-  for (size_t i = 0; i < ARRAYSIZE(kUseLocalCoord); ++i) {
-    if (kUseLocalCoord[i] == class_name) {
-      mode |= USE_LOCAL_COORD_FOR_CANDIDATE_FORM;
-      break;
+  {
+    const wchar_t *kUseLocalCoord[] = {
+        L"gdkWindowToplevel",
+        L"SunAwtDialog",
+        L"SunAwtFrame",
+    };
+    for (size_t i = 0; i < ARRAYSIZE(kUseLocalCoord); ++i) {
+      if (kUseLocalCoord[i] == class_name) {
+        mode |= USE_LOCAL_COORD_FOR_CANDIDATE_FORM;
+        break;
+      }
     }
   }
-}
 
-{
-  const wchar_t *kIgnoreDefaultCompositionForm[] = {
-      L"SunAwtDialog",
-      L"SunAwtFrame",
-  };
-  for (size_t i = 0; i < ARRAYSIZE(kIgnoreDefaultCompositionForm); ++i) {
-    if (kIgnoreDefaultCompositionForm[i] == class_name) {
-      mode |= IGNORE_DEFAULT_COMPOSITION_FORM;
-      break;
+  {
+    const wchar_t *kIgnoreDefaultCompositionForm[] = {
+        L"SunAwtDialog",
+        L"SunAwtFrame",
+    };
+    for (size_t i = 0; i < ARRAYSIZE(kIgnoreDefaultCompositionForm); ++i) {
+      if (kIgnoreDefaultCompositionForm[i] == class_name) {
+        mode |= IGNORE_DEFAULT_COMPOSITION_FORM;
+        break;
+      }
     }
   }
-}
 
-{
-  const wchar_t *kShowInfolistImmediately[] = {
-      L"Emacs",
-      L"MEADOW",
-  };
-  for (size_t i = 0; i < ARRAYSIZE(kShowInfolistImmediately); ++i) {
-    if (kShowInfolistImmediately[i] == class_name) {
-      mode |= SHOW_INFOLIST_IMMEDIATELY;
-      break;
+  {
+    const wchar_t *kShowInfolistImmediately[] = {
+        L"Emacs",
+        L"MEADOW",
+    };
+    for (size_t i = 0; i < ARRAYSIZE(kShowInfolistImmediately); ++i) {
+      if (kShowInfolistImmediately[i] == class_name) {
+        mode |= SHOW_INFOLIST_IMMEDIATELY;
+        break;
+      }
     }
   }
-}
 
-return mode;
-}  // namespace renderer
+  return mode;
+}
 
 bool LayoutManager::LayoutIndicatorWindow(
     const commands::RendererCommand_ApplicationInfo &app_info,
