@@ -37,8 +37,7 @@
 #include "base/util.h"
 #include "protocol/renderer_command.pb.h"
 #include "renderer/win32/window_manager.h"
-
-using std::unique_ptr;
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 namespace renderer {
@@ -85,7 +84,7 @@ Win32Server::~Win32Server() { ::CloseHandle(event_); }
 void Win32Server::AsyncHide() {
   {
     // Cancel the remaining event
-    scoped_lock l(&mutex_);
+    absl::MutexLock l(&mutex_);
     ::ResetEvent(event_);
   }
   window_manager_->AsyncHideAllWindows();
@@ -94,7 +93,7 @@ void Win32Server::AsyncHide() {
 void Win32Server::AsyncQuit() {
   {
     // Cancel the remaining event
-    scoped_lock l(&mutex_);
+    absl::MutexLock l(&mutex_);
     ::ResetEvent(event_);
   }
   window_manager_->AsyncQuitAllWindows();
@@ -143,10 +142,10 @@ void Win32Server::SetSendCommandInterface(
   window_manager_->SetSendCommandInterface(send_command_interface);
 }
 
-bool Win32Server::AsyncExecCommand(string *proto_message) {
+bool Win32Server::AsyncExecCommand(std::string *proto_message) {
   // Take the ownership of |proto_message|.
-  std::unique_ptr<string> proto_message_owner(proto_message);
-  scoped_lock l(&mutex_);
+  std::unique_ptr<std::string> proto_message_owner(proto_message);
+  absl::MutexLock l(&mutex_);
   if (message_ == *proto_message_owner.get()) {
     // This is exactly the same to the previous message. Theoretically it is
     // safe to do nothing here.
@@ -184,9 +183,9 @@ int Win32Server::StartMessageLoop() {
     if (wait_result == WAIT_OBJECT_0) {
       // "event_" is signaled so that we have to handle the renderer command
       // stored in "message_"
-      string message;
+      std::string message;
       {
-        scoped_lock l(&mutex_);
+        absl::MutexLock l(&mutex_);
         message.assign(message_);
         ::ResetEvent(event_);
       }
