@@ -35,10 +35,10 @@
 #include <memory>
 #include <string>
 
-#include "base/mutex.h"
 #include "base/port.h"
 #include "renderer/renderer_interface.h"
 #include "renderer/renderer_server.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 namespace renderer {
@@ -56,24 +56,27 @@ class WindowManager;
 class Win32Server : public RendererServer, public RendererInterface {
  public:
   Win32Server();
-  virtual ~Win32Server();
-  virtual void AsyncHide();
-  virtual void AsyncQuit();
-  virtual bool Activate();
-  virtual bool IsAvailable() const;
-  virtual bool ExecCommand(const commands::RendererCommand &command);
-  virtual void SetSendCommandInterface(
-      client::SendCommandInterface *send_command_interface);
-  virtual bool AsyncExecCommand(string *proto_message);
-  virtual int StartMessageLoop();
+
+  Win32Server(const Win32Server &) = delete;
+  Win32Server &operator=(const Win32Server &) = delete;
+
+  ~Win32Server() override;
+
+  void AsyncHide() override;
+  void AsyncQuit() override;
+  bool Activate() override;
+  bool IsAvailable() const override;
+  bool ExecCommand(const commands::RendererCommand &command) override;
+  void SetSendCommandInterface(
+      client::SendCommandInterface *send_command_interface) override;
+  bool AsyncExecCommand(std::string *proto_message) override;
+  int StartMessageLoop() override;
 
  private:
-  string message_;
-  Mutex mutex_;
+  std::string message_;
+  absl::Mutex mutex_;
   HANDLE event_;
   std::unique_ptr<WindowManager> window_manager_;
-
-  DISALLOW_COPY_AND_ASSIGN(Win32Server);
 };
 
 }  // namespace win32
