@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,8 @@
 #include "base/port.h"
 
 namespace mozc {
+constexpr size_t kMaxConversionCandidatesSize = 200;
+
 // Protocol buffers, commands::Request and config::Config should be forward
 // declaration instead of include header files.  Otherwise, we need to specify
 // 'hard_dependency' to all affected rules in the GYP files.
@@ -57,6 +59,15 @@ class Config;
 // detailed context information such as commands::Context.
 class ConversionRequest {
  public:
+  enum RequestType {
+    CONVERSION,          // normal conversion
+    REVERSE_CONVERSION,  // reverse conversion
+    PREDICTION,          // show prediction with user tab key
+    SUGGESTION,          // show prediction automatically
+    PARTIAL_PREDICTION,  // show prediction using the text before cursor
+    PARTIAL_SUGGESTION,  // show suggestion using the text before cursor
+  };
+
   enum ComposerKeySelection {
     // Use Composer::GetQueryForConversion() to generate conversion key. This
     // option uses the exact composition which user sees, e.g., "とうk".
@@ -77,8 +88,16 @@ class ConversionRequest {
   ConversionRequest(const composer::Composer *c,
                     const commands::Request *request,
                     const config::Config *config);
+
+  // This class is copyable.
+  ConversionRequest(const ConversionRequest &x);
+  ConversionRequest &operator=(const ConversionRequest &x);
+
   ~ConversionRequest();
 
+  RequestType request_type() const;
+  void set_request_type(RequestType request_type);
+
   bool has_composer() const;
   const composer::Composer &composer() const;
   void set_composer(const composer::Composer *c);
@@ -89,6 +108,9 @@ class ConversionRequest {
   bool create_partial_candidates() const;
   void set_create_partial_candidates(bool value);
 
+  bool enable_user_history_for_conversion() const;
+  void set_enable_user_history_for_conversion(bool value);
+
   ComposerKeySelection composer_key_selection() const;
   void set_composer_key_selection(ComposerKeySelection selection);
 
@@ -98,8 +120,6 @@ class ConversionRequest {
   const config::Config &config() const;
   void set_config(const config::Config *config);
 
-  void CopyFrom(const ConversionRequest &request);
-
   // TODO(noriyukit): Remove these methods after removing skip_slow_rewriters_
   // flag.
   bool skip_slow_rewriters() const;
@@ -107,7 +127,25 @@ class ConversionRequest {
 
   bool IsKanaModifierInsensitiveConversion() const;
 
+  size_t max_conversion_candidates_size() const;
+  void set_max_conversion_candidates_size(size_t value);
+
+  size_t max_user_history_prediction_candidates_size() const;
+  void set_max_user_history_prediction_candidates_size(size_t value);
+
+  size_t max_user_history_prediction_candidates_size_for_zero_query() const;
+  void set_max_user_history_prediction_candidates_size_for_zero_query(
+      size_t value);
+
+  size_t max_dictionary_prediction_candidates_size() const;
+  void set_max_dictionary_prediction_candidates_size(size_t value);
+
+  bool should_call_set_key_in_prediction() const;
+  void set_should_call_set_key_in_prediction(bool value);
+
  private:
+  RequestType request_type_ = CONVERSION;
+
   // Required fields
   // Input composer to generate a key for conversion, suggestion, etc.
   const composer::Composer *composer_;
@@ -118,31 +156,41 @@ class ConversionRequest {
   // Input config.
   const config::Config *config_;
 
+  // Which composer's method to use for conversion key; see the comment around
+  // the definition of ComposerKeySelection above.
+  ComposerKeySelection composer_key_selection_ = CONVERSION_KEY;
+
+  int max_conversion_candidates_size_ = kMaxConversionCandidatesSize;
+  int max_user_history_prediction_candidates_size_ = 3;
+  int max_user_history_prediction_candidates_size_for_zero_query_ = 4;
+  int max_dictionary_prediction_candidates_size_ = 20;
+
   // If true, insert a top candidate from the actual (non-immutable) converter
   // to realtime conversion results. Note that setting this true causes a big
   // performance loss (3 times slower).
-  bool use_actual_converter_for_realtime_conversion_;
-
-  // Which composer's method to use for conversion key; see the comment around
-  // the definition of ComposerKeySelection above.
-  ComposerKeySelection composer_key_selection_;
+  bool use_actual_converter_for_realtime_conversion_ = false;
 
   // Don't use this flag directly. This flag is used by DictionaryPredictor to
   // skip some heavy rewriters, such as UserBoundaryHistoryRewriter and
   // TransliterationRewriter.
   // TODO(noriyukit): Fix such a hacky handling for realtime conversion.
-  bool skip_slow_rewriters_;
+  bool skip_slow_rewriters_ = false;
 
   // If true, partial candidates are created on prediction/suggestion.
   // For example, "私の" is created from composition "わたしのなまえ".
-  bool create_partial_candidates_;
+  bool create_partial_candidates_ = false;
+
+  // If false, stop using user history for conversion.
+  // This is used for supporting CONVERT_WITHOUT_HISTORY command.
+  // Please refer to session/internal/keymap_interface.h
+  bool enable_user_history_for_conversion_ = true;
+
+  // If true, set conversion key to output segments in prediction.
+  bool should_call_set_key_in_prediction_ = false;
 
   // TODO(noriyukit): Moves all the members of Segments that are irrelevant to
-  // this structure, e.g., Segments::user_history_enabled_ and
-  // Segments::request_type_. Also, a key for conversion is eligible to live in
-  // this class.
-
-  DISALLOW_COPY_AND_ASSIGN(ConversionRequest);
+  // this structure, e.g., Segments::request_type_.
+  // Also, a key for conversion is eligible to live in this class.
 };
 
 }  // namespace mozc
