@@ -48,7 +48,7 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/match.h"
 
 namespace mozc {
 namespace {
@@ -74,11 +74,10 @@ void SetSegment(const std::string &key, const std::string &value,
   AddSegment(key, value, segments);
 }
 
-const char kCalculationDescription[] = "計算結果";
+constexpr char kCalculationDescription[] = "計算結果";
 
 bool ContainsCalculatedResult(const Segment::Candidate &candidate) {
-  return candidate.description.find(kCalculationDescription) !=
-         std::string::npos;
+  return absl::StrContains(candidate.description, kCalculationDescription);
 }
 
 // If the segment has a candidate which was inserted by CalculatorRewriter,
@@ -111,7 +110,7 @@ class CalculatorRewriterTest : public ::testing::Test {
   CalculatorMock &calculator_mock() { return calculator_mock_; }
 
   CalculatorRewriter *BuildCalculatorRewriterWithConverterMock() {
-    converter_mock_ = absl::make_unique<ConverterMock>();
+    converter_mock_ = std::make_unique<ConverterMock>();
     return new CalculatorRewriter(converter_mock_.get());
   }
 
@@ -199,9 +198,10 @@ TEST_F(CalculatorRewriterTest, SeparatedSegmentsTest) {
   // Since this test depends on the actual implementation of
   // Converter::ResizeSegments(), we cannot use converter mock here. However,
   // the test itself is independent of data.
-  std::unique_ptr<EngineInterface> engine_(MockDataEngineFactory::Create());
-  std::unique_ptr<CalculatorRewriter> calculator_rewriter(
-      new CalculatorRewriter(engine_->GetConverter()));
+  std::unique_ptr<EngineInterface> engine_ =
+      MockDataEngineFactory::Create().value();
+  auto calculator_rewriter =
+      std::make_unique<CalculatorRewriter>(engine_->GetConverter());
 
   // Push back separated segments.
   Segments segments;
@@ -247,7 +247,7 @@ TEST_F(CalculatorRewriterTest, ExpressionStartingWithEqualTest) {
 
 // Verify the description of calculator candidate.
 TEST_F(CalculatorRewriterTest, DescriptionCheckTest) {
-  const char kExpression[] = "５・（８／４）ー７％３＋６＾−１＊９＝";
+  constexpr char kExpression[] = "５・（８／４）ー７％３＋６＾−１＊９＝";
   // Expected description
   const std::string description = kCalculationDescription;
 
@@ -274,7 +274,8 @@ TEST_F(CalculatorRewriterTest, ConfigTest) {
   // Since this test depends on the actual implementation of
   // Converter::ResizeSegments(), we cannot use converter mock here. However,
   // the test itself is independent of data.
-  std::unique_ptr<EngineInterface> engine_(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine_ =
+      MockDataEngineFactory::Create().value();
   std::unique_ptr<CalculatorRewriter> calculator_rewriter(
       new CalculatorRewriter(engine_->GetConverter()));
   {
@@ -299,7 +300,8 @@ TEST_F(CalculatorRewriterTest, ConfigTest) {
 }
 
 TEST_F(CalculatorRewriterTest, MobileEnvironmentTest) {
-  std::unique_ptr<EngineInterface> engine_(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine_ =
+      MockDataEngineFactory::Create().value();
   std::unique_ptr<CalculatorRewriter> rewriter(
       new CalculatorRewriter(engine_->GetConverter()));
 
@@ -315,7 +317,8 @@ TEST_F(CalculatorRewriterTest, MobileEnvironmentTest) {
 }
 
 TEST_F(CalculatorRewriterTest, EmptyKeyTest) {
-  std::unique_ptr<EngineInterface> engine_(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine_ =
+      MockDataEngineFactory::Create().value();
   std::unique_ptr<CalculatorRewriter> calculator_rewriter(
       new CalculatorRewriter(engine_->GetConverter()));
   {
