@@ -30,6 +30,7 @@
 #include "rewriter/collocation_rewriter.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <vector>
@@ -44,7 +45,7 @@
 #include "rewriter/collocation_util.h"
 #include "storage/existence_filter.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/match.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
 
@@ -55,8 +56,8 @@ namespace mozc {
 using mozc::storage::ExistenceFilter;
 
 namespace {
-const size_t kCandidateSize = 12;
-const int kMaxCostDiff = 3453;  // -500*log(1/1000)
+constexpr size_t kCandidateSize = 12;
+constexpr int kMaxCostDiff = 3453;  // -500*log(1/1000)
 
 // For collocation, we use two segments.
 enum SegmentLookupType {
@@ -101,7 +102,7 @@ bool ParseCompound(const absl::string_view value,
   // Check if the middle part matches |pattern|.
   const absl::string_view remaining_value =
       absl::ClippedSubstr(value, first_content->size());
-  if (!Util::StartsWith(remaining_value, pattern)) {
+  if (!absl::StartsWith(remaining_value, pattern)) {
     return false;
   }
 
@@ -130,29 +131,29 @@ void ResolveCompoundSegment(const std::string &top_value,
                             const std::string &value, SegmentLookupType type,
                             std::vector<std::string> *output) {
   // see "http://ja.wikipedia.org/wiki/助詞"
-  static const char kPat1[] = "が";
+  static constexpr char kPat1[] = "が";
   // "の" was not good...
-  // static const char kPat2[] = "の";
-  static const char kPat3[] = "を";
-  static const char kPat4[] = "に";
-  static const char kPat5[] = "へ";
-  static const char kPat6[] = "と";
-  static const char kPat7[] = "から";
-  static const char kPat8[] = "より";
-  static const char kPat9[] = "で";
+  // static constexpr char kPat2[] = "の";
+  static constexpr char kPat3[] = "を";
+  static constexpr char kPat4[] = "に";
+  static constexpr char kPat5[] = "へ";
+  static constexpr char kPat6[] = "と";
+  static constexpr char kPat7[] = "から";
+  static constexpr char kPat8[] = "より";
+  static constexpr char kPat9[] = "で";
 
   static const struct {
     const char *pat;
     size_t len;
-  } kParticles[] = {{kPat1, arraysize(kPat1) - 1},
-                    //    {kPat2, arraysize(kPat2) - 1},
-                    {kPat3, arraysize(kPat3) - 1},
-                    {kPat4, arraysize(kPat4) - 1},
-                    {kPat5, arraysize(kPat5) - 1},
-                    {kPat6, arraysize(kPat6) - 1},
-                    {kPat7, arraysize(kPat7) - 1},
-                    {kPat8, arraysize(kPat8) - 1},
-                    {kPat9, arraysize(kPat9) - 1},
+  } kParticles[] = {{kPat1, std::size(kPat1) - 1},
+                    //    {kPat2, std::size(kPat2) - 1},
+                    {kPat3, std::size(kPat3) - 1},
+                    {kPat4, std::size(kPat4) - 1},
+                    {kPat5, std::size(kPat5) - 1},
+                    {kPat6, std::size(kPat6) - 1},
+                    {kPat7, std::size(kPat7) - 1},
+                    {kPat8, std::size(kPat8) - 1},
+                    {kPat9, std::size(kPat9) - 1},
                     {nullptr, 0}};
 
   for (size_t i = 0; kParticles[i].pat != nullptr; ++i) {
@@ -196,8 +197,8 @@ bool IsNaturalContent(const Segment::Candidate &cand,
     output->push_back(content);
     // "舞って" workaround
     // V+"て" is often treated as one compound.
-    static const char kPat[] = "て";
-    if (Util::EndsWith(content, absl::string_view(kPat, arraysize(kPat) - 1))) {
+    static constexpr char kPat[] = "て";
+    if (absl::EndsWith(content, absl::string_view(kPat, std::size(kPat) - 1))) {
       PushBackStringView(Util::Utf8SubString(content, 0, content_len - 1),
                          output);
     }
@@ -225,7 +226,7 @@ bool IsNaturalContent(const Segment::Candidate &cand,
     const char *begin = top_content.data();
     const char *end = top_content.data() + top_content.size();
     size_t mblen = 0;
-    const char32 wchar = Util::UTF8ToUCS4(begin, end, &mblen);
+    const char32 wchar = Util::Utf8ToUcs4(begin, end, &mblen);
 
     switch (wchar) {
       case 0x304a:  // "お"
@@ -263,11 +264,11 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXいる|>" can be rewrote to "<YY|いる>" and vice versa
   {
-    static const char kPat[] = "いる";  // "いる"
-    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
+    static constexpr char kPat[] = "いる";  // "いる"
+    const absl::string_view kSuffix(kPat, std::size(kPat) - 1);
     if (top_aux_value_len == 0 && aux_value_len == 2 &&
-        Util::EndsWith(top_value, kSuffix) &&
-        Util::EndsWith(aux_value, kSuffix)) {
+        absl::EndsWith(top_value, kSuffix) &&
+        absl::EndsWith(aux_value, kSuffix)) {
       if (type == RIGHT) {
         // "YYいる" in addition to "YY"
         output->push_back(value);
@@ -275,8 +276,8 @@ bool IsNaturalContent(const Segment::Candidate &cand,
       return true;
     }
     if (aux_value_len == 0 && top_aux_value_len == 2 &&
-        Util::EndsWith(value, kSuffix) &&
-        Util::EndsWith(top_aux_value, kSuffix)) {
+        absl::EndsWith(value, kSuffix) &&
+        absl::EndsWith(top_aux_value, kSuffix)) {
       if (type == RIGHT) {
         // "YY" in addition to "YYいる"
         PushBackStringView(Util::Utf8SubString(value, 0, value_len - 2),
@@ -288,11 +289,11 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXせる|>" can be rewrote to "<YY|せる>" and vice versa
   {
-    const char kPat[] = "せる";
-    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
+    constexpr char kPat[] = "せる";
+    const absl::string_view kSuffix(kPat, std::size(kPat) - 1);
     if (top_aux_value_len == 0 && aux_value_len == 2 &&
-        Util::EndsWith(top_value, kSuffix) &&
-        Util::EndsWith(aux_value, kSuffix)) {
+        absl::EndsWith(top_value, kSuffix) &&
+        absl::EndsWith(aux_value, kSuffix)) {
       if (type == RIGHT) {
         // "YYせる" in addition to "YY"
         output->push_back(value);
@@ -300,8 +301,8 @@ bool IsNaturalContent(const Segment::Candidate &cand,
       return true;
     }
     if (aux_value_len == 0 && top_aux_value_len == 2 &&
-        Util::EndsWith(value, kSuffix) &&
-        Util::EndsWith(top_aux_value, kSuffix)) {
+        absl::EndsWith(value, kSuffix) &&
+        absl::EndsWith(top_aux_value, kSuffix)) {
       if (type == RIGHT) {
         // "YY" in addition to "YYせる"
         PushBackStringView(Util::Utf8SubString(value, 0, value_len - 2),
@@ -316,9 +317,9 @@ bool IsNaturalContent(const Segment::Candidate &cand,
   // "<XX|する>" can be rewrote using "<XXす|る>" and "<XX|する>"
   // in "<XX|する>", XX must be single script type
   {
-    static const char kPat[] = "する";
-    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
-    if (aux_value_len == 2 && Util::EndsWith(aux_value, kSuffix)) {
+    static constexpr char kPat[] = "する";
+    const absl::string_view kSuffix(kPat, std::size(kPat) - 1);
+    if (aux_value_len == 2 && absl::EndsWith(aux_value, kSuffix)) {
       if (content_script_type != Util::KATAKANA &&
           content_script_type != Util::HIRAGANA &&
           content_script_type != Util::KANJI &&
@@ -337,9 +338,9 @@ bool IsNaturalContent(const Segment::Candidate &cand,
   // "<XXる>" can be rewrote using "<XX|る>"
   // "まとめる", "衰える"
   {
-    static const char kPat[] = "る";
-    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
-    if (aux_value_len == 0 && Util::EndsWith(value, kSuffix)) {
+    static constexpr char kPat[] = "る";
+    const absl::string_view kSuffix(kPat, std::size(kPat) - 1);
+    if (aux_value_len == 0 && absl::EndsWith(value, kSuffix)) {
       if (type == RIGHT) {
         // "YY" in addition to "YYる"
         PushBackStringView(Util::Utf8SubString(value, 0, value_len - 1),
@@ -351,16 +352,16 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXす>" can be rewrote using "XXする"
   {
-    static const char kPat[] = "す";
-    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
-    if (Util::EndsWith(value, kSuffix) &&
+    static constexpr char kPat[] = "す";
+    const absl::string_view kSuffix(kPat, std::size(kPat) - 1);
+    if (absl::EndsWith(value, kSuffix) &&
         Util::IsScriptType(Util::Utf8SubString(value, 0, value_len - 1),
                            Util::KANJI)) {
       if (type == RIGHT) {
-        const char kRu[] = "る";
+        constexpr char kRu[] = "る";
         // "YYする" in addition to "YY"
         output->push_back(
-            absl::StrCat(value, absl::string_view(kRu, arraysize(kRu) - 1)));
+            absl::StrCat(value, absl::string_view(kRu, std::size(kRu) - 1)));
       }
       return true;
     }
@@ -368,10 +369,10 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXし|た>" can be rewrote using "<XX|した>"
   {
-    static const char kPat[] = "した";
+    static constexpr char kPat[] = "した";
     const absl::string_view kShi(kPat, 3), kTa(kPat + 3, 3);
-    if (Util::EndsWith(content, kShi) && aux_value == kTa &&
-        Util::EndsWith(top_content, kShi) && top_aux_value == kTa) {
+    if (absl::EndsWith(content, kShi) && aux_value == kTa &&
+        absl::EndsWith(top_content, kShi) && top_aux_value == kTa) {
       if (type == RIGHT) {
         const absl::string_view val =
             Util::Utf8SubString(content, 0, content_len - 1);
@@ -515,7 +516,7 @@ class CollocationRewriter::CollocationFilter {
     std::string key;
     key.reserve(left.size() + right.size());
     key.assign(left).append(right);
-    const uint64 id = Hash::Fingerprint(key);
+    const uint64_t id = Hash::Fingerprint(key);
     return filter_->Exists(id);
   }
 
@@ -537,7 +538,7 @@ class CollocationRewriter::SuppressionFilter {
     std::string key;
     key.reserve(cand.content_value.size() + 1 + cand.content_key.size());
     key.assign(cand.content_value).append("\t").append(cand.content_key);
-    const uint64 id = Hash::Fingerprint(key);
+    const uint64_t id = Hash::Fingerprint(key);
     return filter_->Exists(id);
   }
 
@@ -549,17 +550,17 @@ class CollocationRewriter::SuppressionFilter {
 
 CollocationRewriter::CollocationRewriter(
     const DataManagerInterface *data_manager)
-    : pos_matcher_(data_manager->GetPOSMatcherData()),
+    : pos_matcher_(data_manager->GetPosMatcherData()),
       first_name_id_(pos_matcher_.GetFirstNameId()),
       last_name_id_(pos_matcher_.GetLastNameId()) {
   const char *data = nullptr;
   size_t size = 0;
 
   data_manager->GetCollocationData(&data, &size);
-  collocation_filter_ = absl::make_unique<CollocationFilter>(data, size);
+  collocation_filter_ = std::make_unique<CollocationFilter>(data, size);
 
   data_manager->GetCollocationSuppressionData(&data, &size);
-  suppression_filter_ = absl::make_unique<SuppressionFilter>(data, size);
+  suppression_filter_ = std::make_unique<SuppressionFilter>(data, size);
 }
 
 CollocationRewriter::~CollocationRewriter() {}
