@@ -30,6 +30,7 @@
 #include "rewriter/collocation_rewriter.h"
 
 #include <cstddef>
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -42,12 +43,11 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace {
 
-using dictionary::POSMatcher;
+using dictionary::PosMatcher;
 
 class CollocationRewriterTest : public ::testing::Test {
  protected:
@@ -58,9 +58,9 @@ class CollocationRewriterTest : public ::testing::Test {
     const char *content_key;
     const char *value;
     const char *content_value;
-    const int32 cost;
-    const uint16 lid;
-    const uint16 rid;
+    const int32_t cost;
+    const uint16_t lid;
+    const uint16_t rid;
   };
 
   // Used to generate Segment.
@@ -83,9 +83,9 @@ class CollocationRewriterTest : public ::testing::Test {
     SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
 
     const mozc::testing::MockDataManager data_manager;
-    pos_matcher_.Set(data_manager.GetPOSMatcherData());
+    pos_matcher_.Set(data_manager.GetPosMatcherData());
     collocation_rewriter_ =
-        absl::make_unique<CollocationRewriter>(&data_manager);
+        std::make_unique<CollocationRewriter>(&data_manager);
   }
 
   // Makes a segment from SegmentData.
@@ -129,7 +129,7 @@ class CollocationRewriterTest : public ::testing::Test {
     return result;
   }
 
-  POSMatcher pos_matcher_;
+  PosMatcher pos_matcher_;
 
  private:
   std::unique_ptr<const CollocationRewriter> collocation_rewriter_;
@@ -145,7 +145,7 @@ TEST_F(CollocationRewriterTest, NekowoKaitai) {
   //         | "飼いたい"
   const char *kNekowo = "ねこを";
   const char *kNeko = "ねこ";
-  const uint16 id = pos_matcher_.GetUnknownId();
+  const uint16_t id = pos_matcher_.GetUnknownId();
   const CandidateData kNekowoCands[] = {
       {kNekowo, kNeko, "ネコを", "ネコを", 0, id, id},
       {kNekowo, kNeko, "猫を", "猫を", 0, id, id},
@@ -160,10 +160,10 @@ TEST_F(CollocationRewriterTest, NekowoKaitai) {
       {kKaitaiHiragana, kKaitaiHiragana, kFeed, kFeed, 0, id, id},
   };
   const SegmentData kSegmentData[] = {
-      {kNekowo, kNekowoCands, arraysize(kNekowoCands)},
-      {kKaitaiHiragana, kKaitaiCands, arraysize(kKaitaiCands)},
+      {kNekowo, kNekowoCands, std::size(kNekowoCands)},
+      {kKaitaiHiragana, kKaitaiCands, std::size(kKaitaiCands)},
   };
-  const SegmentsData kSegments = {kSegmentData, arraysize(kSegmentData)};
+  const SegmentsData kSegments = {kSegmentData, std::size(kSegmentData)};
 
   Segments segments;
   MakeSegments(kSegments, &segments);
@@ -182,7 +182,7 @@ TEST_F(CollocationRewriterTest, MagurowoKaitai) {
   //          | "飼いたい"
   const char *kMagurowo = "まぐろを";
   const char *kMaguro = "まぐろ";
-  const uint16 id = pos_matcher_.GetUnknownId();
+  const uint16_t id = pos_matcher_.GetUnknownId();
   const CandidateData kMagurowoCands[] = {
       {kMagurowo, kMaguro, "マグロを", "マグロ", 0, id, id},
       {kMagurowo, kMaguro, "鮪を", "鮪", 0, id, id},
@@ -197,10 +197,10 @@ TEST_F(CollocationRewriterTest, MagurowoKaitai) {
       {kKaitaiHiragana, kKaitaiHiragana, kFeed, kFeed, 0, id, id},
   };
   const SegmentData kSegmentData[] = {
-      {kMagurowo, kMagurowoCands, arraysize(kMagurowoCands)},
-      {kKaitaiHiragana, kKaitaiCands, arraysize(kKaitaiCands)},
+      {kMagurowo, kMagurowoCands, std::size(kMagurowoCands)},
+      {kKaitaiHiragana, kKaitaiCands, std::size(kKaitaiCands)},
   };
-  const SegmentsData kSegments = {kSegmentData, arraysize(kSegmentData)};
+  const SegmentsData kSegments = {kSegmentData, std::size(kSegmentData)};
 
   Segments segments;
   MakeSegments(kSegments, &segments);
@@ -216,14 +216,14 @@ TEST_F(CollocationRewriterTest, CrossOverAdverbSegment) {
   // "かいたい"  | "買いたい" "解体" "飼いたい"
   const char *kNekowo = "ねこを";
   const char *kNeko = "ねこ";
-  const uint16 id = pos_matcher_.GetUnknownId();
+  const uint16_t id = pos_matcher_.GetUnknownId();
   const CandidateData kNekowoCands[] = {
       {kNekowo, kNeko, "ネコを", "ネコを", 0, id, id},
       {kNekowo, kNeko, "猫を", "猫を", 0, id, id},
   };
 
   const char *kSugoku = "すごく";
-  const uint16 adverb_id = pos_matcher_.GetAdverbId();
+  const uint16_t adverb_id = pos_matcher_.GetAdverbId();
   const CandidateData kSugokuCands[] = {
       {kSugoku, kSugoku, kSugoku, kSugoku, 0, adverb_id, adverb_id},
   };
@@ -238,11 +238,11 @@ TEST_F(CollocationRewriterTest, CrossOverAdverbSegment) {
       {kKaitaiHiragana, kKaitaiHiragana, kFeed, kFeed, 0, id, id},
   };
   const SegmentData kSegmentData[] = {
-      {kNekowo, kNekowoCands, arraysize(kNekowoCands)},
-      {kSugoku, kSugokuCands, arraysize(kSugokuCands)},
-      {kKaitaiHiragana, kKaitaiCands, arraysize(kKaitaiCands)},
+      {kNekowo, kNekowoCands, std::size(kNekowoCands)},
+      {kSugoku, kSugokuCands, std::size(kSugokuCands)},
+      {kKaitaiHiragana, kKaitaiCands, std::size(kKaitaiCands)},
   };
-  const SegmentsData kSegments = {kSegmentData, arraysize(kSegmentData)};
+  const SegmentsData kSegments = {kSegmentData, std::size(kSegmentData)};
 
   Segments segments;
   MakeSegments(kSegments, &segments);
@@ -259,7 +259,7 @@ TEST_F(CollocationRewriterTest, DoNotCrossOverNonAdverbSegment) {
   // "かいたい"  | "買いたい" "解体" "飼いたい"
   const char *kNekowo = "ねこを";
   const char *kNeko = "ねこ";
-  const uint16 id = pos_matcher_.GetUnknownId();
+  const uint16_t id = pos_matcher_.GetUnknownId();
   const CandidateData kNekowoCands[] = {
       {kNekowo, kNeko, "ネコを", "ネコを", 0, id, id},
       {kNekowo, kNeko, "猫を", "猫を", 0, id, id},
@@ -280,11 +280,11 @@ TEST_F(CollocationRewriterTest, DoNotCrossOverNonAdverbSegment) {
       {kKaitaiHiragana, kKaitaiHiragana, kFeed, kFeed, 0, id, id},
   };
   const SegmentData kSegmentData[] = {
-      {kNekowo, kNekowoCands, arraysize(kNekowoCands)},
-      {kSugoku, kSugokuCands, arraysize(kSugokuCands)},
-      {kKaitaiHiragana, kKaitaiCands, arraysize(kKaitaiCands)},
+      {kNekowo, kNekowoCands, std::size(kNekowoCands)},
+      {kSugoku, kSugokuCands, std::size(kSugokuCands)},
+      {kKaitaiHiragana, kKaitaiCands, std::size(kKaitaiCands)},
   };
-  const SegmentsData kSegments = {kSegmentData, arraysize(kSegmentData)};
+  const SegmentsData kSegments = {kSegmentData, std::size(kSegmentData)};
 
   Segments segments;
   MakeSegments(kSegments, &segments);
@@ -308,7 +308,7 @@ TEST_F(CollocationRewriterTest, DoNotPromoteHighCostCandidate) {
   //         | "飼いたい" (high cost)
   const char *kNekowo = "ねこを";
   const char *kNeko = "ねこ";
-  const uint16 id = pos_matcher_.GetUnknownId();
+  const uint16_t id = pos_matcher_.GetUnknownId();
   const CandidateData kNekowoCands[] = {
       {kNekowo, kNeko, "ネコを", "ネコを", 0, id, id},
       {kNekowo, kNeko, "猫を", "猫を", 0, id, id},
@@ -323,10 +323,10 @@ TEST_F(CollocationRewriterTest, DoNotPromoteHighCostCandidate) {
       {kKaitaiHiragana, kKaitaiHiragana, kFeed, kFeed, 10000, id, id},
   };
   const SegmentData kSegmentData[] = {
-      {kNekowo, kNekowoCands, arraysize(kNekowoCands)},
-      {kKaitaiHiragana, kKaitaiCands, arraysize(kKaitaiCands)},
+      {kNekowo, kNekowoCands, std::size(kNekowoCands)},
+      {kKaitaiHiragana, kKaitaiCands, std::size(kKaitaiCands)},
   };
-  const SegmentsData kSegments = {kSegmentData, arraysize(kSegmentData)};
+  const SegmentsData kSegments = {kSegmentData, std::size(kSegmentData)};
 
   Segments segments;
   MakeSegments(kSegments, &segments);
