@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -86,7 +86,7 @@ void CollocationUtil::RemoveExtraCharacters(const absl::string_view input,
         w == 0x0025 || w == 0xFF05 ||  // "%", "％"
         w == 0x3006 ||                 // "〆"
         w == 0x301C || w == 0xFF5E) {  // "〜", "～"
-      Util::UCS4ToUTF8Append(w, output);
+      Util::Ucs4ToUtf8Append(w, output);
     }
   }
 }
