@@ -42,9 +42,9 @@
 namespace mozc {
 namespace {
 
-const char kPrefix[] = "【";
-const char kSuffix[] = "】";
-const char kDescription[] = "設定を変更します";
+constexpr char kPrefix[] = "【";
+constexpr char kSuffix[] = "】";
+constexpr char kDescription[] = "設定を変更します";
 
 // Trigger CommandRewriter if and only if the Segment::key is one of
 // kTriggerKeys[]
@@ -66,12 +66,12 @@ const char *kDisableAllSuggestionValues[] = {"サジェスト",         "予測"
                                              "予測入力",           "予測変換",
                                              "プレゼンテーション", "プレゼン"};
 
-const char kIncoginitoModeOn[] = "シークレットモードをオン";
-const char kIncoginitoModeOff[] = "シークレットモードをオフ";
-const char kDisableAllSuggestionOn[] = "サジェスト機能の一時停止";
-const char kDisableAllSuggestionOff[] = "サジェスト機能を元に戻す";
+constexpr char kIncoginitoModeOn[] = "シークレットモードをオン";
+constexpr char kIncoginitoModeOff[] = "シークレットモードをオフ";
+constexpr char kDisableAllSuggestionOn[] = "サジェスト機能の一時停止";
+constexpr char kDisableAllSuggestionOff[] = "サジェスト機能を元に戻す";
 
-bool FindString(const string &query, const char **values, size_t size) {
+bool FindString(const std::string &query, const char **values, size_t size) {
   DCHECK(values);
   DCHECK_GT(size, 0);
   for (size_t i = 0; i < size; ++i) {
@@ -89,7 +89,7 @@ Segment::Candidate *InsertCommandCandidate(Segment *segment,
   Segment::Candidate *candidate = segment->insert_candidate(
       std::min(segment->candidates_size(), insert_pos));
   DCHECK(candidate);
-  candidate->CopyFrom(segment->candidate(reference_pos));
+  *candidate = segment->candidate(reference_pos);
   candidate->attributes |= Segment::Candidate::COMMAND_CANDIDATE;
   candidate->attributes |= Segment::Candidate::NO_LEARNING;
   candidate->description = kDescription;
@@ -152,20 +152,20 @@ bool CommandRewriter::RewriteSegment(const config::Config &config,
   DCHECK(segment);
 
   for (size_t i = 0; i < segment->candidates_size(); ++i) {
-    const string &value = segment->candidate(i).value;
-    if (FindString(value, kCommandValues, arraysize(kCommandValues))) {
+    const std::string &value = segment->candidate(i).value;
+    if (FindString(value, kCommandValues, std::size(kCommandValues))) {
       // insert command candidate at an fixed position.
       InsertDisableAllSuggestionToggleCommand(config, segment, i, 6);
       InsertIncognitoModeToggleCommand(config, segment, i, 6);
       return true;
     }
     if (FindString(value, kIncognitoModeValues,
-                   arraysize(kIncognitoModeValues))) {
+                   std::size(kIncognitoModeValues))) {
       InsertIncognitoModeToggleCommand(config, segment, i, i + 3);
       return true;
     }
     if (FindString(value, kDisableAllSuggestionValues,
-                   arraysize(kDisableAllSuggestionValues))) {
+                   std::size(kDisableAllSuggestionValues))) {
       InsertDisableAllSuggestionToggleCommand(config, segment, i, i + 3);
       return true;
     }
@@ -182,11 +182,11 @@ bool CommandRewriter::Rewrite(const ConversionRequest &request,
 
   Segment *segment = segments->mutable_conversion_segment(0);
   DCHECK(segment);
-  const string &key = segment->key();
+  const std::string &key = segment->key();
 
   // TODO(taku): we want to replace the linear search with STL map when
   // kTriggerKeys become bigger.
-  if (!FindString(key, kTriggerKeys, arraysize(kTriggerKeys))) {
+  if (!FindString(key, kTriggerKeys, std::size(kTriggerKeys))) {
     return false;
   }
 
