@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,6 +30,7 @@
 #include "rewriter/correction_rewriter.h"
 
 #include <algorithm>
+#include <memory>
 #include <string>
 #include <vector>
 
@@ -57,7 +58,7 @@ void CorrectionRewriter::SetCandidate(const ReadingCorrectionItem &item,
 }
 
 bool CorrectionRewriter::LookupCorrection(
-    const string &key, const string &value,
+    const std::string &key, const std::string &value,
     std::vector<ReadingCorrectionItem> *results) const {
   CHECK(results);
   results->clear();
@@ -89,13 +90,14 @@ CorrectionRewriter::CorrectionRewriter(
 }
 
 // static
-CorrectionRewriter *CorrectionRewriter::CreateCorrectionRewriter(
+std::unique_ptr<CorrectionRewriter>
+CorrectionRewriter::CreateCorrectionRewriter(
     const DataManagerInterface *data_manager) {
   absl::string_view value_array_data, error_array_data, correction_array_data;
   data_manager->GetReadingCorrectionData(&value_array_data, &error_array_data,
                                          &correction_array_data);
-  return new CorrectionRewriter(value_array_data, error_array_data,
-                                correction_array_data);
+  return std::make_unique<CorrectionRewriter>(
+      value_array_data, error_array_data, correction_array_data);
 }
 
 CorrectionRewriter::~CorrectionRewriter() = default;
@@ -139,7 +141,7 @@ bool CorrectionRewriter::Rewrite(const ConversionRequest &request,
     // defined in the tsv file, we want to add miss-read entries to
     // the system dictionary.
     const size_t kInsertPosition =
-        std::min(static_cast<size_t>(3), segment->candidates_size());
+        std::min<size_t>(3, segment->candidates_size());
     const Segment::Candidate &top_candidate = segment->candidate(0);
     if (!LookupCorrection(top_candidate.content_key, "", &results)) {
       continue;
@@ -148,11 +150,13 @@ bool CorrectionRewriter::Rewrite(const ConversionRequest &request,
       Segment::Candidate *mutable_candidate =
           segment->insert_candidate(kInsertPosition);
       DCHECK(mutable_candidate);
-      mutable_candidate->CopyFrom(top_candidate);
-      Util::ConcatStrings(results[k].error, top_candidate.functional_key(),
-                          &mutable_candidate->key);
-      Util::ConcatStrings(results[k].value, top_candidate.functional_value(),
-                          &mutable_candidate->value);
+      *mutable_candidate = top_candidate;
+      mutable_candidate->key.clear();
+      mutable_candidate->value.clear();
+      absl::StrAppend(&mutable_candidate->key, results[k].error,
+                      top_candidate.functional_key());
+      absl::StrAppend(&mutable_candidate->value, results[k].value,
+                      top_candidate.functional_value());
       mutable_candidate->inner_segment_boundary.clear();
       SetCandidate(results[k], mutable_candidate);
       modified = true;
