@@ -29,6 +29,7 @@
 
 #include "rewriter/correction_rewriter.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -40,7 +41,6 @@
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -79,7 +79,7 @@ class CorrectionRewriterTest : public testing::Test {
     const std::vector<absl::string_view> values = {"TSUKIGIME"};
     const std::vector<absl::string_view> errors = {"gekkyoku"};
     const std::vector<absl::string_view> corrections = {"tsukigime"};
-    rewriter_ = absl::make_unique<CorrectionRewriter>(
+    rewriter_ = std::make_unique<CorrectionRewriter>(
         SerializedStringArray::SerializeToBuffer(values, &values_buf_),
         SerializedStringArray::SerializeToBuffer(errors, &errors_buf_),
         SerializedStringArray::SerializeToBuffer(corrections,
@@ -94,9 +94,9 @@ class CorrectionRewriterTest : public testing::Test {
   config::Config config_;
 
  private:
-  std::unique_ptr<uint32[]> values_buf_;
-  std::unique_ptr<uint32[]> errors_buf_;
-  std::unique_ptr<uint32[]> corrections_buf_;
+  std::unique_ptr<uint32_t[]> values_buf_;
+  std::unique_ptr<uint32_t[]> errors_buf_;
+  std::unique_ptr<uint32_t[]> corrections_buf_;
 };
 
 TEST_F(CorrectionRewriterTest, CapabilityTest) {
