@@ -38,11 +38,14 @@
 #include "rewriter/date_rewriter.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <cstdio>
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "base/clock.h"
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/number_util.h"
 #include "base/util.h"
@@ -53,7 +56,10 @@
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
+#include "absl/strings/match.h"
 #include "absl/strings/str_cat.h"
+#include "absl/strings/str_format.h"
+#include "absl/strings/str_replace.h"
 #include "absl/strings/string_view.h"
 #include "absl/time/time.h"
 
@@ -126,12 +132,12 @@ const struct DateRewriter::DateData kDateData[] = {
 // Absl::Weekday starts from Monday, while std::tm.tm_wday starts from Sunday.
 const char *kWeekDayString[] = {"月", "火", "水", "木", "金", "土", "日"};
 
-const char kDateDescription[] = "日付";
-const char kTimeDescription[] = "時刻";
+constexpr char kDateDescription[] = "日付";
+constexpr char kTimeDescription[] = "時刻";
 
 struct YearData {
   int ad;           // AD year
-  const char *era;  // Japanese year a.k.a, GENGO
+  const char *era;  // Japanese year a.k.a., GENGO
   const char *key;  // reading of the `era`
 };
 
@@ -371,6 +377,7 @@ const YearData kEraData[] = {
     {2019, "令和", "れいわ"}};
 
 const YearData kNorthEraData[] = {
+    // clang-format off
     // "元徳", "建武" and "明徳" are used for both south and north courts.
     {1329, "元徳", "げんとく"},
     {1332, "正慶", "しょうけい"},
@@ -390,36 +397,37 @@ const YearData kNorthEraData[] = {
     {1384, "至徳", "しとく"},
     {1387, "嘉慶", "かけい"},
     {1389, "康応", "こうおう"},
-    {1390, "明徳", "めいとく"}};
+    {1390, "明徳", "めいとく"},
+    // clang-format on
+};
 
-bool PrintUint32(const char *format, uint32 num, char *buf, size_t buf_size) {
+bool PrintUint32(const char *format, uint32_t num, char *buf, size_t buf_size) {
   const int ret = std::snprintf(buf, buf_size, format, num);
   return 0 <= ret && ret < buf_size;
 }
 
 // Helper function to generate "H時M分" time formats.
 void GenerateKanjiTimeFormats(
-    const char *hour_format, const char *min_format, uint32 hour, uint32 min,
-    std::vector<std::pair<std::string, const char *>> *results) {
+    const char *hour_format, const char *min_format, uint32_t hour,
+    uint32_t min, std::vector<std::pair<std::string, const char *>> *results) {
   char hour_s[4], min_s[4];
   if (!PrintUint32(hour_format, hour, hour_s, 4) ||
       !PrintUint32(min_format, min, min_s, 4)) {
     return;
   }
-  results->emplace_back(Util::StringPrintf("%s時%s分", hour_s, min_s),
+  results->emplace_back(absl::StrFormat("%s時%s分", hour_s, min_s),
                         kTimeDescription);
   // "H時半".  Don't generate it when the printed hour starts with 0 because
   // formats like "03時半" is rarely used (but "3時半" is ok).
   if (hour_s[0] != '0' && min == 30) {
-    results->emplace_back(Util::StringPrintf("%s時半", hour_s),
-                          kTimeDescription);
+    results->emplace_back(absl::StrFormat("%s時半", hour_s), kTimeDescription);
   }
 }
 
 // Helper function to generate "午前..." and "午後..." time formats.
 void GenerateGozenGogoTimeFormats(
-    const char *hour_format, const char *min_format, uint32 hour, uint32 min,
-    std::vector<std::pair<std::string, const char *>> *results) {
+    const char *hour_format, const char *min_format, uint32_t hour,
+    uint32_t min, std::vector<std::pair<std::string, const char *>> *results) {
   // "午前" and "午後" prefixes are only used for [0, 11].
   if (hour >= 12) {
     return;
@@ -429,17 +437,17 @@ void GenerateGozenGogoTimeFormats(
       !PrintUint32(min_format, min, min_s, 4)) {
     return;
   }
-  results->emplace_back(Util::StringPrintf("午前%s時%s分", hour_s, min_s),
+  results->emplace_back(absl::StrFormat("午前%s時%s分", hour_s, min_s),
                         kTimeDescription);
   if (min == 30) {
-    results->emplace_back(Util::StringPrintf("午前%s時半", hour_s),
+    results->emplace_back(absl::StrFormat("午前%s時半", hour_s),
                           kTimeDescription);
   }
 
-  results->emplace_back(Util::StringPrintf("午後%s時%s分", hour_s, min_s),
+  results->emplace_back(absl::StrFormat("午後%s時%s分", hour_s, min_s),
                         kTimeDescription);
   if (min == 30) {
-    results->emplace_back(Util::StringPrintf("午後%s時半", hour_s),
+    results->emplace_back(absl::StrFormat("午後%s時半", hour_s),
                           kTimeDescription);
   }
 }
@@ -482,24 +490,23 @@ bool ExpandYear(const std::string &prefix, int year,
   return true;
 }
 
-void Insert(const Segment::Candidate &base_candidate, int position,
-            const std::string &value, const char *description,
-            Segment *segment) {
-  position = std::min(position, static_cast<int>(segment->candidates_size()));
-  Segment::Candidate *c = segment->insert_candidate(position);
-  DCHECK(c);
-  c->Init();
-  c->lid = base_candidate.lid;
-  c->rid = base_candidate.rid;
-  c->cost = base_candidate.cost;
-  c->value = value;
-  c->key = base_candidate.key;
-  c->content_key = base_candidate.content_key;
-  c->attributes |= Segment::Candidate::NO_LEARNING;
-  c->attributes |= Segment::Candidate::NO_VARIANTS_EXPANSION;
+std::unique_ptr<Segment::Candidate> CreateCandidate(
+    const Segment::Candidate &base_candidate, const std::string &value,
+    const char *description) {
+  auto candidate = std::make_unique<Segment::Candidate>();
+  candidate->Init();
+  candidate->lid = base_candidate.lid;
+  candidate->rid = base_candidate.rid;
+  candidate->cost = base_candidate.cost;
+  candidate->value = value;
+  candidate->key = base_candidate.key;
+  candidate->content_key = base_candidate.content_key;
+  candidate->attributes |= (Segment::Candidate::NO_LEARNING |
+                            Segment::Candidate::NO_VARIANTS_EXPANSION);
   if (description != nullptr) {
-    c->description = description;
+    candidate->description = description;
   }
+  return candidate;
 }
 
 bool AdToEraForCourt(const YearData *data, int size, int year,
@@ -529,17 +536,17 @@ bool AdToEraForCourt(const YearData *data, int size, int year,
   return false;
 }
 
-const char kNenKey[] = "ねん";
-const char kNenValue[] = "年";
+constexpr char kNenKey[] = "ねん";
+constexpr char kNenValue[] = "年";
 
 bool ExtractYearFromKey(const YearData &year_data, const std::string &key,
                         int *year, std::string *description) {
-  const char kGanKey[] = "がん";
-  const char kGanValue[] = "元";
+  constexpr char kGanKey[] = "がん";
+  constexpr char kGanValue[] = "元";
 
-  // Util::EndsWith(key, kNenKey) is expected to always return true
-  DCHECK(Util::EndsWith(key, kNenKey));
-  if (!Util::StartsWith(key, year_data.key)) {
+  // absl::EndsWith(key, kNenKey) is expected to always return true
+  DCHECK(absl::EndsWith(key, kNenKey));
+  if (!absl::StartsWith(key, year_data.key)) {
     return false;
   }
   // key="しょうわ59ねん" -> era_year_str="59"
@@ -571,14 +578,14 @@ bool ExtractYearFromKey(const YearData &year_data, const std::string &key,
 bool EraToAdForCourt(const YearData *data, size_t size, const std::string &key,
                      std::vector<std::string> *results,
                      std::vector<std::string> *descriptions) {
-  if (!Util::EndsWith(key, kNenKey)) {
+  if (!absl::EndsWith(key, kNenKey)) {
     return false;
   }
 
   bool modified = false;
   for (size_t i = 0; i < size; ++i) {
     const YearData &year_data = data[i];
-    if (!Util::StartsWith(key, year_data.key)) {
+    if (!absl::StartsWith(key, year_data.key)) {
       continue;
     }
 
@@ -619,14 +626,14 @@ bool EraToAdForCourt(const YearData *data, size_t size, const std::string &key,
 // Checkes if the given date is valid or not.
 // Over 24 hour expression is allowed in this function.
 // Acceptable hour is between 0 and 29.
-bool IsValidTime(uint32 hour, uint32 minute) {
+bool IsValidTime(uint32_t hour, uint32_t minute) {
   return hour < 30 && minute < 60;
 }
 
 // Returns February last day.
 // This function deals with leap year with Gregorian calendar.
-uint32 GetFebruaryLastDay(uint32 year) {
-  uint32 february_end = (year % 4 == 0) ? 29 : 28;
+uint32_t GetFebruaryLastDay(uint32_t year) {
+  uint32_t february_end = (year % 4 == 0) ? 29 : 28;
   if (year % 100 == 0 && year % 400 != 0) {
     february_end = 28;
   }
@@ -634,7 +641,7 @@ uint32 GetFebruaryLastDay(uint32 year) {
 }
 
 // Checkes given date is valid or not.
-bool IsValidDate(uint32 year, uint32 month, uint32 day) {
+bool IsValidDate(uint32_t year, uint32_t month, uint32_t day) {
   if (day < 1) {
     return false;
   }
@@ -681,7 +688,7 @@ bool IsValidDate(uint32 year, uint32 month, uint32 day) {
 }
 
 // Checks if a pair of month and day is valid.
-bool IsValidMonthAndDay(uint32 month, uint32 day) {
+bool IsValidMonthAndDay(uint32_t month, uint32_t day) {
   if (day == 0) {
     return false;
   }
@@ -770,43 +777,43 @@ bool DateRewriter::EraToAd(const std::string &key,
   return ret;
 }
 
-bool DateRewriter::ConvertTime(uint32 hour, uint32 min,
+bool DateRewriter::ConvertTime(uint32_t hour, uint32_t min,
                                std::vector<std::string> *results) {
   DCHECK(results);
   if (!IsValidTime(hour, min)) {
     return false;
   }
-  results->push_back(Util::StringPrintf("%d:%2.2d", hour, min));
-  results->push_back(Util::StringPrintf("%d時%2.2d分", hour, min));
+  results->push_back(absl::StrFormat("%d:%2.2d", hour, min));
+  results->push_back(absl::StrFormat("%d時%2.2d分", hour, min));
   if (min == 30) {
-    results->push_back(Util::StringPrintf("%d時半", hour));
+    results->push_back(absl::StrFormat("%d時半", hour));
   }
 
   if ((hour % 24) * 60 + min < 720) {  // 0:00 -- 11:59
-    results->push_back(Util::StringPrintf("午前%d時%d分", hour % 24, min));
+    results->push_back(absl::StrFormat("午前%d時%d分", hour % 24, min));
     if (min == 30) {
-      results->push_back(Util::StringPrintf("午前%d時半", hour % 24));
+      results->push_back(absl::StrFormat("午前%d時半", hour % 24));
     }
   } else {
-    results->push_back(
-        Util::StringPrintf("午後%d時%d分", (hour - 12) % 24, min));
+    results->push_back(absl::StrFormat("午後%d時%d分", (hour - 12) % 24, min));
     if (min == 30) {
-      results->push_back(Util::StringPrintf("午後%d時半", (hour - 12) % 24));
+      results->push_back(absl::StrFormat("午後%d時半", (hour - 12) % 24));
     }
   }
   return true;
 }
 
-bool DateRewriter::ConvertDateWithYear(uint32 year, uint32 month, uint32 day,
+bool DateRewriter::ConvertDateWithYear(uint32_t year, uint32_t month,
+                                       uint32_t day,
                                        std::vector<std::string> *results) {
   DCHECK(results);
   if (!IsValidDate(year, month, day)) {
     return false;
   }
   // Generate "Y/MM/DD", "Y-MM-DD" and "Y年M月D日" formats.
-  results->push_back(Util::StringPrintf("%d/%2.2d/%2.2d", year, month, day));
-  results->push_back(Util::StringPrintf("%d-%2.2d-%2.2d", year, month, day));
-  results->push_back(Util::StringPrintf("%d年%d月%d日", year, month, day));
+  results->push_back(absl::StrFormat("%d/%2.2d/%2.2d", year, month, day));
+  results->push_back(absl::StrFormat("%d-%2.2d-%2.2d", year, month, day));
+  results->push_back(absl::StrFormat("%d年%d月%d日", year, month, day));
   return true;
 }
 
@@ -837,10 +844,17 @@ absl::CivilMinute GetCivilMinuteWithDiff(int type, int diff) {
   return absl::ToCivilMinute(at, tz);
 }
 
-std::vector<std::string> GetConversions(const DateRewriter::DateData &data) {
+std::vector<std::string> GetConversions(const DateRewriter::DateData &data,
+                                        const std::string &extra_format) {
   std::vector<std::string> results;
   const absl::CivilMinute cm = GetCivilMinuteWithDiff(data.type, data.diff);
 
+  if (!extra_format.empty()) {
+    const absl::TimeZone &tz = Clock::GetTimeZone();
+    const absl::Time at = absl::FromCivil(cm, tz);
+    results.push_back(absl::FormatTime(extra_format, at, tz));
+  }
+
   switch (data.type) {
     case DATE:
     case WEEKDAY: {
@@ -849,28 +863,28 @@ std::vector<std::string> GetConversions(const DateRewriter::DateData &data) {
       std::vector<std::string> era;
       if (DateRewriter::AdToEra(cm.year(), cm.month(), &era) && !era.empty()) {
         results.push_back(
-            Util::StringPrintf("%s年%d月%d日", era[0], cm.month(), cm.day()));
+            absl::StrFormat("%s年%d月%d日", era[0], cm.month(), cm.day()));
       }
       const int weekday = static_cast<int>(absl::GetWeekday(cm));
-      results.push_back(Util::StringPrintf("%s曜日", kWeekDayString[weekday]));
+      results.push_back(absl::StrFormat("%s曜日", kWeekDayString[weekday]));
       break;
     }
 
     case MONTH: {
-      results.push_back(Util::StringPrintf("%d", cm.month()));
-      results.push_back(Util::StringPrintf("%d月", cm.month()));
+      results.push_back(absl::StrFormat("%d", cm.month()));
+      results.push_back(absl::StrFormat("%d月", cm.month()));
       break;
     }
 
     case YEAR: {
-      results.push_back(Util::StringPrintf("%d", cm.year()));
-      results.push_back(Util::StringPrintf("%d年", cm.year()));
+      results.push_back(absl::StrFormat("%d", cm.year()));
+      results.push_back(absl::StrFormat("%d年", cm.year()));
 
       std::vector<std::string> era;
       if (DateRewriter::AdToEra(cm.year(), 0, /* unknown mounth */ &era) &&
           !era.empty()) {
         for (auto rit = era.crbegin(); rit != era.crend(); ++rit) {
-          results.push_back(Util::StringPrintf("%s年", *rit));
+          results.push_back(absl::StrFormat("%s年", *rit));
         }
       }
       break;
@@ -884,8 +898,8 @@ std::vector<std::string> GetConversions(const DateRewriter::DateData &data) {
     case DATE_AND_CURRENT_TIME: {
       // Y/MM/DD H:MM
       const std::string ymmddhmm =
-          Util::StringPrintf("%d/%2.2d/%2.2d %2d:%2.2d", cm.year(), cm.month(),
-                             cm.day(), cm.hour(), cm.minute());
+          absl::StrFormat("%d/%2.2d/%2.2d %2d:%2.2d", cm.year(), cm.month(),
+                          cm.day(), cm.hour(), cm.minute());
       results.push_back(ymmddhmm);
       break;
     }
@@ -894,27 +908,30 @@ std::vector<std::string> GetConversions(const DateRewriter::DateData &data) {
       // Unknown type
     }
   }
+
   return results;
 }
 }  // namespace
 
-bool DateRewriter::RewriteDate(Segment *segment) {
+bool DateRewriter::RewriteDate(Segment *segment,
+                               const std::string &extra_format) {
   const std::string &key = segment->key();
   auto rit = std::find_if(std::begin(kDateData), std::end(kDateData),
                           [&key](auto data) { return key == data.key; });
   if (rit == std::end(kDateData)) {
     return false;
   }
-  const DateData &data = *rit;
-  const std::vector<std::string> &conversions = GetConversions(data);
 
+  const DateData &data = *rit;
+  const std::vector<std::string> &conversions =
+      GetConversions(data, extra_format);
   if (conversions.empty()) {
     return false;
   }
 
   // Calculate insert_idx
   // Candidates will be inserted less than 10th candidate.
-  const size_t kMaxIdx = 10;
+  constexpr size_t kMaxIdx = 10;
   const size_t end_idx = std::min(kMaxIdx, segment->candidates_size());
   size_t cand_idx = 0;
   for (cand_idx = 0; cand_idx < end_idx; ++cand_idx) {
@@ -926,16 +943,20 @@ bool DateRewriter::RewriteDate(Segment *segment) {
     return false;
   }
 
-  // Date candidates are too many, therefore highest candidate show at most 3rd.
-  // TODO(nona): learn date candidate even if the date is changed.
-  const size_t kMinIdx = 3;
-  size_t insert_idx = std::min(std::max(kMinIdx, cand_idx + 1), end_idx);
-
   // Insert words.
   const Segment::Candidate &base_cand = segment->candidate(cand_idx);
+  std::vector<std::unique_ptr<Segment::Candidate>> candidates;
+  candidates.reserve(conversions.size());
   for (const std::string &conversion : conversions) {
-    Insert(base_cand, insert_idx++, conversion, data.description, segment);
+    candidates.emplace_back(
+        CreateCandidate(base_cand, conversion, data.description));
   }
+
+  // Date candidates are too many, therefore highest candidate show at most 3rd.
+  // TODO(nona): learn date candidate even if the date is changed.
+  constexpr size_t kMinIdx = 3;
+  size_t insert_idx = std::min(std::max(kMinIdx, cand_idx + 1), end_idx);
+  segment->insert_candidates(insert_idx, std::move(candidates));
   return true;
 }
 
@@ -965,9 +986,9 @@ bool DateRewriter::RewriteEra(Segment *current_segment,
   }
 
   std::string year_str;
-  Util::FullWidthAsciiToHalfWidthAscii(current_key, &year_str);
+  japanese_util::FullWidthAsciiToHalfWidthAscii(current_key, &year_str);
 
-  uint32 year = 0;
+  uint32_t year = 0;
   if (!NumberUtil::SafeStrToUInt32(year_str, &year)) {
     return false;
   }
@@ -977,24 +998,26 @@ bool DateRewriter::RewriteEra(Segment *current_segment,
     return false;
   }
 
-  const int kInsertPosition = 2;
-  const int position = std::min(
-      kInsertPosition, static_cast<int>(current_segment->candidates_size()));
-
-  const char kDescription[] = "和暦";
-  for (auto rit = results.crbegin(); rit != results.crend(); ++rit) {
-    Insert(current_segment->candidate(0), position, *rit, kDescription,
-           current_segment);
-    current_segment->mutable_candidate(position)->attributes &=
-        ~Segment::Candidate::NO_VARIANTS_EXPANSION;
+  constexpr char kDescription[] = "和暦";
+  const Segment::Candidate &base_cand = current_segment->candidate(0);
+  std::vector<std::unique_ptr<Segment::Candidate>> candidates;
+  candidates.reserve(results.size());
+  for (const std::string &value : results) {
+    std::unique_ptr<Segment::Candidate> candidate =
+        CreateCandidate(base_cand, value, kDescription);
+    candidate->attributes &= ~Segment::Candidate::NO_VARIANTS_EXPANSION;
+    candidates.push_back(std::move(candidate));
   }
 
+  constexpr int kInsertPosition = 2;
+  current_segment->insert_candidates(kInsertPosition, std::move(candidates));
+
   return true;
 }
 
 bool DateRewriter::RewriteAd(Segment *segment) {
   const std::string &key = segment->key();
-  if (!Util::EndsWith(key, kNenKey)) {
+  if (!absl::EndsWith(key, kNenKey)) {
     return false;
   }
   if (segment->candidates_size() == 0) {
@@ -1004,12 +1027,17 @@ bool DateRewriter::RewriteAd(Segment *segment) {
   std::vector<std::string> results, descriptions;
   const bool ret = EraToAd(key, &results, &descriptions);
 
+  const Segment::Candidate &base_cand = segment->candidate(0);
+  std::vector<std::unique_ptr<Segment::Candidate>> candidates;
+  candidates.reserve(results.size());
+  for (size_t i = 0; i < results.size(); ++i) {
+    candidates.emplace_back(
+        CreateCandidate(base_cand, results[i], descriptions[i].c_str()));
+  }
+
   // Insert position is the last of candidates
   const int position = static_cast<int>(segment->candidates_size());
-  for (size_t i = 0; i < results.size(); ++i) {
-    Insert(segment->candidate(0), position, results[i], descriptions[i].c_str(),
-           segment);
-  }
+  segment->insert_candidates(position, std::move(candidates));
   return ret;
 }
 
@@ -1039,15 +1067,15 @@ bool GetNDigits(const composer::Composer &composer, const Segments &segments,
 
   // 1. Segment's key
   if (IsNDigits(segment.key(), n)) {
-    Util::FullWidthAsciiToHalfWidthAscii(segment.key(), output);
+    japanese_util::FullWidthAsciiToHalfWidthAscii(segment.key(), output);
     return true;
   }
 
   // 2. Meta candidates
   for (size_t i = 0; i < segment.meta_candidates_size(); ++i) {
     if (IsNDigits(segment.meta_candidate(i).value, n)) {
-      Util::FullWidthAsciiToHalfWidthAscii(segment.meta_candidate(i).value,
-                                           output);
+      japanese_util::FullWidthAsciiToHalfWidthAscii(
+          segment.meta_candidate(i).value, output);
       return true;
     }
   }
@@ -1059,7 +1087,7 @@ bool GetNDigits(const composer::Composer &composer, const Segments &segments,
   // the whole composition.
   composer.GetRawSubString(0, Util::CharsLen(segment.key()), &raw);
   if (IsNDigits(raw, n)) {
-    Util::FullWidthAsciiToHalfWidthAscii(raw, output);
+    japanese_util::FullWidthAsciiToHalfWidthAscii(raw, output);
     return true;
   }
 
@@ -1113,13 +1141,17 @@ bool DateRewriter::RewriteConsecutiveDigits(const composer::Composer &composer,
   const Segment::Candidate &top_cand = (segment->candidates_size() > 0)
                                            ? segment->candidate(0)
                                            : segment->meta_candidate(0);
+  std::vector<std::unique_ptr<Segment::Candidate>> candidates;
+  candidates.reserve(results.size());
+  for (const auto &result : results) {
+    candidates.emplace_back(
+        CreateCandidate(top_cand, result.first, result.second));
+  }
+
   if (insert_position < 0) {
     insert_position = static_cast<int>(segment->candidates_size());
   }
-  for (const auto &result : results) {
-    Insert(top_cand, insert_position++, result.first, result.second, segment);
-  }
-
+  segment->insert_candidates(insert_position, std::move(candidates));
   return true;
 }
 
@@ -1128,12 +1160,12 @@ bool DateRewriter::RewriteConsecutiveTwoDigits(
     std::vector<std::pair<std::string, const char *>> *results) {
   DCHECK_EQ(2, str.size());
   const auto orig_size = results->size();
-  const uint32 high = static_cast<uint32>(str[0] - '0');
-  const uint32 low = static_cast<uint32>(str[1] - '0');
+  const uint32_t high = static_cast<uint32_t>(str[0] - '0');
+  const uint32_t low = static_cast<uint32_t>(str[1] - '0');
   if (IsValidMonthAndDay(high, low)) {
-    results->emplace_back(Util::StringPrintf("%c/%c", str[0], str[1]),
+    results->emplace_back(absl::StrFormat("%c/%c", str[0], str[1]),
                           kDateDescription);
-    results->emplace_back(Util::StringPrintf("%c月%c日", str[0], str[1]),
+    results->emplace_back(absl::StrFormat("%c月%c日", str[0], str[1]),
                           kDateDescription);
   }
   if (IsValidTime(high, low)) {
@@ -1151,50 +1183,48 @@ bool DateRewriter::RewriteConsecutiveThreeDigits(
   DCHECK_EQ(3, str.size());
   const auto orig_size = results->size();
 
-  const uint32 n[] = {static_cast<uint32>(str[0] - '0'),
-                      static_cast<uint32>(str[1] - '0'),
-                      static_cast<uint32>(str[2] - '0')};
+  const uint32_t n[] = {static_cast<uint32_t>(str[0] - '0'),
+                        static_cast<uint32_t>(str[1] - '0'),
+                        static_cast<uint32_t>(str[2] - '0')};
 
   // Split pattern 1: N|NN
-  const uint32 high1 = n[0];
-  const uint32 low1 = 10 * n[1] + n[2];
+  const uint32_t high1 = n[0];
+  const uint32_t low1 = 10 * n[1] + n[2];
   const bool is_valid_date1 = IsValidMonthAndDay(high1, low1) && str[1] != '0';
   const bool is_valid_time1 = IsValidTime(high1, low1);
 
   // Split pattern 2: NN|N
-  const uint32 high2 = 10 * n[0] + n[1];
-  const uint32 low2 = n[2];
+  const uint32_t high2 = 10 * n[0] + n[1];
+  const uint32_t low2 = n[2];
   const bool is_valid_date2 = IsValidMonthAndDay(high2, low2) && str[0] != '0';
   const bool is_valid_time2 = IsValidTime(high2, low2) && str[0] != '0';
 
   if (is_valid_date1) {
     // "M/DD"
-    results->emplace_back(Util::StringPrintf("%c/%c%c", str[0], str[1], str[2]),
+    results->emplace_back(absl::StrFormat("%c/%c%c", str[0], str[1], str[2]),
                           kDateDescription);
   }
   if (is_valid_date2) {
     // "MM/D"
-    results->emplace_back(Util::StringPrintf("%c%c/%c", str[0], str[1], str[2]),
+    results->emplace_back(absl::StrFormat("%c%c/%c", str[0], str[1], str[2]),
                           kDateDescription);
   }
   if (is_valid_time1) {
     // "H:MM"
-    results->emplace_back(Util::StringPrintf("%c:%c%c", str[0], str[1], str[2]),
+    results->emplace_back(absl::StrFormat("%c:%c%c", str[0], str[1], str[2]),
                           kTimeDescription);
   }
   // Don't generate HH:M form as it is unusual.
 
   if (is_valid_date1) {
     // "M月DD日".
-    results->emplace_back(
-        Util::StringPrintf("%c月%c%c日", str[0], str[1], str[2]),
-        kDateDescription);
+    results->emplace_back(absl::StrFormat("%c月%c%c日", str[0], str[1], str[2]),
+                          kDateDescription);
   }
   if (is_valid_date2) {
     // "MM月D日"
-    results->emplace_back(
-        Util::StringPrintf("%c%c月%c日", str[0], str[1], str[2]),
-        kDateDescription);
+    results->emplace_back(absl::StrFormat("%c%c月%c日", str[0], str[1], str[2]),
+                          kDateDescription);
   }
   if (is_valid_time1) {
     // "M時DD分" etc.
@@ -1222,10 +1252,10 @@ bool DateRewriter::RewriteConsecutiveFourDigits(
   DCHECK_EQ(4, str.size());
   const auto orig_size = results->size();
 
-  const uint32 high = (10 * static_cast<uint32>(str[0] - '0') +
-                       static_cast<uint32>(str[1] - '0'));
-  const uint32 low = (10 * static_cast<uint32>(str[2] - '0') +
-                      static_cast<uint32>(str[3] - '0'));
+  const uint32_t high = (10 * static_cast<uint32_t>(str[0] - '0') +
+                         static_cast<uint32_t>(str[1] - '0'));
+  const uint32_t low = (10 * static_cast<uint32_t>(str[2] - '0') +
+                        static_cast<uint32_t>(str[3] - '0'));
 
   const bool is_valid_date = IsValidMonthAndDay(high, low);
   const bool is_valid_time = IsValidTime(high, low);
@@ -1233,13 +1263,13 @@ bool DateRewriter::RewriteConsecutiveFourDigits(
   if (is_valid_date) {
     // "MM/DD"
     results->emplace_back(
-        Util::StringPrintf("%c%c/%c%c", str[0], str[1], str[2], str[3]),
+        absl::StrFormat("%c%c/%c%c", str[0], str[1], str[2], str[3]),
         kDateDescription);
   }
   if (is_valid_time) {
     // "MM:DD"
     results->emplace_back(
-        Util::StringPrintf("%c%c:%c%c", str[0], str[1], str[2], str[3]),
+        absl::StrFormat("%c%c:%c%c", str[0], str[1], str[2], str[3]),
         kTimeDescription);
   }
   if (is_valid_date && str[0] != '0' && str[2] != '0') {
@@ -1248,7 +1278,7 @@ bool DateRewriter::RewriteConsecutiveFourDigits(
     // generate "1月1日" too, as we shouldn't remove the zero explicitly added
     // by user.
     results->emplace_back(
-        Util::StringPrintf("%c%c月%c%c日", str[0], str[1], str[2], str[3]),
+        absl::StrFormat("%c%c月%c%c日", str[0], str[1], str[2], str[3]),
         kDateDescription);
   }
   if (is_valid_time) {
@@ -1266,7 +1296,8 @@ bool DateRewriter::RewriteConsecutiveFourDigits(
 DateRewriter::DateRewriter() = default;
 DateRewriter::~DateRewriter() = default;
 
-DateRewriter::DateRewriter(const dictionary::DictionaryInterface *dictionary) {}
+DateRewriter::DateRewriter(const dictionary::DictionaryInterface *dictionary)
+    : dictionary_(dictionary) {}
 
 int DateRewriter::capability(const ConversionRequest &request) const {
   if (request.request().mixed_conversion()) {
@@ -1275,6 +1306,44 @@ int DateRewriter::capability(const ConversionRequest &request) const {
   return RewriterInterface::CONVERSION;
 }
 
+namespace {
+std::string ConvertExtraFormat(const std::string &base) {
+  return absl::StrReplaceAll(base, {{"%", "%%"},
+                                    {"{YEAR}", "%Y"},
+                                    {"{MONTH}", "%m"},
+                                    {"{DATE}", "%d"},
+                                    {"{{}", "{"}});
+}
+
+std::string GetExtraFormat(const dictionary::DictionaryInterface *dictionary) {
+  if (dictionary == nullptr) {
+    return "";
+  }
+
+  class EntryCollector : public dictionary::DictionaryInterface::Callback {
+   public:
+    explicit EntryCollector(std::string *token) : token_(token) {}
+    ResultType OnToken(absl::string_view key, absl::string_view actual_key,
+                       const dictionary::Token &token) override {
+      if (token.attributes != dictionary::Token::USER_DICTIONARY) {
+        return TRAVERSE_CONTINUE;
+      }
+      *token_ = token.value;
+      return TRAVERSE_DONE;
+    }
+    std::string *token_;
+  };
+
+  std::string extra_format;
+
+  ConversionRequest crequest;
+  EntryCollector callback(&extra_format);
+  dictionary->LookupExact(DateRewriter::kExtraFormatKey, crequest, &callback);
+
+  return ConvertExtraFormat(extra_format);
+}
+}  // namespace
+
 bool DateRewriter::Rewrite(const ConversionRequest &request,
                            Segments *segments) const {
   if (!request.config().use_date_conversion()) {
@@ -1292,6 +1361,7 @@ bool DateRewriter::Rewrite(const ConversionRequest &request,
     }
   }
 
+  const std::string extra_format = GetExtraFormat(dictionary_);
   for (size_t i = segments->history_segments_size();
        i < segments->segments_size(); ++i) {
     Segment *seg = segments->mutable_segment(i);
@@ -1300,7 +1370,7 @@ bool DateRewriter::Rewrite(const ConversionRequest &request,
       return false;
     }
 
-    if (RewriteDate(seg)) {
+    if (RewriteDate(seg, extra_format)) {
       modified = true;
     } else if (i + 1 < segments->segments_size() &&
                RewriteEra(seg, segments->segment(i + 1))) {
