@@ -30,7 +30,9 @@
 #include "rewriter/date_rewriter.h"
 
 #include <cstddef>
+#include <cstdint>
 #include <memory>
+#include <string>
 
 #include "base/clock.h"
 #include "base/clock_mock.h"
@@ -184,9 +186,9 @@ bool AllElementsAreSame(const std::string &key,
 }
 
 // "2011-04-18 15:06:31 (Mon)" UTC
-const uint64 kTestSeconds = 1303139191uLL;
+constexpr uint64_t kTestSeconds = 1303139191uLL;
 // micro seconds. it is random value.
-const uint32 kTestMicroSeconds = 588377u;
+constexpr uint32_t kTestMicroSeconds = 588377u;
 
 }  // namespace
 
@@ -262,7 +264,7 @@ TEST_F(DateRewriterTest, DateRewriteTest) {
   // DateRewrite candidate order check.
   {
     // This parameter is copied from date_rewriter.cc.
-    const size_t kMinimumDateCandidateIdx = 3;
+    constexpr size_t kMinimumDateCandidateIdx = 3;
     const char *kTodayCandidate[] = {"2011/04/18", "2011-04-18",
                                      "2011年4月18日",
                                      "平成23年"
@@ -275,7 +277,7 @@ TEST_F(DateRewriterTest, DateRewriteTest) {
     EXPECT_TRUE(rewriter.Rewrite(request, &segments));
     EXPECT_EQ(5, CountDescription(segments, "今日の日付"));
     size_t offset = 1;
-    for (int rel_cand_idx = 0; rel_cand_idx < arraysize(kTodayCandidate);
+    for (int rel_cand_idx = 0; rel_cand_idx < std::size(kTodayCandidate);
          ++rel_cand_idx) {
       EXPECT_EQ(kTodayCandidate[rel_cand_idx],
                 GetNthCandidateValue(segments, rel_cand_idx + offset));
@@ -296,7 +298,7 @@ TEST_F(DateRewriterTest, DateRewriteTest) {
     EXPECT_EQ(5, CountDescription(segments, "今日の日付"));
 
     offset = 5;
-    for (int rel_cand_idx = 0; rel_cand_idx < arraysize(kTodayCandidate);
+    for (int rel_cand_idx = 0; rel_cand_idx < std::size(kTodayCandidate);
          ++rel_cand_idx) {
       EXPECT_EQ(kTodayCandidate[rel_cand_idx],
                 GetNthCandidateValue(segments, rel_cand_idx + offset));
@@ -316,7 +318,7 @@ TEST_F(DateRewriterTest, DateRewriteTest) {
     EXPECT_TRUE(rewriter.Rewrite(request, &segments));
     EXPECT_EQ(5, CountDescription(segments, "今日の日付"));
 
-    for (int rel_cand_idx = 0; rel_cand_idx < arraysize(kTodayCandidate);
+    for (int rel_cand_idx = 0; rel_cand_idx < std::size(kTodayCandidate);
          ++rel_cand_idx) {
       EXPECT_EQ(kTodayCandidate[rel_cand_idx],
                 GetNthCandidateValue(segments,
@@ -475,7 +477,7 @@ TEST_F(DateRewriterTest, ERAToAD) {
   std::vector<std::string> results, descriptions;
   const ConversionRequest request;
   // "1234", "１２３４", "一二三四"
-  const int kNumYearRepresentation = 3;
+  constexpr int kNumYearRepresentation = 3;
 
   results.clear();
   descriptions.clear();
@@ -682,7 +684,7 @@ TEST_F(DateRewriterTest, ConvertDateTest) {
                               {6, 30},  {7, 31},  {8, 31}, {9, 30},
                               {10, 31}, {11, 30}, {12, 31}};
 
-  for (size_t i = 0; i < arraysize(month_days_test_data); ++i) {
+  for (size_t i = 0; i < std::size(month_days_test_data); ++i) {
     EXPECT_TRUE(
         rewriter.ConvertDateWithYear(2001, month_days_test_data[i].month,
                                      month_days_test_data[i].days, &results));
@@ -1196,8 +1198,7 @@ TEST_F(DateRewriterTest, ConsecutiveDigitsInsertPositionTest) {
         commands::Request::QWERTY_MOBILE_TO_HALFWIDTHASCII);
 
     DateRewriter rewriter;
-    Segments segments;
-    segments.CopyFrom(test_segments);
+    Segments segments = test_segments;
     EXPECT_TRUE(rewriter.Rewrite(conversion_request, &segments));
 
     // Verify that the top candidate wans't modified and the next two were moved
@@ -1216,8 +1217,7 @@ TEST_F(DateRewriterTest, ConsecutiveDigitsInsertPositionTest) {
         commands::Request::TWELVE_KEYS_TO_HIRAGANA);
 
     DateRewriter rewriter;
-    Segments segments;
-    segments.CopyFrom(test_segments);
+    Segments segments = test_segments;
     EXPECT_TRUE(rewriter.Rewrite(conversion_request, &segments));
 
     // Verify that the first three candidate weren't moved.
@@ -1262,4 +1262,65 @@ TEST_F(DateRewriterTest, ConsecutiveDigitsInsertPositionWithHistory) {
   ASSERT_LT(3, segments.conversion_segment(0).candidates_size());
 }
 
+TEST_F(DateRewriterTest, ExtraFormatTest) {
+  ClockMock clock(kTestSeconds, kTestMicroSeconds);
+  Clock::SetClockForUnitTest(&clock);
+
+  dictionary::DictionaryMock dictionary;
+  dictionary.AddLookupExact(DateRewriter::kExtraFormatKey,
+                            DateRewriter::kExtraFormatKey,
+                            "{YEAR}{MONTH}{DATE}",
+                            dictionary::Token::USER_DICTIONARY);
+
+  DateRewriter rewriter(&dictionary);
+  Segments segments;
+  const ConversionRequest request;
+
+  {
+    InitSegment("きょう", "今日", &segments);
+    EXPECT_TRUE(rewriter.Rewrite(request, &segments));
+    EXPECT_EQ(6, CountDescription(segments, "今日の日付"));
+    EXPECT_TRUE(ContainCandidate(segments, "平成23年4月18日"));
+    EXPECT_TRUE(ContainCandidate(segments, "2011年4月18日"));
+    EXPECT_TRUE(ContainCandidate(segments, "2011-04-18"));
+    EXPECT_TRUE(ContainCandidate(segments, "2011/04/18"));
+    EXPECT_TRUE(ContainCandidate(segments, "月曜日"));
+    EXPECT_EQ(GetNthCandidateValue(segments, 1), "20110418");
+  }
+  Clock::SetClockForUnitTest(nullptr);
+}
+
+TEST_F(DateRewriterTest, ExtraFormatSyntaxTest) {
+  ClockMock clock(kTestSeconds, kTestMicroSeconds);
+  Clock::SetClockForUnitTest(&clock);
+
+  auto syntax_test = [](const std::string &input, const std::string &output) {
+    const ConversionRequest request;
+    dictionary::DictionaryMock dictionary;
+    dictionary.AddLookupExact(DateRewriter::kExtraFormatKey,
+                              DateRewriter::kExtraFormatKey,
+                              input, dictionary::Token::USER_DICTIONARY);
+
+    DateRewriter rewriter(&dictionary);
+    Segments segments;
+    InitSegment("きょう", "今日", &segments);
+    EXPECT_TRUE(rewriter.Rewrite(request, &segments));
+    EXPECT_EQ(GetNthCandidateValue(segments, 1), output);
+  };
+
+  syntax_test("%", "%");  // Single % (illformat)
+  syntax_test("%%", "%%");  // Double
+  syntax_test("%Y", "%Y");  // %Y remains as-is.
+  syntax_test("{{}", "{");  // {{} is converted to {.
+  syntax_test("{{}}}", "{}}");
+  syntax_test("{}", "{}");
+  syntax_test("{{}YEAR}", "{YEAR}");
+  syntax_test("{MOZC}", "{MOZC}");  // invalid keyword.
+  syntax_test("{year}", "{year}");  // upper case only.
+
+  // If the format is empty, it is ignored.
+  // "2011/04/18" is the default first conversion.
+  syntax_test("", "2011/04/18");
+  Clock::SetClockForUnitTest(nullptr);
+}
 }  // namespace mozc
