@@ -32,6 +32,7 @@
 #include "rewriter/dictionary_generator.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <map>
 #include <string>
 #include <vector>
@@ -42,14 +43,11 @@
 #include "base/logging.h"
 #include "dictionary/pos_matcher.h"
 #include "dictionary/user_pos.h"
+#include "absl/container/btree_map.h"
 
 namespace mozc {
 namespace rewriter {
 
-Token::Token() : sorting_key_(0) {}
-
-Token::~Token() {}
-
 void Token::MergeFrom(const Token &token) {
   if (token.sorting_key() != 0) {
     sorting_key_ = token.sorting_key();
@@ -71,38 +69,36 @@ void Token::MergeFrom(const Token &token) {
   }
 }
 
-uint64 Token::GetID() const {
+uint64_t Token::GetID() const {
   return Hash::Fingerprint(key_ + "\t" + value_ + "\t" + pos_);
 }
 
-static const size_t kTokenSize = 1000;
+static constexpr size_t kTokenSize = 1000;
 
 DictionaryGenerator::DictionaryGenerator(
     const DataManagerInterface &data_manager)
-    : token_pool_(new ObjectPool<Token>(kTokenSize)),
-      token_map_(new std::map<uint64, Token *>) {
-  const dictionary::POSMatcher pos_matcher(data_manager.GetPOSMatcherData());
+    : token_pool_(kTokenSize) {
+  const dictionary::PosMatcher pos_matcher(data_manager.GetPosMatcherData());
   open_bracket_id_ = pos_matcher.GetOpenBracketId();
   close_bracket_id_ = pos_matcher.GetCloseBracketId();
-  user_pos_ = dictionary::UserPOS::CreateFromDataManager(data_manager);
+  user_pos_ = dictionary::UserPos::CreateFromDataManager(data_manager);
 }
 
-DictionaryGenerator::~DictionaryGenerator() {}
+DictionaryGenerator::~DictionaryGenerator() = default;
 
 void DictionaryGenerator::AddToken(const Token &token) {
   Token *new_token = nullptr;
-  std::map<uint64, Token *>::const_iterator it =
-      token_map_->find(token.GetID());
-  if (it != token_map_->end()) {
+  if (auto it = token_map_.find(token.GetID()); it != token_map_.end()) {
     new_token = it->second;
   } else {
-    new_token = token_pool_->Alloc();
-    token_map_->insert(std::make_pair(token.GetID(), new_token));
+    new_token = token_pool_.Alloc();
+    token_map_.emplace(token.GetID(), new_token);
   }
   new_token->MergeFrom(token);
 }
 
 namespace {
+
 struct CompareToken {
   bool operator()(const Token *t1, const Token *t2) const {
     if (t1->key() != t2->key()) {
@@ -118,15 +114,17 @@ struct CompareToken {
   }
 };
 
-void GetSortedTokens(const std::map<uint64, Token *> *token_map,
-                     std::vector<const Token *> *tokens) {
-  tokens->clear();
-  for (std::map<uint64, Token *>::const_iterator it = token_map->begin();
-       it != token_map->end(); ++it) {
-    tokens->push_back(it->second);
+std::vector<const Token *> GetSortedTokens(
+    const absl::btree_map<uint64_t, Token *> &token_map) {
+  std::vector<const Token *> tokens;
+  tokens.reserve(token_map.size());
+  for (auto [unused, token] : token_map) {
+    tokens.push_back(token);
   }
-  std::sort(tokens->begin(), tokens->end(), CompareToken());
+  std::sort(tokens.begin(), tokens.end(), CompareToken());
+  return tokens;
 }
+
 }  // namespace
 
 bool DictionaryGenerator::Output(const std::string &filename) const {
@@ -136,40 +134,38 @@ bool DictionaryGenerator::Output(const std::string &filename) const {
     return false;
   }
 
-  std::vector<const Token *> tokens;
-  GetSortedTokens(token_map_.get(), &tokens);
+  const std::vector<const Token *> tokens = GetSortedTokens(token_map_);
 
-  uint32 num_same_keys = 0;
+  uint32_t num_same_keys = 0;
   std::string prev_key;
-  for (size_t i = 0; i < tokens.size(); ++i) {
-    const Token &token = *(tokens[i]);
-    const std::string &pos = token.pos();
+  for (const Token *token : tokens) {
+    const std::string &pos = token->pos();
 
     // Update the number of the sequence of the same keys
-    if (prev_key == token.key()) {
+    if (prev_key == token->key()) {
       ++num_same_keys;
     } else {
       num_same_keys = 0;
-      prev_key = token.key();
+      prev_key = token->key();
     }
-    const uint32 cost = 10 * num_same_keys;
+    const uint32_t cost = 10 * num_same_keys;
 
-    uint16 id;
+    uint16_t id;
     if (pos == "括弧開") {
       id = open_bracket_id_;
     } else if (pos == "括弧閉") {
       id = close_bracket_id_;
     } else {
-      CHECK(user_pos_->GetPOSIDs(pos, &id)) << "Unknown POS type: " << pos;
+      CHECK(user_pos_->GetPosIds(pos, &id)) << "Unknown POS type: " << pos;
     }
 
     // Output in mozc dictionary format
-    ofs << token.key() << "\t" << id << "\t" << id << "\t" << cost << "\t"
-        << token.value() << "\t"
-        << (token.description().empty() ? "" : token.description()) << "\t"
-        << (token.additional_description().empty()
+    ofs << token->key() << "\t" << id << "\t" << id << "\t" << cost << "\t"
+        << token->value() << "\t"
+        << (token->description().empty() ? "" : token->description()) << "\t"
+        << (token->additional_description().empty()
                 ? ""
-                : token.additional_description());
+                : token->additional_description());
     ofs << std::endl;
   }
   return true;
