@@ -30,6 +30,7 @@
 #include "rewriter/emoji_rewriter.h"
 
 #include <cstddef>
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <vector>
@@ -49,7 +50,7 @@
 #include "testing/base/public/mozctest.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
-#include "absl/memory/memory.h"
+#include "absl/container/btree_map.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -57,7 +58,7 @@ namespace {
 
 using mozc::commands::Request;
 
-const char kEmoji[] = "えもじ";
+constexpr char kEmoji[] = "えもじ";
 
 // Makes |segments| to have only a segment with a key-value paired candidate.
 void SetSegment(const std::string &key, const std::string &value,
@@ -117,7 +118,7 @@ void ChooseEmojiCandidate(Segments *segments) {
 struct EmojiData {
   const char *key;
   const char *unicode;
-  const uint32 android_pua;
+  const uint32_t android_pua;
   const char *description_unicode;
   const char *description_docomo;
   const char *description_softbank;
@@ -159,7 +160,7 @@ class TestDataManager : public testing::MockDataManager {
  public:
   TestDataManager() {
     // Collect all the strings and temporarily assign 0 as index.
-    std::map<std::string, size_t> string_index;
+    absl::btree_map<std::string, size_t> string_index;
     for (const EmojiData &data : kTestEmojiList) {
       string_index[data.key] = 0;
       string_index[data.unicode] = 0;
@@ -198,14 +199,14 @@ class TestDataManager : public testing::MockDataManager {
       absl::string_view *string_array_data) const override {
     *token_array_data =
         absl::string_view(reinterpret_cast<const char *>(token_array_.data()),
-                          token_array_.size() * sizeof(uint32));
+                          token_array_.size() * sizeof(uint32_t));
     *string_array_data = string_array_data_;
   }
 
  private:
-  std::vector<uint32> token_array_;
+  std::vector<uint32_t> token_array_;
   absl::string_view string_array_data_;
-  std::unique_ptr<uint32[]> string_array_buf_;
+  std::unique_ptr<uint32_t[]> string_array_buf_;
 };
 
 class EmojiRewriterTest : public ::testing::Test {
@@ -222,8 +223,8 @@ class EmojiRewriterTest : public ::testing::Test {
 
     mozc::usage_stats::UsageStats::ClearAllStatsForTest();
 
-    rewriter_ = absl::make_unique<EmojiRewriter>(test_data_manager_);
-    full_data_rewriter_ = absl::make_unique<EmojiRewriter>(mock_data_manager_);
+    rewriter_ = std::make_unique<EmojiRewriter>(test_data_manager_);
+    full_data_rewriter_ = std::make_unique<EmojiRewriter>(mock_data_manager_);
   }
 
   void TearDown() override {
@@ -403,7 +404,7 @@ TEST_F(EmojiRewriterTest, CheckDescription) {
   const testing::MockDataManager data_manager;
   Segments segments;
   VariantsRewriter variants_rewriter(
-      dictionary::POSMatcher(data_manager.GetPOSMatcherData()));
+      dictionary::PosMatcher(data_manager.GetPosMatcherData()));
 
   SetSegment("Emoji", "test", &segments);
   EXPECT_TRUE(rewriter_->Rewrite(convreq_, &segments));
@@ -417,8 +418,6 @@ TEST_F(EmojiRewriterTest, CheckDescription) {
     if (!EmojiRewriter::IsEmojiCandidate(candidate)) {
       continue;
     }
-    EXPECT_NE(std::string::npos, description.find("<機種依存文字>"))
-        << "for \"" << candidate.value << "\" : \"" << description << "\"";
     EXPECT_EQ(std::string::npos, description.find("[全]"))
         << "for \"" << candidate.value << "\" : \"" << description << "\"";
   }
@@ -430,7 +429,7 @@ TEST_F(EmojiRewriterTest, CheckInsertPosition) {
 
   // |kExpectPosition| has the same number with |kDefaultInsertPos| defined in
   // emoji_rewriter.cc.
-  const int kExpectPosition = 6;
+  constexpr int kExpectPosition = 6;
 
   Segments segments;
   {
@@ -461,7 +460,7 @@ TEST_F(EmojiRewriterTest, CheckInsertPosition) {
 TEST_F(EmojiRewriterTest, CheckUsageStats) {
   // This test checks the data stored in usage stats for EmojiRewriter.
 
-  const char kStatsKey[] = "CommitEmoji";
+  constexpr char kStatsKey[] = "CommitEmoji";
   Segments segments;
 
   // No use, no registered keys
