@@ -30,14 +30,17 @@
 #include "rewriter/english_variants_rewriter.h"
 
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "base/logging.h"
-#include "base/mozc_hash_set.h"
 #include "base/util.h"
 #include "converter/segments.h"
 #include "protocol/commands.pb.h"
 #include "request/conversion_request.h"
+#include "absl/container/flat_hash_set.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_cat.h"
 
 namespace mozc {
 
@@ -54,7 +57,7 @@ bool EnglishVariantsRewriter::ExpandEnglishVariants(
   }
 
   // multi-word
-  if (input.find(' ') != std::string::npos) {
+  if (absl::StrContains(input, " ")) {
     return false;
   }
 
@@ -108,8 +111,8 @@ bool EnglishVariantsRewriter::ExpandEnglishVariantsWithSegment(
   CHECK(seg);
 
   bool modified = false;
-  mozc_hash_set<std::string> expanded_t13n_candidates;
-  mozc_hash_set<std::string> original_candidates;
+  absl::flat_hash_set<std::string> expanded_t13n_candidates;
+  absl::flat_hash_set<std::string> original_candidates;
 
   for (size_t i = 0; i < seg->candidates_size(); ++i) {
     original_candidates.insert(seg->candidate(i).value);
@@ -145,9 +148,8 @@ bool EnglishVariantsRewriter::ExpandEnglishVariantsWithSegment(
       if (ExpandEnglishVariants(original_candidate->content_value, &variants)) {
         CHECK(!variants.empty());
         for (auto it = variants.rbegin(); it != variants.rend(); ++it) {
-          std::string new_value;
-          Util::ConcatStrings(*it, original_candidate->functional_value(),
-                              &new_value);
+          const std::string new_value =
+              absl::StrCat(*it, original_candidate->functional_value());
           expanded_t13n_candidates.insert(new_value);
           if (original_candidates.find(new_value) !=
               original_candidates.end()) {
