@@ -42,7 +42,6 @@
 #include "testing/base/public/gunit.h"
 #include "transliteration/transliteration.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace {
@@ -68,7 +67,7 @@ class FocusCandidateRewriterTest : public ::testing::Test {
  protected:
   void SetUp() override {
     SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
-    rewriter_ = absl::make_unique<FocusCandidateRewriter>(&mock_data_manager_);
+    rewriter_ = std::make_unique<FocusCandidateRewriter>(&mock_data_manager_);
   }
 
   const RewriterInterface *GetRewriter() { return rewriter_.get(); }
@@ -184,7 +183,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterRightToLeft) {
 TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterLeftToRightNest) {
   Segments segments;
   Segment *seg[7];
-  for (int i = 0; i < arraysize(seg); ++i) {
+  for (int i = 0; i < std::size(seg); ++i) {
     seg[i] = segments.add_segment();
   }
 
@@ -228,7 +227,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterLeftToRightNest) {
 TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterRightToLeftNest) {
   Segments segments;
   Segment *seg[7];
-  for (int i = 0; i < arraysize(seg); ++i) {
+  for (int i = 0; i < std::size(seg); ++i) {
     seg[i] = segments.add_segment();
   }
 
@@ -272,7 +271,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterRightToLeftNest) {
 TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterMetaCandidate) {
   Segments segments;
   Segment *seg[3];
-  for (int i = 0; i < arraysize(seg); ++i) {
+  for (int i = 0; i < std::size(seg); ++i) {
     seg[i] = segments.add_segment();
   }
 
@@ -342,7 +341,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterMetaCandidate) {
 TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterNumber) {
   Segments segments;
   Segment *seg[7];
-  for (int i = 0; i < arraysize(seg); ++i) {
+  for (int i = 0; i < std::size(seg); ++i) {
     seg[i] = segments.add_segment();
   }
 
@@ -412,7 +411,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterNumber) {
 TEST_F(FocusCandidateRewriterTest, DontChangeNonNumberSegment) {
   Segments segments;
   Segment *seg[2];
-  for (int i = 0; i < arraysize(seg); ++i) {
+  for (int i = 0; i < std::size(seg); ++i) {
     seg[i] = segments.add_segment();
   }
 
@@ -433,7 +432,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterSuffix) {
   {
     Segments segments;
     Segment *seg[6];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
@@ -467,7 +466,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterSuffix) {
   {
     Segments segments;
     Segment *seg[3];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
@@ -488,7 +487,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterSuffix) {
   {
     Segments segments;
     Segment *seg[3];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
@@ -509,7 +508,7 @@ TEST_F(FocusCandidateRewriterTest, FocusCandidateRewriterSuffix) {
   {
     Segments segments;
     Segment *seg[3];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
@@ -540,7 +539,7 @@ TEST_F(FocusCandidateRewriterTest, NumberAndSuffixCompound) {
     // Then, focusing on (Seg 0, cand 1) should move "二回" in Seg 1 to the top.
     Segments segments;
     Segment *seg[2];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
     seg[0]->set_key("いっかい");
@@ -569,12 +568,12 @@ TEST_F(FocusCandidateRewriterTest, NumberAndSuffixCompound) {
     // Then, focusing on (Seg 0, cand 1) should move "二回" in Seg 1 to the top.
     Segments segments;
     Segment *seg[2];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
-    const int kNounId = 1939;
-    const int kParallelMarkerYa = 290;
+    constexpr int kNounId = 1939;
+    constexpr int kParallelMarkerYa = 290;
 
     seg[0]->set_key("いっかいや");
 
@@ -615,12 +614,12 @@ TEST_F(FocusCandidateRewriterTest, NumberAndSuffixCompound) {
     // " in Seg 2 to the top of each segment.
     Segments segments;
     Segment *seg[3];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
-    const int kNounId = 1939;
-    const int kParallelMarkerYa = 290;
+    constexpr int kNounId = 1939;
+    constexpr int kParallelMarkerYa = 290;
 
     seg[0]->set_key("いっかいや");
 
@@ -670,12 +669,12 @@ TEST_F(FocusCandidateRewriterTest, NumberAndSuffixCompound) {
     // Then, focusing on (Seg 0, cand 1) cannot move "二回" in Seg 3 to the top.
     Segments segments;
     Segment *seg[5];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
-    const int kNounId = 1939;
-    const int kParallelMarkerYa = 290;
+    constexpr int kNounId = 1939;
+    constexpr int kParallelMarkerYa = 290;
 
     seg[0]->set_key("いっかいや");
 
@@ -720,14 +719,14 @@ TEST_F(FocusCandidateRewriterTest, NumberAndSuffixCompound) {
     // 1 to the top.
     Segments segments;
     Segment *seg[3];
-    for (int i = 0; i < arraysize(seg); ++i) {
+    for (int i = 0; i < std::size(seg); ++i) {
       seg[i] = segments.add_segment();
     }
 
-    const int kNounId = 1939;
-    const int kKakariJoshiHa = 299;
-    const int kIkuTaSetsuzoku = 1501;
-    const int kJodoushiTa = 161;
+    constexpr int kNounId = 1939;
+    constexpr int kKakariJoshiHa = 299;
+    constexpr int kIkuTaSetsuzoku = 1501;
+    constexpr int kJodoushiTa = 161;
 
     seg[0]->set_key("いっかいへは");
 
