@@ -30,11 +30,13 @@
 #include "rewriter/number_rewriter.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <cstdio>
 #include <string>
 #include <utility>
 #include <vector>
 
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/number_util.h"
 #include "base/serialized_string_array.h"
@@ -47,9 +49,10 @@
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
 #include "rewriter/number_compound_util.h"
+#include "absl/container/flat_hash_set.h"
 #include "absl/strings/string_view.h"
 
-using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosMatcher;
 
 namespace mozc {
 namespace {
@@ -73,7 +76,7 @@ struct RewriteCandidateInfo {
 // POS information, cost, etc will be copied from base candidate.
 RewriteType GetRewriteTypeAndBase(const SerializedStringArray &suffix_array,
                                   const Segment &seg, int base_candidate_pos,
-                                  const POSMatcher &pos_matcher,
+                                  const PosMatcher &pos_matcher,
                                   Segment::Candidate *arabic_candidate) {
   DCHECK(arabic_candidate);
 
@@ -83,14 +86,22 @@ RewriteType GetRewriteTypeAndBase(const SerializedStringArray &suffix_array,
   }
 
   if (Util::GetScriptType(c.content_value) == Util::NUMBER) {
-    arabic_candidate->CopyFrom(c);
+    *arabic_candidate = c;
     arabic_candidate->inner_segment_boundary.clear();
     DCHECK(arabic_candidate->IsValid());
-    return ARABIC_FIRST;
+    if (Util::GetScriptType(c.content_key) == Util::NUMBER ||
+        (c.attributes & Segment::Candidate::USER_DICTIONARY)) {
+      // ARABIC_FIRST when:
+      // - a user types number key
+      // - or, the entry came from the user dictionary
+      return ARABIC_FIRST;
+    }
+    return KANJI_FIRST;
   }
 
   std::string half_width_new_content_value;
-  Util::FullWidthToHalfWidth(c.content_key, &half_width_new_content_value);
+  japanese_util::FullWidthToHalfWidth(c.content_key,
+                                      &half_width_new_content_value);
   // Try to get normalized kanji_number and arabic_number.
   // If it failed, do nothing.
   // Retain suffix for later use.
@@ -126,27 +137,36 @@ RewriteType GetRewriteTypeAndBase(const SerializedStringArray &suffix_array,
 
 void GetRewriteCandidateInfos(
     const SerializedStringArray &suffix_array, const Segment &seg,
-    const POSMatcher &pos_matcher,
+    const PosMatcher &pos_matcher,
     std::vector<RewriteCandidateInfo> *rewrite_candidate_info) {
   DCHECK(rewrite_candidate_info);
   RewriteCandidateInfo info;
 
+  // Use the higher ranked candidate for deciding the insertion position.
+  absl::flat_hash_set<std::string> seen;
   for (size_t i = 0; i < seg.candidates_size(); ++i) {
     const RewriteType type = GetRewriteTypeAndBase(
         suffix_array, seg, i, pos_matcher, &info.candidate);
     if (type == NO_REWRITE) {
       continue;
     }
-    info.type = type;
-    info.position = i;
-    rewrite_candidate_info->push_back(info);
+    if (seen.insert(info.candidate.value).second) {
+      info.type = type;
+      info.position = i;
+      rewrite_candidate_info->push_back(info);
+    }
   }
 }
 
 // If top candidate is Kanji numeric, we want to expand at least
 // 5 candidates apart from base candidate.
 // http://b/issue?id=2872048
-const int kArabicNumericOffset = 5;
+constexpr int kArabicNumericOffset = 5;
+
+int GetInsertOffset(RewriteType type) {
+  // +2 for arabic half_width full_width expansion
+  return (type == ARABIC_FIRST) ? 2 : kArabicNumericOffset;
+}
 
 void PushBackCandidate(const std::string &value, const std::string &desc,
                        NumberUtil::NumberString::Style style,
@@ -194,15 +214,18 @@ class CheckValueOperator {
 
 // If we have the candidates to be inserted before the base candidate,
 // delete them.
-// TODO(toshiyuki): Delete candidates between base pos and insert pos
-// if necessary.
 void EraseExistingCandidates(
     const std::vector<Segment::Candidate> &results, int base_candidate_pos,
-    Segment *seg,
+    RewriteType type, Segment *seg,
     std::vector<RewriteCandidateInfo> *rewrite_candidate_info_list) {
   DCHECK(seg);
   // Remember base candidate value
-  for (int pos = base_candidate_pos - 1; pos >= 0; --pos) {
+  const int start_pos = std::min<int>(
+      base_candidate_pos + GetInsertOffset(type), seg->candidates_size() - 1);
+  for (int pos = start_pos; pos >= 0; --pos) {
+    if (pos == base_candidate_pos) {
+      continue;
+    }
     // Simple liner search. |results| size is small. (at most 10 or so)
     const std::vector<Segment::Candidate>::const_iterator iter =
         std::find_if(results.begin(), results.end(),
@@ -257,7 +280,7 @@ void MergeCandidateInfoInternal(const Segment::Candidate &base_cand,
       base_cand.attributes & Segment::Candidate::PARTIALLY_KEY_CONSUMED;
 }
 
-void InsertCandidate(Segment *segment, int32 insert_position,
+void InsertCandidate(Segment *segment, int32_t insert_position,
                      const Segment::Candidate &base_cand,
                      const Segment::Candidate &result_cand) {
   DCHECK(segment);
@@ -266,7 +289,7 @@ void InsertCandidate(Segment *segment, int32 insert_position,
   MergeCandidateInfoInternal(base_cand, result_cand, c);
 }
 
-void UpdateCandidate(Segment *segment, int32 update_position,
+void UpdateCandidate(Segment *segment, int32_t update_position,
                      const Segment::Candidate &base_cand,
                      const Segment::Candidate &result_cand) {
   DCHECK(segment);
@@ -324,13 +347,8 @@ void InsertConvertedCandidates(const std::vector<Segment::Candidate> &results,
 }
 
 int GetInsertPos(int base_pos, const Segment &segment, RewriteType type) {
-  if (type == ARABIC_FIRST) {
-    // +2 for arabic half_width full_width expansion
-    return std::min(base_pos + 2, static_cast<int>(segment.candidates_size()));
-  } else {
-    return std::min(base_pos + kArabicNumericOffset,
-                    static_cast<int>(segment.candidates_size()));
-  }
+  return std::min<int>(base_pos + GetInsertOffset(type),
+                       segment.candidates_size());
 }
 
 void InsertHalfArabic(const std::string &half_arabic,
@@ -363,7 +381,7 @@ void GetNumbers(RewriteType type, bool exec_radix_conversion,
 }
 
 bool RewriteOneSegment(const SerializedStringArray &suffix_array,
-                       const POSMatcher &pos_matcher,
+                       const PosMatcher &pos_matcher,
                        bool exec_radix_conversion, Segment *seg) {
   DCHECK(seg);
   bool modified = false;
@@ -379,13 +397,13 @@ bool RewriteOneSegment(const SerializedStringArray &suffix_array,
     }
 
     std::string arabic_content_value;
-    Util::FullWidthToHalfWidth(info.candidate.content_value,
-                               &arabic_content_value);
+    japanese_util::FullWidthToHalfWidth(info.candidate.content_value,
+                                        &arabic_content_value);
     if (Util::GetScriptType(arabic_content_value) != Util::NUMBER) {
       if (Util::GetFirstScriptType(arabic_content_value) == Util::NUMBER) {
         // Rewrite for number suffix
-        const int insert_pos = std::min(
-            info.position + 1, static_cast<int>(seg->candidates_size()));
+        const int insert_pos =
+            std::min<int>(info.position + 1, seg->candidates_size());
         InsertCandidate(seg, insert_pos, info.candidate, info.candidate);
         modified = true;
         continue;
@@ -406,7 +424,7 @@ bool RewriteOneSegment(const SerializedStringArray &suffix_array,
     // Caution!!!: This invocation will update the data inside of the
     // rewrite_candidate_infos. Thus, |info| also can be updated as well
     // regardless of whether it's const reference-ness.
-    EraseExistingCandidates(converted_numbers, info.position, seg,
+    EraseExistingCandidates(converted_numbers, info.position, info.type, seg,
                             &rewrite_candidate_infos);
     int insert_pos = GetInsertPos(info.position, *seg, info.type);
     DCHECK_LT(info.position, insert_pos);
@@ -419,7 +437,7 @@ bool RewriteOneSegment(const SerializedStringArray &suffix_array,
 }  // namespace
 
 NumberRewriter::NumberRewriter(const DataManagerInterface *data_manager)
-    : pos_matcher_(data_manager->GetPOSMatcherData()) {
+    : pos_matcher_(data_manager->GetPosMatcherData()) {
   const char *array = nullptr;
   size_t size = 0;
   data_manager->GetCounterSuffixSortedArray(&array, &size);
@@ -452,7 +470,7 @@ bool NumberRewriter::Rewrite(const ConversionRequest &request,
   // Showing radix candidates is annoying for a user.
   const bool exec_radix_conversion =
       (segments->conversion_segments_size() == 1 &&
-       segments->request_type() == Segments::CONVERSION);
+       request.request_type() == ConversionRequest::CONVERSION);
 
   for (size_t i = 0; i < segments->conversion_segments_size(); ++i) {
     Segment *seg = segments->mutable_conversion_segment(i);
