@@ -44,6 +44,8 @@
 #include "request/conversion_request.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_format.h"
 
 // To show the value of size_t, 'z' speficier should be used.
 // But MSVC doesn't support it yet so use 'l' instead.
@@ -56,14 +58,14 @@
 namespace mozc {
 namespace {
 
-using dictionary::POSMatcher;
+using dictionary::PosMatcher;
 
-const char kKanjiDescription[] = "漢数字";
-const char kArabicDescription[] = "数字";
-const char kOldKanjiDescription[] = "大字";
-const char kMaruNumberDescription[] = "丸数字";
-const char kRomanCapitalDescription[] = "ローマ数字(大文字)";
-const char kRomanNoCapitalDescription[] = "ローマ数字(小文字)";
+constexpr char kKanjiDescription[] = "漢数字";
+constexpr char kArabicDescription[] = "数字";
+constexpr char kOldKanjiDescription[] = "大字";
+constexpr char kMaruNumberDescription[] = "丸数字";
+constexpr char kRomanCapitalDescription[] = "ローマ数字(大文字)";
+constexpr char kRomanNoCapitalDescription[] = "ローマ数字(小文字)";
 
 bool FindValue(const Segment &segment, const std::string &value) {
   for (size_t i = 0; i < segment.candidates_size(); ++i) {
@@ -74,7 +76,7 @@ bool FindValue(const Segment &segment, const std::string &value) {
   return false;
 }
 
-Segment *SetupSegments(const POSMatcher &pos_matcher,
+Segment *SetupSegments(const PosMatcher &pos_matcher,
                        const std::string &candidate_value, Segments *segments) {
   segments->Clear();
   Segment *segment = segments->push_back_segment();
@@ -116,7 +118,7 @@ class NumberRewriterTest : public ::testing::Test {
   NumberRewriterTest() {}
 
   void SetUp() override {
-    pos_matcher_.Set(mock_data_manager_.GetPOSMatcherData());
+    pos_matcher_.Set(mock_data_manager_.GetPosMatcherData());
   }
 
   NumberRewriter *CreateNumberRewriter() {
@@ -124,7 +126,7 @@ class NumberRewriterTest : public ::testing::Test {
   }
 
   const testing::MockDataManager mock_data_manager_;
-  POSMatcher pos_matcher_;
+  PosMatcher pos_matcher_;
   const ConversionRequest default_request_;
 
  private:
@@ -150,6 +152,8 @@ TEST_F(NumberRewriterTest, BasicTest) {
   candidate->rid = pos_matcher_.GetNumberId();
   candidate->value = "012";
   candidate->content_value = "012";
+  candidate->key = "012";
+  candidate->content_key = "012";
 
   EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
 
@@ -167,11 +171,11 @@ TEST_F(NumberRewriterTest, BasicTest) {
       {"0b1100", "0b1100", "2進数"},
   };
 
-  const size_t kExpectResultSize = arraysize(kExpectResults);
+  constexpr size_t kExpectResultSize = std::size(kExpectResults);
   EXPECT_EQ(kExpectResultSize, seg->candidates_size());
 
   for (size_t i = 0; i < kExpectResultSize; ++i) {
-    SCOPED_TRACE(Util::StringPrintf("i = " SIZE_T_PRINTF_FORMAT, i));
+    SCOPED_TRACE(absl::StrFormat("i = " SIZE_T_PRINTF_FORMAT, i));
     EXPECT_EQ(kExpectResults[i].value, seg->candidate(i).value);
     EXPECT_EQ(kExpectResults[i].content_value, seg->candidate(i).content_value);
     EXPECT_EQ(kExpectResults[i].description, seg->candidate(i).description);
@@ -182,25 +186,24 @@ TEST_F(NumberRewriterTest, BasicTest) {
 TEST_F(NumberRewriterTest, RequestType) {
   class TestData {
    public:
-    Segments::RequestType request_type_;
+    ConversionRequest::RequestType request_type_;
     int expected_candidate_number_;
-    TestData(Segments::RequestType request_type, int expected_number)
+    TestData(ConversionRequest::RequestType request_type, int expected_number)
         : request_type_(request_type),
           expected_candidate_number_(expected_number) {}
   };
   TestData test_data_list[] = {
-      TestData(Segments::CONVERSION, 11),  // 11 comes from BasicTest
-      TestData(Segments::REVERSE_CONVERSION, 8),
-      TestData(Segments::PREDICTION, 8),
-      TestData(Segments::SUGGESTION, 8),
+      TestData(ConversionRequest::CONVERSION, 11),  // 11 comes from BasicTest
+      TestData(ConversionRequest::REVERSE_CONVERSION, 8),
+      TestData(ConversionRequest::PREDICTION, 8),
+      TestData(ConversionRequest::SUGGESTION, 8),
   };
 
   std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
-  for (size_t i = 0; i < arraysize(test_data_list); ++i) {
+  for (size_t i = 0; i < std::size(test_data_list); ++i) {
     TestData &test_data = test_data_list[i];
     Segments segments;
-    segments.set_request_type(test_data.request_type_);
     Segment *seg = segments.push_back_segment();
     Segment::Candidate *candidate = seg->add_candidate();
     candidate->Init();
@@ -208,7 +211,9 @@ TEST_F(NumberRewriterTest, RequestType) {
     candidate->rid = pos_matcher_.GetNumberId();
     candidate->value = "012";
     candidate->content_value = "012";
-    EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
+    ConversionRequest request;
+    request.set_request_type(test_data.request_type_);
+    EXPECT_TRUE(number_rewriter->Rewrite(request, &segments));
     EXPECT_EQ(test_data.expected_candidate_number_, seg->candidates_size());
   }
 }
@@ -224,6 +229,8 @@ TEST_F(NumberRewriterTest, BasicTestWithSuffix) {
   candidate->rid = pos_matcher_.GetNumberId();
   candidate->value = "012が";
   candidate->content_value = "012";
+  candidate->key = "012が";
+  candidate->content_key = "012";
 
   EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
 
@@ -241,11 +248,11 @@ TEST_F(NumberRewriterTest, BasicTestWithSuffix) {
       {"0b1100が", "0b1100", "2進数"},
   };
 
-  const size_t kExpectResultSize = arraysize(kExpectResults);
+  constexpr size_t kExpectResultSize = std::size(kExpectResults);
   EXPECT_EQ(kExpectResultSize, seg->candidates_size());
 
   for (size_t i = 0; i < kExpectResultSize; ++i) {
-    SCOPED_TRACE(Util::StringPrintf("i = " SIZE_T_PRINTF_FORMAT, i));
+    SCOPED_TRACE(absl::StrFormat("i = " SIZE_T_PRINTF_FORMAT, i));
     EXPECT_EQ(kExpectResults[i].value, seg->candidate(i).value);
     EXPECT_EQ(kExpectResults[i].content_value, seg->candidate(i).content_value);
     EXPECT_EQ(kExpectResults[i].description, seg->candidate(i).description);
@@ -387,6 +394,8 @@ TEST_F(NumberRewriterTest, OneOfCandidatesIsEmpty) {
   second_candidate->lid = pos_matcher_.GetNumberId();
   second_candidate->rid = pos_matcher_.GetNumberId();
   second_candidate->content_value = second_candidate->value;
+  second_candidate->key = "0";
+  second_candidate->content_key = "0";
 
   EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
 
@@ -444,6 +453,8 @@ TEST_F(NumberRewriterTest, NumberIsZero) {
   candidate->rid = pos_matcher_.GetNumberId();
   candidate->value = "0";
   candidate->content_value = "0";
+  candidate->key = "0";
+  candidate->content_key = "0";
 
   EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
 
@@ -479,6 +490,8 @@ TEST_F(NumberRewriterTest, NumberIsZeroZero) {
   candidate->rid = pos_matcher_.GetNumberId();
   candidate->value = "00";
   candidate->content_value = "00";
+  candidate->key = "00";
+  candidate->content_key = "00";
 
   EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
 
@@ -514,6 +527,8 @@ TEST_F(NumberRewriterTest, NumberIs19Digit) {
   candidate->rid = pos_matcher_.GetNumberId();
   candidate->value = "1000000000000000000";
   candidate->content_value = "1000000000000000000";
+  candidate->key = "1000000000000000000";
+  candidate->content_key = "1000000000000000000";
 
   EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
 
@@ -539,11 +554,11 @@ TEST_F(NumberRewriterTest, NumberIs19Digit) {
        "2進数"},
   };
 
-  const size_t kExpectResultSize = arraysize(kExpectResults);
+  constexpr size_t kExpectResultSize = std::size(kExpectResults);
   EXPECT_EQ(kExpectResultSize, seg->candidates_size());
 
   for (size_t i = 0; i < kExpectResultSize; ++i) {
-    SCOPED_TRACE(Util::StringPrintf("i = " SIZE_T_PRINTF_FORMAT, i));
+    SCOPED_TRACE(absl::StrFormat("i = " SIZE_T_PRINTF_FORMAT, i));
     EXPECT_EQ(kExpectResults[i].value, seg->candidate(i).value);
     EXPECT_EQ(kExpectResults[i].content_value, seg->candidate(i).content_value);
     EXPECT_EQ(kExpectResults[i].description, seg->candidate(i).description);
@@ -563,6 +578,8 @@ TEST_F(NumberRewriterTest, NumberIsGreaterThanUInt64Max) {
   candidate->rid = pos_matcher_.GetNumberId();
   candidate->value = "18446744073709551616";  // 2^64
   candidate->content_value = "18446744073709551616";
+  candidate->key = "18446744073709551616";
+  candidate->content_key = "18446744073709551616";
 
   EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
 
@@ -589,11 +606,11 @@ TEST_F(NumberRewriterTest, NumberIsGreaterThanUInt64Max) {
        kOldKanjiDescription},
   };
 
-  const size_t kExpectResultSize = arraysize(kExpectResults);
+  constexpr size_t kExpectResultSize = std::size(kExpectResults);
   EXPECT_EQ(kExpectResultSize, seg->candidates_size());
 
   for (size_t i = 0; i < kExpectResultSize; ++i) {
-    SCOPED_TRACE(Util::StringPrintf("i = " SIZE_T_PRINTF_FORMAT, i));
+    SCOPED_TRACE(absl::StrFormat("i = " SIZE_T_PRINTF_FORMAT, i));
     EXPECT_EQ(kExpectResults[i].value, seg->candidate(i).value);
     EXPECT_EQ(kExpectResults[i].content_value, seg->candidate(i).content_value);
     EXPECT_EQ(kExpectResults[i].description, seg->candidate(i).description);
@@ -789,7 +806,7 @@ TEST_F(NumberRewriterTest, SeparatedArabicsTest) {
       {"1234.5", "1,234.5", "１，２３４．５"},
   };
 
-  for (size_t i = 0; i < arraysize(kSuccess); ++i) {
+  for (size_t i = 0; i < std::size(kSuccess); ++i) {
     Segments segments;
     Segment *seg = segments.push_back_segment();
     Segment::Candidate *candidate = seg->add_candidate();
@@ -812,7 +829,7 @@ TEST_F(NumberRewriterTest, SeparatedArabicsTest) {
       {"0000", "0,000", "０，０００"},
   };
 
-  for (size_t i = 0; i < arraysize(kFail); ++i) {
+  for (size_t i = 0; i < std::size(kFail); ++i) {
     Segments segments;
     Segment *seg = segments.push_back_segment();
     Segment::Candidate *candidate = seg->add_candidate();
@@ -896,7 +913,7 @@ TEST_F(NumberRewriterTest, NonNumberNounTest) {
   std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   Segments segments;
   Segment *segment = segments.push_back_segment();
-  segment->set_key("もず");
+  segment->set_key("");
   Segment::Candidate *cand = segment->add_candidate();
   cand->Init();
   cand->key = "もず";
@@ -908,10 +925,43 @@ TEST_F(NumberRewriterTest, NonNumberNounTest) {
   EXPECT_FALSE(number_rewriter->Rewrite(default_request_, &segments));
 }
 
+TEST_F(NumberRewriterTest, RewriteArabicNumberTest) {
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  Segments segments;
+  Segment *segment = segments.push_back_segment();
+  segment->set_key("いち");
+  struct CandData {
+    const char *value;
+    int pos_id;
+  };
+  const CandData kCandList[] = {
+      {"1", pos_matcher_.GetNumberId()},
+      {"一", pos_matcher_.GetNumberId()},
+      {"位置", pos_matcher_.GetGeneralNounId()},
+      {"イチ", pos_matcher_.GetGeneralNounId()},
+      {"壱", pos_matcher_.GetGeneralNounId()},
+  };
+
+  for (const auto &cand_data : kCandList) {
+    Segment::Candidate *cand = segment->add_candidate();
+    cand->Init();
+    cand->key = "いち";
+    cand->content_key = cand->key;
+    cand->value = cand_data.value;
+    cand->content_value = cand->value;
+    cand->lid = cand_data.pos_id;
+    cand->rid = cand_data.pos_id;
+  }
+  EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
+  EXPECT_GT(segment->candidates_size(), 1);
+  EXPECT_EQ("一", segment->candidate(0).value);
+  EXPECT_EQ("位置", segment->candidate(1).value);
+}
+
 TEST_F(NumberRewriterTest, RewriteForPartialSuggestion_b16765535) {
   std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
-  const char kBubun[] = "部分";
+  constexpr char kBubun[] = "部分";
   Segments segments;
   {
     Segment *seg = segments.push_back_segment();
@@ -943,7 +993,7 @@ TEST_F(NumberRewriterTest, RewriteForPartialSuggestion_b16765535) {
   ASSERT_LE(2, seg.candidates_size());
   for (size_t i = 0; i < seg.candidates_size(); ++i) {
     const Segment::Candidate &candidate = seg.candidate(i);
-    EXPECT_TRUE(Util::StartsWith(candidate.description, kBubun));
+    EXPECT_TRUE(absl::StartsWith(candidate.description, kBubun));
     EXPECT_TRUE(candidate.attributes &
                 Segment::Candidate::PARTIALLY_KEY_CONSUMED);
   }
@@ -952,7 +1002,7 @@ TEST_F(NumberRewriterTest, RewriteForPartialSuggestion_b16765535) {
 TEST_F(NumberRewriterTest, RewriteForPartialSuggestion_b19470020) {
   std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
-  const char kBubun[] = "部分";
+  constexpr char kBubun[] = "部分";
   Segments segments;
   {
     Segment *seg = segments.push_back_segment();
@@ -982,7 +1032,7 @@ TEST_F(NumberRewriterTest, RewriteForPartialSuggestion_b19470020) {
     }
     found_halfwidth = true;
     EXPECT_EQ(3, candidate.consumed_key_size);
-    EXPECT_TRUE(Util::StartsWith(candidate.description, kBubun));
+    EXPECT_TRUE(absl::StartsWith(candidate.description, kBubun));
     EXPECT_TRUE(candidate.attributes &
                 Segment::Candidate::PARTIALLY_KEY_CONSUMED);
   }
