@@ -29,10 +29,12 @@
 
 #include "rewriter/transliteration_rewriter.h"
 
+#include <cstdint>
 #include <string>
 #include <type_traits>
 #include <vector>
 
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/number_util.h"
 #include "base/text_normalizer.h"
@@ -56,13 +58,13 @@ bool IsComposerApplicable(const ConversionRequest &request,
   }
 
   std::string conversion_query;
-  if (segments->request_type() == Segments::PREDICTION ||
-      segments->request_type() == Segments::SUGGESTION) {
+  if (request.request_type() == ConversionRequest::PREDICTION ||
+      request.request_type() == ConversionRequest::SUGGESTION) {
     request.composer().GetQueryForPrediction(&conversion_query);
   } else {
     request.composer().GetQueryForConversion(&conversion_query);
-    if (segments->request_type() == Segments::PARTIAL_PREDICTION ||
-        segments->request_type() == Segments::PARTIAL_SUGGESTION) {
+    if (request.request_type() == ConversionRequest::PARTIAL_PREDICTION ||
+        request.request_type() == ConversionRequest::PARTIAL_SUGGESTION) {
       Util::Utf8SubString(conversion_query, 0, request.composer().GetCursor(),
                           &conversion_query);
     }
@@ -82,11 +84,8 @@ bool IsComposerApplicable(const ConversionRequest &request,
 
 void NormalizeT13ns(std::vector<std::string> *t13ns) {
   DCHECK(t13ns);
-  std::string normalized;
   for (size_t i = 0; i < t13ns->size(); ++i) {
-    normalized.clear();
-    TextNormalizer::NormalizeText(t13ns->at(i), &normalized);
-    t13ns->at(i) = normalized;
+    t13ns->at(i) = TextNormalizer::NormalizeText(t13ns->at(i));
   }
 }
 
@@ -141,7 +140,7 @@ void ModifyT13nsForGodan(const std::string &key,
   for (std::string::const_iterator c = src.begin(); c != src.end(); ++c) {
     using IsNonnegativeAndLessThanType = IsNonnegativeAndLessThan<
         std::is_unsigned<std::string::value_type>::type>;
-    if (IsNonnegativeAndLessThanType()(*c, arraysize(kKeycodeToT13nMap)) &&
+    if (IsNonnegativeAndLessThanType()(*c, std::size(kKeycodeToT13nMap)) &&
         kKeycodeToT13nMap[*c] != nullptr) {
       dst.append(kKeycodeToT13nMap[*c]);
     } else {
@@ -156,7 +155,7 @@ void ModifyT13nsForGodan(const std::string &key,
   //   removed in the later phase of de-dupping.
   const std::string &half_ascii = dst.empty() ? key : dst;
   std::string full_ascii;
-  Util::HalfWidthAsciiToFullWidthAscii(half_ascii, &full_ascii);
+  japanese_util::HalfWidthAsciiToFullWidthAscii(half_ascii, &full_ascii);
   std::string half_ascii_upper = half_ascii;
   std::string half_ascii_lower = half_ascii;
   std::string half_ascii_capitalized = half_ascii;
@@ -195,12 +194,12 @@ bool IsTransliterated(const std::vector<std::string> &t13ns) {
 }
 
 struct T13nIds {
-  uint16 hiragana_lid;
-  uint16 hiragana_rid;
-  uint16 katakana_lid;
-  uint16 katakana_rid;
-  uint16 ascii_lid;
-  uint16 ascii_rid;
+  uint16_t hiragana_lid;
+  uint16_t hiragana_rid;
+  uint16_t katakana_lid;
+  uint16_t katakana_rid;
+  uint16_t ascii_lid;
+  uint16_t ascii_rid;
   T13nIds()
       : hiragana_lid(0),
         hiragana_rid(0),
@@ -293,12 +292,12 @@ bool TransliterationRewriter::FillT13nsFromKey(Segments *segments) const {
     }
     const std::string &hiragana = segment->key();
     std::string full_katakana, ascii;
-    Util::HiraganaToKatakana(hiragana, &full_katakana);
-    Util::HiraganaToRomanji(hiragana, &ascii);
+    japanese_util::HiraganaToKatakana(hiragana, &full_katakana);
+    japanese_util::HiraganaToRomanji(hiragana, &ascii);
     std::string half_ascii, full_ascii, half_katakana;
-    Util::FullWidthAsciiToHalfWidthAscii(ascii, &half_ascii);
-    Util::HalfWidthAsciiToFullWidthAscii(half_ascii, &full_ascii);
-    Util::FullWidthToHalfWidth(full_katakana, &half_katakana);
+    japanese_util::FullWidthAsciiToHalfWidthAscii(ascii, &half_ascii);
+    japanese_util::HalfWidthAsciiToFullWidthAscii(half_ascii, &full_ascii);
+    japanese_util::FullWidthToHalfWidth(full_katakana, &half_katakana);
     std::string half_ascii_upper = half_ascii;
     std::string half_ascii_lower = half_ascii;
     std::string half_ascii_capitalized = half_ascii;
@@ -333,7 +332,7 @@ bool TransliterationRewriter::FillT13nsFromKey(Segments *segments) const {
 }
 
 TransliterationRewriter::TransliterationRewriter(
-    const dictionary::POSMatcher &pos_matcher)
+    const dictionary::PosMatcher &pos_matcher)
     : unknown_id_(pos_matcher.GetUnknownId()) {}
 
 TransliterationRewriter::~TransliterationRewriter() {}
@@ -395,7 +394,7 @@ bool TransliterationRewriter::AddRawNumberT13nCandidates(
 
   // Do the same thing on full form.
   std::string full_raw;
-  Util::HalfWidthAsciiToFullWidthAscii(raw, &full_raw);
+  japanese_util::HalfWidthAsciiToFullWidthAscii(raw, &full_raw);
   DCHECK(!full_raw.empty());
   if (segment->meta_candidates_size() < transliteration::FULL_ASCII ||
       segment->meta_candidate(transliteration::FULL_ASCII).value != full_raw) {
@@ -425,8 +424,8 @@ bool TransliterationRewriter::Rewrite(const ConversionRequest &request,
 }
 
 void TransliterationRewriter::InitT13nCandidate(
-    const std::string &key, const std::string &value, uint16 lid, uint16 rid,
-    Segment::Candidate *cand) const {
+    const std::string &key, const std::string &value, uint16_t lid,
+    uint16_t rid, Segment::Candidate *cand) const {
   DCHECK(cand);
   cand->Init();
   cand->value = value;
