@@ -30,6 +30,7 @@
 #ifndef MOZC_REWRITER_TRANSLITERATION_REWRITER_H_
 #define MOZC_REWRITER_TRANSLITERATION_REWRITER_H_
 
+#include <cstdint>
 #include <string>
 #include <vector>
 
@@ -42,19 +43,19 @@ namespace mozc {
 
 class TransliterationRewriter : public RewriterInterface {
  public:
-  explicit TransliterationRewriter(const dictionary::POSMatcher &pos_matcher);
+  explicit TransliterationRewriter(const dictionary::PosMatcher &pos_matcher);
   ~TransliterationRewriter() override;
 
   int capability(const ConversionRequest &request) const override;
 
   bool Rewrite(const ConversionRequest &request,
-                       Segments *segments) const;
+               Segments *segments) const override;
 
   void Finish(const ConversionRequest &request, Segments *segments) override {}
 
  private:
   void InitT13nCandidate(const std::string &key, const std::string &value,
-                         uint16 lid, uint16 rid,
+                         uint16_t lid, uint16_t rid,
                          Segment::Candidate *cand) const;
   // Sets transliteration values into segment.  If t13ns is invalid,
   // false is returned.
@@ -66,7 +67,7 @@ class TransliterationRewriter : public RewriterInterface {
   bool AddRawNumberT13nCandidates(const ConversionRequest &request,
                                   Segments *segments) const;
 
-  const uint16 unknown_id_;
+  const uint16_t unknown_id_;
 
   DISALLOW_COPY_AND_ASSIGN(TransliterationRewriter);
 };
