@@ -50,6 +50,7 @@
 #include "transliteration/transliteration.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 namespace {
@@ -87,7 +88,7 @@ class TransliterationRewriterTest : public ::testing::Test {
 
   TransliterationRewriter *CreateTransliterationRewriter() const {
     return new TransliterationRewriter(
-        dictionary::POSMatcher(mock_data_manager_.GetPOSMatcherData()));
+        dictionary::PosMatcher(mock_data_manager_.GetPosMatcherData()));
   }
 
   const commands::Request &default_request() const { return default_request_; }
@@ -208,13 +209,13 @@ TEST_F(TransliterationRewriterTest, KeyOfT13nFromComposerTest) {
   InsertASCIISequence("ssh", &composer);
 
   Segments segments;
-  segments.set_request_type(Segments::SUGGESTION);
   Segment *segment = segments.add_segment();
   CHECK(segment);
 
   commands::Request input;
   input.set_mixed_conversion(true);
   ConversionRequest request(&composer, &input, &default_config());
+  request.set_request_type(ConversionRequest::SUGGESTION);
   {
     // Although the segment key is "っ" as a partical string of the full
     // composition, the transliteration key should be "っsh" as the
@@ -777,7 +778,7 @@ TEST_F(TransliterationRewriterTest, MobileT13nTestWithGodan) {
   }
 }
 
-TEST_F(TransliterationRewriterTest, MobileT13nTest_ValidateGodanT13nTable) {
+TEST_F(TransliterationRewriterTest, MobileT13nTestValidateGodanT13nTable) {
   std::unique_ptr<TransliterationRewriter> t13n_rewriter(
       CreateTransliterationRewriter());
 
@@ -825,9 +826,8 @@ TEST_F(TransliterationRewriterTest, MobileT13nTest_ValidateGodanT13nTable) {
     InsertASCIISequence(ascii_input, &composer);
     std::string query;
     composer.GetQueryForConversion(&query);
-    SCOPED_TRACE(
-        Util::StringPrintf("char code = %d, ascii_input = %s, query = %s", i,
-                           ascii_input.c_str(), query.c_str()));
+    SCOPED_TRACE(absl::StrFormat("char code = %d, ascii_input = %s, query = %s",
+                                 i, ascii_input.c_str(), query.c_str()));
 
     Segments segments;
     Segment *segment = segments.add_segment();
@@ -874,10 +874,10 @@ TEST_F(TransliterationRewriterTest, T13nOnSuggestion) {
     EXPECT_EQ(kXtsu, query);
 
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
     Segment *segment = segments.add_segment();
     segment->set_key(kXtsu);
     ConversionRequest request(&composer, &client_request, &default_config());
+    request.set_request_type(ConversionRequest::SUGGESTION);
     EXPECT_TRUE(t13n_rewriter->Rewrite(request, &segments));
 
     const Segment &seg = segments.conversion_segment(0);
@@ -908,10 +908,10 @@ TEST_F(TransliterationRewriterTest, T13nOnPartialSuggestion) {
     composer.MoveCursorTo(1);  // "っ|sh"
 
     Segments segments;
-    segments.set_request_type(Segments::PARTIAL_SUGGESTION);
     Segment *segment = segments.add_segment();
     segment->set_key(kXtsu);
     ConversionRequest request(&composer, &client_request, &default_config());
+    request.set_request_type(ConversionRequest::PARTIAL_SUGGESTION);
     EXPECT_TRUE(t13n_rewriter->Rewrite(request, &segments));
 
     const Segment &seg = segments.conversion_segment(0);
