@@ -30,6 +30,7 @@
 #include "rewriter/unicode_rewriter.h"
 
 #include <cctype>
+#include <cstdint>
 #include <string>
 
 #include "base/logging.h"
@@ -39,6 +40,8 @@
 #include "converter/converter_interface.h"
 #include "converter/segments.h"
 #include "request/conversion_request.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 
@@ -52,12 +55,12 @@ UnicodeRewriter::~UnicodeRewriter() {}
 namespace {
 
 // Checks given string is ucs4 expression or not.
-bool IsValidUCS4Expression(const std::string &input) {
+bool IsValidUcs4Expression(const std::string &input) {
   if (input.size() < 3 || input.size() > 8) {
     return false;
   }
 
-  if (!Util::StartsWith(input, "U+")) {
+  if (!absl::StartsWith(input, "U+")) {
     return false;
   }
 
@@ -72,14 +75,14 @@ bool IsValidUCS4Expression(const std::string &input) {
 }
 
 // Converts given string to 32bit unsigned integer.
-bool UCS4ExpressionToInteger(const std::string &input, uint32 *ucs4) {
+bool UCS4ExpressionToInteger(const std::string &input, uint32_t *ucs4) {
   DCHECK(ucs4);
   const std::string hexcode(input, 2, input.npos);
   return NumberUtil::SafeHexStrToUInt32(hexcode, ucs4);
 }
 
 // Checks if given ucs4 value is acceptable or not.
-bool IsAcceptableUnicode(const uint32 ucs4) {
+bool IsAcceptableUnicode(const uint32_t ucs4) {
   // Unicode character should be less than 0x10FFFF.
   if (ucs4 > 0x10FFFF) {
     return false;
@@ -143,9 +146,9 @@ bool UnicodeRewriter::RewriteToUnicodeCharFormat(
 
   const std::string &source_char = request.composer().source_text();
   size_t mblen = 0;
-  const char32 ucs4 = Util::UTF8ToUCS4(
+  const char32 ucs4 = Util::Utf8ToUcs4(
       source_char.data(), source_char.data() + source_char.size(), &mblen);
-  const std::string value = Util::StringPrintf("U+%04X", ucs4);
+  const std::string value = absl::StrFormat("U+%04X", ucs4);
 
   const std::string &key = segments->conversion_segment(0).key();
   Segment *segment = segments->mutable_conversion_segment(0);
@@ -162,11 +165,11 @@ bool UnicodeRewriter::RewriteFromUnicodeCharFormat(
     key += segments->conversion_segment(i).key();
   }
 
-  if (!IsValidUCS4Expression(key)) {
+  if (!IsValidUcs4Expression(key)) {
     return false;
   }
 
-  uint32 ucs4 = 0;
+  uint32_t ucs4 = 0;
   if (!UCS4ExpressionToInteger(key, &ucs4)) {
     return false;
   }
@@ -176,7 +179,7 @@ bool UnicodeRewriter::RewriteFromUnicodeCharFormat(
   }
 
   std::string value;
-  Util::UCS4ToUTF8(ucs4, &value);
+  Util::Ucs4ToUtf8(ucs4, &value);
   if (value.empty()) {
     return false;
   }
@@ -187,7 +190,7 @@ bool UnicodeRewriter::RewriteFromUnicodeCharFormat(
       return false;
     }
 
-    const uint32 resize_len =
+    const uint32_t resize_len =
         Util::CharsLen(key) -
         Util::CharsLen(segments->conversion_segment(0).key());
     if (!parent_converter_->ResizeSegment(segments, request, 0, resize_len)) {
