@@ -30,6 +30,7 @@
 #include "rewriter/unicode_rewriter.h"
 
 #include <cstddef>
+#include <cstdint>
 #include <cstdlib>
 #include <memory>
 #include <string>
@@ -48,6 +49,7 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 namespace {
@@ -88,7 +90,7 @@ class UnicodeRewriterTest : public ::testing::Test {
 
   void SetUp() override {
     SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
-    engine_.reset(MockDataEngineFactory::Create());
+    engine_ = MockDataEngineFactory::Create().value();
   }
 
   std::unique_ptr<EngineInterface> engine_;
@@ -167,22 +169,22 @@ TEST_F(UnicodeRewriterTest, UnicodeConversionTest) {
   };
 
   // All ascii code would be accepted.
-  for (uint32 ascii = 0x20; ascii < 0x7F; ++ascii) {
-    const std::string ucs4 = Util::StringPrintf("U+00%02X", ascii);
+  for (uint32_t ascii = 0x20; ascii < 0x7F; ++ascii) {
+    const std::string ucs4 = absl::StrFormat("U+00%02X", ascii);
     InitSegments(ucs4, ucs4, &segments);
     EXPECT_TRUE(rewriter.Rewrite(request, &segments));
     EXPECT_EQ(ascii, segments.segment(0).candidate(0).value.at(0));
   }
 
   // Mozc accepts Japanese characters
-  for (size_t i = 0; i < arraysize(kUcs4Utf8Data); ++i) {
+  for (size_t i = 0; i < std::size(kUcs4Utf8Data); ++i) {
     InitSegments(kUcs4Utf8Data[i].ucs4, kUcs4Utf8Data[i].ucs4, &segments);
     EXPECT_TRUE(rewriter.Rewrite(request, &segments));
     EXPECT_TRUE(ContainCandidate(segments, kUcs4Utf8Data[i].utf8));
   }
 
   // Mozc does not accept other characters
-  for (size_t i = 0; i < arraysize(kMozcUnsupportedUtf8); ++i) {
+  for (size_t i = 0; i < std::size(kMozcUnsupportedUtf8); ++i) {
     InitSegments(kMozcUnsupportedUtf8[i], kMozcUnsupportedUtf8[i], &segments);
     EXPECT_FALSE(rewriter.Rewrite(request, &segments));
   }
