@@ -49,14 +49,13 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace {
 
 using dictionary::SuppressionDictionary;
 using dictionary::UserDictionary;
-using dictionary::UserPOS;
+using dictionary::UserPos;
 
 void AddCandidate(const std::string &key, const std::string &value,
                   const std::string &content_key,
@@ -82,11 +81,11 @@ class UsageRewriterTest : public ::testing::Test {
     SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
     config::ConfigHandler::GetDefaultConfig(&config_);
 
-    data_manager_ = absl::make_unique<testing::MockDataManager>();
-    pos_matcher_.Set(data_manager_->GetPOSMatcherData());
-    suppression_dictionary_ = absl::make_unique<SuppressionDictionary>();
-    user_dictionary_ = absl::make_unique<UserDictionary>(
-        UserPOS::CreateFromDataManager(*data_manager_), pos_matcher_,
+    data_manager_ = std::make_unique<testing::MockDataManager>();
+    pos_matcher_.Set(data_manager_->GetPosMatcherData());
+    suppression_dictionary_ = std::make_unique<SuppressionDictionary>();
+    user_dictionary_ = std::make_unique<UserDictionary>(
+        UserPos::CreateFromDataManager(*data_manager_), pos_matcher_,
         suppression_dictionary_.get());
   }
 
@@ -106,7 +105,7 @@ class UsageRewriterTest : public ::testing::Test {
   std::unique_ptr<SuppressionDictionary> suppression_dictionary_;
   std::unique_ptr<UserDictionary> user_dictionary_;
   std::unique_ptr<testing::MockDataManager> data_manager_;
-  dictionary::POSMatcher pos_matcher_;
+  dictionary::PosMatcher pos_matcher_;
 };
 
 TEST_F(UsageRewriterTest, CapabilityTest) {
