@@ -41,13 +41,13 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
+#include "absl/strings/str_join.h"
 
 namespace mozc {
 
 namespace {
 void AddCandidate(const std::string &value, bool is_user_dictionary,
                   Segments *segments) {
-  segments->set_request_type(Segments::CONVERSION);
   Segment *seg = nullptr;
   if (segments->segments_size() == 0) {
     seg = segments->push_back_segment();
@@ -73,9 +73,7 @@ std::string GetCandidates(const Segments &segments) {
   for (size_t i = 0; i < seg.candidates_size(); ++i) {
     results.push_back(seg.candidate(i).value);
   }
-  std::string result;
-  Util::JoinStrings(results, " ", &result);
-  return result;
+  return absl::StrJoin(results, " ");
 }
 }  // namespace
 
