@@ -31,6 +31,7 @@
 
 #include <algorithm>
 #include <cctype>
+#include <cstdint>
 #include <set>
 #include <string>
 #include <vector>
@@ -53,27 +54,29 @@
 #include "storage/lru_storage.h"
 #include "transliteration/transliteration.h"
 #include "usage_stats/usage_stats.h"
+#include "absl/container/btree_set.h"
+#include "absl/status/status.h"
 #include "absl/strings/string_view.h"
 
 using mozc::config::CharacterFormManager;
 using mozc::config::Config;
 using mozc::dictionary::PosGroup;
-using mozc::dictionary::POSMatcher;
-using mozc::storage::LRUStorage;
+using mozc::dictionary::PosMatcher;
+using mozc::storage::LruStorage;
 
 namespace mozc {
 namespace {
 
-const uint32 kValueSize = 4;
-const uint32 kLRUSize = 20000;
-const uint32 kSeedValue = 0xf28defe3;
-const uint32 kMaxCandidatesSize = 255;
+constexpr uint32_t kValueSize = 4;
+constexpr uint32_t kLruSize = 20000;
+constexpr uint32_t kSeedValue = 0xf28defe3;
+constexpr uint32_t kMaxCandidatesSize = 255;
 // Size of candidates to be reranked to the top at one sorting operation.
 // Note, if sorting operation is called twice, up to 10 (= 5 * 2) candidates
 // could be reranked in total.
-const size_t kMaxRerankSize = 5;
+constexpr size_t kMaxRerankSize = 5;
 
-const char kFileName[] = "user://segment.db";
+constexpr char kFileName[] = "user://segment.db";
 
 // Temporarily disable unused private field warning against
 // FeatureValue::reserved_ from Clang.
@@ -83,7 +86,7 @@ MOZC_CLANG_PUSH_WARNING();
 // clang-format off
 #if MOZC_CLANG_HAS_WARNING(unused-private-field)
 MOZC_CLANG_DISABLE_WARNING(unused-private-field);
-#endif
+#endif  // MOZC_CLANG_HAS_WARNING(unused-private-field)
 // clang-format on
 class FeatureValue {
  public:
@@ -91,8 +94,8 @@ class FeatureValue {
   bool IsValid() const { return (feature_type_ == 1); }
 
  private:
-  uint32 feature_type_ : 1;  // always 1
-  uint32 reserved_ : 31;     // this area is reserved for future
+  uint32_t feature_type_ : 1;  // always 1
+  uint32_t reserved_ : 31;     // this area is reserved for future
 };
 MOZC_CLANG_POP_WARNING();
 
@@ -109,7 +112,7 @@ MOZC_CLANG_PUSH_WARNING();
 // clang-format off
 #if MOZC_CLANG_HAS_WARNING(unused-private-field)
 MOZC_CLANG_DISABLE_WARNING(unused-private-field);
-#endif
+#endif  // MOZC_CLANG_HAS_WARNING(unused-private-field)
 // clang-format on
 class KeyTriggerValue {
  public:
@@ -117,17 +120,17 @@ class KeyTriggerValue {
 
   bool IsValid() const { return (feature_type_ == 0); }
 
-  uint32 candidates_size() const { return candidates_size_; }
+  uint32_t candidates_size() const { return candidates_size_; }
 
-  void set_candidates_size(uint32 size) {
+  void set_candidates_size(uint32_t size) {
     candidates_size_ = std::min(size, kMaxCandidatesSize);
   }
 
  private:
-  uint32 feature_type_ : 1;  // always 0
-  uint32 reserved_ : 23;     // this area is reserved for future
+  uint32_t feature_type_ : 1;  // always 0
+  uint32_t reserved_ : 23;     // this area is reserved for future
   // want to encode POS, freq etc.
-  uint32 candidates_size_ : 8;  // candidate size
+  uint32_t candidates_size_ : 8;  // candidate size
 };
 MOZC_CLANG_POP_WARNING();
 
@@ -146,8 +149,7 @@ class ScoreTypeCompare {
 inline int GetDefaultCandidateIndex(const Segment &segment) {
   // Check up to kMaxRerankSize + 1 candidates because candidate with
   // BEST_CANDIDATE is highly possibly in that range (http://b/9992330).
-  const int size =
-      static_cast<int>(std::min(segment.candidates_size(), kMaxRerankSize + 1));
+  const int size = std::min<int>(segment.candidates_size(), kMaxRerankSize + 1);
   for (int i = 0; i < size; ++i) {
     if (segment.candidate(i).attributes & Segment::Candidate::BEST_CANDIDATE) {
       return i;
@@ -161,7 +163,7 @@ inline int GetDefaultCandidateIndex(const Segment &segment) {
 }
 
 // JoinStringWithTabN joins N strings with TAB delimiters ('\t') in a way
-// similar to Util::JoinStrings() and/or Util::AppendStringWithDelimiter() but
+// similar to absl::StrJoin() and/or Util::AppendStringWithDelimiter() but
 // in a more efficient way. Since this module is called every key stroke and
 // performs many string concatenation, we use these functions instead of ones
 // from Util.
@@ -325,7 +327,7 @@ inline bool GetFeatureS(const Segments &segments, size_t i,
 
 // Feature "Number"
 // used for number rewrite
-inline bool GetFeatureN(uint16 type, std::string *value) {
+inline bool GetFeatureN(uint16_t type, std::string *value) {
   DCHECK(value);
   JoinStringsWithTab2("N", std::to_string(type), value);
   return true;
@@ -435,10 +437,10 @@ bool IsT13NCandidate(const Segment::Candidate &cand) {
 
 bool UserSegmentHistoryRewriter::SortCandidates(
     const std::vector<ScoreType> &sorted_scores, Segment *segment) const {
-  const uint32 top_score = sorted_scores[0].score;
+  const uint32_t top_score = sorted_scores[0].score;
   const size_t size = std::min(sorted_scores.size(), kMaxRerankSize);
-  const uint32 kScoreGap = 20;  // TODO(taku): no justification
-  std::set<std::string> seen;
+  constexpr uint32_t kScoreGap = 20;  // TODO(taku): no justification
+  absl::btree_set<std::string> seen;
 
   size_t next_pos = 0;
   for (size_t n = 0; n < size; ++n) {
@@ -463,16 +465,17 @@ bool UserSegmentHistoryRewriter::SortCandidates(
 
     if (normalized_value != candidate->value) {
       const Segment::Candidate *normalized_cand = nullptr;
+      int pos = segment->candidates_size();
       for (size_t l = 0; l < segment->candidates_size(); ++l) {
         if (segment->candidate(l).value == normalized_value) {
           normalized_cand = &segment->candidate(l);
+          pos = l;
           break;
         }
       }
 
       if (normalized_cand != nullptr) {
         if (seen.find(normalized_value) == seen.end()) {
-          const int pos = segment->indexOf(normalized_cand);
           DCHECK(pos != segment->candidates_size());
           segment->move_candidate(pos, next_pos);
           ++next_pos;
@@ -511,14 +514,14 @@ bool UserSegmentHistoryRewriter::SortCandidates(
 }
 
 UserSegmentHistoryRewriter::UserSegmentHistoryRewriter(
-    const POSMatcher *pos_matcher, const PosGroup *pos_group)
-    : storage_(new LRUStorage),
+    const PosMatcher *pos_matcher, const PosGroup *pos_group)
+    : storage_(new LruStorage),
       pos_matcher_(pos_matcher),
       pos_group_(pos_group) {
   Reload();
 
-  CHECK_EQ(sizeof(uint32), sizeof(FeatureValue));
-  CHECK_EQ(sizeof(uint32), sizeof(KeyTriggerValue));
+  CHECK_EQ(sizeof(uint32_t), sizeof(FeatureValue));
+  CHECK_EQ(sizeof(uint32_t), sizeof(KeyTriggerValue));
 }
 
 UserSegmentHistoryRewriter::~UserSegmentHistoryRewriter() {}
@@ -551,8 +554,8 @@ UserSegmentHistoryRewriter::~UserSegmentHistoryRewriter() {}
 
 bool UserSegmentHistoryRewriter::GetScore(const Segments &segments,
                                           size_t segment_index,
-                                          int candidate_index, uint32 *score,
-                                          uint32 *last_access_time) const {
+                                          int candidate_index, uint32_t *score,
+                                          uint32_t *last_access_time) const {
   const size_t segments_size = segments.conversion_segments_size();
   const Segment::Candidate &top_candidate =
       segments.segment(segment_index).candidate(0);
@@ -577,14 +580,14 @@ bool UserSegmentHistoryRewriter::GetScore(const Segments &segments,
   *last_access_time = 0;
 
   // They are used inside FETCH_FEATURE
-  uint32 last_access_time_result = 0;
+  uint32_t last_access_time_result = 0;
   std::string feature_key;
 
-  const uint32 trigram_score = (segments_size == 3) ? 180 : 30;
-  const uint32 bigram_score = (segments_size == 2) ? 60 : 10;
-  const uint32 bigram_number_score = (segments_size == 2) ? 50 : 8;
-  const uint32 unigram_score = (segments_size == 1) ? 36 : 6;
-  const uint32 single_score = (segments_size == 1) ? 90 : 15;
+  const uint32_t trigram_score = (segments_size == 3) ? 180 : 30;
+  const uint32_t bigram_score = (segments_size == 2) ? 60 : 10;
+  const uint32_t bigram_number_score = (segments_size == 2) ? 50 : 8;
+  const uint32_t unigram_score = (segments_size == 1) ? 36 : 6;
+  const uint32_t single_score = (segments_size == 1) ? 90 : 15;
 
   FETCH_FEATURE(GetFeatureLR, all_key, all_value, trigram_score);
   FETCH_FEATURE(GetFeatureLL, all_key, all_value, trigram_score);
@@ -754,8 +757,8 @@ bool UserSegmentHistoryRewriter::IsAvailable(const ConversionRequest &request,
     return false;
   }
 
-  if (!segments.user_history_enabled()) {
-    VLOG(2) << "!user_history_enabled";
+  if (!request.enable_user_history_for_conversion()) {
+    VLOG(2) << "user history for conversion is disabled";
     return false;
   }
 
@@ -777,7 +780,7 @@ bool UserSegmentHistoryRewriter::IsAvailable(const ConversionRequest &request,
 
 void UserSegmentHistoryRewriter::Finish(const ConversionRequest &request,
                                         Segments *segments) {
-  if (segments->request_type() != Segments::CONVERSION) {
+  if (request.request_type() != ConversionRequest::CONVERSION) {
     return;
   }
 
@@ -820,20 +823,22 @@ bool UserSegmentHistoryRewriter::Sync() {
 
 bool UserSegmentHistoryRewriter::Reload() {
   const std::string filename = ConfigFileStream::GetFileName(kFileName);
-  if (!storage_->OpenOrCreate(filename.c_str(), kValueSize, kLRUSize,
+  if (!storage_->OpenOrCreate(filename.c_str(), kValueSize, kLruSize,
                               kSeedValue)) {
     LOG(WARNING) << "cannot initialize UserSegmentHistoryRewriter";
     storage_.reset();
     return false;
   }
 
-  const char kFileSuffix[] = ".merge_pending";
+  constexpr char kFileSuffix[] = ".merge_pending";
   const std::string merge_pending_file = filename + kFileSuffix;
 
   // merge pending file does not always exist.
-  if (FileUtil::FileExists(merge_pending_file)) {
+  if (absl::Status s = FileUtil::FileExists(merge_pending_file); s.ok()) {
     storage_->Merge(merge_pending_file.c_str());
-    FileUtil::Unlink(merge_pending_file);
+    FileUtil::UnlinkOrLogError(merge_pending_file);
+  } else if (!absl::IsNotFound(s)) {
+    LOG(ERROR) << "Cannot check if " << merge_pending_file << " exists: " << s;
   }
 
   return true;
@@ -875,7 +880,7 @@ void UserSegmentHistoryRewriter::InsertTriggerKey(const Segment &segment) {
   DCHECK(storage_.get());
 
   KeyTriggerValue v;
-  static_assert(sizeof(uint32) == sizeof(v),
+  static_assert(sizeof(uint32_t) == sizeof(v),
                 "KeyTriggerValue must be 32-bit int size.");
 
   // TODO(taku): saving segment.candidate_size() might be too heavy and
@@ -903,8 +908,8 @@ bool UserSegmentHistoryRewriter::RewriteNumber(Segment *segment) const {
       j -= static_cast<int>(segment->candidates_size() +
                             segment->meta_candidates_size());
     }
-    uint32 score = 0;
-    uint32 last_access_time = 0;
+    uint32_t score = 0;
+    uint32_t last_access_time = 0;
     std::string feature_key;
     GetFeatureN(segment->candidate(j).style, &feature_key);
     const FeatureValue *v = reinterpret_cast<const FeatureValue *>(
@@ -996,8 +1001,8 @@ bool UserSegmentHistoryRewriter::Rewrite(const ConversionRequest &request,
                               transliteration::NUM_T13N_TYPES);
       }
 
-      uint32 score = 0;
-      uint32 last_access_time = 0;
+      uint32_t score = 0;
+      uint32_t last_access_time = 0;
       if (GetScore(*segments, i, j, &score, &last_access_time)) {
         scores.push_back(ScoreType());
         scores.back().score = score;
