@@ -29,6 +29,7 @@
 
 #include "rewriter/user_segment_history_rewriter.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -49,10 +50,11 @@
 #include "request/conversion_request.h"
 #include "rewriter/number_rewriter.h"
 #include "rewriter/variants_rewriter.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
@@ -61,9 +63,9 @@ using config::CharacterFormManager;
 using config::Config;
 using config::ConfigHandler;
 using dictionary::PosGroup;
-using dictionary::POSMatcher;
+using dictionary::PosMatcher;
 
-const size_t kCandidatesSize = 20;
+constexpr size_t kCandidatesSize = 20;
 
 void InitSegments(Segments *segments, size_t size, size_t candidate_size) {
   segments->Clear();
@@ -71,12 +73,12 @@ void InitSegments(Segments *segments, size_t size, size_t candidate_size) {
     Segment *segment = segments->add_segment();
     CHECK(segment);
     segment->set_key(std::string("segment") +
-                     std::to_string(static_cast<uint32>(i)));
+                     std::to_string(static_cast<uint32_t>(i)));
     for (size_t j = 0; j < candidate_size; ++j) {
       Segment::Candidate *c = segment->add_candidate();
       c->content_key = segment->key();
       c->content_value =
-          std::string("candidate") + std::to_string(static_cast<uint32>(j));
+          std::string("candidate") + std::to_string(static_cast<uint32_t>(j));
       c->value = c->content_value;
       if (j == 0) {
         c->attributes |= Segment::Candidate::BEST_CANDIDATE;
@@ -92,7 +94,8 @@ void InitSegments(Segments *segments, size_t size) {
 }
 
 void AppendCandidateSuffix(Segment *segment, size_t index,
-                           const std::string &suffix, uint16 lid, uint16 rid) {
+                           const std::string &suffix, uint16_t lid,
+                           uint16_t rid) {
   segment->set_key(segment->key() + suffix);
   segment->mutable_candidate(index)->value += suffix;
   segment->mutable_candidate(index)->lid = lid;
@@ -100,7 +103,7 @@ void AppendCandidateSuffix(Segment *segment, size_t index,
 }
 
 void AppendCandidateSuffixWithLid(Segment *segment, size_t index,
-                                  const std::string &suffix, uint16 lid) {
+                                  const std::string &suffix, uint16_t lid) {
   // if lid == 0 and rid == 0, we assume that candidate is t13n.
   // we set 1 as rid to avoid this.
   AppendCandidateSuffix(segment, index, suffix, lid, 1);
@@ -128,9 +131,9 @@ class UserSegmentHistoryRewriterTest : public ::testing::Test {
 
     Clock::SetClockForUnitTest(nullptr);
 
-    pos_matcher_.Set(mock_data_manager_.GetPOSMatcherData());
+    pos_matcher_.Set(mock_data_manager_.GetPosMatcherData());
     pos_group_ =
-        absl::make_unique<PosGroup>(mock_data_manager_.GetPosGroupData());
+        std::make_unique<PosGroup>(mock_data_manager_.GetPosGroupData());
     ASSERT_TRUE(pos_group_.get() != nullptr);
   }
 
@@ -145,7 +148,7 @@ class UserSegmentHistoryRewriterTest : public ::testing::Test {
     CharacterFormManager::GetCharacterFormManager()->SetDefaultRule();
   }
 
-  const POSMatcher &pos_matcher() const { return pos_matcher_; }
+  const PosMatcher &pos_matcher() const { return pos_matcher_; }
 
   NumberRewriter *CreateNumberRewriter() const {
     return new NumberRewriter(&mock_data_manager_);
@@ -172,7 +175,7 @@ class UserSegmentHistoryRewriterTest : public ::testing::Test {
 
  private:
   const testing::MockDataManager mock_data_manager_;
-  POSMatcher pos_matcher_;
+  PosMatcher pos_matcher_;
   std::unique_ptr<const PosGroup> pos_group_;
   DISALLOW_COPY_AND_ASSIGN(UserSegmentHistoryRewriterTest);
 };
@@ -182,7 +185,7 @@ TEST_F(UserSegmentHistoryRewriterTest, CreateFile) {
       CreateUserSegmentHistoryRewriter());
   const std::string history_file =
       FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "/segment.db");
-  EXPECT_TRUE(FileUtil::FileExists(history_file));
+  EXPECT_OK(FileUtil::FileExists(history_file));
 }
 
 TEST_F(UserSegmentHistoryRewriterTest, InvalidInputsTest) {
@@ -278,41 +281,41 @@ TEST_F(UserSegmentHistoryRewriterTest, DisableTest) {
   Segments segments;
   std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
+  ConversionRequest conversion_request(request_);
 
   {
     InitSegments(&segments, 1);
-    segments.set_user_history_enabled(true);
+    conversion_request.set_enable_user_history_for_conversion(true);
     segments.mutable_segment(0)->move_candidate(2, 0);
     segments.mutable_segment(0)->mutable_candidate(0)->attributes |=
         Segment::Candidate::RERANKED;
     segments.mutable_segment(0)->set_segment_type(Segment::FIXED_VALUE);
-    rewriter->Finish(request_, &segments);
+    rewriter->Finish(conversion_request, &segments);
     InitSegments(&segments, 1);
-    rewriter->Rewrite(request_, &segments);
+    rewriter->Rewrite(conversion_request, &segments);
     EXPECT_EQ("candidate2", segments.segment(0).candidate(0).value);
 
     InitSegments(&segments, 1);
-    segments.set_user_history_enabled(false);
-    rewriter->Rewrite(request_, &segments);
+    conversion_request.set_enable_user_history_for_conversion(false);
+    rewriter->Rewrite(conversion_request, &segments);
     EXPECT_EQ("candidate0", segments.segment(0).candidate(0).value);
 
     InitSegments(&segments, 1);
-    segments.set_user_history_enabled(true);
-    rewriter->Rewrite(request_, &segments);
+    conversion_request.set_enable_user_history_for_conversion(true);
+    rewriter->Rewrite(conversion_request, &segments);
     EXPECT_EQ("candidate2", segments.segment(0).candidate(0).value);
   }
 
   {
     InitSegments(&segments, 1);
-    segments.set_user_history_enabled(false);
+    conversion_request.set_enable_user_history_for_conversion(false);
     segments.mutable_segment(0)->move_candidate(2, 0);
     segments.mutable_segment(0)->mutable_candidate(0)->attributes |=
         Segment::Candidate::RERANKED;
     segments.mutable_segment(0)->set_segment_type(Segment::FIXED_VALUE);
-    rewriter->Finish(request_, &segments);
+    rewriter->Finish(conversion_request, &segments);
     InitSegments(&segments, 1);
-    rewriter->Rewrite(request_, &segments);
-    segments.set_user_history_enabled(true);
+    rewriter->Rewrite(conversion_request, &segments);
     EXPECT_EQ("candidate0", segments.segment(0).candidate(0).value);
   }
 }
@@ -408,8 +411,8 @@ TEST_F(UserSegmentHistoryRewriterTest, SequenceTest) {
 
   rewriter->Clear();
 
-  const uint64 kSeconds = 0;
-  const uint32 kMicroSeconds = 0;
+  constexpr uint64_t kSeconds = 0;
+  constexpr uint32_t kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
   Clock::SetClockForUnitTest(&clock);
 
@@ -500,8 +503,8 @@ TEST_F(UserSegmentHistoryRewriterTest, DupTest) {
 
   rewriter->Clear();
 
-  const uint64 kSeconds = 0;
-  const uint32 kMicroSeconds = 0;
+  constexpr uint64_t kSeconds = 0;
+  constexpr uint32_t kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
   Clock::SetClockForUnitTest(&clock);
 
@@ -1320,8 +1323,8 @@ TEST_F(UserSegmentHistoryRewriterTest, Regression2459519) {
 
   rewriter->Clear();
 
-  const uint64 kSeconds = 0;
-  const uint32 kMicroSeconds = 0;
+  constexpr uint64_t kSeconds = 0;
+  constexpr uint32_t kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
   Clock::SetClockForUnitTest(&clock);
 
@@ -1394,7 +1397,7 @@ TEST_F(UserSegmentHistoryRewriterTest, PuntuationsTest) {
   std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
 
-  const uint16 id = pos_matcher().GetJapanesePunctuationsId();
+  const uint16_t id = pos_matcher().GetJapanesePunctuationsId();
 
   rewriter->Clear();
 
@@ -1448,8 +1451,8 @@ TEST_F(UserSegmentHistoryRewriterTest, RandomTest) {
   std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
 
-  const uint64 kSeconds = 0;
-  const uint32 kMicroSeconds = 0;
+  constexpr uint64_t kSeconds = 0;
+  constexpr uint32_t kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
   Clock::SetClockForUnitTest(&clock);
 
@@ -1509,10 +1512,10 @@ TEST_F(UserSegmentHistoryRewriterTest, AnnotationAfterLearning) {
     rewriter->Rewrite(request_, &segments);
     EXPECT_EQ("abc", segments.segment(0).candidate(0).content_value);
     // "[半] アルファベット"
-    std::string expectation = VariantsRewriter::kHalfWidth;
-    const std::string alphabet = VariantsRewriter::kAlphabet;
+    auto expectation = std::string(VariantsRewriter::kHalfWidth);
+    const absl::string_view alphabet = VariantsRewriter::kAlphabet;
     if (!alphabet.empty()) {
-      expectation += ' ' + alphabet;
+      expectation.append(1, ' ').append(alphabet.data(), alphabet.size());
     }
     EXPECT_EQ(expectation, segments.segment(0).candidate(0).description);
     rewriter->Finish(request_, &segments);
