@@ -29,9 +29,12 @@
 
 #include "rewriter/variants_rewriter.h"
 
+#include <cstdint>
 #include <string>
+#include <utility>
 #include <vector>
 
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/number_util.h"
 #include "base/util.h"
@@ -40,13 +43,15 @@
 #include "dictionary/pos_matcher.h"
 #include "protocol/commands.pb.h"
 #include "request/conversion_request.h"
+#include "absl/strings/match.h"
+#include "absl/strings/str_replace.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
 
 using ::mozc::config::CharacterFormManager;
-using ::mozc::dictionary::POSMatcher;
+using ::mozc::dictionary::PosMatcher;
 
 // Append |src| to |dst| with a separator ' '.
 void AppendString(absl::string_view src, std::string *dst) {
@@ -59,13 +64,30 @@ void AppendString(absl::string_view src, std::string *dst) {
   }
 }
 
-// Return true if all charcters in |value| are UNKNOWN_SCRIPT
-// and FormType of |value| are consistent, e.g. all fullwith or
-// all halfwidth.
+// Returns true if |full| has the corresponding half width form.
+bool IsConvertibleToHalfWidthForm(const std::string &full) {
+  // TODO(b/209357879): remove this line once FullWidthToHalfWidth() itself will
+  // support the conversion.
+  const std::string tmp =
+      absl::StrReplaceAll(full, {{"＼", "\\"}, {"￥", "¥"}});
+
+  std::string half;
+  japanese_util::FullWidthToHalfWidth(tmp, &half);
+  return full != half;
+}
+
+// Returns true if |value| meets all the following 1) ~ 3) conditions.
+// 1) all charcters in |value| are UNKNOWN_SCRIPT
+// 2) FormType of |value| are consistent, e.g. all fullwith or all halfwidth
+// 3) if they're all fullwidth characters, they're potentially convertible to
+//    their corresponding halfwidth form, e.g. '／' => '/'
 // Example:
 // "&-()" => true (all symbol and all half)
+// "／" => true (all symbol, all full and convertible to the corresponding half)
 // "&-（）" => false (all symbol but contains both full/half width)
 // "google" => false (not symbol)
+// "㌫" => false (all symbol, all full but not convertible to the corresponding
+// half)
 bool HasCharacterFormDescription(const std::string &value) {
   if (value.empty()) {
     return false;
@@ -83,70 +105,48 @@ bool HasCharacterFormDescription(const std::string &value) {
     }
     prev = type;
   }
-  return true;
+
+  if (prev == Util::HALF_WIDTH) {
+    return true;
+  }
+
+  // returns false here only if all the characters are fullwidth and they're not
+  // convertible to their corresponding halfwidth forms.
+  return IsConvertibleToHalfWidthForm(value);
 }
 
 }  // namespace
 
-#ifdef OS_ANDROID
-const char *VariantsRewriter::kHiragana = "";
-const char *VariantsRewriter::kKatakana = "";
-const char *VariantsRewriter::kNumber = "";
-const char *VariantsRewriter::kAlphabet = "";
-const char *VariantsRewriter::kKanji = "";
-const char *VariantsRewriter::kFullWidth = "[全]";
-const char *VariantsRewriter::kHalfWidth = "[半]";
-const char *VariantsRewriter::kPlatformDependent = "<機種依存>";
-const char *VariantsRewriter::kDidYouMean = "<もしかして>";
-const char *VariantsRewriter::kYenKigou = "円記号";
-#else   // OS_ANDROID
-const char *VariantsRewriter::kHiragana = "ひらがな";
-const char *VariantsRewriter::kKatakana = "カタカナ";
-const char *VariantsRewriter::kNumber = "数字";
-const char *VariantsRewriter::kAlphabet = "アルファベット";
-const char *VariantsRewriter::kKanji = "漢字";
-const char *VariantsRewriter::kFullWidth = "[全]";
-const char *VariantsRewriter::kHalfWidth = "[半]";
-const char *VariantsRewriter::kPlatformDependent = "<機種依存文字>";
-const char *VariantsRewriter::kDidYouMean = "<もしかして>";
-const char *VariantsRewriter::kYenKigou = "円記号";
-#endif  // OS_ANDROID
-
-VariantsRewriter::VariantsRewriter(const POSMatcher pos_matcher)
+VariantsRewriter::VariantsRewriter(const PosMatcher pos_matcher)
     : pos_matcher_(pos_matcher) {}
 
 VariantsRewriter::~VariantsRewriter() = default;
 
 // static
 void VariantsRewriter::SetDescriptionForCandidate(
-    const POSMatcher &pos_matcher, Segment::Candidate *candidate) {
-  SetDescription(pos_matcher,
-                 FULL_HALF_WIDTH | CHARACTER_FORM |
-                     PLATFORM_DEPENDENT_CHARACTER | ZIPCODE |
-                     SPELLING_CORRECTION,
-                 candidate);
+    const PosMatcher &pos_matcher, Segment::Candidate *candidate) {
+  SetDescription(
+      pos_matcher,
+      (FULL_HALF_WIDTH | CHARACTER_FORM | ZIPCODE | SPELLING_CORRECTION),
+      candidate);
 }
 
 // static
 void VariantsRewriter::SetDescriptionForTransliteration(
-    const POSMatcher &pos_matcher, Segment::Candidate *candidate) {
+    const PosMatcher &pos_matcher, Segment::Candidate *candidate) {
   SetDescription(pos_matcher,
-                 FULL_HALF_WIDTH | FULL_HALF_WIDTH_WITH_UNKNOWN |
-                     CHARACTER_FORM | PLATFORM_DEPENDENT_CHARACTER |
-                     SPELLING_CORRECTION,
+                 (FULL_HALF_WIDTH | CHARACTER_FORM | SPELLING_CORRECTION),
                  candidate);
 }
 
 // static
 void VariantsRewriter::SetDescriptionForPrediction(
-    const POSMatcher &pos_matcher, Segment::Candidate *candidate) {
-  SetDescription(pos_matcher,
-                 PLATFORM_DEPENDENT_CHARACTER | ZIPCODE | SPELLING_CORRECTION,
-                 candidate);
+    const PosMatcher &pos_matcher, Segment::Candidate *candidate) {
+  SetDescription(pos_matcher, ZIPCODE | SPELLING_CORRECTION, candidate);
 }
 
 // static
-void VariantsRewriter::SetDescription(const POSMatcher &pos_matcher,
+void VariantsRewriter::SetDescription(const PosMatcher &pos_matcher,
                                       int description_type,
                                       Segment::Candidate *candidate) {
   absl::string_view character_form_message;
@@ -157,22 +157,22 @@ void VariantsRewriter::SetDescription(const POSMatcher &pos_matcher,
         Util::GetScriptTypeWithoutSymbols(candidate->value);
     switch (type) {
       case Util::HIRAGANA:
-        character_form_message = absl::string_view(kHiragana);
+        character_form_message = kHiragana;
         // don't need to set full/half, because hiragana only has
         // full form
         description_type &= ~FULL_HALF_WIDTH;
         break;
       case Util::KATAKANA:
         // character_form_message = "カタカナ";
-        character_form_message = absl::string_view(kKatakana);
+        character_form_message = kKatakana;
         break;
       case Util::NUMBER:
         // character_form_message = "数字";
-        character_form_message = absl::string_view(kNumber);
+        character_form_message = kNumber;
         break;
       case Util::ALPHABET:
         // character_form_message = "アルファベット";
-        character_form_message = absl::string_view(kAlphabet);
+        character_form_message = kAlphabet;
         break;
       case Util::KANJI:
       case Util::EMOJI:
@@ -181,8 +181,7 @@ void VariantsRewriter::SetDescription(const POSMatcher &pos_matcher,
         description_type &= ~FULL_HALF_WIDTH;
         break;
       case Util::UNKNOWN_SCRIPT:  // mixed character
-        if ((description_type & FULL_HALF_WIDTH_WITH_UNKNOWN) ||
-            HasCharacterFormDescription(candidate->value)) {
+        if (HasCharacterFormDescription(candidate->value)) {
           description_type |= FULL_HALF_WIDTH;
         } else {
           description_type &= ~FULL_HALF_WIDTH;
@@ -208,21 +207,21 @@ void VariantsRewriter::SetDescription(const POSMatcher &pos_matcher,
     switch (form) {
       case Util::FULL_WIDTH:
         // description = "[全]";
-        description = kFullWidth;
+        description = std::string(kFullWidth);
         break;
       case Util::HALF_WIDTH:
         // description = "[半]";
-        description = kHalfWidth;
+        description = std::string(kHalfWidth);
         break;
       default:
         break;
     }
   } else if (description_type & FULL_WIDTH) {
     // description = "[全]";
-    description = kFullWidth;
+    description = std::string(kFullWidth);
   } else if (description_type & HALF_WIDTH) {
     // description = "[半]";
-    description = kHalfWidth;
+    description = std::string(kHalfWidth);
   }
 
   // add character_form_message
@@ -234,23 +233,18 @@ void VariantsRewriter::SetDescription(const POSMatcher &pos_matcher,
     // if "\" (half-width backslash) or "＼" ()
     AppendString("バックスラッシュ", &description);
   } else if (candidate->value == "¥") {
-    // if "¥" (half-width Yen sign), append kYenKigou and kPlatformDependent.
+    // if "¥" (half-width Yen sign), append kYenKigou.
     AppendString(kYenKigou, &description);
-    AppendString(kPlatformDependent, &description);
   } else if (candidate->value == "￥") {
     // if "￥" (full-width Yen sign), append only kYenKigou
     AppendString(kYenKigou, &description);
+  } else if (candidate->value == "~") {
+    AppendString("チルダ", &description);
   } else {
     AppendString(candidate->description, &description);
   }
 
-  // Platform dependent char description
-  if (description_type & PLATFORM_DEPENDENT_CHARACTER &&
-      Util::GetCharacterSet(candidate->value) >= Util::JISX0212) {
-    AppendString(kPlatformDependent, &description);
-  }
-
-  // The follwoing description tries to overwrite existing description.
+  // The following description tries to overwrite existing description.
   // TODO(taku): reconsider this behavior.
   // Zipcode description
   if ((description_type & ZIPCODE) && pos_matcher.IsZipcode(candidate->lid) &&
@@ -260,12 +254,12 @@ void VariantsRewriter::SetDescription(const POSMatcher &pos_matcher,
     AppendString(candidate->description, &description);
   }
 
-  // The follwoing description tries to overwrite existing description.
+  // The following description tries to overwrite existing description.
   // TODO(taku): reconsider this behavior.
   // Spelling Correction description
   if ((description_type & SPELLING_CORRECTION) &&
       (candidate->attributes & Segment::Candidate::SPELLING_CORRECTION)) {
-    description = kDidYouMean;
+    description = std::string(kDidYouMean);
     // Add prefix to distinguish this candidate.
     candidate->prefix = "→ ";
     // Append default description because it may contain extra description.
@@ -273,7 +267,7 @@ void VariantsRewriter::SetDescription(const POSMatcher &pos_matcher,
   }
 
   // set new description
-  candidate->description.swap(description);
+  candidate->description = std::move(description);
   candidate->attributes |= Segment::Candidate::NO_EXTRA_DESCRIPTION;
 }
 
@@ -299,8 +293,8 @@ bool VariantsRewriter::RewriteSegment(RewriteType type, Segment *seg) const {
   // Regular Candidate
   std::string default_value, alternative_value;
   std::string default_content_value, alternative_content_value;
-  std::vector<uint32> default_inner_segment_boundary;
-  std::vector<uint32> alternative_inner_segment_boundary;
+  std::vector<uint32_t> default_inner_segment_boundary;
+  std::vector<uint32_t> alternative_inner_segment_boundary;
   for (size_t i = 0; i < seg->candidates_size(); ++i) {
     Segment::Candidate *original_candidate = seg->mutable_candidate(i);
     DCHECK(original_candidate);
@@ -332,12 +326,10 @@ bool VariantsRewriter::RewriteSegment(RewriteType type, Segment *seg) const {
         CharacterFormManager::UNKNOWN_FORM;
 
     int default_description_type =
-        (CHARACTER_FORM | PLATFORM_DEPENDENT_CHARACTER | ZIPCODE |
-         SPELLING_CORRECTION);
+        (CHARACTER_FORM | ZIPCODE | SPELLING_CORRECTION);
 
     int alternative_description_type =
-        (CHARACTER_FORM | PLATFORM_DEPENDENT_CHARACTER | ZIPCODE |
-         SPELLING_CORRECTION);
+        (CHARACTER_FORM | ZIPCODE | SPELLING_CORRECTION);
 
     if (CharacterFormManager::GetFormTypesFromStringPair(
             default_value, &default_form, alternative_value,
@@ -406,8 +398,8 @@ bool VariantsRewriter::GenerateAlternatives(
     const Segment::Candidate &original, std::string *default_value,
     std::string *alternative_value, std::string *default_content_value,
     std::string *alternative_content_value,
-    std::vector<uint32> *default_inner_segment_boundary,
-    std::vector<uint32> *alternative_inner_segment_boundary) const {
+    std::vector<uint32_t> *default_inner_segment_boundary,
+    std::vector<uint32_t> *alternative_inner_segment_boundary) const {
   default_value->clear();
   alternative_value->clear();
   default_content_value->clear();
@@ -492,7 +484,7 @@ bool VariantsRewriter::GenerateAlternatives(
 void VariantsRewriter::Finish(const ConversionRequest &request,
                               Segments *segments) {
   if (!request.request().mixed_conversion() &&
-      segments->request_type() != Segments::CONVERSION) {
+      request.request_type() != ConversionRequest::CONVERSION) {
     return;
   }
 
@@ -531,12 +523,12 @@ void VariantsRewriter::Finish(const ConversionRequest &request,
     // annotation in the description for character width, using it is
     // more reliable than guessing from |candidate.value|.
     if (Util::GetFirstScriptType(candidate.value) == Util::NUMBER) {
-      if (candidate.description.find(kHalfWidth) != std::string::npos) {
+      if (absl::StrContains(candidate.description, kHalfWidth)) {
         CharacterFormManager::GetCharacterFormManager()->SetCharacterForm(
             "0", config::Config::HALF_WIDTH);
         continue;
       }
-      if (candidate.description.find(kFullWidth) != std::string::npos) {
+      if (absl::StrContains(candidate.description, kFullWidth)) {
         CharacterFormManager::GetCharacterFormManager()->SetCharacterForm(
             "0", config::Config::FULL_WIDTH);
         continue;
@@ -559,7 +551,7 @@ bool VariantsRewriter::Rewrite(const ConversionRequest &request,
   RewriteType type;
   if (request.request().mixed_conversion()) {  // For mobile.
     type = EXPAND_VARIANT;
-  } else if (segments->request_type() == Segments::SUGGESTION) {
+  } else if (request.request_type() == ConversionRequest::SUGGESTION) {
     type = SELECT_VARIANT;
   } else {
     type = EXPAND_VARIANT;
