@@ -32,8 +32,8 @@
 #include <memory>
 #include <string>
 
+#include "base/japanese_util.h"
 #include "base/logging.h"
-#include "base/util.h"
 #include "config/character_form_manager.h"
 #include "converter/segments.h"
 #include "data_manager/testing/mock_data_manager.h"
@@ -43,6 +43,7 @@
 #include "request/conversion_request.h"
 #include "testing/base/public/gunit.h"
 #include "testing/base/public/mozctest.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
@@ -50,13 +51,14 @@ namespace {
 using ::mozc::commands::Request;
 using ::mozc::config::CharacterFormManager;
 using ::mozc::config::Config;
-using ::mozc::dictionary::POSMatcher;
+using ::mozc::dictionary::PosMatcher;
 
-std::string AppendString(const std::string &lhs, const std::string &rhs) {
+std::string AppendString(absl::string_view lhs, absl::string_view rhs) {
+  auto result = std::string(lhs);
   if (!rhs.empty()) {
-    return lhs + ' ' + rhs;
+    result.append(1, ' ').append(rhs.data(), rhs.size());
   }
-  return lhs;
+  return result;
 }
 
 }  // namespace
@@ -69,7 +71,7 @@ class VariantsRewriterTest : public ::testing::Test {
 
   void SetUp() override {
     Reset();
-    pos_matcher_.Set(mock_data_manager_.GetPOSMatcherData());
+    pos_matcher_.Set(mock_data_manager_.GetPosMatcherData());
   }
 
   void TearDown() override { Reset(); }
@@ -97,7 +99,7 @@ class VariantsRewriterTest : public ::testing::Test {
     return new VariantsRewriter(pos_matcher_);
   }
 
-  POSMatcher pos_matcher_;
+  PosMatcher pos_matcher_;
 
  private:
   const testing::ScopedTmpUserProfileDirectory tmp_profile_dir_;
@@ -242,7 +244,8 @@ TEST_F(VariantsRewriterTest, RewriteTestManyCandidates) {
       EXPECT_EQ(std::to_string(i), seg->candidate(3 * i + 1).value);
       EXPECT_EQ(std::to_string(i), seg->candidate(3 * i + 1).content_value);
       std::string full_width;
-      Util::HalfWidthToFullWidth(seg->candidate(3 * i + 1).value, &full_width);
+      japanese_util::HalfWidthToFullWidth(seg->candidate(3 * i + 1).value,
+                                          &full_width);
       EXPECT_EQ(full_width, seg->candidate(3 * i).value);
       EXPECT_EQ(full_width, seg->candidate(3 * i).content_value);
       EXPECT_EQ("ぐーぐる", seg->candidate(3 * i + 2).value);
@@ -273,7 +276,8 @@ TEST_F(VariantsRewriterTest, RewriteTestManyCandidates) {
       EXPECT_EQ(std::to_string(i), seg->candidate(3 * i + 2).value);
       EXPECT_EQ(std::to_string(i), seg->candidate(3 * i + 2).content_value);
       std::string full_width;
-      Util::HalfWidthToFullWidth(seg->candidate(3 * i + 2).value, &full_width);
+      japanese_util::HalfWidthToFullWidth(seg->candidate(3 * i + 2).value,
+                                          &full_width);
       EXPECT_EQ(full_width, seg->candidate(3 * i + 1).value);
       EXPECT_EQ(full_width, seg->candidate(3 * i + 1).content_value);
       EXPECT_EQ("ぐーぐる", seg->candidate(3 * i).value);
@@ -365,15 +369,6 @@ TEST_F(VariantsRewriterTest, SetDescriptionForCandidate) {
         AppendString(VariantsRewriter::kFullWidth, VariantsRewriter::kAlphabet),
         candidate.description);
   }
-  {
-    Segment::Candidate candidate;
-    candidate.Init();
-    candidate.value = "草彅剛";
-    candidate.content_value = candidate.value;
-    candidate.content_key = "くさなぎつよし";
-    VariantsRewriter::SetDescriptionForCandidate(pos_matcher_, &candidate);
-    EXPECT_EQ(VariantsRewriter::kPlatformDependent, candidate.description);
-  }
   {
     Segment::Candidate candidate;
     candidate.Init();
@@ -389,7 +384,7 @@ TEST_F(VariantsRewriterTest, SetDescriptionForCandidate) {
     candidate.Init();
     candidate.value = "＼";  // Full-width backslash
     candidate.content_value = candidate.value;
-    candidate.content_key = "えん";
+    candidate.content_key = "ばっくすらっしゅ";
     VariantsRewriter::SetDescriptionForCandidate(pos_matcher_, &candidate);
     const char *expected = "[全] バックスラッシュ";
     EXPECT_EQ(expected, candidate.description);
@@ -401,10 +396,7 @@ TEST_F(VariantsRewriterTest, SetDescriptionForCandidate) {
     candidate.content_value = candidate.value;
     candidate.content_key = "えん";
     VariantsRewriter::SetDescriptionForCandidate(pos_matcher_, &candidate);
-    // "[半] 円記号 <機種依存文字>" for Desktop,
-    // "[半] 円記号 <機種依存>" for Android
-    std::string expected = "[半] 円記号 ";
-    expected.append(VariantsRewriter::kPlatformDependent);
+    std::string expected = "[半] 円記号";
     EXPECT_EQ(expected, candidate.description);
   }
   {
@@ -417,6 +409,16 @@ TEST_F(VariantsRewriterTest, SetDescriptionForCandidate) {
     const char *expected = "[全] 円記号";
     EXPECT_EQ(expected, candidate.description);
   }
+  {
+    Segment::Candidate candidate;
+    candidate.Init();
+    candidate.value = "~";  // Tilde
+    candidate.content_value = candidate.value;
+    candidate.content_key = "~";
+    VariantsRewriter::SetDescriptionForCandidate(pos_matcher_, &candidate);
+    std::string expected = "[半] チルダ";
+    EXPECT_EQ(expected, candidate.description);
+  }
   {
     Segment::Candidate candidate;
     candidate.Init();
@@ -426,11 +428,31 @@ TEST_F(VariantsRewriterTest, SetDescriptionForCandidate) {
     candidate.content_key = "ねずみ";
     candidate.description = "絵文字";
     VariantsRewriter::SetDescriptionForCandidate(pos_matcher_, &candidate);
-    // "絵文字 <機種依存文字>" for Desktop, "絵文字 <機種依存>" for Android
-    std::string expected(
-        "絵文字"
-        " ");
-    expected.append(VariantsRewriter::kPlatformDependent);
+    std::string expected = "絵文字";
+    EXPECT_EQ(expected, candidate.description);
+  }
+  {
+    Segment::Candidate candidate;
+    candidate.Init();
+    // A symbol representing "パーセント".
+    candidate.value = "㌫";
+    candidate.content_value = candidate.value;
+    candidate.content_key = "ぱーせんと";
+    candidate.description = "単位";
+    VariantsRewriter::SetDescriptionForCandidate(pos_matcher_, &candidate);
+    std::string expected = "単位";
+    EXPECT_EQ(expected, candidate.description);
+  }
+  {
+    Segment::Candidate candidate;
+    candidate.Init();
+    // Minus sign.
+    candidate.value = "−";
+    candidate.content_value = candidate.value;
+    candidate.content_key = "まいなす";
+    candidate.description = "マイナス";
+    VariantsRewriter::SetDescriptionForCandidate(pos_matcher_, &candidate);
+    std::string expected = "[全] マイナス";
     EXPECT_EQ(expected, candidate.description);
   }
 }
@@ -476,12 +498,28 @@ TEST_F(VariantsRewriterTest, SetDescriptionForTransliteration) {
   {
     Segment::Candidate candidate;
     candidate.Init();
-    candidate.value = "草彅剛";
+    // A symbol representing "パーセント".
+    candidate.value = "㌫";
     candidate.content_value = candidate.value;
-    candidate.content_key = "くさなぎつよし";
+    candidate.content_key = "ぱーせんと";
+    candidate.description = "単位";
     VariantsRewriter::SetDescriptionForTransliteration(pos_matcher_,
                                                        &candidate);
-    EXPECT_EQ(VariantsRewriter::kPlatformDependent, candidate.description);
+    std::string expected = "単位";
+    EXPECT_EQ(expected, candidate.description);
+  }
+  {
+    Segment::Candidate candidate;
+    candidate.Init();
+    // Minus sign.
+    candidate.value = "−";
+    candidate.content_value = candidate.value;
+    candidate.content_key = "まいなす";
+    candidate.description = "マイナス";
+    VariantsRewriter::SetDescriptionForTransliteration(pos_matcher_,
+                                                       &candidate);
+    std::string expected = "[全] マイナス";
+    EXPECT_EQ(expected, candidate.description);
   }
 }
 
@@ -544,11 +582,24 @@ TEST_F(VariantsRewriterTest, SetDescriptionForPrediction) {
   {
     Segment::Candidate candidate;
     candidate.Init();
-    candidate.value = "草彅剛";
+    // A symbol representing "パーセント".
+    candidate.value = "㌫";
     candidate.content_value = candidate.value;
-    candidate.content_key = "くさなぎつよし";
+    candidate.content_key = "ぱーせんと";
     VariantsRewriter::SetDescriptionForPrediction(pos_matcher_, &candidate);
-    EXPECT_EQ(VariantsRewriter::kPlatformDependent, candidate.description);
+    std::string expected = "";
+    EXPECT_EQ(expected, candidate.description);
+  }
+  {
+    Segment::Candidate candidate;
+    candidate.Init();
+    // Minus sign.
+    candidate.value = "−";
+    candidate.content_value = candidate.value;
+    candidate.content_key = "まいなす";
+    VariantsRewriter::SetDescriptionForPrediction(pos_matcher_, &candidate);
+    std::string expected = "";
+    EXPECT_EQ(expected, candidate.description);
   }
 }
 
@@ -556,10 +607,9 @@ TEST_F(VariantsRewriterTest, RewriteForConversion) {
   CharacterFormManager *character_form_manager =
       CharacterFormManager::GetCharacterFormManager();
   std::unique_ptr<VariantsRewriter> rewriter(CreateVariantsRewriter());
-  const ConversionRequest request;
+  ConversionRequest request;
   {
     Segments segments;
-    segments.set_request_type(Segments::CONVERSION);
     {
       Segment *segment = segments.push_back_segment();
       segment->set_key("abc");
@@ -583,7 +633,6 @@ TEST_F(VariantsRewriterTest, RewriteForConversion) {
   {
     character_form_manager->SetCharacterForm("abc", Config::HALF_WIDTH);
     Segments segments;
-    segments.set_request_type(Segments::CONVERSION);
     {
       Segment *segment = segments.push_back_segment();
       segment->set_key("abc");
@@ -604,16 +653,41 @@ TEST_F(VariantsRewriterTest, RewriteForConversion) {
     EXPECT_EQ("abc", segments.segment(0).candidate(0).value);
     EXPECT_EQ("ａｂｃ", segments.segment(0).candidate(1).value);
   }
+  {
+    Segments segments;
+    {
+      Segment *segment = segments.push_back_segment();
+      segment->set_key("~");
+      Segment::Candidate *candidate = segment->add_candidate();
+      candidate->Init();
+      candidate->key = "~";
+      candidate->content_key = "~";
+      candidate->value = "〜";
+      candidate->content_value = "〜";
+      candidate->description = "波ダッシュ";
+    }
+    EXPECT_TRUE(rewriter->Rewrite(request, &segments));
+    EXPECT_EQ(1, segments.segments_size());
+    EXPECT_EQ(2, segments.segment(0).candidates_size());
+
+    EXPECT_EQ(Config::FULL_WIDTH,
+              character_form_manager->GetConversionCharacterForm("~"));
+
+    EXPECT_EQ("〜", segments.segment(0).candidate(0).value);
+    EXPECT_EQ("[全] 波ダッシュ", segments.segment(0).candidate(0).description);
+    EXPECT_EQ("~", segments.segment(0).candidate(1).value);
+    EXPECT_EQ("[半] チルダ", segments.segment(0).candidate(1).description);
+  }
 }
 
 TEST_F(VariantsRewriterTest, RewriteForPrediction) {
   CharacterFormManager *character_form_manager =
       CharacterFormManager::GetCharacterFormManager();
   std::unique_ptr<VariantsRewriter> rewriter(CreateVariantsRewriter());
-  const ConversionRequest request;
+  ConversionRequest request;
+  request.set_request_type(ConversionRequest::PREDICTION);
   {
     Segments segments;
-    segments.set_request_type(Segments::PREDICTION);
     InitSegmentsForAlphabetRewrite("abc", &segments);
     EXPECT_TRUE(rewriter->Rewrite(request, &segments));
     EXPECT_EQ(1, segments.segments_size());
@@ -628,7 +702,6 @@ TEST_F(VariantsRewriterTest, RewriteForPrediction) {
   {
     character_form_manager->SetCharacterForm("abc", Config::HALF_WIDTH);
     Segments segments;
-    segments.set_request_type(Segments::PREDICTION);
     InitSegmentsForAlphabetRewrite("abc", &segments);
     EXPECT_TRUE(rewriter->Rewrite(request, &segments));
     EXPECT_EQ(1, segments.segments_size());
@@ -650,9 +723,9 @@ TEST_F(VariantsRewriterTest, RewriteForMixedConversion) {
   request.set_mixed_conversion(true);  // Request mixed conversion.
   ConversionRequest conv_request;
   conv_request.set_request(&request);
+  conv_request.set_request_type(ConversionRequest::SUGGESTION);
   {
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
     InitSegmentsForAlphabetRewrite("abc", &segments);
     EXPECT_TRUE(rewriter->Rewrite(conv_request, &segments));
     EXPECT_EQ(1, segments.segments_size());
@@ -665,7 +738,6 @@ TEST_F(VariantsRewriterTest, RewriteForMixedConversion) {
   {
     character_form_manager->SetCharacterForm("abc", Config::HALF_WIDTH);
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
     InitSegmentsForAlphabetRewrite("abc", &segments);
     EXPECT_TRUE(rewriter->Rewrite(conv_request, &segments));
     EXPECT_EQ(1, segments.segments_size());
@@ -681,7 +753,6 @@ TEST_F(VariantsRewriterTest, RewriteForMixedConversion) {
     character_form_manager->SetCharacterForm("0", Config::HALF_WIDTH);
 
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
 
     Segment *segment = segments.push_back_segment();
     segment->set_key("さんえん");
@@ -734,9 +805,9 @@ TEST_F(VariantsRewriterTest, RewriteForPartialSuggestion) {
   request.set_mixed_conversion(true);  // Request mixed conversion.
   ConversionRequest conv_request;
   conv_request.set_request(&request);
+  conv_request.set_request_type(ConversionRequest::SUGGESTION);
   {
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
 
     Segment *segment = segments.push_back_segment();
     segment->set_key("3えん");
@@ -770,10 +841,10 @@ TEST_F(VariantsRewriterTest, RewriteForSuggestion) {
   CharacterFormManager *character_form_manager =
       CharacterFormManager::GetCharacterFormManager();
   std::unique_ptr<VariantsRewriter> rewriter(CreateVariantsRewriter());
-  const ConversionRequest request;
+  ConversionRequest request;
+  request.set_request_type(ConversionRequest::SUGGESTION);
   {
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
     InitSegmentsForAlphabetRewrite("abc", &segments);
     EXPECT_TRUE(rewriter->Rewrite(request, &segments));
     EXPECT_EQ(1, segments.segments_size());
@@ -787,7 +858,6 @@ TEST_F(VariantsRewriterTest, RewriteForSuggestion) {
   {
     character_form_manager->SetCharacterForm("abc", Config::HALF_WIDTH);
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
     InitSegmentsForAlphabetRewrite("abc", &segments);
     EXPECT_TRUE(rewriter->Rewrite(request, &segments));
     EXPECT_EQ(1, segments.segments_size());
@@ -801,7 +871,6 @@ TEST_F(VariantsRewriterTest, RewriteForSuggestion) {
   {
     // Test for candidate with inner segment boundary.
     Segments segments;
-    segments.set_request_type(Segments::SUGGESTION);
 
     Segment *segment = segments.push_back_segment();
     segment->set_key("まじ!");
@@ -853,7 +922,6 @@ TEST_F(VariantsRewriterTest, Finish) {
   const ConversionRequest request;
 
   Segments segments;
-  segments.set_request_type(Segments::CONVERSION);
 
   Segment *segment = segments.push_back_segment();
   segment->set_key("いちにさん");
@@ -882,7 +950,7 @@ TEST_F(VariantsRewriterTest, Finish) {
   cand->value = "3時";
   cand->content_value = cand->value;
   cand->style = NumberUtil::NumberString::DEFAULT_STYLE;
-  cand->description = VariantsRewriter::kHalfWidth;
+  cand->description = std::string(VariantsRewriter::kHalfWidth);
   rewriter->Finish(request, &segments);
   EXPECT_EQ(Config::HALF_WIDTH, manager->GetConversionCharacterForm("0"));
 
@@ -890,7 +958,7 @@ TEST_F(VariantsRewriterTest, Finish) {
   cand->value = "３時";
   cand->content_value = cand->value;
   cand->style = NumberUtil::NumberString::DEFAULT_STYLE;
-  cand->description = VariantsRewriter::kFullWidth;
+  cand->description = std::string(VariantsRewriter::kFullWidth);
   rewriter->Finish(request, &segments);
   EXPECT_EQ(Config::FULL_WIDTH, manager->GetConversionCharacterForm("0"));
 }
