@@ -41,6 +41,7 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
+#include "absl/strings/match.h"
 
 namespace mozc {
 namespace {
@@ -75,7 +76,7 @@ class VersionRewriterTest : public ::testing::Test {
                                       const Segments &segments) {
     for (size_t i = 0; i < segments.segments_size(); ++i) {
       for (size_t j = 0; j < segments.segment(i).candidates_size(); ++j) {
-        if (Util::StartsWith(segments.segment(i).candidate(j).value, prefix)) {
+        if (absl::StartsWith(segments.segment(i).candidate(j).value, prefix)) {
           return true;
         }
       }
@@ -109,26 +110,38 @@ TEST_F(VersionRewriterTest, MobileEnvironmentTest) {
 }
 
 
-TEST_F(VersionRewriterTest, RewriteTest_Version) {
+TEST_F(VersionRewriterTest, RewriteTestVersion) {
 #ifdef GOOGLE_JAPANESE_INPUT_BUILD
-  static const char kVersionPrefixExpected[] = "GoogleJapaneseInput-";
-  static const char kVersionPrefixUnexpected[] = "Mozc-";
-#else
-  static const char kVersionPrefixExpected[] = "Mozc-";
-  static const char kVersionPrefixUnexpected[] = "GoogleJapaneseInput-";
+  static constexpr char kVersionPrefixExpected[] = "GoogleJapaneseInput-";
+  static constexpr char kVersionPrefixUnexpected[] = "Mozc-";
+#else   // GOOGLE_JAPANESE_INPUT_BUILD
+  static constexpr char kVersionPrefixExpected[] = "Mozc-";
+  static constexpr char kVersionPrefixUnexpected[] = "GoogleJapaneseInput-";
 #endif  // GOOGLE_JAPANESE_INPUT_BUILD
 
   VersionRewriter version_rewriter(kDummyDataVersion);
 
   const ConversionRequest request;
-  Segments segments;
-  VersionRewriterTest::AddSegment("ばーじょん", "バージョン", &segments);
+  {
+    Segments segments;
+    VersionRewriterTest::AddSegment("ばーじょん", "バージョン", &segments);
 
-  EXPECT_TRUE(version_rewriter.Rewrite(request, &segments));
-  EXPECT_TRUE(VersionRewriterTest::FindCandidateWithPrefix(
-      kVersionPrefixExpected, segments));
-  EXPECT_FALSE(VersionRewriterTest::FindCandidateWithPrefix(
-      kVersionPrefixUnexpected, segments));
+    EXPECT_TRUE(version_rewriter.Rewrite(request, &segments));
+    EXPECT_TRUE(VersionRewriterTest::FindCandidateWithPrefix(
+        kVersionPrefixExpected, segments));
+    EXPECT_FALSE(VersionRewriterTest::FindCandidateWithPrefix(
+        kVersionPrefixUnexpected, segments));
+  }
+  {
+    Segments segments;
+    VersionRewriterTest::AddSegment("Version", "Version", &segments);
+
+    EXPECT_TRUE(version_rewriter.Rewrite(request, &segments));
+    EXPECT_TRUE(VersionRewriterTest::FindCandidateWithPrefix(
+        kVersionPrefixExpected, segments));
+    EXPECT_FALSE(VersionRewriterTest::FindCandidateWithPrefix(
+        kVersionPrefixUnexpected, segments));
+  }
 }
 
 }  // namespace mozc
