@@ -292,8 +292,8 @@ void SetAdvancedConfig(const ScopedSCHandle &service_handle) {
 // function to install nor uninstall the cache service.
 bool RestoreStateInternal(const cache_service::Win32ServiceState &state) {
   ScopedSCHandle service_handle;
-  const DWORD kSCRights = SC_MANAGER_CONNECT;
-  const DWORD kServiceRights =
+  constexpr DWORD kSCRights = SC_MANAGER_CONNECT;
+  constexpr DWORD kServiceRights =
       GENERIC_READ | GENERIC_WRITE | SERVICE_START | SERVICE_STOP;
   if (!GetCacheService(kSCRights, kServiceRights, &service_handle) ||
       (NULL == service_handle.get())) {
@@ -321,7 +321,7 @@ bool RestoreStateInternal(const cache_service::Win32ServiceState &state) {
     std::vector<std::wstring> arguments(state.arguments_size());
     arguments.resize(state.arguments_size());
     for (size_t i = 0; i < state.arguments_size(); ++i) {
-      if (Util::UTF8ToWide(state.arguments(i), &arguments[i]) <= 0) {
+      if (Util::Utf8ToWide(state.arguments(i), &arguments[i]) <= 0) {
         return false;
       }
     }
@@ -424,10 +424,10 @@ const wchar_t *CacheServiceManager::GetServiceName() {
 }
 
 std::wstring CacheServiceManager::GetUnquotedServicePath() {
-  const string lock_service_path = FileUtil::JoinPath(
+  const std::string lock_service_path = FileUtil::JoinPath(
       SystemUtil::GetServerDirectory(), kMozcCacheServiceExeName);
   std::wstring wlock_service_path;
-  if (Util::UTF8ToWide(lock_service_path, &wlock_service_path) <= 0) {
+  if (Util::Utf8ToWide(lock_service_path, &wlock_service_path) <= 0) {
     return L"";
   }
   return wlock_service_path;
@@ -489,7 +489,7 @@ bool CacheServiceManager::RestartService() {
     LOG(ERROR) << "ControlService failed: " << ::GetLastError();
   }
 
-  const int kNumTrial = 10;
+  constexpr int kNumTrial = 10;
   for (int i = 0; i < kNumTrial; ++i) {
     SERVICE_STATUS service_status = {};
     if (!::QueryServiceStatus(service_handle.get(), &service_status)) {
@@ -574,8 +574,8 @@ bool CacheServiceManager::RestoreStateFromString(
 
 bool CacheServiceManager::EnsureServiceStopped() {
   ScopedSCHandle service_handle;
-  const DWORD kSCRights = SC_MANAGER_CONNECT;
-  const DWORD kServiceRights = GENERIC_READ | SERVICE_STOP;
+  constexpr DWORD kSCRights = SC_MANAGER_CONNECT;
+  constexpr DWORD kServiceRights = GENERIC_READ | SERVICE_STOP;
   if (!GetCacheService(kSCRights, kServiceRights, &service_handle)) {
     return false;
   }
