@@ -64,8 +64,8 @@ void LogMessageImpl(const wchar_t (&file)[num_elements], int line,
 std::wstring GetMappedFileNameByAddress(LPVOID address) {
   wchar_t path[MAX_PATH];
   const int length = ::GetMappedFileName(::GetCurrentProcess(), address, path,
-                                         arraysize(path));
-  if (length == 0 || arraysize(path) <= length) {
+                                         std::size(path));
+  if (length == 0 || std::size(path) <= length) {
     LOG_WIN32_ERROR(L"GetMappedFileName failed.");
     return L"";
   }
@@ -188,10 +188,10 @@ bool VerifyPrivilegeRestrictionIfNeeded(DWORD dwArgc, LPTSTR *lpszArgv) {
     return true;
   }
 
-  const string temp_path = mozc::FileUtil::JoinPath(
+  const std::string temp_path = mozc::FileUtil::JoinPath(
       mozc::SystemUtil::GetServerDirectory(), "delete_me.txt");
   std::wstring wtemp_path;
-  mozc::Util::UTF8ToWide(temp_path, &wtemp_path);
+  mozc::Util::Utf8ToWide(temp_path, &wtemp_path);
   const HANDLE temp_file =
       ::CreateFileW(wtemp_path.c_str(), GENERIC_READ | GENERIC_WRITE,
                     FILE_SHARE_READ, NULL, CREATE_ALWAYS,
@@ -266,7 +266,7 @@ VOID WINAPI ServiceMain(DWORD dwArgc, LPTSTR *lpszArgv) {
   }
 
   std::wstring server_path;
-  mozc::Util::UTF8ToWide(mozc::SystemUtil::GetServerPath(), &server_path);
+  mozc::Util::Utf8ToWide(mozc::SystemUtil::GetServerPath(), &server_path);
 
   mozc::ScopedHandle file_handle(::CreateFile(server_path.c_str(), GENERIC_READ,
                                               FILE_SHARE_READ, 0, OPEN_EXISTING,
@@ -279,7 +279,7 @@ VOID WINAPI ServiceMain(DWORD dwArgc, LPTSTR *lpszArgv) {
   const size_t size = ::GetFileSize(file_handle.get(), 0);
 
   // Do not load image if the file size is too big
-  const DWORD kMaxImageSize = 100 * 1024 * 1024;  // 100MB
+  constexpr DWORD kMaxImageSize = 100 * 1024 * 1024;  // 100MB
   if (size > kMaxImageSize) {
     STOP_SERVICE_AND_EXIT_FUNCTION();
   }
@@ -327,8 +327,8 @@ VOID WINAPI ServiceMain(DWORD dwArgc, LPTSTR *lpszArgv) {
     STOP_SERVICE_AND_EXIT_FUNCTION();
   }
 
-  const DWORD kMinAdditionalSize = 512 * 1024;       // 512KB
-  const DWORD kMaxAdditionalSize = 2 * 1024 * 1024;  // 2MB
+  constexpr DWORD kMinAdditionalSize = 512 * 1024;       // 512KB
+  constexpr DWORD kMaxAdditionalSize = 2 * 1024 * 1024;  // 2MB
 
   if (!::SetProcessWorkingSetSize(::GetCurrentProcess(),
                                   mem_info.RegionSize + kMinAdditionalSize,
@@ -343,7 +343,7 @@ VOID WINAPI ServiceMain(DWORD dwArgc, LPTSTR *lpszArgv) {
 WAIT_HIGH : {
   const HANDLE handles[] = {g_stop_event, high_memory_event.get()};
   const DWORD result =
-      ::WaitForMultipleObjects(arraysize(handles), handles, FALSE, INFINITE);
+      ::WaitForMultipleObjects(std::size(handles), handles, FALSE, INFINITE);
   switch (result) {
     case WAIT_OBJECT_0 + 1:  // high is signaled
       goto TRY_LOCK;
@@ -355,8 +355,8 @@ WAIT_HIGH : {
 }
 
 TRY_LOCK : {
-  const int kMaxTimeout = 10 * 60 * 1000;  // 10 min.
-  const int kMinTimeout = 1 * 60 * 1000;   // 1min.
+  constexpr int kMaxTimeout = 10 * 60 * 1000;  // 10 min.
+  constexpr int kMinTimeout = 1 * 60 * 1000;   // 1min.
 
   // if the low event is signaled just after calling VirtualLock(),
   // the VirtualLock() itself may indirectly raise the low event.
@@ -397,7 +397,7 @@ TRY_LOCK : {
 WAIT_LOW : {
   const HANDLE handles[] = {g_stop_event, low_memory_event.get()};
   const DWORD result =
-      ::WaitForMultipleObjects(arraysize(handles), handles, FALSE, INFINITE);
+      ::WaitForMultipleObjects(std::size(handles), handles, FALSE, INFINITE);
   switch (result) {
     case WAIT_OBJECT_0 + 1:  // low is signaled
       if (!::VirtualUnlock(mem_info.BaseAddress, mem_info.RegionSize)) {
