@@ -33,7 +33,6 @@
 #include <string>
 
 #include "testing/base/public/gunit.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace session {
@@ -41,9 +40,9 @@ namespace session {
 class CandidateListTest : public testing::Test {
  protected:
   void SetUp() override {
-    main_list_ = absl::make_unique<CandidateList>(true);
-    sub_list_2_ = absl::make_unique<CandidateList>(true);
-    sub_sub_list_2_1_ = absl::make_unique<CandidateList>(false);
+    main_list_ = std::make_unique<CandidateList>(true);
+    sub_list_2_ = std::make_unique<CandidateList>(true);
+    sub_sub_list_2_1_ = std::make_unique<CandidateList>(false);
 
     main_list_->AddCandidate(0, "0");                           // main0
     main_list_->AddCandidate(1, "1");                           // main1
@@ -287,7 +286,7 @@ TEST_F(CandidateListTest, FocusedId) {
   EXPECT_EQ(0, empty_list.focused_id());
 }
 
-TEST_F(CandidateListTest, set_page_size) {
+TEST_F(CandidateListTest, SetPageSize) {
   EXPECT_EQ(9, main_list_->page_size());
   // Move to the 10th item.
   EXPECT_TRUE(main_list_->MoveToId(7));
