@@ -30,7 +30,6 @@
 // Keymap utils of Mozc interface.
 
 #include "session/internal/keymap.h"
-#include "session/internal/keymap-inl.h"
 
 #include <memory>
 #include <set>
@@ -48,21 +47,24 @@
 #include "config/config_handler.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
+#include "session/internal/keymap-inl.h"
+#include "absl/container/btree_set.h"
+#include "absl/strings/str_split.h"
 
 namespace mozc {
 namespace keymap {
 namespace {
-static const char kMSIMEKeyMapFile[] = "system://ms-ime.tsv";
-static const char kATOKKeyMapFile[] = "system://atok.tsv";
-static const char kKotoeriKeyMapFile[] = "system://kotoeri.tsv";
-static const char kCustomKeyMapFile[] = "user://keymap.tsv";
-static const char kMobileKeyMapFile[] = "system://mobile.tsv";
-static const char kChromeOsKeyMapFile[] = "system://chromeos.tsv";
+static constexpr char kMSIMEKeyMapFile[] = "system://ms-ime.tsv";
+static constexpr char kATOKKeyMapFile[] = "system://atok.tsv";
+static constexpr char kKotoeriKeyMapFile[] = "system://kotoeri.tsv";
+static constexpr char kCustomKeyMapFile[] = "user://keymap.tsv";
+static constexpr char kMobileKeyMapFile[] = "system://mobile.tsv";
+static constexpr char kChromeOsKeyMapFile[] = "system://chromeos.tsv";
 }  // namespace
 
 #if defined(__APPLE__)
 const bool KeyMapManager::kInputModeXCommandSupported = false;
-#else
+#else   // __APPLE__
 const bool KeyMapManager::kInputModeXCommandSupported = true;
 #endif  // __APPLE__
 
@@ -125,7 +127,7 @@ bool KeyMapManager::ReloadConfig(const config::Config &config) {
     ofs << "# Nothing happens when you edit this file manually." << std::endl;
     ofs << custom_keymap_table;
   }
-#endif
+#endif  // MOZC_NO_LOGGING
 
   std::istringstream ifs(custom_keymap_table);
   return LoadStream(&ifs);
@@ -191,8 +193,8 @@ bool KeyMapManager::LoadStreamWithErrors(std::istream *ifs,
       continue;
     }
 
-    std::vector<std::string> rules;
-    Util::SplitStringUsing(line, "\t", &rules);
+    std::vector<std::string> rules =
+        absl::StrSplit(line, '\t', absl::SkipEmpty());
     if (rules.size() != 3) {
       LOG(ERROR) << "Invalid format: " << line;
       continue;
@@ -735,7 +737,7 @@ bool KeyMapManager::ParseCommandConversion(
 }
 
 void KeyMapManager::GetAvailableCommandNameDirect(
-    std::set<std::string> *command_names) const {
+    absl::btree_set<std::string> *command_names) const {
   DCHECK(command_names);
   for (std::map<std::string, DirectInputState::Commands>::const_iterator iter =
            command_direct_map_.begin();
@@ -745,7 +747,7 @@ void KeyMapManager::GetAvailableCommandNameDirect(
 }
 
 void KeyMapManager::GetAvailableCommandNamePrecomposition(
-    std::set<std::string> *command_names) const {
+    absl::btree_set<std::string> *command_names) const {
   DCHECK(command_names);
   for (std::map<std::string, PrecompositionState::Commands>::const_iterator
            iter = command_precomposition_map_.begin();
@@ -755,7 +757,7 @@ void KeyMapManager::GetAvailableCommandNamePrecomposition(
 }
 
 void KeyMapManager::GetAvailableCommandNameComposition(
-    std::set<std::string> *command_names) const {
+    absl::btree_set<std::string> *command_names) const {
   DCHECK(command_names);
   for (std::map<std::string, CompositionState::Commands>::const_iterator iter =
            command_composition_map_.begin();
@@ -765,7 +767,7 @@ void KeyMapManager::GetAvailableCommandNameComposition(
 }
 
 void KeyMapManager::GetAvailableCommandNameConversion(
-    std::set<std::string> *command_names) const {
+    absl::btree_set<std::string> *command_names) const {
   DCHECK(command_names);
   for (std::map<std::string, ConversionState::Commands>::const_iterator iter =
            command_conversion_map_.begin();
@@ -775,17 +777,17 @@ void KeyMapManager::GetAvailableCommandNameConversion(
 }
 
 void KeyMapManager::GetAvailableCommandNameZeroQuerySuggestion(
-    std::set<std::string> *command_names) const {
+    absl::btree_set<std::string> *command_names) const {
   GetAvailableCommandNamePrecomposition(command_names);
 }
 
 void KeyMapManager::GetAvailableCommandNameSuggestion(
-    std::set<std::string> *command_names) const {
+    absl::btree_set<std::string> *command_names) const {
   GetAvailableCommandNameComposition(command_names);
 }
 
 void KeyMapManager::GetAvailableCommandNamePrediction(
-    std::set<std::string> *command_names) const {
+    absl::btree_set<std::string> *command_names) const {
   GetAvailableCommandNameConversion(command_names);
 }
 
