@@ -32,6 +32,7 @@
 #include "session/internal/session_output.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <map>
 #include <string>
 #include <vector>
@@ -43,8 +44,10 @@
 #include "base/version.h"
 #include "composer/composer.h"
 #include "converter/segments.h"
+#include "protocol/candidates.pb.h"
 #include "protocol/commands.pb.h"
 #include "session/internal/candidate_list.h"
+#include "absl/strings/str_split.h"
 
 namespace mozc {
 namespace session {
@@ -73,55 +76,53 @@ bool FillAnnotation(const Segment::Candidate &candidate_value,
   return is_modified;
 }
 
-void FillCandidateWord(
-    const Segment::Candidate &segment_candidate,
-    const int id, const int index, const std::string base_key,
-    commands::CandidateWord *candidate_word_proto) {
+void FillCandidateWord(const Segment::Candidate &segment_candidate,
+                       const int id, const int index,
+                       const std::string &base_key,
+                       commands::CandidateWord *candidate_word_proto) {
+  // id
+  candidate_word_proto->set_id(id);
 
-    // id
-    candidate_word_proto->set_id(id);
+  // index
+  candidate_word_proto->set_index(index);
 
-    // index
-    candidate_word_proto->set_index(index);
+  // key
+  if (base_key != segment_candidate.content_key) {
+    candidate_word_proto->set_key(segment_candidate.content_key);
+  }
+  // value
+  candidate_word_proto->set_value(segment_candidate.value);
 
-    // key
-    if (base_key != segment_candidate.content_key) {
-      candidate_word_proto->set_key(segment_candidate.content_key);
-    }
-    // value
-    candidate_word_proto->set_value(segment_candidate.value);
+  // annotations
+  commands::Annotation annotation;
+  if (FillAnnotation(segment_candidate, &annotation)) {
+    *candidate_word_proto->mutable_annotation() = annotation;
+  }
 
-    // annotations
-    commands::Annotation annotation;
-    if (FillAnnotation(segment_candidate, &annotation)) {
-      candidate_word_proto->mutable_annotation()->CopyFrom(annotation);
-    }
+  if (segment_candidate.attributes & Segment::Candidate::USER_DICTIONARY) {
+    candidate_word_proto->add_attributes(commands::USER_DICTIONARY);
+  }
+  if (segment_candidate.attributes &
+      Segment::Candidate::USER_HISTORY_PREDICTION) {
+    candidate_word_proto->add_attributes(commands::USER_HISTORY);
+  }
+  if (segment_candidate.attributes & Segment::Candidate::SPELLING_CORRECTION) {
+    candidate_word_proto->add_attributes(commands::SPELLING_CORRECTION);
+  }
+  if (segment_candidate.attributes & Segment::Candidate::TYPING_CORRECTION) {
+    candidate_word_proto->add_attributes(commands::TYPING_CORRECTION);
+  }
 
-    if (segment_candidate.attributes & Segment::Candidate::USER_DICTIONARY) {
-      candidate_word_proto->add_attributes(commands::USER_DICTIONARY);
-    }
-    if (segment_candidate.attributes &
-        Segment::Candidate::USER_HISTORY_PREDICTION) {
-      candidate_word_proto->add_attributes(commands::USER_HISTORY);
-    }
-    if (segment_candidate.attributes &
-        Segment::Candidate::SPELLING_CORRECTION) {
-      candidate_word_proto->add_attributes(commands::SPELLING_CORRECTION);
-    }
-    if (segment_candidate.attributes & Segment::Candidate::TYPING_CORRECTION) {
-      candidate_word_proto->add_attributes(commands::TYPING_CORRECTION);
-    }
-
-    // number of segments
-    candidate_word_proto->set_num_segments_in_candidate(1);
-    if (!segment_candidate.inner_segment_boundary.empty()) {
-      candidate_word_proto->set_num_segments_in_candidate(
-          segment_candidate.inner_segment_boundary.size());
-    }
+  // number of segments
+  candidate_word_proto->set_num_segments_in_candidate(1);
+  if (!segment_candidate.inner_segment_boundary.empty()) {
+    candidate_word_proto->set_num_segments_in_candidate(
+        segment_candidate.inner_segment_boundary.size());
+  }
 
 #ifndef NDEBUG
-    candidate_word_proto->set_log(segment_candidate.DebugString() +
-                                  segment_candidate.log);
+  candidate_word_proto->set_log(segment_candidate.DebugString() +
+                                segment_candidate.log);
 #endif  // NDEBUG
 }
 
@@ -173,7 +174,7 @@ void SessionOutput::FillCandidate(
   // Set annotations
   commands::Annotation annotation;
   if (FillAnnotation(candidate_value, &annotation)) {
-    candidate_proto->mutable_annotation()->CopyFrom(annotation);
+    *candidate_proto->mutable_annotation() = annotation;
   }
 
   if (!candidate_value.usage_title.empty()) {
@@ -277,8 +278,8 @@ void SessionOutput::FillUsages(const Segment &segment,
   size_t c_end = 0;
   cand_list.GetPageRange(cand_list.focused_index(), &c_begin, &c_end);
 
-  typedef std::pair<int32, commands::Information *> IndexInfoPair;
-  std::map<int32, IndexInfoPair> usageid_information_map;
+  typedef std::pair<int32_t, commands::Information *> IndexInfoPair;
+  std::map<int32_t, IndexInfoPair> usageid_information_map;
   // Store usages.
   for (size_t i = c_begin; i <= c_end; ++i) {
     if (cand_list.candidate(i).IsSubcandidateList()) {
@@ -292,7 +293,7 @@ void SessionOutput::FillUsages(const Segment &segment,
 
     int index;
     commands::Information *info;
-    std::map<int32, IndexInfoPair>::iterator info_itr =
+    std::map<int32_t, IndexInfoPair>::iterator info_itr =
         usageid_information_map.find(candidate.usage_id);
 
     if (info_itr == usageid_information_map.end()) {
@@ -319,8 +320,7 @@ void SessionOutput::FillUsages(const Segment &segment,
 void SessionOutput::FillShortcuts(const std::string &shortcuts,
                                   commands::Candidates *candidates_proto) {
   const size_t num_loop =
-      std::min(static_cast<size_t>(candidates_proto->candidate_size()),
-               shortcuts.size());
+      std::min<size_t>(candidates_proto->candidate_size(), shortcuts.size());
   for (size_t i = 0; i < num_loop; ++i) {
     const std::string shortcut = shortcuts.substr(i, 1);
     candidates_proto->mutable_candidate(i)->mutable_annotation()->set_shortcut(
@@ -336,8 +336,8 @@ void SessionOutput::FillSubLabel(commands::Footer *footer) {
 
   // Append third number of the version to sub_label.
   const std::string version = Version::GetMozcVersion();
-  std::vector<std::string> version_numbers;
-  Util::SplitStringUsing(version, ".", &version_numbers);
+  std::vector<std::string> version_numbers =
+      absl::StrSplit(version, '.', absl::SkipEmpty());
   if (version_numbers.size() > 2) {
     std::string sub_label("build ");
     sub_label.append(version_numbers[2]);
@@ -359,7 +359,7 @@ bool SessionOutput::FillFooter(const commands::Category category,
   commands::Footer *footer = candidates->mutable_footer();
   if (category == commands::SUGGESTION) {
     // TODO(komatsu): Enable to localized the message.
-    const char kLabel[] = "Tabキーで選択";
+    constexpr char kLabel[] = "Tabキーで選択";
     // TODO(komatsu): Need to check if Tab is not changed to other key binding.
     footer->set_label(kLabel);
   } else {
@@ -378,11 +378,13 @@ bool SessionOutput::FillFooter(const commands::Category category,
         if (cand.has_annotation() && cand.annotation().deletable()) {
           // TODO(noriyukit): Change the message depending on user's keymap.
 #if defined(__APPLE__)
-          const char kDeleteInstruction[] = "control+fn+deleteで履歴から削除";
+          constexpr char kDeleteInstruction[] =
+              "control+fn+deleteで履歴から削除";
 #elif defined(OS_CHROMEOS)
-          const char kDeleteInstruction[] = "ctrl+alt+backspaceで履歴から削除";
+          constexpr char kDeleteInstruction[] =
+              "ctrl+alt+backspaceで履歴から削除";
 #else   // !__APPLE__ && !OS_CHROMEOS
-          const char kDeleteInstruction[] = "Ctrl+Delで履歴から削除";
+          constexpr char kDeleteInstruction[] = "Ctrl+Delで履歴から削除";
 #endif  // __APPLE__ || OS_CHROMEOS
           footer->set_label(kDeleteInstruction);
           show_build_number = false;
@@ -405,15 +407,14 @@ bool SessionOutput::FillFooter(const commands::Category category,
 
 // static
 bool SessionOutput::AddSegment(const std::string &key, const std::string &value,
-                               const uint32 segment_type_mask,
+                               const uint32_t segment_type_mask,
                                commands::Preedit *preedit) {
   // Key is always normalized as a preedit text.
-  std::string normalized_key;
-  TextNormalizer::NormalizeText(key, &normalized_key);
+  const std::string normalized_key = TextNormalizer::NormalizeText(key);
 
   std::string normalized_value;
   if (segment_type_mask & PREEDIT) {
-    TextNormalizer::NormalizeText(value, &normalized_value);
+    normalized_value = TextNormalizer::NormalizeText(value);
   } else if (segment_type_mask & CONVERSION) {
     normalized_value = value;
   } else {
@@ -444,9 +445,9 @@ void SessionOutput::FillPreedit(const composer::Composer &composer,
   std::string output;
   composer.GetStringForPreedit(&output);
 
-  const uint32 kBaseType = PREEDIT;
+  constexpr uint32_t kBaseType = PREEDIT;
   AddSegment(output, output, kBaseType, preedit);
-  preedit->set_cursor(static_cast<uint32>(composer.GetCursor()));
+  preedit->set_cursor(static_cast<uint32_t>(composer.GetCursor()));
   preedit->set_is_toggleable(composer.IsToggleable());
 }
 
@@ -455,7 +456,7 @@ void SessionOutput::FillConversion(const Segments &segments,
                                    const size_t segment_index,
                                    const int candidate_id,
                                    commands::Preedit *preedit) {
-  const uint32 kBaseType = CONVERSION;
+  constexpr uint32_t kBaseType = CONVERSION;
   // Cursor position in conversion state should be the end of the preedit.
   size_t cursor = 0;
   for (size_t i = 0; i < segments.conversion_segments_size(); ++i) {
@@ -490,8 +491,7 @@ void SessionOutput::FillConversionResult(const std::string &key,
                                          const std::string &result,
                                          commands::Result *result_proto) {
   // Key should be normalized as a preedit text.
-  std::string normalized_key;
-  TextNormalizer::NormalizeText(key, &normalized_key);
+  const std::string normalized_key = TextNormalizer::NormalizeText(key);
 
   // value is already normalized by converter.
   FillConversionResultWithoutNormalization(normalized_key, result,
@@ -501,8 +501,7 @@ void SessionOutput::FillConversionResult(const std::string &key,
 // static
 void SessionOutput::FillPreeditResult(const std::string &preedit,
                                       commands::Result *result_proto) {
-  std::string normalized_preedit;
-  TextNormalizer::NormalizeText(preedit, &normalized_preedit);
+  const std::string normalized_preedit = TextNormalizer::NormalizeText(preedit);
 
   FillConversionResultWithoutNormalization(normalized_preedit,
                                            normalized_preedit, result_proto);
