@@ -29,12 +29,14 @@
 
 #include "session/internal/session_output.h"
 
+#include <cstdint>
 #include <string>
 
 #include "base/port.h"
 #include "base/text_normalizer.h"
 #include "base/util.h"
 #include "converter/segments.h"
+#include "protocol/candidates.pb.h"
 #include "protocol/commands.pb.h"
 #include "session/internal/candidate_list.h"
 #include "testing/base/public/gunit.h"
@@ -44,7 +46,7 @@ namespace session {
 
 struct DummySegment {
   const char *value;
-  const int32 usage_id;
+  const int32_t usage_id;
   const char *usage_title;
   const char *usage_description;
 };
@@ -84,7 +86,7 @@ TEST(SessionOutputTest, FillCandidate) {
   segment.mutable_candidate(42)->suffix = kSuffix42;
   segment.mutable_candidate(42)->description = kDescription42;
   candidate_list.set_name(kSubcandidateList);
-  static const int kFirstIdInSubList = -123;
+  static constexpr int kFirstIdInSubList = -123;
   candidate_list.AddCandidate(kFirstIdInSubList, "minus 123");
   candidate_list.AddCandidate(-456, "minus 456");
   candidate_list.AddCandidate(-789, "minus 789");
@@ -118,7 +120,6 @@ TEST(SessionOutputTest, FillCandidate) {
 
 TEST(SessionOutputTest, FillCandidates) {
   Segment segment;
-  Candidate candidate;
   CandidateList candidate_list(true);
   CandidateList subcandidate_list(true);
   commands::Candidates candidates_proto;
@@ -229,7 +230,7 @@ TEST(SessionOutputTest, FillAllCandidateWords) {
 
   const char *kValues[7] = {"2",      "sub1_1",    "sub1_3",   "sub2_1",
                             "sub2_2", "subsub1_1", "subsub1_2"};
-  const size_t kValueSize = arraysize(kValues);
+  constexpr size_t kValueSize = std::size(kValues);
   for (size_t i = 0; i < kValueSize; ++i) {
     Segment::Candidate *candidate = segment.push_back_candidate();
     candidate->content_key = kNormalKey;
@@ -343,7 +344,7 @@ TEST(SessionOutputTest, FillAllCandidateWords_Attributes) {
 
   const char *kValues[5] = {"value_0", "value_1", "value_2", "value_3",
                             "value_4"};
-  const size_t kValueSize = arraysize(kValues);
+  constexpr size_t kValueSize = std::size(kValues);
   for (size_t i = 0; i < kValueSize; ++i) {
     Segment::Candidate *candidate = segment.push_back_candidate();
     candidate->content_key = kKey;
@@ -652,7 +653,7 @@ TEST(SessionOutputTest, FillFooter) {
 #else   // CHANNEL_DEV && GOOGLE_JAPANESE_INPUT_BUILD
   EXPECT_TRUE(candidates.footer().has_label());
   EXPECT_FALSE(candidates.footer().has_sub_label());
-  const char kLabel[] = "Tabキーで選択";
+  constexpr char kLabel[] = "Tabキーで選択";
   EXPECT_EQ(kLabel, candidates.footer().label());
 #endif  // CHANNEL_DEV && GOOGLE_JAPANESE_INPUT_BUILD
 
@@ -699,11 +700,11 @@ TEST(SessionOutputTest, FillFooter) {
       ASSERT_TRUE(candidates.has_footer());
       ASSERT_TRUE(candidates.footer().has_label());
 #if defined(__APPLE__)
-      const char kDeleteInstruction[] = "control+fn+deleteで履歴から削除";
+      constexpr char kDeleteInstruction[] = "control+fn+deleteで履歴から削除";
 #elif defined(OS_CHROMEOS)
-      const char kDeleteInstruction[] = "ctrl+alt+backspaceで履歴から削除";
+      constexpr char kDeleteInstruction[] = "ctrl+alt+backspaceで履歴から削除";
 #else   // !__APPLE__ && !OS_CHROMEOS
-      const char kDeleteInstruction[] = "Ctrl+Delで履歴から削除";
+      constexpr char kDeleteInstruction[] = "Ctrl+Delで履歴から削除";
 #endif  // __APPLE__ || OS_CHROMEOS
       EXPECT_EQ(kDeleteInstruction, candidates.footer().label());
 #if defined(CHANNEL_DEV) && defined(GOOGLE_JAPANESE_INPUT_BUILD)
@@ -739,11 +740,9 @@ TEST(SessionOutputTest, AddSegment) {
     EXPECT_EQ(index + 1, preedit.segment_size());
     const commands::Preedit::Segment &segment = preedit.segment(index);
 
-    std::string normalized_key;
-    TextNormalizer::NormalizeText(kKey, &normalized_key);
+    const std::string normalized_key = TextNormalizer::NormalizeText(kKey);
     EXPECT_EQ(normalized_key, segment.key());
-    std::string normalized_value;
-    TextNormalizer::NormalizeText(kValue, &normalized_value);
+    const std::string normalized_value = TextNormalizer::NormalizeText(kValue);
     EXPECT_EQ(normalized_value, segment.value());
     EXPECT_EQ(Util::CharsLen(normalized_value), segment.value_length());
     EXPECT_EQ(commands::Preedit::Segment::UNDERLINE, segment.annotation());
@@ -758,11 +757,9 @@ TEST(SessionOutputTest, AddSegment) {
     EXPECT_EQ(index + 1, preedit.segment_size());
     const commands::Preedit::Segment &segment = preedit.segment(index);
 
-    std::string normalized_key;
-    TextNormalizer::NormalizeText(kKey, &normalized_key);
+    const std::string normalized_key = TextNormalizer::NormalizeText(kKey);
     EXPECT_EQ(normalized_key, segment.key());
-    std::string normalized_value;
-    TextNormalizer::NormalizeText(kValue, &normalized_value);
+    const std::string normalized_value = TextNormalizer::NormalizeText(kValue);
     EXPECT_EQ(normalized_value, segment.value());
     EXPECT_EQ(Util::CharsLen(normalized_value), segment.value_length());
     EXPECT_EQ(commands::Preedit::Segment::UNDERLINE, segment.annotation());
@@ -777,8 +774,7 @@ TEST(SessionOutputTest, AddSegment) {
     EXPECT_EQ(index + 1, preedit.segment_size());
     const commands::Preedit::Segment &segment = preedit.segment(index);
 
-    std::string normalized_key;
-    TextNormalizer::NormalizeText(kKey, &normalized_key);
+    const std::string normalized_key = TextNormalizer::NormalizeText(kKey);
     EXPECT_EQ(normalized_key, segment.key());
     // Normalization is performed in Rewriter.
     std::string normalized_value = kValue;
@@ -796,8 +792,7 @@ TEST(SessionOutputTest, AddSegment) {
     EXPECT_EQ(index + 1, preedit.segment_size());
     const commands::Preedit::Segment &segment = preedit.segment(index);
 
-    std::string normalized_key;
-    TextNormalizer::NormalizeText(kKey, &normalized_key);
+    const std::string normalized_key = TextNormalizer::NormalizeText(kKey);
     EXPECT_EQ(normalized_key, segment.key());
     // Normalization is performed in Rewriter.
     std::string normalized_value = kValue;
@@ -817,7 +812,7 @@ TEST(SessionOutputTest, AddSegment) {
 }
 
 TEST(SessionOutputTest, FillConversionResultWithoutNormalization) {
-  const char kInput[] = "ゔ";
+  constexpr char kInput[] = "ゔ";
 
   commands::Result result;
   SessionOutput::FillConversionResultWithoutNormalization(kInput, kInput,
