@@ -29,15 +29,18 @@
 
 #include "session/output_util.h"
 
+#include <cstdint>
+
 #include "base/logging.h"
 #include "base/port.h"
+#include "protocol/candidates.pb.h"
 #include "protocol/commands.pb.h"
 
 namespace mozc {
 
 bool OutputUtil::GetCandidateIndexById(const commands::Output &output,
-                                       int32 mozc_candidate_id,
-                                       int32 *candidate_index) {
+                                       int32_t mozc_candidate_id,
+                                       int32_t *candidate_index) {
   if (candidate_index == nullptr) {
     return false;
   }
@@ -61,8 +64,8 @@ bool OutputUtil::GetCandidateIndexById(const commands::Output &output,
 }
 
 bool OutputUtil::GetCandidateIdByIndex(const commands::Output &output,
-                                       int32 candidate_index,
-                                       int32 *mozc_candidate_id) {
+                                       int32_t candidate_index,
+                                       int32_t *mozc_candidate_id) {
   if (mozc_candidate_id == nullptr) {
     return false;
   }
@@ -86,7 +89,7 @@ bool OutputUtil::GetCandidateIdByIndex(const commands::Output &output,
 }
 
 bool OutputUtil::GetFocusedCandidateId(const commands::Output &output,
-                                       int32 *mozc_candidate_id) {
+                                       int32_t *mozc_candidate_id) {
   if (mozc_candidate_id == nullptr) {
     return false;
   }
@@ -97,7 +100,7 @@ bool OutputUtil::GetFocusedCandidateId(const commands::Output &output,
   if (!list.has_focused_index()) {
     return false;
   }
-  const int32 focused_index = list.focused_index();
+  const int32_t focused_index = list.focused_index();
   for (size_t i = 0; i < list.candidates_size(); ++i) {
     const commands::CandidateWord &word = list.candidates(i);
     if (!word.has_id() || !word.has_index()) {
