@@ -31,6 +31,7 @@
 
 #include "session/session.h"
 
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <vector>
@@ -59,7 +60,7 @@
 #include "session/session_converter.h"
 #include "session/session_usage_stats_util.h"
 #include "usage_stats/usage_stats.h"
-#include "absl/memory/memory.h"
+#include "absl/strings/match.h"
 
 namespace mozc {
 namespace session {
@@ -222,9 +223,9 @@ void Session::InitContext(ImeContext *context) const {
   // On Windows session is started with direct mode.
   // FIXME(toshiyuki): Ditto for Mac after verifying on Mac.
   context->set_state(ImeContext::DIRECT);
-#else
+#else   // OS_WIN
   context->set_state(ImeContext::PRECOMPOSITION);
-#endif
+#endif  // OS_WIN
   context->mutable_client_context()->Clear();
 
   context->SetConfig(&context->GetConfig());
@@ -237,7 +238,7 @@ void Session::InitContext(ImeContext *context) const {
 
 void Session::PushUndoContext() {
   // TODO(komatsu): Support multiple undo.
-  prev_context_ = absl::make_unique<ImeContext>();
+  prev_context_ = std::make_unique<ImeContext>();
   InitContext(prev_context_.get());
   ImeContext::CopyContext(*context_, prev_context_.get());
 }
@@ -571,7 +572,7 @@ bool Session::SendKeyPrecompositionState(commands::Command *command) {
   // context is updated only here. In other words, we will stop updating the
   // client context once a conversion starts (mainly for performance reasons).
   if (command->has_input() && command->input().has_context()) {
-    context_->mutable_client_context()->CopyFrom(command->input().context());
+    *context_->mutable_client_context() = command->input().context();
   } else {
     context_->mutable_client_context()->Clear();
   }
@@ -952,8 +953,7 @@ void Session::UpdatePreferences(commands::Command *command) {
   }
 
   if (command->input().has_capability()) {
-    context_->mutable_client_capability()->CopyFrom(
-        command->input().capability());
+    *context_->mutable_client_capability() = command->input().capability();
   }
 
   // Update config values modified temporarily.
@@ -1321,7 +1321,7 @@ bool Session::CommitCandidate(commands::Command *command) {
         context_->mutable_composer()->DeleteRange(0, consumed_key_size);
         MoveCursorToEnd(command);
         // Copy the previous output for Undo.
-        context_->mutable_output()->CopyFrom(command->output());
+        *context_->mutable_output() = command->output();
         return true;
       }
     }
@@ -1341,7 +1341,7 @@ bool Session::CommitCandidate(commands::Command *command) {
   }
   Output(command);
   // Copy the previous output for Undo.
-  context_->mutable_output()->CopyFrom(command->output());
+  *context_->mutable_output() = command->output();
   return true;
 }
 
@@ -1374,21 +1374,23 @@ bool Session::MaybeSelectCandidate(commands::Command *command) {
 }
 
 void Session::set_client_capability(const commands::Capability &capability) {
-  context_->mutable_client_capability()->CopyFrom(capability);
+  *context_->mutable_client_capability() = capability;
 }
 
 void Session::set_application_info(
     const commands::ApplicationInfo &application_info) {
-  context_->mutable_application_info()->CopyFrom(application_info);
+  *context_->mutable_application_info() = application_info;
 }
 
 const commands::ApplicationInfo &Session::application_info() const {
   return context_->application_info();
 }
 
-uint64 Session::create_session_time() const { return context_->create_time(); }
+uint64_t Session::create_session_time() const {
+  return context_->create_time();
+}
 
-uint64 Session::last_command_time() const {
+uint64_t Session::last_command_time() const {
   return context_->last_command_time();
 }
 
@@ -1446,7 +1448,7 @@ bool Session::InsertCharacter(commands::Command *command) {
           commands::Request::SPACE_OR_CONVERT_COMMITTING_COMPOSITION &&
       context_->state() == ImeContext::COMPOSITION &&
       // TODO(komatsu): Support FullWidthSpace
-      Util::EndsWith(composition, " ")) {
+      absl::EndsWith(composition, " ")) {
     should_commit = true;
   }
 
@@ -1509,9 +1511,8 @@ bool Session::IsFullWidthInsertSpace(const commands::Input &input) const {
       return context_->composer().GetInputMode();
     }
 
-    composer::Composer temporary_composer;
     // Copy the current composer state just in case.
-    temporary_composer.CopyFrom(context_->composer());
+    composer::Composer temporary_composer = context_->composer();
     ApplyInputMode(input.key().mode(), &temporary_composer);
     // Refer to this temporary composer in this method.
     return temporary_composer.GetInputMode();
@@ -1725,7 +1726,7 @@ bool Session::CommitInternal(commands::Command *command,
 
   Output(command);
   // Copy the previous output for Undo.
-  context_->mutable_output()->CopyFrom(command->output());
+  *context_->mutable_output() = command->output();
   return true;
 }
 
@@ -1768,7 +1769,7 @@ bool Session::CommitFirstSuggestion(commands::Command *command) {
 
   PushUndoContext();
 
-  const int kFirstIndex = 0;
+  constexpr int kFirstIndex = 0;
   size_t committed_key_size = 0;
   context_->mutable_converter()->CommitSuggestionByIndex(
       kFirstIndex, context_->composer(), command->input().context(),
@@ -1784,7 +1785,7 @@ bool Session::CommitFirstSuggestion(commands::Command *command) {
 
   Output(command);
   // Copy the previous output for Undo.
-  context_->mutable_output()->CopyFrom(command->output());
+  *context_->mutable_output() = command->output();
   return true;
 }
 
@@ -1811,7 +1812,7 @@ bool Session::CommitSegment(commands::Command *command) {
   }
   Output(command);
   // Copy the previous output for Undo.
-  context_->mutable_output()->CopyFrom(command->output());
+  *context_->mutable_output() = command->output();
   return true;
 }
 
@@ -2281,7 +2282,8 @@ bool Session::Convert(commands::Command *command) {
       command->input().key().has_special_key() &&
       command->input().key().special_key() == commands::KeyEvent::SPACE) {
     // TODO(komatsu): Consider FullWidth Space too.
-    if (!Util::EndsWith(composition, " ")) {
+    if (!absl::EndsWith(composition, " ") ||
+        context_->composer().GetLength() != context_->composer().GetCursor()) {
       if (context_->GetRequest().space_on_alphanumeric() ==
           commands::Request::COMMIT) {
         // Space is committed with the composition
@@ -2392,7 +2394,7 @@ bool Session::MoveCursorLeft(commands::Command *command) {
 
     // Move the cursor to the beginning of the values.
     command->mutable_output()->mutable_result()->set_cursor_offset(
-        -static_cast<int32>(
+        -static_cast<int32_t>(
             Util::CharsLen(command->output().result().value())));
 
     // Do not consume.
@@ -2428,6 +2430,12 @@ bool Session::MoveCursorToEnd(commands::Command *command) {
 }
 
 bool Session::MoveCursorTo(commands::Command *command) {
+  // This method moves the cursor *inside* the composition text.
+  // Therefore on PRECOMPOSITION state, where there is no composition text,
+  // this method shouldn't consume the event but send back it to the client.
+  if (context_->state() == ImeContext::PRECOMPOSITION) {
+    return EchoBack(command);
+  }
   if (context_->state() != ImeContext::COMPOSITION) {
     return DoNothing(command);
   }
@@ -2677,7 +2685,7 @@ void Session::OutputComposition(commands::Command *command) const {
 void Session::OutputKey(commands::Command *command) const {
   OutputMode(command);
   commands::KeyEvent *key = command->mutable_output()->mutable_key();
-  key->CopyFrom(command->input().key());
+  *key = command->input().key();
 }
 
 namespace {
@@ -2700,23 +2708,23 @@ namespace {
 //   key_string == "!" || key_string == "！") &&
 //  (config.auto_conversion_key() &
 //   config::Config::AUTO_CONVERSION_EXCLAMATION_MARK));
-bool IsValidKey(const config::Config &config, const uint32 key_code,
+bool IsValidKey(const config::Config &config, const uint32_t key_code,
                 absl::string_view key_string) {
-  return (((key_code == static_cast<uint32>('.') && key_string.empty()) ||
+  return (((key_code == static_cast<uint32_t>('.') && key_string.empty()) ||
            key_string == "." || key_string == "．" || key_string == "。" ||
            key_string == "｡") &&
           (config.auto_conversion_key() &
            config::Config::AUTO_CONVERSION_KUTEN)) ||
-         (((key_code == static_cast<uint32>(',') && key_string.empty()) ||
+         (((key_code == static_cast<uint32_t>(',') && key_string.empty()) ||
            key_string == "," || key_string == "，" || key_string == "、" ||
            key_string == "､") &&
           (config.auto_conversion_key() &
            config::Config::AUTO_CONVERSION_TOUTEN)) ||
-         (((key_code == static_cast<uint32>('?') && key_string.empty()) ||
+         (((key_code == static_cast<uint32_t>('?') && key_string.empty()) ||
            key_string == "?" || key_string == "？") &&
           (config.auto_conversion_key() &
            config::Config::AUTO_CONVERSION_QUESTION_MARK)) ||
-         (((key_code == static_cast<uint32>('!') && key_string.empty()) ||
+         (((key_code == static_cast<uint32_t>('!') && key_string.empty()) ||
            key_string == "!" || key_string == "！") &&
           (config.auto_conversion_key() &
            config::Config::AUTO_CONVERSION_EXCLAMATION_MARK));
@@ -2759,7 +2767,7 @@ bool Session::CanStartAutoConversion(
     return false;
   }
 
-  const uint32 key_code = key_event.key_code();
+  const uint32_t key_code = key_event.key_code();
 
   std::string preedit;
   context_->composer().GetStringForPreedit(&preedit);
@@ -2817,14 +2825,14 @@ bool Session::HandleIndirectImeOnOff(commands::Command *command) {
   if (state == ImeContext::DIRECT && key.activated()) {
     // Indirect IME On found.
     commands::Command on_command;
-    on_command.CopyFrom(*command);
+    on_command = *command;
     if (!IMEOn(&on_command)) {
       return false;
     }
   } else if (state != ImeContext::DIRECT && !key.activated()) {
     // Indirect IME Off found.
     commands::Command off_command;
-    off_command.CopyFrom(*command);
+    off_command = *command;
     if (!IMEOff(&off_command)) {
       return false;
     }
