@@ -32,6 +32,7 @@
 #include "session/session_converter.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <limits>
 #include <string>
 
@@ -44,6 +45,7 @@
 #include "converter/converter_interface.h"
 #include "converter/converter_util.h"
 #include "converter/segments.h"
+#include "protocol/candidates.pb.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
@@ -53,13 +55,14 @@
 #include "transliteration/transliteration.h"
 #include "usage_stats/usage_stats.h"
 #include "absl/flags/flag.h"
+#include "absl/strings/match.h"
 
 using mozc::usage_stats::UsageStats;
 
 #ifdef OS_ANDROID
-const bool kDefaultUseActualConverterForRealtimeConversion = false;
-#else
-const bool kDefaultUseActualConverterForRealtimeConversion = true;
+constexpr bool kDefaultUseActualConverterForRealtimeConversion = false;
+#else   // OS_ANDROID
+constexpr bool kDefaultUseActualConverterForRealtimeConversion = true;
 #endif  // OS_ANDROID
 
 ABSL_FLAG(bool, use_actual_converter_for_realtime_conversion,
@@ -74,9 +77,8 @@ namespace {
 
 using mozc::commands::Request;
 using mozc::config::Config;
-using mozc::config::ConfigHandler;
 
-const size_t kDefaultMaxHistorySize = 3;
+constexpr size_t kDefaultMaxHistorySize = 3;
 
 const char *GetCandidateShortcuts(
     config::Config::SelectionShortcut selection_shortcut) {
@@ -110,15 +112,16 @@ const size_t SessionConverter::kConsumedAllCharacters =
 SessionConverter::SessionConverter(const ConverterInterface *converter,
                                    const Request *request, const Config *config)
     : SessionConverterInterface(),
-      state_(COMPOSITION),
       converter_(converter),
       segments_(new Segments),
       segment_index_(0),
       result_(new commands::Result),
       candidate_list_(new CandidateList(true)),
-      candidate_list_visible_(false),
       request_(request),
-      client_revision_(0) {
+      state_(COMPOSITION),
+      request_type_(ConversionRequest::CONVERSION),
+      client_revision_(0),
+      candidate_list_visible_(false) {
   conversion_preferences_.use_history = true;
   conversion_preferences_.max_history_size = kDefaultMaxHistorySize;
   conversion_preferences_.request_suggestion = true;
@@ -150,10 +153,10 @@ bool SessionConverter::ConvertWithPreferences(
     const ConversionPreferences &preferences) {
   DCHECK(CheckState(COMPOSITION | SUGGESTION | CONVERSION));
 
-  segments_->set_request_type(Segments::CONVERSION);
-  SetConversionPreferences(preferences, segments_.get());
+  ConversionRequest conversion_request(&composer, request_, config_);
+  SetConversionPreferences(preferences, segments_.get(), &conversion_request);
+  SetRequestType(ConversionRequest::CONVERSION, &conversion_request);
 
-  const ConversionRequest conversion_request(&composer, request_, config_);
   if (!converter_->StartConversionForRequest(conversion_request,
                                              segments_.get())) {
     LOG(WARNING) << "StartConversionForRequest() failed";
@@ -174,6 +177,8 @@ bool SessionConverter::GetReadingText(const std::string &source_text,
   DCHECK(reading);
   reading->clear();
   Segments reverse_segments;
+  // TODO(team): Replace with StartReverseConversionForRequest()
+  // once it is implemented.
   if (!converter_->StartReverseConversion(&reverse_segments, source_text)) {
     return false;
   }
@@ -393,7 +398,7 @@ void PrependCandidates(const Segment &previous_segment,
   const size_t cands_size = previous_segment.candidates_size();
   for (size_t i = 0; i < cands_size; ++i) {
     Segment::Candidate *candidate = segment->push_front_candidate();
-    candidate->CopyFrom(previous_segment.candidate(cands_size - i - 1));
+    *candidate = previous_segment.candidate(cands_size - i - 1);
   }
   *(segment->mutable_meta_candidates()) = previous_segment.meta_candidates();
 }
@@ -418,10 +423,10 @@ bool SessionConverter::SuggestWithPreferences(
     return false;
   }
 
-  // Initialize the segments for suggestion.
-  SetConversionPreferences(preferences, segments_.get());
-
   ConversionRequest conversion_request(&composer, request_, config_);
+  // Initialize the conversion request and segments for suggestion.
+  SetConversionPreferences(preferences, segments_.get(), &conversion_request);
+
   const size_t cursor = composer.GetCursor();
   if (cursor == composer.GetLength() || cursor == 0 ||
       !request_->mixed_conversion()) {
@@ -429,6 +434,7 @@ bool SessionConverter::SuggestWithPreferences(
         request_->auto_partial_suggestion());
     conversion_request.set_use_actual_converter_for_realtime_conversion(
         absl::GetFlag(FLAGS_use_actual_converter_for_realtime_conversion));
+    SetRequestType(ConversionRequest::SUGGESTION, &conversion_request);
     if (!converter_->StartSuggestionForRequest(conversion_request,
                                                segments_.get())) {
       // TODO(komatsu): Because suggestion is a prefix search, once
@@ -447,6 +453,7 @@ bool SessionConverter::SuggestWithPreferences(
     // implementation reason. If the flag is true, all the composition
     // characters will be used in the below process, which conflicts
     // with *partial* prediction.
+    SetRequestType(ConversionRequest::PARTIAL_SUGGESTION, &conversion_request);
     if (!converter_->StartPartialSuggestionForRequest(conversion_request,
                                                       segments_.get())) {
       VLOG(1) << "StartPartialSuggestionForRequest() returns no suggestions.";
@@ -459,7 +466,7 @@ bool SessionConverter::SuggestWithPreferences(
 
   // Copy current suggestions so that we can merge
   // prediction/suggestions later
-  previous_suggestions_.CopyFrom(segments_->conversion_segment(0));
+  previous_suggestions_ = segments_->conversion_segment(0);
 
   // TODO(komatsu): the next line can be deleted.
   segment_index_ = 0;
@@ -488,8 +495,9 @@ bool SessionConverter::PredictWithPreferences(
   ResetResult();
 
   // Initialize the segments for prediction
-  segments_->set_request_type(Segments::PREDICTION);
-  SetConversionPreferences(preferences, segments_.get());
+  ConversionRequest conversion_request(&composer, request_, config_);
+  SetConversionPreferences(preferences, segments_.get(), &conversion_request);
+  SetRequestType(ConversionRequest::PREDICTION, &conversion_request);
 
   const bool predict_first =
       !CheckState(PREDICTION) && IsEmptySegment(previous_suggestions_);
@@ -502,9 +510,9 @@ bool SessionConverter::PredictWithPreferences(
   segments_->clear_conversion_segments();
 
   if (predict_expand || predict_first) {
-    ConversionRequest conversion_request(&composer, request_, config_);
     conversion_request.set_use_actual_converter_for_realtime_conversion(
         absl::GetFlag(FLAGS_use_actual_converter_for_realtime_conversion));
+    SetRequestType(ConversionRequest::PREDICTION, &conversion_request);
     if (!converter_->StartPredictionForRequest(conversion_request,
                                                segments_.get())) {
       LOG(WARNING) << "StartPredictionForRequest() failed";
@@ -559,7 +567,8 @@ bool SessionConverter::ExpandSuggestionWithPreferences(
   //     after implementation of partial conversion.
 
   // Initialize the segments for prediction.
-  SetConversionPreferences(preferences, segments_.get());
+  ConversionRequest conversion_request(&composer, request_, config_);
+  SetConversionPreferences(preferences, segments_.get(), &conversion_request);
 
   std::string preedit;
   composer.GetQueryForPrediction(&preedit);
@@ -567,8 +576,9 @@ bool SessionConverter::ExpandSuggestionWithPreferences(
   // We do not need "segments_->clear_conversion_segments()".
   // Without this statement we can add additional candidates into
   // existing segments.
-
-  ConversionRequest conversion_request(&composer, request_, config_);
+  DCHECK(request_type_ != ConversionRequest::PREDICTION &&
+         request_type_ != ConversionRequest::PARTIAL_PREDICTION);
+  conversion_request.set_should_call_set_key_in_prediction(true);
 
   const size_t cursor = composer.GetCursor();
   if (cursor == composer.GetLength() || cursor == 0 ||
@@ -580,12 +590,14 @@ bool SessionConverter::ExpandSuggestionWithPreferences(
     // This is abuse of StartPrediction().
     // TODO(matsuzakit or yamaguchi): Add ExpandSuggestion method
     //    to Converter class.
+    SetRequestType(ConversionRequest::PREDICTION, &conversion_request);
     if (!converter_->StartPredictionForRequest(conversion_request,
                                                segments_.get())) {
       LOG(WARNING) << "StartPredictionForRequest() failed";
     }
   } else {
     // c.f. SuggestWithPreferences for ConversionRequest flags.
+    SetRequestType(ConversionRequest::PARTIAL_PREDICTION, &conversion_request);
     if (!converter_->StartPartialPredictionForRequest(conversion_request,
                                                       segments_.get())) {
       VLOG(1) << "StartPartialPredictionForRequest() returns no suggestions.";
@@ -596,12 +608,13 @@ bool SessionConverter::ExpandSuggestionWithPreferences(
   }
   // Overwrite the request type to SUGGESTION.
   // Without this logic, a candidate gets focused that is unexpected behavior.
-  segments_->set_request_type(Segments::SUGGESTION);
+  request_type_ = ConversionRequest::SUGGESTION;
 
   // Merge suggestions and predictions.
   PrependCandidates(previous_suggestions_, preedit, segments_.get());
 
   segment_index_ = 0;
+
   // Call AppendCandidateList instead of UpdateCandidateList because
   // we want to keep existing candidates.
   // As a result, ExpandSuggestionWithPreferences adds expanded suggestion
@@ -825,17 +838,23 @@ void SessionConverter::CommitSegmentsInternal(
 
 void SessionConverter::CommitPreedit(const composer::Composer &composer,
                                      const commands::Context &context) {
-  std::string key, preedit, normalized_preedit;
+  std::string key, preedit;
   composer.GetQueryForConversion(&key);
   composer.GetStringForSubmission(&preedit);
-  TextNormalizer::NormalizeText(preedit, &normalized_preedit);
+  const std::string normalized_preedit = TextNormalizer::NormalizeText(preedit);
   SessionOutput::FillPreeditResult(preedit, result_.get());
 
+  // TODO(toshiyuki): Move ConverterUtil::InitSegmentsFromString()
+  // into here, because this is the only usage of the method.
   ConverterUtil::InitSegmentsFromString(key, normalized_preedit,
                                         segments_.get());
 
   CommitUsageStats(SessionConverterInterface::COMPOSITION, context);
   ConversionRequest conversion_request(&composer, request_, config_);
+  // the request mode is CONVERSION, as the user experience
+  // is similar to conversion. UserHistryPredictor distinguishes
+  // CONVERSION from SUGGESTION now.
+  SetRequestType(ConversionRequest::CONVERSION, &conversion_request);
   converter_->FinishConversion(conversion_request, segments_.get());
   ResetState();
 }
@@ -851,8 +870,7 @@ void SessionConverter::CommitHead(size_t count,
     *consumed_key_size = count;
   }
   Util::Utf8SubString(preedit, 0, *consumed_key_size, &preedit);
-  std::string composition;
-  TextNormalizer::NormalizeText(preedit, &composition);
+  const std::string composition = TextNormalizer::NormalizeText(preedit);
   SessionOutput::FillPreeditResult(composition, result_.get());
 }
 
@@ -1150,9 +1168,10 @@ void SessionConverter::FillOutput(const composer::Composer &composer,
 
 // static
 void SessionConverter::SetConversionPreferences(
-    const ConversionPreferences &preferences, Segments *segments) {
-  segments->set_user_history_enabled(preferences.use_history);
+    const ConversionPreferences &preferences, Segments *segments,
+    ConversionRequest *request) {
   segments->set_max_history_segments_size(preferences.max_history_size);
+  request->set_enable_user_history_for_conversion(preferences.use_history);
 }
 
 SessionConverter *SessionConverter::Clone() const {
@@ -1167,11 +1186,11 @@ SessionConverter *SessionConverter::Clone() const {
   // moment it's ok because the current design guarantees that the converter is
   // singleton. However, we should refactor such bad design; see also the
   // comment right above.
-  session_converter->segments_->CopyFrom(*segments_);
+  *session_converter->segments_ = *segments_;
   session_converter->segment_index_ = segment_index_;
-  session_converter->previous_suggestions_.CopyFrom(previous_suggestions_);
+  session_converter->previous_suggestions_ = previous_suggestions_;
   session_converter->conversion_preferences_ = conversion_preferences();
-  session_converter->result_->CopyFrom(*result_);
+  *session_converter->result_ = *result_;
   session_converter->request_ = request_;
   session_converter->config_ = config_;
   session_converter->use_cascading_window_ = use_cascading_window_;
@@ -1356,9 +1375,9 @@ void SessionConverter::AppendCandidateList() {
   }
 
   const bool focused =
-      (segments_->request_type() != Segments::SUGGESTION &&
-       segments_->request_type() != Segments::PARTIAL_SUGGESTION &&
-       segments_->request_type() != Segments::PARTIAL_PREDICTION);
+      (request_type_ != ConversionRequest::SUGGESTION &&
+       request_type_ != ConversionRequest::PARTIAL_SUGGESTION &&
+       request_type_ != ConversionRequest::PARTIAL_PREDICTION);
   candidate_list_->set_focused(focused);
 
   if (segment.meta_candidates_size() == 0) {
@@ -1378,11 +1397,11 @@ void SessionConverter::AppendCandidateList() {
   // Set transliteration candidates
   CandidateList *transliterations;
   if (use_cascading_window_) {
-    const bool kNoRotate = false;
+    constexpr bool kNoRotate = false;
     transliterations = candidate_list_->AllocateSubCandidateList(kNoRotate);
     transliterations->set_focused(true);
 
-    const char kT13nLabel[] = "そのほかの文字種";
+    constexpr char kT13nLabel[] = "そのほかの文字種";
     transliterations->set_name(kT13nLabel);
   } else {
     transliterations = candidate_list_.get();
@@ -1442,7 +1461,7 @@ void SessionConverter::FillConversion(commands::Preedit *preedit) const {
 }
 
 void SessionConverter::FillResult(commands::Result *result) const {
-  result->CopyFrom(*result_);
+  *result = *result_;
 }
 
 void SessionConverter::FillCandidates(commands::Candidates *candidates) const {
@@ -1474,25 +1493,25 @@ void SessionConverter::FillCandidates(commands::Candidates *candidates) const {
   }
 
   // Store category
-  switch (segments_->request_type()) {
-    case Segments::CONVERSION:
+  switch (request_type_) {
+    case ConversionRequest::CONVERSION:
       candidates->set_category(commands::CONVERSION);
       break;
-    case Segments::PREDICTION:
+    case ConversionRequest::PREDICTION:
       candidates->set_category(commands::PREDICTION);
       break;
-    case Segments::SUGGESTION:
+    case ConversionRequest::SUGGESTION:
       candidates->set_category(commands::SUGGESTION);
       break;
-    case Segments::PARTIAL_PREDICTION:
+    case ConversionRequest::PARTIAL_PREDICTION:
       // Not PREDICTION because we do not want to get focused candidate.
       candidates->set_category(commands::SUGGESTION);
       break;
-    case Segments::PARTIAL_SUGGESTION:
+    case ConversionRequest::PARTIAL_SUGGESTION:
       candidates->set_category(commands::SUGGESTION);
       break;
     default:
-      LOG(WARNING) << "Unknown request type: " << segments_->request_type();
+      LOG(WARNING) << "Unknown request type: " << request_type_;
       candidates->set_category(commands::CONVERSION);
       break;
   }
@@ -1526,25 +1545,25 @@ void SessionConverter::FillAllCandidateWords(
     commands::CandidateList *candidates) const {
   DCHECK(CheckState(SUGGESTION | PREDICTION | CONVERSION));
   commands::Category category;
-  switch (segments_->request_type()) {
-    case Segments::CONVERSION:
+  switch (request_type_) {
+    case ConversionRequest::CONVERSION:
       category = commands::CONVERSION;
       break;
-    case Segments::PREDICTION:
+    case ConversionRequest::PREDICTION:
       category = commands::PREDICTION;
       break;
-    case Segments::SUGGESTION:
+    case ConversionRequest::SUGGESTION:
       category = commands::SUGGESTION;
       break;
-    case Segments::PARTIAL_PREDICTION:
+    case ConversionRequest::PARTIAL_PREDICTION:
       // Not PREDICTION because we do not want to get focused candidate.
       category = commands::SUGGESTION;
       break;
-    case Segments::PARTIAL_SUGGESTION:
+    case ConversionRequest::PARTIAL_SUGGESTION:
       category = commands::SUGGESTION;
       break;
     default:
-      LOG(WARNING) << "Unknown request type: " << segments_->request_type();
+      LOG(WARNING) << "Unknown request type: " << request_type_;
       category = commands::CONVERSION;
       break;
   }
@@ -1608,12 +1627,12 @@ void SessionConverter::OnStartComposition(const commands::Context &context) {
     DCHECK(!preceding_text.empty());
     DCHECK(!history_text.empty());
     if (preceding_text.size() > history_text.size()) {
-      if (Util::EndsWith(preceding_text, history_text)) {
+      if (absl::EndsWith(preceding_text, history_text)) {
         // History segments seem to be consistent with preceding text.
         return;
       }
     } else {
-      if (Util::EndsWith(history_text, preceding_text)) {
+      if (absl::EndsWith(history_text, preceding_text)) {
         // History segments seem to be consistent with preceding text.
         return;
       }
@@ -1645,7 +1664,7 @@ void SessionConverter::InitializeSelectedCandidateIndices() {
 }
 
 void SessionConverter::UpdateCandidateStats(const std::string &base_name,
-                                            int32 index) {
+                                            int32_t index) {
   std::string prefix;
   if (index < 0) {
     prefix = "TransliterationCandidates";
@@ -1730,5 +1749,13 @@ void SessionConverter::CommitUsageStatsWithSegmentsSize(
   selected_candidate_indices_.erase(it, it + commit_segments_size);
 }
 
+// Sets request type and update the session_converter's state
+void SessionConverter::SetRequestType(
+    ConversionRequest::RequestType request_type,
+    ConversionRequest *conversion_request) {
+  request_type_ = request_type;
+  conversion_request->set_request_type(request_type);
+}
+
 }  // namespace session
 }  // namespace mozc
