@@ -32,6 +32,7 @@
 #ifndef MOZC_SESSION_SESSION_CONVERTER_H_
 #define MOZC_SESSION_SESSION_CONVERTER_H_
 
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <vector>
@@ -252,9 +253,10 @@ class SessionConverter : public SessionConverterInterface {
   // Set setting by the context.
   void OnStartComposition(const commands::Context &context) override;
 
-  // Fills segments with the conversion preferences.
+  // Fills conversion request and segments with the conversion preferences.
   static void SetConversionPreferences(const ConversionPreferences &preferences,
-                                       Segments *segments);
+                                       Segments *segments,
+                                       ConversionRequest *request);
 
   // Copies SessionConverter
   // TODO(hsumita): Copy all member variables.
@@ -342,7 +344,7 @@ class SessionConverter : public SessionConverterInterface {
   // True is returned if the selected candidate is successfully committed.
   bool CommitSuggestionInternal(const composer::Composer &composer,
                                 const commands::Context &context,
-                                size_t *committed_length);
+                                size_t *consumed_key_size);
 
   void SegmentFocusInternal(size_t segment_index);
   void ResizeSegmentWidth(const composer::Composer &composer, int delta);
@@ -356,14 +358,15 @@ class SessionConverter : public SessionConverterInterface {
   // Handles selected_indices for usage stats.
   void InitializeSelectedCandidateIndices();
   void UpdateSelectedCandidateIndex();
-  void UpdateCandidateStats(const std::string &base_name, int32 index);
+  void UpdateCandidateStats(const std::string &base_name, int32_t index);
   void CommitUsageStats(SessionConverterInterface::State commit_state,
                         const commands::Context &context);
   void CommitUsageStatsWithSegmentsSize(
       SessionConverterInterface::State commit_state,
-      const commands::Context &context, size_t submit_segment_size);
+      const commands::Context &context, size_t commit_segments_size);
 
-  SessionConverterInterface::State state_;
+  void SetRequestType(ConversionRequest::RequestType request_type,
+                      ConversionRequest *conversion_request);
 
   const ConverterInterface *converter_;
   std::unique_ptr<Segments> segments_;
@@ -372,32 +375,41 @@ class SessionConverter : public SessionConverterInterface {
   // Previous suggestions to be merged with the current predictions.
   Segment previous_suggestions_;
 
-  // Default conversion preferences.
-  ConversionPreferences conversion_preferences_;
-
   std::unique_ptr<commands::Result> result_;
 
   std::unique_ptr<CandidateList> candidate_list_;
-  bool candidate_list_visible_;
 
   const commands::Request *request_;
   const config::Config *config_;
 
-  // Mutable values of |config_|.  These values may be changed temporaliry per
-  // session.
-  bool use_cascading_window_;
-  config::Config::SelectionShortcut selection_shortcut_;
+  SessionConverterInterface::State state_;
 
-  // Indicates whether config_ will be updated by the command candidate.
-  Segment::Candidate::Command updated_command_;
+  // Remembers request type to manage state.
+  // TODO(team): Check whether we can switch behaviors using state_
+  // instead of request_type_.
+  ConversionRequest::RequestType request_type_;
+
+  // Default conversion preferences.
+  ConversionPreferences conversion_preferences_;
+
+  config::Config::SelectionShortcut selection_shortcut_;
 
   // Selected index data of each segments for usage stats.
   std::vector<int> selected_candidate_indices_;
 
+  // Indicates whether config_ will be updated by the command candidate.
+  Segment::Candidate::Command updated_command_;
+
   // Revision number of client context with which the converter determines when
   // the history segments should be invalidated. See the implementation of
   // OnStartComposition for details.
-  int32 client_revision_;
+  int32_t client_revision_;
+
+  bool candidate_list_visible_;
+
+  // Mutable values of |config_|.  These values may be changed temporaliry per
+  // session.
+  bool use_cascading_window_;
 
   DISALLOW_COPY_AND_ASSIGN(SessionConverter);
 };
