@@ -27,6 +27,7 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -51,7 +52,7 @@ ABSL_FLAG(bool, test_deterministic, true,
           "if false, srand() is initialized by current time "
           "and \"test_srand_seed\" is ignored");
 
-ABSL_FLAG(int32, test_srand_seed, 0,
+ABSL_FLAG(int32_t, test_srand_seed, 0,
           "seed number for srand(). "
           "used only when \"test_deterministic\" is true");
 
@@ -66,10 +67,10 @@ class SessionConverterStressTest : public ::testing::Test {
   SessionConverterStressTest() {
     if (!absl::GetFlag(FLAGS_test_deterministic)) {
       absl::SetFlag(&FLAGS_test_srand_seed,
-                    static_cast<int32>(Clock::GetTime()));
+                    static_cast<int32_t>(Clock::GetTime()));
     }
     Util::SetRandomSeed(
-        static_cast<uint32>(absl::GetFlag(FLAGS_test_srand_seed)));
+        static_cast<uint32_t>(absl::GetFlag(FLAGS_test_srand_seed)));
   }
 
   void SetUp() override {
@@ -97,7 +98,7 @@ void GenerateRandomInput(size_t length, char min_code, char max_code,
 TEST_F(SessionConverterStressTest, ConvertToHalfWidthForRandomAsciiInput) {
   // ConvertToHalfWidth has to return the same string as the input.
 
-  const int kTestCaseSize = 2;
+  constexpr int kTestCaseSize = 2;
   struct TestCase {
     int min, max;
   } kTestCases[] = {
@@ -109,7 +110,8 @@ TEST_F(SessionConverterStressTest, ConvertToHalfWidthForRandomAsciiInput) {
   const commands::Request request;
   config::Config config;
 
-  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine =
+      MockDataEngineFactory::Create().value();
   ConverterInterface* converter = engine->GetConverter();
   SessionConverter sconverter(converter, &request, &config);
   composer::Table table;
@@ -119,7 +121,7 @@ TEST_F(SessionConverterStressTest, ConvertToHalfWidthForRandomAsciiInput) {
   std::string input;
 
   for (int test = 0; test < kTestCaseSize; ++test) {
-    const int kLoopLimit = 100;
+    constexpr int kLoopLimit = 100;
     for (int i = 0; i < kLoopLimit; ++i) {
       composer.Reset();
       sconverter.Reset();
@@ -127,7 +129,7 @@ TEST_F(SessionConverterStressTest, ConvertToHalfWidthForRandomAsciiInput) {
       input.clear();
 
       // Limited by kMaxCharLength in immutable_converter.cc
-      const int kInputStringLength = 32;
+      constexpr int kInputStringLength = 32;
       GenerateRandomInput(kInputStringLength, kTestCases[test].min,
                           kTestCases[test].max, &input);
 
