@@ -33,6 +33,7 @@
 #include "session/session_handler.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <string>
 #include <utility>
 #include <vector>
@@ -61,31 +62,32 @@
 #ifndef MOZC_DISABLE_SESSION_WATCHDOG
 #include "session/session_watch_dog.h"
 #endif  // MOZC_DISABLE_SESSION_WATCHDOG
+#include <memory>
+
 #include "usage_stats/usage_stats.h"
-#include "absl/memory/memory.h"
 
 using mozc::usage_stats::UsageStats;
 
-ABSL_FLAG(int32, timeout, -1,
+ABSL_FLAG(int32_t, timeout, -1,
           "server timeout. "
           "if sessions get empty for \"timeout\", "
           "shutdown message is automatically emitted");
 
-ABSL_FLAG(int32, max_session_size, 64,
+ABSL_FLAG(int32_t, max_session_size, 64,
           "maximum sessions size. "
           "if size of sessions reaches to \"max_session_size\", "
           "oldest session is removed");
 
-ABSL_FLAG(int32, create_session_min_interval, 0,
+ABSL_FLAG(int32_t, create_session_min_interval, 0,
           "minimum interval (sec) for create session");
 
-ABSL_FLAG(int32, watch_dog_interval, 180, "watch dog timer intaval (sec)");
+ABSL_FLAG(int32_t, watch_dog_interval, 180, "watch dog timer intaval (sec)");
 
-ABSL_FLAG(int32, last_command_timeout, 3600,
+ABSL_FLAG(int32_t, last_command_timeout, 3600,
           "remove session if it is not accessed for "
           "\"last_command_timeout\" sec");
 
-ABSL_FLAG(int32, last_create_session_timeout, 300,
+ABSL_FLAG(int32_t, last_create_session_timeout, 300,
           "remove session if it is not accessed for "
           "\"last_create_session_timeout\" sec "
           "after create session command");
@@ -139,13 +141,13 @@ void SessionHandler::Init(
   last_create_session_time_ = 0;
   engine_ = std::move(engine);
   engine_builder_ = std::move(engine_builder);
-  observer_handler_ = absl::make_unique<session::SessionObserverHandler>();
-  stopwatch_ = absl::make_unique<Stopwatch>();
+  observer_handler_ = std::make_unique<session::SessionObserverHandler>();
+  stopwatch_ = std::make_unique<Stopwatch>();
   user_dictionary_session_handler_ =
-      absl::make_unique<user_dictionary::UserDictionarySessionHandler>();
-  table_manager_ = absl::make_unique<composer::TableManager>();
-  request_ = absl::make_unique<commands::Request>();
-  config_ = absl::make_unique<config::Config>();
+      std::make_unique<user_dictionary::UserDictionarySessionHandler>();
+  table_manager_ = std::make_unique<composer::TableManager>();
+  request_ = std::make_unique<commands::Request>();
+  config_ = std::make_unique<config::Config>();
 
   if (absl::GetFlag(FLAGS_restricted)) {
     VLOG(1) << "Server starts with restricted mode";
@@ -162,7 +164,7 @@ void SessionHandler::Init(
   }
 
 #ifndef MOZC_DISABLE_SESSION_WATCHDOG
-  session_watch_dog_ = absl::make_unique<SessionWatchDog>(
+  session_watch_dog_ = std::make_unique<SessionWatchDog>(
       absl::GetFlag(FLAGS_watch_dog_interval));
 #endif  // MOZC_DISABLE_SESSION_WATCHDOG
 
@@ -171,7 +173,7 @@ void SessionHandler::Init(
   // allow [2..128] sessions
   max_session_size_ =
       std::max(2, std::min(absl::GetFlag(FLAGS_max_session_size), 128));
-  session_map_ = absl::make_unique<SessionMap>(max_session_size_);
+  session_map_ = std::make_unique<SessionMap>(max_session_size_);
 
   if (!engine_) {
     return;
@@ -330,7 +332,7 @@ bool SessionHandler::SetRequest(commands::Command *command) {
     return false;
   }
 
-  request_->CopyFrom(command->input().request());
+  *request_ = command->input().request();
 
   Reload(command);
 
@@ -405,6 +407,12 @@ bool SessionHandler::EvalCommand(commands::Command *command) {
     case commands::Input::NO_OPERATION:
       eval_succeeded = NoOperation(command);
       break;
+    case commands::Input::CHECK_SPELLING:
+      eval_succeeded = CheckSpelling(command);
+      break;
+    case commands::Input::RELOAD_SPELL_CHECKER:
+      eval_succeeded = ReloadSpellChecker(command);
+      break;
     default:
       eval_succeeded = false;
   }
@@ -492,11 +500,10 @@ bool SessionHandler::SendCommand(commands::Command *command) {
 bool SessionHandler::CreateSession(commands::Command *command) {
   // prevent DOS attack
   // don't allow CreateSession in very short period.
-  const int create_session_minimum_interval =
-      std::max(0, std::min(absl::GetFlag(FLAGS_create_session_min_interval),
-                           10));
+  const int create_session_minimum_interval = std::max(
+      0, std::min(absl::GetFlag(FLAGS_create_session_min_interval), 10));
 
-  uint64 current_time = Clock::GetTime();
+  uint64_t current_time = Clock::GetTime();
   if (last_create_session_time_ != 0 &&
       (current_time - last_create_session_time_) <
           create_session_minimum_interval) {
@@ -592,10 +599,10 @@ bool SessionHandler::DeleteSession(commands::Command *command) {
 // no active session and client doesn't send any conversion
 // request to the server for FLAGS_timeout sec.
 bool SessionHandler::Cleanup(commands::Command *command) {
-  const uint64 current_time = Clock::GetTime();
+  const uint64_t current_time = Clock::GetTime();
 
   // suspend/hibernation may happen
-  uint64 suspend_time = 0;
+  uint64_t suspend_time = 0;
 #ifndef MOZC_DISABLE_SESSION_WATCHDOG
   if (last_cleanup_time_ != 0 && session_watch_dog_->IsRunning() &&
       (current_time - last_cleanup_time_) >
@@ -608,13 +615,13 @@ bool SessionHandler::Cleanup(commands::Command *command) {
 #endif  // MOZC_DISABLE_SESSION_WATCHDOG
 
   // allow [1..600] sec. default: 300
-  const uint64 create_session_timeout =
+  const uint64_t create_session_timeout =
       suspend_time +
-      std::max(1, std::min(absl::GetFlag(FLAGS_last_create_session_timeout),
-                           600));
+      std::max(1,
+               std::min(absl::GetFlag(FLAGS_last_create_session_timeout), 600));
 
   // allow [10..7200] sec. default 3600
-  const uint64 last_command_timeout =
+  const uint64_t last_command_timeout =
       suspend_time +
       std::max(10, std::min(absl::GetFlag(FLAGS_last_command_timeout), 7200));
 
@@ -686,6 +693,19 @@ bool SessionHandler::SendEngineReloadRequest(commands::Command *command) {
 
 bool SessionHandler::NoOperation(commands::Command *command) { return true; }
 
+bool SessionHandler::CheckSpelling(commands::Command *command) {
+  if (!command->input().has_check_spelling_request() ||
+      command->input().check_spelling_request().text().empty()) {
+    return true;
+  }
+
+  return true;
+}
+
+bool SessionHandler::ReloadSpellChecker(commands::Command *command) {
+  return true;
+}
+
 // Create Random Session ID in order to make the session id unpredicable
 SessionID SessionHandler::CreateNewSessionID() {
   SessionID id = 0;
