@@ -29,6 +29,7 @@
 
 #include "session/session_handler_tool.h"
 
+#include <cstdint>
 #include <memory>
 
 #include "base/config_file_stream.h"
@@ -38,7 +39,6 @@
 #include "base/protobuf/descriptor.h"
 #include "base/protobuf/message.h"
 #include "base/protobuf/text_format.h"
-#include "base/status.h"
 #include "base/util.h"
 #include "composer/key_parser.h"
 #include "config/character_form_manager.h"
@@ -47,6 +47,7 @@
 #include "engine/engine_factory.h"
 #include "engine/user_data_manager_interface.h"
 #include "prediction/user_history_predictor.h"
+#include "protocol/candidates.pb.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
 #include "session/request_test_util.h"
@@ -55,34 +56,32 @@
 #include "session/session_usage_observer.h"
 #include "storage/registry.h"
 #include "usage_stats/usage_stats.h"
-#include "absl/memory/memory.h"
+#include "absl/status/status.h"
 #include "absl/strings/str_cat.h"
+#include "absl/strings/str_split.h"
 #include "absl/strings/string_view.h"
 
-using mozc::commands::CandidateList;
-using mozc::commands::CandidateWord;
-using mozc::commands::CompositionMode;
-using mozc::commands::Input;
-using mozc::commands::KeyEvent;
-using mozc::commands::Output;
-using mozc::commands::Request;
-using mozc::commands::RequestForUnitTest;
-using mozc::config::CharacterFormManager;
-using mozc::config::Config;
-using mozc::config::ConfigHandler;
-using mozc::protobuf::FieldDescriptor;
-using mozc::protobuf::Message;
-using mozc::protobuf::TextFormat;
-using mozc::session::SessionHandlerTool;
-
 namespace mozc {
 namespace session {
 
+using commands::CandidateList;
+using commands::CandidateWord;
 using commands::Command;
+using commands::CompositionMode;
+using commands::Input;
+using commands::KeyEvent;
+using commands::Output;
+using commands::Request;
+using commands::RequestForUnitTest;
 using config::CharacterFormManager;
+using config::Config;
 using config::ConfigHandler;
+using protobuf::FieldDescriptor;
+using protobuf::Message;
+using protobuf::TextFormat;
+using session::SessionHandlerTool;
 
-bool CreateSession(SessionHandlerInterface *handler, uint64 *id) {
+bool CreateSession(SessionHandlerInterface *handler, uint64_t *id) {
   Command command;
   command.mutable_input()->set_type(commands::Input::CREATE_SESSION);
   command.mutable_input()->mutable_capability()->set_text_deletion(
@@ -94,21 +93,21 @@ bool CreateSession(SessionHandlerInterface *handler, uint64 *id) {
   return (command.output().error_code() == commands::Output::SESSION_SUCCESS);
 }
 
-bool DeleteSession(SessionHandlerInterface *handler, uint64 id) {
+bool DeleteSession(SessionHandlerInterface *handler, uint64_t id) {
   Command command;
   command.mutable_input()->set_id(id);
   command.mutable_input()->set_type(commands::Input::DELETE_SESSION);
   return handler->EvalCommand(&command);
 }
 
-bool CleanUp(SessionHandlerInterface *handler, uint64 id) {
+bool CleanUp(SessionHandlerInterface *handler, uint64_t id) {
   Command command;
   command.mutable_input()->set_id(id);
   command.mutable_input()->set_type(commands::Input::CLEANUP);
   return handler->EvalCommand(&command);
 }
 
-bool IsGoodSession(SessionHandlerInterface *handler, uint64 id) {
+bool IsGoodSession(SessionHandlerInterface *handler, uint64_t id) {
   Command command;
   command.mutable_input()->set_id(id);
   command.mutable_input()->set_type(commands::Input::SEND_KEY);
@@ -160,26 +159,27 @@ bool SessionHandlerTool::ClearUserPrediction() {
 }
 
 bool SessionHandlerTool::SendKeyWithOption(const commands::KeyEvent &key,
-                                          const commands::Input &option,
-                                          commands::Output *output) {
+                                           const commands::Input &option,
+                                           commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::SEND_KEY);
-  input.mutable_key()->CopyFrom(key);
+  *input.mutable_key() = key;
   input.MergeFrom(option);
   return EvalCommand(&input, output);
 }
 
 bool SessionHandlerTool::TestSendKeyWithOption(const commands::KeyEvent &key,
-                                              const commands::Input &option,
-                                              commands::Output *output) {
+                                               const commands::Input &option,
+                                               commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::TEST_SEND_KEY);
-  input.mutable_key()->CopyFrom(key);
+  *input.mutable_key() = key;
   input.MergeFrom(option);
   return EvalCommand(&input, output);
 }
 
-bool SessionHandlerTool::SelectCandidate(uint32 id, commands::Output *output) {
+bool SessionHandlerTool::SelectCandidate(uint32_t id,
+                                         commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::SEND_COMMAND);
   input.mutable_command()->set_type(commands::SessionCommand::SELECT_CANDIDATE);
@@ -187,7 +187,8 @@ bool SessionHandlerTool::SelectCandidate(uint32 id, commands::Output *output) {
   return EvalCommand(&input, output);
 }
 
-bool SessionHandlerTool::SubmitCandidate(uint32 id, commands::Output *output) {
+bool SessionHandlerTool::SubmitCandidate(uint32_t id,
+                                         commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::SEND_COMMAND);
   input.mutable_command()->set_type(commands::SessionCommand::SUBMIT_CANDIDATE);
@@ -234,38 +235,36 @@ bool SessionHandlerTool::SwitchInputMode(
 }
 
 bool SessionHandlerTool::SetRequest(const commands::Request &request,
-                                   commands::Output *output) {
+                                    commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::SET_REQUEST);
-  input.mutable_request()->CopyFrom(request);
+  *input.mutable_request() = request;
   return EvalCommand(&input, output);
 }
 
 bool SessionHandlerTool::SetConfig(const config::Config &config,
-                                  commands::Output *output) {
+                                   commands::Output *output) {
   commands::Input input;
   input.set_type(commands::Input::SET_CONFIG);
   *input.mutable_config() = config;
   return EvalCommand(&input, output);
 }
 
-bool SessionHandlerTool::SyncData() {
-  return data_manager_->Wait();
-}
+bool SessionHandlerTool::SyncData() { return data_manager_->Wait(); }
 
 void SessionHandlerTool::SetCallbackText(const std::string &text) {
   callback_text_ = text;
 }
 
 bool SessionHandlerTool::EvalCommandInternal(commands::Input *input,
-                                            commands::Output *output,
-                                            bool allow_callback) {
+                                             commands::Output *output,
+                                             bool allow_callback) {
   input->set_id(id_);
   commands::Command command;
-  command.mutable_input()->CopyFrom(*input);
+  *command.mutable_input() = *input;
   bool result = handler_->EvalCommand(&command);
   if (result && output != nullptr) {
-    output->CopyFrom(command.output());
+    *output = command.output();
   }
 
   // If callback is allowed and the callback field exists, evaluate the callback
@@ -274,8 +273,7 @@ bool SessionHandlerTool::EvalCommandInternal(commands::Input *input,
       command.output().callback().has_session_command()) {
     commands::Input input2;
     input2.set_type(commands::Input::SEND_COMMAND);
-    input2.mutable_command()->CopyFrom(
-        command.output().callback().session_command());
+    *input2.mutable_command() = command.output().callback().session_command();
     input2.mutable_command()->set_text(callback_text_);
     // Disallow further recursion.
     result = EvalCommandInternal(&input2, output, false);
@@ -285,21 +283,19 @@ bool SessionHandlerTool::EvalCommandInternal(commands::Input *input,
 }
 
 bool SessionHandlerTool::EvalCommand(commands::Input *input,
-                                    commands::Output *output) {
+                                     commands::Output *output) {
   return EvalCommandInternal(input, output, true);
 }
 
 SessionHandlerInterpreter::SessionHandlerInterpreter()
-    : SessionHandlerInterpreter(
-          std::unique_ptr<EngineInterface>(EngineFactory::Create())) {}
+    : SessionHandlerInterpreter(EngineFactory::Create().value()) {}
 
 SessionHandlerInterpreter::SessionHandlerInterpreter(
     std::unique_ptr<EngineInterface> engine) {
-
-  client_ = absl::make_unique<SessionHandlerTool>(std::move(engine));
-  config_ = absl::make_unique<Config>();
-  last_output_ = absl::make_unique<Output>();
-  request_ = absl::make_unique<Request>();
+  client_ = std::make_unique<SessionHandlerTool>(std::move(engine));
+  config_ = std::make_unique<Config>();
+  last_output_ = std::make_unique<Output>();
+  request_ = std::make_unique<Request>();
 
   ConfigHandler::GetConfig(config_.get());
 
@@ -330,9 +326,12 @@ void SessionHandlerInterpreter::ClearState() {
   // Some destructors may save the state on storages. To clear the state, we
   // explicitly call destructors before clearing storages.
   mozc::storage::Registry::Clear();
-  FileUtil::Unlink(mozc::ConfigFileStream::GetFileName("user://boundary.db"));
-  FileUtil::Unlink(mozc::ConfigFileStream::GetFileName("user://segment.db"));
-  FileUtil::Unlink(mozc::UserHistoryPredictor::GetUserHistoryFileName());
+  FileUtil::UnlinkOrLogError(
+      mozc::ConfigFileStream::GetFileName("user://boundary.db"));
+  FileUtil::UnlinkOrLogError(
+      mozc::ConfigFileStream::GetFileName("user://segment.db"));
+  FileUtil::UnlinkOrLogError(
+      mozc::UserHistoryPredictor::GetUserHistoryFileName());
 }
 
 void SessionHandlerInterpreter::ClearAll() {
@@ -359,13 +358,34 @@ void SessionHandlerInterpreter::ClearUsageStats() {
   mozc::usage_stats::UsageStats::ClearAllStatsForTest();
 }
 
-const Output& SessionHandlerInterpreter::LastOutput() const {
-  return *(last_output_.get());
+const Output &SessionHandlerInterpreter::LastOutput() const {
+  return *last_output_;
 }
 
+const CandidateWord &SessionHandlerInterpreter::GetCandidateByValue(
+    const absl::string_view value) {
+  const Output &output = LastOutput();
+
+  for (const CandidateWord &candidate :
+       output.all_candidate_words().candidates()) {
+    if (candidate.value() == value) {
+      return candidate;
+    }
+  }
+
+  for (const CandidateWord &candidate :
+       output.removed_candidate_words_for_debug().candidates()) {
+    if (candidate.value() == value) {
+      return candidate;
+    }
+  }
+
+  static CandidateWord *fallback_candidate = new CandidateWord;
+  return *fallback_candidate;
+}
 
 bool SessionHandlerInterpreter::GetCandidateIdByValue(
-    const absl::string_view value, uint32 *id) {
+    const absl::string_view value, uint32_t *id) {
   const Output &output = LastOutput();
 
   auto find_id = [&value](const CandidateList &candidate_list,
@@ -417,8 +437,8 @@ bool ParseProtobufFromString(const std::string &text, Message *message) {
   const size_t separator_pos = text.find('=');
   const std::string full_name = text.substr(0, separator_pos);
   const std::string value = text.substr(separator_pos + 1);
-  std::vector<std::string> names;
-  Util::SplitStringUsing(full_name, ".", &names);
+  std::vector<std::string> names =
+      absl::StrSplit(full_name, '.', absl::SkipEmpty());
 
   Message *msg = message;
   for (size_t i = 0; i < names.size() - 1; ++i) {
@@ -434,43 +454,63 @@ bool ParseProtobufFromString(const std::string &text, Message *message) {
   return SetOrAddFieldValueFromString(names[names.size() - 1], value, msg);
 }
 
-#define MOZC_ASSERT_EQ_MSG(expected, actual, message)  \
-  if (expected != actual) {                            \
-    return mozc::InvalidArgumentError(message);        \
+std::vector<std::string> SessionHandlerInterpreter::Parse(
+    const std::string &line) {
+  std::vector<std::string> args;
+  if (line.empty() || line.front() == '#') {
+    return args;
   }
-#define MOZC_ASSERT_EQ(expected, actual)    \
-  if (expected != actual) {                 \
-    return mozc::InvalidArgumentError("");  \
+  std::vector<absl::string_view> columns = absl::StrSplit(line, '\t');
+  for (absl::string_view column : columns) {
+    if (column.empty()) {
+      args.push_back("");
+      continue;
+    }
+    // If the first and last characters are doublequotes, trim them.
+    if (column.size() > 1 && column.front() == '"' && column.back() == '"') {
+      column.remove_prefix(1);
+      column.remove_suffix(1);
+    }
+    args.push_back(std::string(column));
   }
-#define MOZC_ASSERT_TRUE_MSG(result, message)    \
-  if (!(result)) {                               \
-    return mozc::InvalidArgumentError(message);  \
+  return args;
+}
+
+#define MOZC_ASSERT_EQ_MSG(expected, actual, message) \
+  if (expected != actual) {                           \
+    return absl::InvalidArgumentError(message);       \
   }
-#define MOZC_ASSERT_TRUE(result)            \
-  if (!(result)) {                          \
-    return mozc::InvalidArgumentError("");  \
+#define MOZC_ASSERT_EQ(expected, actual)   \
+  if (expected != actual) {                \
+    return absl::InvalidArgumentError(""); \
+  }
+#define MOZC_ASSERT_TRUE_MSG(result, message)   \
+  if (!(result)) {                              \
+    return absl::InvalidArgumentError(message); \
+  }
+#define MOZC_ASSERT_TRUE(result)           \
+  if (!(result)) {                         \
+    return absl::InvalidArgumentError(""); \
   }
 
-Status SessionHandlerInterpreter::ParseLine(const std::string &line_text) {
-  if (line_text.empty() || line_text[0] == '#') {
-    // Skip an empty or comment line.
-    return Status();
+absl::Status SessionHandlerInterpreter::Eval(
+    const std::vector<std::string> &args) {
+  if (args.empty()) {
+    // Skip empty args
+    return absl::Status();
   }
 
   SyncDataToStorage();
 
-  std::vector<std::string> columns;
-  Util::SplitStringUsing(line_text, "\t", &columns);
-  MOZC_ASSERT_TRUE(!columns.empty());
-  const std::string &command = columns[0];
+  const std::string &command = args[0];
   // TODO(hidehiko): Refactor out about each command when the number of
   //   supported commands is increased.
   if (command == "RESET_CONTEXT") {
-    MOZC_ASSERT_EQ(1, columns.size());
+    MOZC_ASSERT_EQ(1, args.size());
     ResetContext();
   } else if (command == "SEND_KEYS") {
-    MOZC_ASSERT_EQ(2, columns.size());
-    const std::string &keys = columns[1];
+    MOZC_ASSERT_EQ(2, args.size());
+    const std::string &keys = args[1];
     KeyEvent key_event;
     for (size_t i = 0; i < keys.size(); ++i) {
       key_event.Clear();
@@ -480,11 +520,11 @@ Status SessionHandlerInterpreter::ParseLine(const std::string &line_text) {
     }
   } else if (command == "SEND_KANA_KEYS") {
     MOZC_ASSERT_TRUE_MSG(
-        columns.size() >= 3,
-        absl::StrCat("SEND_KEY requires more than or equal to two columns ",
-                     line_text));
-    const std::string &keys = columns[1];
-    const std::string &kanas = columns[2];
+        args.size() >= 3,
+        absl::StrCat("SEND_KEY requires more than or equal to two args ",
+                     absl::StrJoin(args, "\t")));
+    const std::string &keys = args[1];
+    const std::string &kanas = args[2];
     MOZC_ASSERT_EQ_MSG(
         keys.size(), Util::CharsLen(kanas),
         "1st and 2nd column must have the same number of characters.");
@@ -493,113 +533,114 @@ Status SessionHandlerInterpreter::ParseLine(const std::string &line_text) {
       key_event.Clear();
       key_event.set_key_code(keys[i]);
       key_event.set_key_string(std::string(Util::Utf8SubString(kanas, i, 1)));
-      MOZC_ASSERT_TRUE_MSG(client_->SendKey(key_event, last_output_.get()),
-                           absl::StrCat("Failed at ", i, "th ", line_text));
+      MOZC_ASSERT_TRUE_MSG(
+          client_->SendKey(key_event, last_output_.get()),
+          absl::StrCat("Failed at ", i, "th ", absl::StrJoin(args, "\t")));
     }
   } else if (command == "SEND_KEY") {
-    MOZC_ASSERT_EQ(2, columns.size());
+    MOZC_ASSERT_EQ(2, args.size());
     KeyEvent key_event;
-    MOZC_ASSERT_TRUE(KeyParser::ParseKey(columns[1], &key_event));
+    MOZC_ASSERT_TRUE(KeyParser::ParseKey(args[1], &key_event));
     MOZC_ASSERT_TRUE(client_->SendKey(key_event, last_output_.get()));
   } else if (command == "SEND_KEY_WITH_OPTION") {
-    MOZC_ASSERT_TRUE(columns.size() >= 3);
+    MOZC_ASSERT_TRUE(args.size() >= 3);
     KeyEvent key_event;
-    MOZC_ASSERT_TRUE(KeyParser::ParseKey(columns[1], &key_event));
+    MOZC_ASSERT_TRUE(KeyParser::ParseKey(args[1], &key_event));
     Input option;
-    for (size_t i = 2; i < columns.size(); ++i) {
-      MOZC_ASSERT_TRUE(ParseProtobufFromString(columns[i], &option));
+    for (size_t i = 2; i < args.size(); ++i) {
+      MOZC_ASSERT_TRUE(ParseProtobufFromString(args[i], &option));
     }
     MOZC_ASSERT_TRUE(
         client_->SendKeyWithOption(key_event, option, last_output_.get()));
   } else if (command == "TEST_SEND_KEY") {
-    MOZC_ASSERT_EQ(2, columns.size());
+    MOZC_ASSERT_EQ(2, args.size());
     KeyEvent key_event;
-    MOZC_ASSERT_TRUE(KeyParser::ParseKey(columns[1], &key_event));
+    MOZC_ASSERT_TRUE(KeyParser::ParseKey(args[1], &key_event));
     MOZC_ASSERT_TRUE(client_->TestSendKey(key_event, last_output_.get()));
   } else if (command == "TEST_SEND_KEY_WITH_OPTION") {
-    MOZC_ASSERT_TRUE(columns.size() >= 3);
+    MOZC_ASSERT_TRUE(args.size() >= 3);
     KeyEvent key_event;
-    MOZC_ASSERT_TRUE(KeyParser::ParseKey(columns[1], &key_event));
+    MOZC_ASSERT_TRUE(KeyParser::ParseKey(args[1], &key_event));
     Input option;
-    for (size_t i = 2; i < columns.size(); ++i) {
-      MOZC_ASSERT_TRUE(ParseProtobufFromString(columns[i], &option));
+    for (size_t i = 2; i < args.size(); ++i) {
+      MOZC_ASSERT_TRUE(ParseProtobufFromString(args[i], &option));
     }
-    MOZC_ASSERT_TRUE(client_->TestSendKeyWithOption(key_event, option,
-                                                    last_output_.get()));
+    MOZC_ASSERT_TRUE(
+        client_->TestSendKeyWithOption(key_event, option, last_output_.get()));
   } else if (command == "SELECT_CANDIDATE") {
-    MOZC_ASSERT_EQ(2, columns.size());
-    MOZC_ASSERT_TRUE(client_->SelectCandidate(
-        NumberUtil::SimpleAtoi(columns[1]), last_output_.get()));
+    MOZC_ASSERT_EQ(2, args.size());
+    MOZC_ASSERT_TRUE(client_->SelectCandidate(NumberUtil::SimpleAtoi(args[1]),
+                                              last_output_.get()));
   } else if (command == "SELECT_CANDIDATE_BY_VALUE") {
-    MOZC_ASSERT_EQ(2, columns.size());
-    uint32 id;
-    MOZC_ASSERT_TRUE(GetCandidateIdByValue(columns[1], &id));
+    MOZC_ASSERT_EQ(2, args.size());
+    uint32_t id;
+    MOZC_ASSERT_TRUE(GetCandidateIdByValue(args[1], &id));
     MOZC_ASSERT_TRUE(client_->SelectCandidate(id, last_output_.get()));
   } else if (command == "SUBMIT_CANDIDATE") {
-    MOZC_ASSERT_EQ(2, columns.size());
-    MOZC_ASSERT_TRUE(client_->SubmitCandidate(
-        NumberUtil::SimpleAtoi(columns[1]), last_output_.get()));
+    MOZC_ASSERT_EQ(2, args.size());
+    MOZC_ASSERT_TRUE(client_->SubmitCandidate(NumberUtil::SimpleAtoi(args[1]),
+                                              last_output_.get()));
   } else if (command == "SUBMIT_CANDIDATE_BY_VALUE") {
-    MOZC_ASSERT_EQ(2, columns.size());
-    uint32 id;
-    MOZC_ASSERT_TRUE(GetCandidateIdByValue(columns[1], &id));
+    MOZC_ASSERT_EQ(2, args.size());
+    uint32_t id;
+    MOZC_ASSERT_TRUE(GetCandidateIdByValue(args[1], &id));
     MOZC_ASSERT_TRUE(client_->SubmitCandidate(id, last_output_.get()));
   } else if (command == "EXPAND_SUGGESTION") {
     MOZC_ASSERT_TRUE(client_->ExpandSuggestion(last_output_.get()));
   } else if (command == "UNDO_OR_REWIND") {
     MOZC_ASSERT_TRUE(client_->UndoOrRewind(last_output_.get()));
   } else if (command == "SWITCH_INPUT_MODE") {
-    MOZC_ASSERT_EQ(2, columns.size());
+    MOZC_ASSERT_EQ(2, args.size());
     CompositionMode composition_mode;
-    MOZC_ASSERT_TRUE_MSG(CompositionMode_Parse(columns[1], &composition_mode),
+    MOZC_ASSERT_TRUE_MSG(CompositionMode_Parse(args[1], &composition_mode),
                          "Unknown CompositionMode");
     MOZC_ASSERT_TRUE(client_->SwitchInputMode(composition_mode));
   } else if (command == "SET_DEFAULT_REQUEST") {
-    request_->CopyFrom(Request::default_instance());
+    *request_ = Request::default_instance();
     MOZC_ASSERT_TRUE(client_->SetRequest(*request_, last_output_.get()));
   } else if (command == "SET_MOBILE_REQUEST") {
     RequestForUnitTest::FillMobileRequest(request_.get());
     MOZC_ASSERT_TRUE(client_->SetRequest(*request_, last_output_.get()));
   } else if (command == "SET_REQUEST") {
-    MOZC_ASSERT_EQ(3, columns.size());
+    MOZC_ASSERT_EQ(3, args.size());
     MOZC_ASSERT_TRUE(
-        SetOrAddFieldValueFromString(columns[1], columns[2], request_.get()));
+        SetOrAddFieldValueFromString(args[1], args[2], request_.get()));
     MOZC_ASSERT_TRUE(client_->SetRequest(*request_, last_output_.get()));
   } else if (command == "SET_CONFIG") {
-    MOZC_ASSERT_EQ(3, columns.size());
+    MOZC_ASSERT_EQ(3, args.size());
     MOZC_ASSERT_TRUE(
-        SetOrAddFieldValueFromString(columns[1], columns[2], config_.get()));
+        SetOrAddFieldValueFromString(args[1], args[2], config_.get()));
     MOZC_ASSERT_TRUE(client_->SetConfig(*config_, last_output_.get()));
   } else if (command == "SET_SELECTION_TEXT") {
-    MOZC_ASSERT_EQ(2, columns.size());
-    client_->SetCallbackText(columns[1]);
+    MOZC_ASSERT_EQ(2, args.size());
+    client_->SetCallbackText(args[1]);
   } else if (command == "UPDATE_MOBILE_KEYBOARD") {
-    MOZC_ASSERT_EQ(3, columns.size());
+    MOZC_ASSERT_EQ(3, args.size());
     Request::SpecialRomanjiTable special_romanji_table;
-    MOZC_ASSERT_TRUE_MSG(Request::SpecialRomanjiTable_Parse(columns[1],
-                                                        &special_romanji_table),
-                     "Unknown SpecialRomanjiTable");
+    MOZC_ASSERT_TRUE_MSG(
+        Request::SpecialRomanjiTable_Parse(args[1], &special_romanji_table),
+        "Unknown SpecialRomanjiTable");
     Request::SpaceOnAlphanumeric space_on_alphanumeric;
-    MOZC_ASSERT_TRUE_MSG(Request::SpaceOnAlphanumeric_Parse(columns[2],
-                                                        &space_on_alphanumeric),
-                     "Unknown SpaceOnAlphanumeric");
+    MOZC_ASSERT_TRUE_MSG(
+        Request::SpaceOnAlphanumeric_Parse(args[2], &space_on_alphanumeric),
+        "Unknown SpaceOnAlphanumeric");
     request_->set_special_romanji_table(special_romanji_table);
     request_->set_space_on_alphanumeric(space_on_alphanumeric);
     MOZC_ASSERT_TRUE(client_->SetRequest(*request_, last_output_.get()));
   } else if (command == "CLEAR_ALL") {
-    MOZC_ASSERT_EQ(1, columns.size());
+    MOZC_ASSERT_EQ(1, args.size());
     ClearAll();
   } else if (command == "CLEAR_USER_PREDICTION") {
-    MOZC_ASSERT_EQ(1, columns.size());
+    MOZC_ASSERT_EQ(1, args.size());
     ClearUserPrediction();
   } else if (command == "CLEAR_USAGE_STATS") {
-    MOZC_ASSERT_EQ(1, columns.size());
+    MOZC_ASSERT_EQ(1, args.size());
     ClearUsageStats();
   } else {
-    return Status(mozc::StatusCode::kUnimplemented, "");
+    return absl::Status(absl::StatusCode::kUnimplemented, "");
   }
 
-  return Status();
+  return absl::Status();
 }
 
 }  // namespace session
