@@ -30,6 +30,7 @@
 // This is a test with the actual converter.  So the result of the
 // conversion may differ from previous versions.
 
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <utility>
@@ -59,7 +60,6 @@
 #include "testing/base/public/gunit.h"
 #include "absl/flags/declare.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
 
 ABSL_DECLARE_FLAG(bool, use_history_rewriter);
 
@@ -99,7 +99,7 @@ class SessionRegressionTest : public ::testing::Test {
 
     // Note: engine must be created after setting all the flags, as it
     // internally depends on global flags, e.g., for creation of rewriters.
-    std::unique_ptr<Engine> engine(MockDataEngineFactory::Create());
+    std::unique_ptr<Engine> engine = MockDataEngineFactory::Create().value();
 
     // Clear previous data just in case. It should work without this clear,
     // however the reality is Windows environment has a flacky test issue.
@@ -107,7 +107,7 @@ class SessionRegressionTest : public ::testing::Test {
     engine->GetUserDataManager()->ClearUserPrediction();
     engine->GetUserDataManager()->Wait();
 
-    handler_ = absl::make_unique<SessionHandler>(std::move(engine));
+    handler_ = std::make_unique<SessionHandler>(std::move(engine));
     ResetSession();
     CHECK(session_.get());
   }
@@ -134,7 +134,7 @@ class SessionRegressionTest : public ::testing::Test {
                           const commands::Context &context,
                           commands::Command *command) {
     command->Clear();
-    command->mutable_input()->mutable_context()->CopyFrom(context);
+    *command->mutable_input()->mutable_context() = context;
     command->mutable_input()->set_type(commands::Input::SEND_KEY);
     if (!KeyParser::ParseKey(key, command->mutable_input()->mutable_key())) {
       return false;
@@ -153,7 +153,7 @@ class SessionRegressionTest : public ::testing::Test {
 
   void InsertCharacterChars(const std::string &chars,
                             commands::Command *command) {
-    const uint32 kNoModifiers = 0;
+    constexpr uint32_t kNoModifiers = 0;
     for (size_t i = 0; i < chars.size(); ++i) {
       command->clear_input();
       command->clear_output();
@@ -167,7 +167,7 @@ class SessionRegressionTest : public ::testing::Test {
   void ResetSession() {
     session_.reset(static_cast<session::Session *>(handler_->NewSession()));
     commands::Request request;
-    table_ = absl::make_unique<composer::Table>();
+    table_ = std::make_unique<composer::Table>();
     table_->InitializeWithRequestAndConfig(request, config_, data_manager_);
     session_->SetTable(table_.get());
   }
@@ -234,9 +234,9 @@ TEST_F(SessionRegressionTest,
     // The MacOS default short cut of F10 is DisplayAsHalfAlphanumeric.
     // It does not start the conversion so output does not have any result.
     EXPECT_FALSE(command.output().has_result());
-#else
+#else   // __APPLE__
     EXPECT_TRUE(command.output().has_result());
-#endif
+#endif  // __APPLE__
     EXPECT_EQ(commands::HIRAGANA, command.output().status().mode());
     EXPECT_EQ(commands::HIRAGANA, command.output().mode());  // obsolete
   }
@@ -363,7 +363,7 @@ TEST_F(SessionRegressionTest, PredictionAfterUndo) {
 // Currently the restriction is removed. This test checks that the logic
 // works well or not.
 TEST_F(SessionRegressionTest, ConsistencyBetweenPredictionAndSuggesion) {
-  const char kKey[] = "aio";
+  constexpr char kKey[] = "aio";
 
   commands::Request request;
   commands::RequestForUnitTest::FillMobileRequest(&request);
@@ -409,7 +409,7 @@ TEST_F(SessionRegressionTest, AutoConversionTest) {
 
     InitSessionToPrecomposition(session_.get());
 
-    const char kInputKeys[] = "123456.7";
+    constexpr char kInputKeys[] = "123456.7";
     for (size_t i = 0; kInputKeys[i]; ++i) {
       command.Clear();
       commands::KeyEvent *key_event = command.mutable_input()->mutable_key();
@@ -432,7 +432,7 @@ TEST_F(SessionRegressionTest, AutoConversionTest) {
     config.set_use_auto_conversion(true);
     session_->SetConfig(&config);
 
-    const char kInputKeys[] = "aiueo.";
+    constexpr char kInputKeys[] = "aiueo.";
     for (size_t i = 0; i < kInputKeys[i]; ++i) {
       command.Clear();
       commands::KeyEvent *key_event = command.mutable_input()->mutable_key();
@@ -455,7 +455,7 @@ TEST_F(SessionRegressionTest, AutoConversionTest) {
     config.set_use_auto_conversion(true);
     session_->SetConfig(&config);
 
-    const char kInputKeys[] = "1234.";
+    constexpr char kInputKeys[] = "1234.";
     for (size_t i = 0; i < kInputKeys[i]; ++i) {
       command.Clear();
       commands::KeyEvent *key_event = command.mutable_input()->mutable_key();
@@ -468,7 +468,7 @@ TEST_F(SessionRegressionTest, AutoConversionTest) {
   }
 }
 
-TEST_F(SessionRegressionTest, Transliteration_Issue2330463) {
+TEST_F(SessionRegressionTest, TransliterationIssue2330463) {
   {
     ResetSession();
     commands::Command command;
@@ -500,7 +500,7 @@ TEST_F(SessionRegressionTest, Transliteration_Issue2330463) {
   }
 }
 
-TEST_F(SessionRegressionTest, Transliteration_Issue6209563) {
+TEST_F(SessionRegressionTest, TransliterationIssue6209563) {
   {  // Romaji mode
     ResetSession();
     commands::Command command;
@@ -548,7 +548,7 @@ TEST_F(SessionRegressionTest, CommitT13nSuggestion) {
   InsertCharacterChars("ssh", &command);
   EXPECT_EQ("っｓｈ", GetComposition(command));
 
-  const int kHiraganaId = -1;
+  constexpr int kHiraganaId = -1;
   SendCommandWithId(commands::SessionCommand::SUBMIT_CANDIDATE, kHiraganaId,
                     &command);
 
