@@ -30,6 +30,7 @@
 #include "session/session_watch_dog.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <cstring>
 #include <memory>
 #include <numeric>
@@ -42,29 +43,28 @@
 #include "base/system_util.h"
 #include "base/unnamed_event.h"
 #include "client/client_interface.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace {
 
 // IPC timeout
-const int32 kCleanupTimeout = 30 * 1000;  // 30 sec for Cleanup Command
-const int32 kPingTimeout = 5 * 1000;      // 5 sec for Ping
+const int32_t kCleanupTimeout = 30 * 1000;  // 30 sec for Cleanup Command
+const int32_t kPingTimeout = 5 * 1000;      // 5 sec for Ping
 
 // number of trials for ping
-const int32 kPingTrial = 3;
-const int32 kPingInterval = 1000;
+const int32_t kPingTrial = 3;
+const int32_t kPingInterval = 1000;
 
 // Average CPU load for last 1min.
 // If the load > kMinimumAllCPULoad, don't send Cleanup
-const float kMinimumAllCPULoad = 0.33f;
+constexpr float kMinimumAllCPULoad = 0.33f;
 
 // Average CPU load for last 10secs.
 // If the load > kMinimumLatestCPULoad, don't send Cleanup
-const float kMinimumLatestCPULoad = 0.66f;
+constexpr float kMinimumLatestCPULoad = 0.66f;
 }  // namespace
 
-SessionWatchDog::SessionWatchDog(int32 interval_sec)
+SessionWatchDog::SessionWatchDog(int32_t interval_sec)
     : interval_sec_(interval_sec),
       client_(nullptr),
       cpu_stats_(nullptr),
@@ -108,7 +108,7 @@ void SessionWatchDog::Run() {
   std::unique_ptr<CPUStatsInterface> cpu_stats_impl;
   if (cpu_stats_ == nullptr) {
     VLOG(2) << "default cpu_stats is used";
-    cpu_stats_impl = absl::make_unique<CPUStats>();
+    cpu_stats_impl = std::make_unique<CPUStats>();
     cpu_stats_ = cpu_stats_impl.get();
   }
 
@@ -128,17 +128,17 @@ void SessionWatchDog::Run() {
   DCHECK_GE(number_of_processors, 1);
 
   // the first (interval_sec_ - 60) sec: -> Do nothing
-  const int32 idle_interval_msec = std::max(0, (interval_sec_ - 60)) * 1000;
+  const int32_t idle_interval_msec = std::max(0, (interval_sec_ - 60)) * 1000;
 
   // last 60 sec: -> check CPU usage
-  const int32 cpu_check_interval_msec = std::min(60, interval_sec_) * 1000;
+  const int32_t cpu_check_interval_msec = std::min(60, interval_sec_) * 1000;
 
   // for every 5 second, get CPU load percentage
-  const int32 cpu_check_duration_msec = std::min(5, interval_sec_) * 1000;
+  const int32_t cpu_check_duration_msec = std::min(5, interval_sec_) * 1000;
 
-  std::fill(cpu_loads, cpu_loads + arraysize(cpu_loads), 0.0);
+  std::fill(cpu_loads, cpu_loads + std::size(cpu_loads), 0.0);
 
-  uint64 last_cleanup_time = Clock::GetTime();
+  uint64_t last_cleanup_time = Clock::GetTime();
 
   while (true) {
     VLOG(1) << "Start sleeping " << idle_interval_msec;
@@ -148,7 +148,7 @@ void SessionWatchDog::Run() {
     }
     VLOG(1) << "Finish sleeping " << idle_interval_msec;
 
-    int32 cpu_loads_index = 0;
+    int32_t cpu_loads_index = 0;
     for (int n = 0; n < cpu_check_interval_msec; n += cpu_check_duration_msec) {
       if (event_->Wait(cpu_check_duration_msec)) {
         VLOG(1) << "Received stop signal";
@@ -170,7 +170,7 @@ void SessionWatchDog::Run() {
 
     DCHECK_GT(cpu_loads_index, 0);
 
-    const uint64 current_cleanup_time = Clock::GetTime();
+    const uint64_t current_cleanup_time = Clock::GetTime();
     if (!CanSendCleanupCommand(cpu_loads, cpu_loads_index, current_cleanup_time,
                                last_cleanup_time)) {
       VLOG(1) << "CanSendCleanupCommand returned false";
@@ -222,7 +222,7 @@ void SessionWatchDog::Run() {
       const std::string tmp = SystemUtil::GetUserNameAsString();
       strncpy(user_name, tmp.c_str(), sizeof(user_name));
       VLOG(1) << "user_name: " << user_name;
-#endif
+#endif  // !MOZC_NO_LOGGING
       LOG(FATAL) << "Cleanup commands failed. Rasing exception...";
     }
   }
@@ -230,8 +230,8 @@ void SessionWatchDog::Run() {
 
 bool SessionWatchDog::CanSendCleanupCommand(const volatile float *cpu_loads,
                                             int cpu_loads_index,
-                                            uint64 current_cleanup_time,
-                                            uint64 last_cleanup_time) const {
+                                            uint64_t current_cleanup_time,
+                                            uint64_t last_cleanup_time) const {
   if (current_cleanup_time <= last_cleanup_time) {
     LOG(ERROR) << "time stamps are the same. clock may be altered";
     return false;
