@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,7 @@
 
 #ifdef OS_WIN
 #include <Windows.h>
-#endif
+#endif  // OS_WIN
 
 #include <cstring>
 #include <string>
@@ -49,10 +49,10 @@ namespace storage {
 
 namespace {
 // Salt size for encryption
-const size_t kSaltSize = 32;
+constexpr size_t kSaltSize = 32;
 
 // Maximum file size (64Mbyte)
-const size_t kMaxFileSize = 64 * 1024 * 1024;
+constexpr size_t kMaxFileSize = 64 * 1024 * 1024;
 }  // namespace
 
 EncryptedStringStorage::EncryptedStringStorage(const std::string &filename)
@@ -150,8 +150,10 @@ bool EncryptedStringStorage::Save(const std::string &input) const {
     ofs.write(output.data(), output.size());
   }
 
-  if (!FileUtil::AtomicRename(tmp_filename, filename_)) {
-    LOG(ERROR) << "AtomicRename failed";
+  if (absl::Status s = FileUtil::AtomicRename(tmp_filename, filename_);
+      !s.ok()) {
+    LOG(ERROR) << "AtomicRename failed: " << s << "; from: " << tmp_filename
+               << ", to: " << filename_;
     return false;
   }
 
@@ -160,7 +162,7 @@ bool EncryptedStringStorage::Save(const std::string &input) const {
     LOG(ERROR) << "Cannot make hidden: " << filename_ << " "
                << ::GetLastError();
   }
-#endif
+#endif  // OS_WIN
 
   return true;
 }
