@@ -31,6 +31,7 @@
 
 #include <iostream>
 #include <memory>
+#include <string>
 
 #include "base/file_stream.h"
 #include "base/file_util.h"
@@ -39,7 +40,6 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
-#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace storage {
@@ -51,18 +51,18 @@ namespace {
 // them, because we cannot launch JVM from native tests on Android.
 class TestEncryptedStringStorage : public EncryptedStringStorage {
  public:
-  explicit TestEncryptedStringStorage(const string &filename)
+  explicit TestEncryptedStringStorage(const std::string &filename)
       : EncryptedStringStorage(filename) {}
 
  protected:
-  virtual bool Encrypt(const string &salt, string *data) const {
+  virtual bool Encrypt(const std::string &salt, std::string *data) const {
     salt_ = salt;
     original_data_ = *data;
     *data = "123456789012345678901234567890";
     return true;
   }
 
-  virtual bool Decrypt(const string &salt, string *data) const {
+  virtual bool Decrypt(const std::string &salt, std::string *data) const {
     if (salt_ != salt) {
       return false;
     }
@@ -71,10 +71,10 @@ class TestEncryptedStringStorage : public EncryptedStringStorage {
     return true;
   }
 
-  mutable string salt_;
-  mutable string original_data_;
+  mutable std::string salt_;
+  mutable std::string original_data_;
 };
-#else
+#else  // OS_ANDROID
 typedef EncryptedStringStorage TestEncryptedStringStorage;
 #endif  // OS_ANDROID
 }  // namespace
@@ -86,7 +86,7 @@ class EncryptedStringStorageTest : public testing::Test {
     filename_ = FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(),
                                    "encrypted_string_storage_for_test.db");
 
-    storage_ = absl::make_unique<TestEncryptedStringStorage>(filename_);
+    storage_ = std::make_unique<TestEncryptedStringStorage>(filename_);
   }
 
   std::string filename_;
@@ -111,7 +111,7 @@ TEST_F(EncryptedStringStorageTest, Encrypt) {
   ASSERT_TRUE(storage_->Save(original_data));
 
   InputFileStream ifs(filename_.c_str(), (std::ios::in | std::ios::binary));
-  const size_t kBufSize = 128;
+  constexpr size_t kBufSize = 128;
   char buf[kBufSize];
   // |ifs.readsome(buf, kBufSize)| returns 0 on Visual C++ because
   // |ifs.rdbuf()->in_avail()| is still 0 just after the file is opened.
