@@ -29,6 +29,7 @@
 
 #include "storage/louds/bit_vector_based_array.h"
 
+#include <cstdint>
 #include <string>
 
 #include "base/port.h"
@@ -63,15 +64,15 @@ TEST_F(BitVectorBasedArrayTest, Get) {
   };
 
   BitVectorBasedArrayBuilder builder;
-  for (size_t i = 0; i < arraysize(kTestData); ++i) {
+  for (size_t i = 0; i < std::size(kTestData); ++i) {
     builder.Add(std::string(kTestData[i].element, kTestData[i].length));
   }
   builder.SetSize(4, 2);
   builder.Build();
 
   BitVectorBasedArray array;
-  array.Open(reinterpret_cast<const uint8*>(builder.image().data()));
-  for (size_t i = 0; i < arraysize(kTestData); ++i) {
+  array.Open(reinterpret_cast<const uint8_t*>(builder.image().data()));
+  for (size_t i = 0; i < std::size(kTestData); ++i) {
     size_t length;
     const char* result = array.Get(i, &length);
     EXPECT_EQ(std::string(kTestData[i].expected_element,
