@@ -30,10 +30,10 @@
 #include "storage/louds/simple_succinct_bit_vector_index.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <iterator>
 #include <vector>
 
-#include "base/iterator_adapter.h"
 #include "base/logging.h"
 #include "base/port.h"
 
@@ -42,30 +42,47 @@ namespace storage {
 namespace louds {
 namespace {
 
-// Simple adapter to convert from 1-bit index to 0-bit index.
-class ZeroBitAdapter : public AdapterBase<int> {
+// An iterator adaptor that gives the view of 1-bit index as 0-bit index.
+class ZeroBitIndexIterator {
  public:
-  // Needs to be default constructive to create invalid iterator.
-  ZeroBitAdapter() : index_(nullptr), chunk_size_(0) {}
+  using difference_type = ptrdiff_t;
+  using value_type = int;
+  using pointer = const int *;
+  using reference = const int &;
+  using iterator_category = std::forward_iterator_tag;
 
-  ZeroBitAdapter(const std::vector<int> *index, int chunk_size)
-      : index_(index), chunk_size_(chunk_size) {}
+  ZeroBitIndexIterator(const std::vector<int> &index, int chunk_size,
+                       const int *ptr)
+      : data_{index.data()}, chunk_size_{chunk_size}, ptr_{ptr} {}
 
-  value_type operator()(const int *ptr) const {
+  const int *ptr() const { return ptr_; }
+
+  ZeroBitIndexIterator &operator++() {
+    ++ptr_;
+    return *this;
+  }
+
+  friend bool operator!=(const ZeroBitIndexIterator &x,
+                         const ZeroBitIndexIterator &y) {
+    return x.ptr_ != y.ptr_;
+  }
+
+  int operator*() const {
     // The number of 0-bits
     //   = (total num bits) - (1-bits)
     //   = (chunk_size [bytes] * 8 [bits/byte] * (ptr's offset) - (1-bits)
-    return chunk_size_ * 8 * (ptr - index_->data()) - *ptr;
+    return chunk_size_ * 8 * (ptr_ - data_) - *ptr_;
   }
 
  private:
-  const std::vector<int> *index_;
+  const int *data_;
   int chunk_size_;
+  const int *ptr_;
 };
 
 #ifdef __GNUC__
 // TODO(hidehiko): Support XMM and 64-bits popcount for 64bits architectures.
-inline int BitCount1(uint32 x) { return __builtin_popcount(x); }
+inline int BitCount1(uint32_t x) { return __builtin_popcount(x); }
 #else
 int BitCount1(uint32 x) {
   x = ((x & 0xaaaaaaaa) >> 1) + (x & 0x55555555);
@@ -77,7 +94,7 @@ int BitCount1(uint32 x) {
 }
 #endif
 
-inline int BitCount0(uint32 x) {
+inline int BitCount0(uint32_t x) {
   // Flip all bits, and count 1-bits.
   return BitCount1(~x);
 }
@@ -90,7 +107,7 @@ inline bool IsPowerOfTwo(int value) {
 }
 
 // Returns 1-bits in the data[0] ... data[length - 1].
-int Count1Bits(const uint32 *data, int length) {
+int Count1Bits(const uint32_t *data, int length) {
   int num_bits = 0;
   for (; length > 0; ++data, --length) {
     num_bits += BitCount1(*data);
@@ -99,7 +116,7 @@ int Count1Bits(const uint32 *data, int length) {
 }
 
 // Stores index (the camulative number of the 1-bits from begin of each chunk).
-void InitIndex(const uint8 *data, int length, int chunk_size,
+void InitIndex(const uint8_t *data, int length, int chunk_size,
                std::vector<int> *index) {
   DCHECK_GE(chunk_size, 4);
   DCHECK(IsPowerOfTwo(chunk_size)) << chunk_size;
@@ -117,7 +134,7 @@ void InitIndex(const uint8 *data, int length, int chunk_size,
   for (int remaining_num_words = length / 4; remaining_num_words > 0;
        data += chunk_size, remaining_num_words -= chunk_size / 4) {
     index->push_back(num_bits);
-    num_bits += Count1Bits(reinterpret_cast<const uint32 *>(data),
+    num_bits += Count1Bits(reinterpret_cast<const uint32_t *>(data),
                            std::min(chunk_size / 4, remaining_num_words));
   }
   index->push_back(num_bits);
@@ -132,15 +149,14 @@ void InitLowerBound0Cache(const std::vector<int> &index, int chunk_size,
   cache->clear();
   cache->reserve(size + 2);
   cache->push_back(index.data());
-  ZeroBitAdapter adapter(&index, chunk_size);
   for (size_t i = 1; i <= size; ++i) {
     const int target_index = increment * i;
     const int *ptr =
-        std::lower_bound(
-            MakeIteratorAdapter(index.data(), adapter),
-            MakeIteratorAdapter(index.data() + index.size(), adapter),
-            target_index)
-            .base();
+        std::lower_bound(ZeroBitIndexIterator(index, chunk_size, index.data()),
+                         ZeroBitIndexIterator(index, chunk_size,
+                                              index.data() + index.size()),
+                         target_index)
+            .ptr();
     cache->push_back(ptr);
   }
   cache->push_back(index.data() + index.size());
@@ -164,7 +180,7 @@ void InitLowerBound1Cache(const std::vector<int> &index, int chunk_size,
 
 }  // namespace
 
-void SimpleSuccinctBitVectorIndex::Init(const uint8 *data, int length,
+void SimpleSuccinctBitVectorIndex::Init(const uint8_t *data, int length,
                                         size_t lb0_cache_size,
                                         size_t lb1_cache_size) {
   data_ = data;
@@ -207,7 +223,7 @@ int SimpleSuccinctBitVectorIndex::Rank1(int n) const {
 
   // Count 1-bits for remaining "words".
   result += Count1Bits(
-      reinterpret_cast<const uint32 *>(data_ + num_chunks * chunk_size_),
+      reinterpret_cast<const uint32_t *>(data_ + num_chunks * chunk_size_),
       (n / 8 - num_chunks * chunk_size_) / 4);
 
   // Count 1-bits for remaining "bits".
@@ -215,7 +231,7 @@ int SimpleSuccinctBitVectorIndex::Rank1(int n) const {
     const int index = n / 32;
     const int shift = 32 - n % 32;
     result +=
-        BitCount1(reinterpret_cast<const uint32 *>(data_)[index] << shift);
+        BitCount1(reinterpret_cast<const uint32_t *>(data_)[index] << shift);
   }
 
   return result;
@@ -232,19 +248,20 @@ int SimpleSuccinctBitVectorIndex::Select0(int n) const {
   DCHECK_GE(lb0_cache_index, 0);
 
   // Binary search on chunks.
-  ZeroBitAdapter adapter(&index_, chunk_size_);
   const int *chunk_ptr =
-      std::lower_bound(
-          MakeIteratorAdapter(lb0_cache_[lb0_cache_index], adapter),
-          MakeIteratorAdapter(lb0_cache_[lb0_cache_index + 1], adapter), n)
-          .base();
+      std::lower_bound(ZeroBitIndexIterator(index_, chunk_size_,
+                                            lb0_cache_[lb0_cache_index]),
+                       ZeroBitIndexIterator(index_, chunk_size_,
+                                            lb0_cache_[lb0_cache_index + 1]),
+                       n)
+          .ptr();
   const int chunk_index = (chunk_ptr - index_.data()) - 1;
   DCHECK_GE(chunk_index, 0);
   n -= chunk_size_ * 8 * chunk_index - index_[chunk_index];
 
   // Linear search on remaining "words"
-  const uint32 *ptr =
-      reinterpret_cast<const uint32 *>(data_) + chunk_index * chunk_size_ / 4;
+  const uint32_t *ptr =
+      reinterpret_cast<const uint32_t *>(data_) + chunk_index * chunk_size_ / 4;
   while (true) {
     const int bit_count = BitCount0(*ptr);
     if (bit_count >= n) {
@@ -254,8 +271,8 @@ int SimpleSuccinctBitVectorIndex::Select0(int n) const {
     ++ptr;
   }
 
-  int index = (ptr - reinterpret_cast<const uint32 *>(data_)) * 32;
-  for (uint32 word = ~(*ptr); n > 0; word >>= 1, ++index) {
+  int index = (ptr - reinterpret_cast<const uint32_t *>(data_)) * 32;
+  for (uint32_t word = ~(*ptr); n > 0; word >>= 1, ++index) {
     n -= (word & 1);
   }
 
@@ -282,8 +299,8 @@ int SimpleSuccinctBitVectorIndex::Select1(int n) const {
   n -= index_[chunk_index];
 
   // Linear search on remaining "words"
-  const uint32 *ptr =
-      reinterpret_cast<const uint32 *>(data_) + chunk_index * chunk_size_ / 4;
+  const uint32_t *ptr =
+      reinterpret_cast<const uint32_t *>(data_) + chunk_index * chunk_size_ / 4;
   while (true) {
     const int bit_count = BitCount1(*ptr);
     if (bit_count >= n) {
@@ -293,8 +310,8 @@ int SimpleSuccinctBitVectorIndex::Select1(int n) const {
     ++ptr;
   }
 
-  int index = (ptr - reinterpret_cast<const uint32 *>(data_)) * 32;
-  for (uint32 word = *ptr; n > 0; word >>= 1, ++index) {
+  int index = (ptr - reinterpret_cast<const uint32_t *>(data_)) * 32;
+  for (uint32_t word = *ptr; n > 0; word >>= 1, ++index) {
     n -= (word & 1);
   }
 
