@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,12 +30,11 @@
 #ifndef MOZC_STORAGE_LRU_CACHE_H_
 #define MOZC_STORAGE_LRU_CACHE_H_
 
-#include <cstring>
-#include <map>
-#include <string>
+#include <memory>
 
 #include "base/logging.h"
 #include "base/port.h"
+#include "absl/container/flat_hash_map.h"
 
 namespace mozc {
 namespace storage {
@@ -44,13 +43,14 @@ namespace storage {
 // such a entry is erased. Be careful to use for such classes.
 // TODO(yukawa): Make this class final once we stop supporting GCC 4.6.
 template <typename Key, typename Value>
-class LRUCache {
+class LruCache {
  public:
-  // Constructs a new LRUCache that can hold at most max_elements
-  explicit LRUCache(size_t max_elements);
+  // Constructs a new LruCache that can hold at most max_elements
+  explicit LruCache(size_t max_elements);
+  ~LruCache() = default;
 
-  // Cleans up all allocated resources.
-  ~LRUCache();
+  LruCache(const LruCache&) = delete;
+  LruCache& operator=(const LruCache&) = delete;
 
   // Every Element is either on the free list or the lru list.  The
   // free list is singly-linked and only uses the next pointer, while
@@ -75,13 +75,15 @@ class LRUCache {
   // ownership of the returned value.  The reference returned by Lookup() could
   // be invalidated by a call to Insert(), so the caller must take care to not
   // access the value if Insert() could have been called after Lookup().
-  const Value* Lookup(const Key& key);
+  const Value* Lookup(const Key& key) { return MutableLookup(key); }
 
   // return non-const Value
   Value* MutableLookup(const Key& key);
 
   // Lookup/MutableLookup don't change the LRU order.
-  const Value* LookupWithoutInsert(const Key& key) const;
+  const Value* LookupWithoutInsert(const Key& key) const {
+    return MutableLookupWithoutInsert(key);
+  }
   Value* MutableLookupWithoutInsert(const Key& key) const;
 
   // Removes the cache entry specified by key.  Returns true if the entry was
@@ -94,9 +96,9 @@ class LRUCache {
   void Clear();
 
   // Returns the number of entries currently in the cache.
-  size_t Size() const;
+  size_t Size() const { return table_.size(); }
 
-  bool HasKey(const Key& key) const;
+  bool HasKey(const Key& key) const { return table_.find(key) != table_.end(); }
 
   // Returns the head of LRU list
   const Element* Head() const { return lru_head_; }
@@ -137,33 +139,27 @@ class LRUCache {
   // lookup is not necessary.
   bool Evict(Element* element);
 
-  typedef std::map<Key, Element*> Table;
-
-  Table* table_;
-  Element* free_list_;   // singly linked list of Element
-  Element* lru_head_;    // head of doubly linked list of Element
-  Element* lru_tail_;    // tail of doubly linked list of Element
-  Element* blocks_[10];  // blocks of Element, with each block being twice
-  //   as big as the previous block.  This allows the
-  //   cache to use a small amount of memory when it
-  //   contains few items, but still have low malloc
-  //   overhead per insert.  The number of blocks is
-  //   arbitrary, but 10 blocks allows the largest
-  //   block to be 2^10 times as large as the smallest
-  //   block, which seems like more than enough.
-  size_t block_count_;      // how many entries in blocks_ have been used
-  size_t block_capacity_;   // how many Elements can be stored in current blocks
-  size_t next_block_size_;  // size of the next block to allocate
-  size_t max_elements_;     // maximum elements to hold
-
-  DISALLOW_COPY_AND_ASSIGN(LRUCache);
+  absl::flat_hash_map<Key, Element*> table_;
+  Element* free_list_ = nullptr;  // singly linked list of Element
+  Element* lru_head_ = nullptr;   // head of doubly linked list of Element
+  Element* lru_tail_ = nullptr;   // tail of doubly linked list of Element
+  std::unique_ptr<Element[]> blocks_[10];  // blocks of Element, with each
+  //   block being twice as big as the previous block.  This allows the cache to
+  //   use a small amount of memory when it contains few items, but still have
+  //   low malloc overhead per insert.  The number of blocks is arbitrary, but
+  //   10 blocks allows the largest block to be 2^10 times as large as the
+  //   smallest block, which seems like more than enough.
+  size_t block_count_ = 0;      // how many entries in blocks_ have been used
+  size_t block_capacity_ = 0;   // num elements the current blocks can hold
+  size_t next_block_size_ = 0;  // size of the next block to allocate
+  const size_t max_elements_;   // maximum elements to hold
 };
 
 template <typename Key, typename Value>
-void LRUCache<Key, Value>::AddBlock() {
+void LruCache<Key, Value>::AddBlock() {
   const size_t max_blocks = sizeof(blocks_) / sizeof(blocks_[0]);
   if (block_count_ < max_blocks && block_capacity_ < max_elements_) {
-    blocks_[block_count_] = new Element[next_block_size_];
+    blocks_[block_count_] = std::make_unique<Element[]>(next_block_size_);
     block_capacity_ += next_block_size_;
     // Add new elements to free list
     for (size_t i = 0; i < next_block_size_; ++i) {
@@ -188,14 +184,14 @@ void LRUCache<Key, Value>::AddBlock() {
 }
 
 template <typename Key, typename Value>
-void LRUCache<Key, Value>::PushFreeList(Element* element) {
+void LruCache<Key, Value>::PushFreeList(Element* element) {
   element->prev = nullptr;
   element->next = free_list_;
   free_list_ = element;
 }
 
 template <typename Key, typename Value>
-typename LRUCache<Key, Value>::Element* LRUCache<Key, Value>::PopFreeList() {
+typename LruCache<Key, Value>::Element* LruCache<Key, Value>::PopFreeList() {
   Element* r = free_list_;
   if (r != nullptr) {
     CHECK(r->prev == nullptr);
@@ -209,8 +205,8 @@ typename LRUCache<Key, Value>::Element* LRUCache<Key, Value>::PopFreeList() {
 }
 
 template <typename Key, typename Value>
-typename LRUCache<Key, Value>::Element*
-LRUCache<Key, Value>::NextFreeElement() {
+typename LruCache<Key, Value>::Element*
+LruCache<Key, Value>::NextFreeElement() {
   Element* r = PopFreeList();
   if (r == nullptr) {
     AddBlock();
@@ -220,17 +216,16 @@ LRUCache<Key, Value>::NextFreeElement() {
 }
 
 template <typename Key, typename Value>
-typename LRUCache<Key, Value>::Element* LRUCache<Key, Value>::LookupInternal(
+typename LruCache<Key, Value>::Element* LruCache<Key, Value>::LookupInternal(
     const Key& key) const {
-  typename Table::iterator iter = table_->find(key);
-  if (iter != table_->end()) {
+  if (auto iter = table_.find(key); iter != table_.end()) {
     return iter->second;
   }
   return nullptr;
 }
 
 template <typename Key, typename Value>
-void LRUCache<Key, Value>::RemoveFromLRU(Element* element) {
+void LruCache<Key, Value>::RemoveFromLRU(Element* element) {
   if (lru_head_ == element) {
     lru_head_ = element->next;
   }
@@ -248,7 +243,7 @@ void LRUCache<Key, Value>::RemoveFromLRU(Element* element) {
 }
 
 template <typename Key, typename Value>
-void LRUCache<Key, Value>::PushLRUHead(Element* element) {
+void LruCache<Key, Value>::PushLRUHead(Element* element) {
   if (lru_head_ == element) {
     // element is already at head, so do nothing.
     return;
@@ -265,9 +260,9 @@ void LRUCache<Key, Value>::PushLRUHead(Element* element) {
 }
 
 template <typename Key, typename Value>
-bool LRUCache<Key, Value>::Evict(Element* e) {
+bool LruCache<Key, Value>::Evict(Element* e) {
   if (e != nullptr) {
-    int erased = table_->erase(e->key);
+    const int erased = table_.erase(e->key);
     CHECK_EQ(erased, 1);
     RemoveFromLRU(e);
     PushFreeList(e);
@@ -277,16 +272,8 @@ bool LRUCache<Key, Value>::Evict(Element* e) {
 }
 
 template <typename Key, typename Value>
-LRUCache<Key, Value>::LRUCache(size_t max_elements)
-    : free_list_(nullptr),
-      lru_head_(nullptr),
-      lru_tail_(nullptr),
-      block_count_(0),
-      block_capacity_(0),
-      max_elements_(max_elements) {
-  ::memset(blocks_, 0, sizeof(blocks_));
-  table_ = new Table;
-  CHECK(table_);
+LruCache<Key, Value>::LruCache(size_t max_elements)
+    : max_elements_(max_elements) {
   if (max_elements_ <= 128) {
     next_block_size_ = max_elements_;
   } else {
@@ -304,17 +291,7 @@ LRUCache<Key, Value>::LRUCache(size_t max_elements)
 }
 
 template <typename Key, typename Value>
-LRUCache<Key, Value>::~LRUCache() {
-  // To free all the memory that I have allocated I need to delete table_ and
-  // any used entries in blocks_.
-  delete table_;
-  for (size_t i = 0; i < block_count_; ++i) {
-    delete[] blocks_[i];
-  }
-}
-
-template <typename Key, typename Value>
-void LRUCache<Key, Value>::Insert(const Key& key, const Value& value) {
+void LruCache<Key, Value>::Insert(const Key& key, const Value& value) {
   Element* e = Insert(key);
   if (e != nullptr) {
     e->value = value;
@@ -322,7 +299,7 @@ void LRUCache<Key, Value>::Insert(const Key& key, const Value& value) {
 }
 
 template <typename Key, typename Value>
-typename LRUCache<Key, Value>::Element* LRUCache<Key, Value>::Insert(
+typename LruCache<Key, Value>::Element* LruCache<Key, Value>::Insert(
     const Key& key) {
   bool erased = false;
   Element* e = LookupInternal(key);
@@ -341,14 +318,14 @@ typename LRUCache<Key, Value>::Element* LRUCache<Key, Value>::Insert(
     CHECK(e != nullptr);
   }
   e->key = key;
-  (*table_)[key] = e;
+  table_[key] = e;
   PushLRUHead(e);
 
   return e;
 }
 
 template <typename Key, typename Value>
-Value* LRUCache<Key, Value>::MutableLookup(const Key& key) {
+Value* LruCache<Key, Value>::MutableLookup(const Key& key) {
   Element* e = LookupInternal(key);
   if (e != nullptr) {
     PushLRUHead(e);
@@ -358,12 +335,7 @@ Value* LRUCache<Key, Value>::MutableLookup(const Key& key) {
 }
 
 template <typename Key, typename Value>
-const Value* LRUCache<Key, Value>::Lookup(const Key& key) {
-  return MutableLookup(key);
-}
-
-template <typename Key, typename Value>
-Value* LRUCache<Key, Value>::MutableLookupWithoutInsert(const Key& key) const {
+Value* LruCache<Key, Value>::MutableLookupWithoutInsert(const Key& key) const {
   Element* e = LookupInternal(key);
   if (e != nullptr) {
     return &(e->value);
@@ -372,19 +344,14 @@ Value* LRUCache<Key, Value>::MutableLookupWithoutInsert(const Key& key) const {
 }
 
 template <typename Key, typename Value>
-const Value* LRUCache<Key, Value>::LookupWithoutInsert(const Key& key) const {
-  return MutableLookupWithoutInsert(key);
-}
-
-template <typename Key, typename Value>
-bool LRUCache<Key, Value>::Erase(const Key& key) {
+bool LruCache<Key, Value>::Erase(const Key& key) {
   Element* e = LookupInternal(key);
   return Evict(e);
 }
 
 template <typename Key, typename Value>
-void LRUCache<Key, Value>::Clear() {
-  table_->clear();
+void LruCache<Key, Value>::Clear() {
+  table_.clear();
   Element* e = lru_head_;
   while (e != nullptr) {
     Element* next = e->next;
@@ -394,16 +361,7 @@ void LRUCache<Key, Value>::Clear() {
   lru_head_ = lru_tail_ = nullptr;
 }
 
-template <typename Key, typename Value>
-bool LRUCache<Key, Value>::HasKey(const Key& key) const {
-  return (table_->find(key) != table_->end());
-}
-
-template <typename Key, typename Value>
-size_t LRUCache<Key, Value>::Size() const {
-  return table_->size();
-}
-
 }  // namespace storage
 }  // namespace mozc
+
 #endif  // MOZC_STORAGE_LRU_CACHE_H_
