@@ -30,6 +30,7 @@
 #include "storage/lru_storage.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <cstdlib>
 #include <cstring>
 #include <ctime>
@@ -44,30 +45,29 @@
 #include "base/hash.h"
 #include "base/logging.h"
 #include "base/mmap.h"
-#include "base/mozc_hash_set.h"
 #include "base/port.h"
 #include "base/util.h"
-#include "absl/memory/memory.h"
+#include "absl/container/flat_hash_set.h"
 
 namespace mozc {
 namespace storage {
 namespace {
 
-const size_t kMaxLRUSize = 1000000;  // 1M
-const size_t kMaxValueSize = 1024;   // 1024 byte
+constexpr size_t kMaxLruSize = 1000000;  // 1M
+constexpr size_t kMaxValueSize = 1024;   // 1024 byte
 
 // The byte length used to store fingerprint and timestamp for each item.
 // * 8 bytes for fingerprint
 // * 4 bytes for timestamp.
-const size_t kItemHeaderSize = 12;
+constexpr size_t kItemHeaderSize = 12;
 
 // The byte length used to store LRU properties.
 // * 4 bytes for user specified value size
 // * 4 bytes for LRU capacity
 // * 4 bytes for fingerprint seed
-const size_t kFileHeaderSize = 12;
+constexpr size_t kFileHeaderSize = 12;
 
-const uint64 k62DaysInSec = 62 * 24 * 60 * 60;
+const uint64_t k62DaysInSec = 62 * 24 * 60 * 60;
 
 template <class T>
 inline void ReadValue(char **ptr, T *value) {
@@ -75,28 +75,30 @@ inline void ReadValue(char **ptr, T *value) {
   *ptr += sizeof(*value);
 }
 
-uint64 GetFP(const char *ptr) { return *reinterpret_cast<const uint64 *>(ptr); }
+uint64_t GetFP(const char *ptr) {
+  return *reinterpret_cast<const uint64_t *>(ptr);
+}
 
-uint32 GetTimeStamp(const char *ptr) {
-  return *reinterpret_cast<const uint32 *>(ptr + 8);
+uint32_t GetTimeStamp(const char *ptr) {
+  return *reinterpret_cast<const uint32_t *>(ptr + 8);
 }
 
 const char *GetValue(const char *ptr) { return ptr + kItemHeaderSize; }
 
 void Update(char *ptr) {
-  const uint32 last_access_time = static_cast<uint32>(Clock::GetTime());
+  const uint32_t last_access_time = static_cast<uint32_t>(Clock::GetTime());
   memcpy(ptr + 8, reinterpret_cast<const char *>(&last_access_time), 4);
 }
 
-void Update(char *ptr, uint64 fp, const char *value, size_t value_size) {
-  const uint32 last_access_time = static_cast<uint32>(Clock::GetTime());
+void Update(char *ptr, uint64_t fp, const char *value, size_t value_size) {
+  const uint32_t last_access_time = static_cast<uint32_t>(Clock::GetTime());
   memcpy(ptr, reinterpret_cast<const char *>(&fp), 8);
   memcpy(ptr + 8, reinterpret_cast<const char *>(&last_access_time), 4);
   memcpy(ptr + 12, value, value_size);
 }
 
-bool IsOlderThan62Days(uint64 timestamp) {
-  const uint64 now = Clock::GetTime();
+bool IsOlderThan62Days(uint64_t timestamp) {
+  const uint64_t now = Clock::GetTime();
   return (timestamp + k62DaysInSec < now);
 }
 
@@ -109,33 +111,33 @@ class CompareByTimeStamp {
 
 }  // namespace
 
-LRUStorage *LRUStorage::Create(const char *filename) {
-  std::unique_ptr<LRUStorage> n(new LRUStorage);
+LruStorage *LruStorage::Create(const char *filename) {
+  std::unique_ptr<LruStorage> n(new LruStorage);
   if (!n->Open(filename)) {
-    LOG(ERROR) << "could not open LRUStorage";
+    LOG(ERROR) << "could not open LruStorage";
     return nullptr;
   }
   return n.release();
 }
 
-LRUStorage *LRUStorage::Create(const char *filename, size_t value_size,
-                               size_t size, uint32 seed) {
-  std::unique_ptr<LRUStorage> n(new LRUStorage);
+LruStorage *LruStorage::Create(const char *filename, size_t value_size,
+                               size_t size, uint32_t seed) {
+  std::unique_ptr<LruStorage> n(new LruStorage);
   if (!n->OpenOrCreate(filename, value_size, size, seed)) {
-    LOG(ERROR) << "could not open LRUStorage";
+    LOG(ERROR) << "could not open LruStorage";
     return nullptr;
   }
   return n.release();
 }
 
-bool LRUStorage::CreateStorageFile(const char *filename, size_t value_size,
-                                   size_t size, uint32 seed) {
+bool LruStorage::CreateStorageFile(const char *filename, size_t value_size,
+                                   size_t size, uint32_t seed) {
   if (value_size == 0 || value_size > kMaxValueSize) {
     LOG(ERROR) << "value_size is out of range";
     return false;
   }
 
-  if (size == 0 || size > kMaxLRUSize) {
+  if (size == 0 || size > kMaxLruSize) {
     LOG(ERROR) << "size is out of range";
     return false;
   }
@@ -151,16 +153,16 @@ bool LRUStorage::CreateStorageFile(const char *filename, size_t value_size,
     return false;
   }
 
-  const uint32 value_size_uint32 = static_cast<uint32>(value_size);
-  const uint32 size_uint32 = static_cast<uint32>(size);
+  const uint32_t value_size_uint32 = static_cast<uint32_t>(value_size);
+  const uint32_t size_uint32 = static_cast<uint32_t>(size);
 
   ofs.write(reinterpret_cast<const char *>(&value_size_uint32),
             sizeof(value_size_uint32));
   ofs.write(reinterpret_cast<const char *>(&size_uint32), sizeof(size_uint32));
   ofs.write(reinterpret_cast<const char *>(&seed), sizeof(seed));
   std::vector<char> ary(value_size, '\0');
-  const uint32 last_access_time = 0;
-  const uint64 fp = 0;
+  const uint32_t last_access_time = 0;
+  const uint64_t fp = 0;
 
   for (size_t i = 0; i < size; ++i) {
     ofs.write(reinterpret_cast<const char *>(&fp), sizeof(fp));
@@ -174,7 +176,7 @@ bool LRUStorage::CreateStorageFile(const char *filename, size_t value_size,
 }
 
 // Reopen file after initializing mapped page.
-bool LRUStorage::Clear() {
+bool LruStorage::Clear() {
   // Don't need to clear the page if the lru list is empty
   if (mmap_ == nullptr || lru_list_.empty()) {
     return true;
@@ -190,15 +192,15 @@ bool LRUStorage::Clear() {
   return true;
 }
 
-bool LRUStorage::Merge(const char *filename) {
-  LRUStorage target_storage;
+bool LruStorage::Merge(const char *filename) {
+  LruStorage target_storage;
   if (!target_storage.Open(filename)) {
     return false;
   }
   return Merge(target_storage);
 }
 
-bool LRUStorage::Merge(const LRUStorage &storage) {
+bool LruStorage::Merge(const LruStorage &storage) {
   if (storage.value_size() != value_size()) {
     return false;
   }
@@ -232,7 +234,7 @@ bool LRUStorage::Merge(const LRUStorage &storage) {
   std::stable_sort(ary.begin(), ary.end(), CompareByTimeStamp());
 
   std::string buf;
-  mozc_hash_set<uint64> seen;  // remove duplicated entries.
+  absl::flat_hash_set<uint64_t> seen;  // remove duplicated entries.
   for (size_t i = 0; i < ary.size(); ++i) {
     if (!seen.insert(GetFP(ary[i])).second) {
       continue;
@@ -254,7 +256,7 @@ bool LRUStorage::Merge(const LRUStorage &storage) {
   return Open(mmap_->begin(), mmap_->size());
 }
 
-LRUStorage::LRUStorage()
+LruStorage::LruStorage()
     : value_size_(0),
       size_(0),
       seed_(0),
@@ -262,14 +264,14 @@ LRUStorage::LRUStorage()
       begin_(nullptr),
       end_(nullptr) {}
 
-LRUStorage::~LRUStorage() { Close(); }
+LruStorage::~LruStorage() { Close(); }
 
-bool LRUStorage::OpenOrCreate(const char *filename, size_t new_value_size,
-                              size_t new_size, uint32 new_seed) {
-  if (!FileUtil::FileExists(filename)) {
+bool LruStorage::OpenOrCreate(const char *filename, size_t new_value_size,
+                              size_t new_size, uint32_t new_seed) {
+  if (absl::Status s = FileUtil::FileExists(filename); !s.ok()) {
     // This is also an expected scenario. Let's create a new data file.
     VLOG(1) << filename << " does not exist. Creating a new one.";
-    if (!LRUStorage::CreateStorageFile(filename, new_value_size, new_size,
+    if (!LruStorage::CreateStorageFile(filename, new_value_size, new_size,
                                        new_seed)) {
       LOG(ERROR) << "CreateStorageFile failed against " << filename;
       return false;
@@ -287,7 +289,7 @@ bool LRUStorage::OpenOrCreate(const char *filename, size_t new_value_size,
     // is likely to result in a simple permanent data loss.
     // TODO(yukawa, team): Do not clear the data whenever we can open the
     //     data file and the content is actually valid.
-    if (!LRUStorage::CreateStorageFile(filename, new_value_size, new_size,
+    if (!LruStorage::CreateStorageFile(filename, new_value_size, new_size,
                                        new_seed)) {
       LOG(ERROR) << "CreateStorageFile failed";
       return false;
@@ -302,7 +304,7 @@ bool LRUStorage::OpenOrCreate(const char *filename, size_t new_value_size,
   // File format has changed
   if (new_value_size != value_size() || new_size != size()) {
     Close();
-    if (!LRUStorage::CreateStorageFile(filename, new_value_size, new_size,
+    if (!LruStorage::CreateStorageFile(filename, new_value_size, new_size,
                                        new_seed)) {
       LOG(ERROR) << "CreateStorageFile failed";
       return false;
@@ -323,8 +325,8 @@ bool LRUStorage::OpenOrCreate(const char *filename, size_t new_value_size,
   return true;
 }
 
-bool LRUStorage::Open(const char *filename) {
-  mmap_ = absl::make_unique<Mmap>();
+bool LruStorage::Open(const char *filename) {
+  mmap_ = std::make_unique<Mmap>();
 
   if (!mmap_) {
     LOG(ERROR) << "cannot make Mmap object";
@@ -345,16 +347,16 @@ bool LRUStorage::Open(const char *filename) {
   return Open(mmap_->begin(), mmap_->size());
 }
 
-bool LRUStorage::Open(char *ptr, size_t ptr_size) {
+bool LruStorage::Open(char *ptr, size_t ptr_size) {
   begin_ = ptr;
   end_ = ptr + ptr_size;
 
-  uint32 value_size_uint32 = 0;
-  uint32 size_uint32 = 0;
+  uint32_t value_size_uint32 = 0;
+  uint32_t size_uint32 = 0;
 
-  ReadValue<uint32>(&begin_, &value_size_uint32);
-  ReadValue<uint32>(&begin_, &size_uint32);
-  ReadValue<uint32>(&begin_, &seed_);
+  ReadValue<uint32_t>(&begin_, &value_size_uint32);
+  ReadValue<uint32_t>(&begin_, &size_uint32);
+  ReadValue<uint32_t>(&begin_, &seed_);
 
   value_size_ = static_cast<size_t>(value_size_uint32);
   size_ = static_cast<size_t>(size_uint32);
@@ -364,7 +366,7 @@ bool LRUStorage::Open(char *ptr, size_t ptr_size) {
     return false;
   }
 
-  if (size_ == 0 || size_ > kMaxLRUSize) {
+  if (size_ == 0 || size_ > kMaxLruSize) {
     LOG(ERROR) << "LRU size is invalid: " << size_;
     return false;
   }
@@ -405,7 +407,7 @@ bool LRUStorage::Open(char *ptr, size_t ptr_size) {
   return true;
 }
 
-void LRUStorage::Close() {
+void LruStorage::Close() {
   // Perform clean up before closing the file.
   DeleteElementsUntouchedFor62Days();
 
@@ -415,19 +417,19 @@ void LRUStorage::Close() {
   lru_map_.clear();
 }
 
-const char *LRUStorage::Lookup(const std::string &key) const {
-  uint32 last_access_time = 0;
+const char *LruStorage::Lookup(const std::string &key) const {
+  uint32_t last_access_time = 0;
   return Lookup(key, &last_access_time);
 }
 
-const char *LRUStorage::Lookup(const std::string &key,
-                               uint32 *last_access_time) const {
-  const uint64 fp = Hash::FingerprintWithSeed(key, seed_);
+const char *LruStorage::Lookup(const std::string &key,
+                               uint32_t *last_access_time) const {
+  const uint64_t fp = Hash::FingerprintWithSeed(key, seed_);
   const auto it = lru_map_.find(fp);
   if (it == lru_map_.end()) {
     return nullptr;
   }
-  const uint32 timestamp = GetTimeStamp(*it->second);
+  const uint32_t timestamp = GetTimeStamp(*it->second);
   if (IsOlderThan62Days(timestamp)) {
     return nullptr;
   }
@@ -435,13 +437,13 @@ const char *LRUStorage::Lookup(const std::string &key,
   return GetValue(*it->second);
 }
 
-void LRUStorage::GetAllValues(std::vector<std::string> *values) const {
+void LruStorage::GetAllValues(std::vector<std::string> *values) const {
   DCHECK(values);
   values->clear();
   // Iterate data from the most recently used element to the least recently used
   // element.
   for (const char *ptr : lru_list_) {
-    const uint32 timestamp = GetTimeStamp(ptr);
+    const uint32_t timestamp = GetTimeStamp(ptr);
     if (IsOlderThan62Days(timestamp)) {
       break;
     }
@@ -452,13 +454,13 @@ void LRUStorage::GetAllValues(std::vector<std::string> *values) const {
   }
 }
 
-bool LRUStorage::Touch(const std::string &key) {
-  const uint64 fp = Hash::FingerprintWithSeed(key, seed_);
+bool LruStorage::Touch(const std::string &key) {
+  const uint64_t fp = Hash::FingerprintWithSeed(key, seed_);
   auto it = lru_map_.find(fp);
   if (it == lru_map_.end()) {
     return false;
   }
-  const uint32 timestamp = GetTimeStamp(*it->second);
+  const uint32_t timestamp = GetTimeStamp(*it->second);
   if (IsOlderThan62Days(timestamp)) {
     return false;
   }
@@ -468,11 +470,11 @@ bool LRUStorage::Touch(const std::string &key) {
   return true;
 }
 
-bool LRUStorage::Insert(const std::string &key, const char *value) {
+bool LruStorage::Insert(const std::string &key, const char *value) {
   if (value == nullptr) {
     return false;
   }
-  const uint64 fp = Hash::FingerprintWithSeed(key, seed_);
+  const uint64_t fp = Hash::FingerprintWithSeed(key, seed_);
 
   // If the data corresponding to |key| already exists in LRU, update it.
   {
@@ -490,7 +492,7 @@ bool LRUStorage::Insert(const std::string &key, const char *value) {
   // overwritten with new data).
   if (lru_map_.size() >= size_ || next_item_ == end_) {
     auto it = std::prev(lru_list_.end());  // Least recently used data.
-    const uint64 old_fp = GetFP(*it);
+    const uint64_t old_fp = GetFP(*it);
     lru_map_.erase(old_fp);
     lru_list_.splice(lru_list_.begin(), lru_list_, it);  // Move to front.
     Update(*it, fp, value, value_size_);
@@ -513,8 +515,8 @@ bool LRUStorage::Insert(const std::string &key, const char *value) {
   return false;
 }
 
-bool LRUStorage::TryInsert(const std::string &key, const char *value) {
-  const uint64 fp = Hash::FingerprintWithSeed(key, seed_);
+bool LruStorage::TryInsert(const std::string &key, const char *value) {
+  const uint64_t fp = Hash::FingerprintWithSeed(key, seed_);
   auto it = lru_map_.find(fp);
   if (it != lru_map_.end()) {
     Update(*it->second, fp, value, value_size_);
@@ -523,21 +525,21 @@ bool LRUStorage::TryInsert(const std::string &key, const char *value) {
   return true;
 }
 
-bool LRUStorage::Delete(const std::string &key) {
-  const uint64 fp = Hash::FingerprintWithSeed(key, seed_);
+bool LruStorage::Delete(const std::string &key) {
+  const uint64_t fp = Hash::FingerprintWithSeed(key, seed_);
   return Delete(fp);
 }
 
-bool LRUStorage::Delete(uint64 fp) {
+bool LruStorage::Delete(uint64_t fp) {
   auto it = lru_map_.find(fp);
   return (it == lru_map_.end() || Delete(fp, it->second));
 }
 
-bool LRUStorage::Delete(std::list<char *>::iterator it) {
+bool LruStorage::Delete(std::list<char *>::iterator it) {
   return (it == lru_list_.end() || Delete(GetFP(*it), it));
 }
 
-bool LRUStorage::Delete(uint64 fp, std::list<char *>::iterator it) {
+bool LruStorage::Delete(uint64_t fp, std::list<char *>::iterator it) {
   // Determine the last element in the mmap region.
   if (next_item_ < begin_ + item_size()) {
     LOG(ERROR) << "next_item_ points to invalid location (broken?)";
@@ -557,7 +559,7 @@ bool LRUStorage::Delete(uint64 fp, std::list<char *>::iterator it) {
     // update the LRU structure for the moved element (the pointer to mmap
     // region in the list node is updated.)
     std::memcpy(deleted_item_pos, next_item_, item_size());
-    const uint64 fp = GetFP(next_item_);
+    const uint64_t fp = GetFP(next_item_);
     *lru_map_[fp] = deleted_item_pos;
   }
 
@@ -567,14 +569,14 @@ bool LRUStorage::Delete(uint64 fp, std::list<char *>::iterator it) {
   return true;
 }
 
-int LRUStorage::DeleteElementsBefore(uint32 timestamp) {
+int LruStorage::DeleteElementsBefore(uint32_t timestamp) {
   if (!mmap_ || begin_ >= end_) {
     return 0;
   }
   int num_deleted = 0;
   while (!lru_list_.empty()) {
     auto it = std::prev(lru_list_.end());
-    const uint32 last_access_time = GetTimeStamp(*it);
+    const uint32_t last_access_time = GetTimeStamp(*it);
     if (last_access_time >= timestamp) {
       break;
     }
@@ -588,27 +590,27 @@ int LRUStorage::DeleteElementsBefore(uint32 timestamp) {
   return num_deleted;
 }
 
-int LRUStorage::DeleteElementsUntouchedFor62Days() {
-  const uint64 now = Clock::GetTime();
-  const uint32 timestamp =
-      static_cast<uint32>((now > k62DaysInSec) ? now - k62DaysInSec : 0);
+int LruStorage::DeleteElementsUntouchedFor62Days() {
+  const uint64_t now = Clock::GetTime();
+  const uint32_t timestamp =
+      static_cast<uint32_t>((now > k62DaysInSec) ? now - k62DaysInSec : 0);
   return DeleteElementsBefore(timestamp);
 }
 
-size_t LRUStorage::item_size() const { return value_size_ + kItemHeaderSize; }
+size_t LruStorage::item_size() const { return value_size_ + kItemHeaderSize; }
 
-size_t LRUStorage::value_size() const { return value_size_; }
+size_t LruStorage::value_size() const { return value_size_; }
 
-size_t LRUStorage::size() const { return size_; }
+size_t LruStorage::size() const { return size_; }
 
-size_t LRUStorage::used_size() const { return lru_list_.size(); }
+size_t LruStorage::used_size() const { return lru_list_.size(); }
 
-uint32 LRUStorage::seed() const { return seed_; }
+uint32_t LruStorage::seed() const { return seed_; }
 
-const std::string &LRUStorage::filename() const { return filename_; }
+const std::string &LruStorage::filename() const { return filename_; }
 
-void LRUStorage::Write(size_t i, uint64 fp, const std::string &value,
-                       uint32 last_access_time) {
+void LruStorage::Write(size_t i, uint64_t fp, const std::string &value,
+                       uint32_t last_access_time) {
   DCHECK_LT(i, size_);
   char *ptr = begin_ + (i * item_size());
   memcpy(ptr, reinterpret_cast<const char *>(&fp), 8);
@@ -620,8 +622,8 @@ void LRUStorage::Write(size_t i, uint64 fp, const std::string &value,
   }
 }
 
-void LRUStorage::Read(size_t i, uint64 *fp, std::string *value,
-                      uint32 *last_access_time) const {
+void LruStorage::Read(size_t i, uint64_t *fp, std::string *value,
+                      uint32_t *last_access_time) const {
   DCHECK_LT(i, size_);
   const char *ptr = begin_ + (i * item_size());
   *fp = GetFP(ptr);
