@@ -30,18 +30,19 @@
 #include "storage/lru_storage.h"
 
 #include <algorithm>
+#include <cstdint>
 #include <set>
 #include <string>
 #include <utility>
 #include <vector>
 
 #include "base/clock_mock.h"
-#include "base/file_stream.h"
 #include "base/file_util.h"
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/util.h"
 #include "storage/lru_cache.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "absl/flags/flag.h"
@@ -50,25 +51,25 @@ namespace mozc {
 namespace storage {
 namespace {
 
-const uint32 kSeed = 0x76fef;  // Seed for fingerprint.
+constexpr uint32_t kSeed = 0x76fef;  // Seed for fingerprint.
 
 std::string GenRandomString(int size) {
   std::string result;
   const size_t len = Util::Random(size) + 1;
   for (int i = 0; i < len; ++i) {
     const char32 l = Util::Random(0x1FFFF) + 1;
-    Util::UCS4ToUTF8Append(l, &result);
+    Util::Ucs4ToUtf8Append(l, &result);
   }
   return result;
 }
 
-void RunTest(LRUStorage *storage, uint32 size) {
-  mozc::storage::LRUCache<std::string, uint32> cache(size);
+void RunTest(LruStorage *storage, uint32_t size) {
+  mozc::storage::LruCache<std::string, uint32_t> cache(size);
   std::set<std::string> used;
-  std::vector<std::pair<std::string, uint32> > values;
+  std::vector<std::pair<std::string, uint32_t> > values;
   for (int i = 0; i < size * 2; ++i) {
     const std::string key = GenRandomString(20);
-    const uint32 value = static_cast<uint32>(Util::Random(10000000));
+    const uint32_t value = static_cast<uint32_t>(Util::Random(10000000));
     if (used.find(key) != used.end()) {
       continue;
     }
@@ -83,12 +84,13 @@ void RunTest(LRUStorage *storage, uint32 size) {
   std::vector<std::string> value_list;
   storage->GetAllValues(&value_list);
 
-  uint32 last_access_time;
+  uint32_t last_access_time;
   for (int i = 0; i < size; ++i) {
-    const uint32 *v1 = cache.Lookup(values[i].first);
-    const uint32 *v2 = reinterpret_cast<const uint32 *>(
+    const uint32_t *v1 = cache.Lookup(values[i].first);
+    const uint32_t *v2 = reinterpret_cast<const uint32_t *>(
         storage->Lookup(values[i].first, &last_access_time));
-    const uint32 *v3 = reinterpret_cast<const uint32 *>(value_list[i].data());
+    const uint32_t *v3 =
+        reinterpret_cast<const uint32_t *>(value_list[i].data());
     EXPECT_TRUE(v1 != nullptr);
     EXPECT_EQ(*v1, values[i].second);
     EXPECT_TRUE(v2 != nullptr);
@@ -98,20 +100,20 @@ void RunTest(LRUStorage *storage, uint32 size) {
   }
 
   for (int i = size; i < values.size(); ++i) {
-    const uint32 *v1 = cache.Lookup(values[i].first);
-    const uint32 *v2 = reinterpret_cast<const uint32 *>(
+    const uint32_t *v1 = cache.Lookup(values[i].first);
+    const uint32_t *v2 = reinterpret_cast<const uint32_t *>(
         storage->Lookup(values[i].first, &last_access_time));
     EXPECT_TRUE(v1 == nullptr);
     EXPECT_TRUE(v2 == nullptr);
   }
 }
 
-std::vector<std::string> GetValuesInStorageOrder(const LRUStorage &storage) {
+std::vector<std::string> GetValuesInStorageOrder(const LruStorage &storage) {
   std::vector<std::string> ret;
   for (size_t i = 0; i < storage.used_size(); ++i) {
-    uint64 fp;
+    uint64_t fp;
     std::string value;
-    uint32 last_access_time;
+    uint32_t last_access_time;
     storage.Read(i, &fp, &value, &last_access_time);
     ret.push_back(value);
   }
@@ -120,9 +122,9 @@ std::vector<std::string> GetValuesInStorageOrder(const LRUStorage &storage) {
 
 }  // namespace
 
-class LRUStorageTest : public ::testing::Test {
+class LruStorageTest : public ::testing::Test {
  protected:
-  LRUStorageTest() {}
+  LruStorageTest() {}
 
   void SetUp() override { UnlinkDBFileIfExists(); }
 
@@ -130,27 +132,25 @@ class LRUStorageTest : public ::testing::Test {
 
   static void UnlinkDBFileIfExists() {
     const std::string path = GetTemporaryFilePath();
-    if (FileUtil::FileExists(path)) {
-      FileUtil::Unlink(path);
-    }
+    EXPECT_OK(FileUtil::UnlinkIfExists(path));
   }
 
   static std::string GetTemporaryFilePath() {
     // This name should be unique to each test.
     return FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir),
-                              "LRUStorageTest_test.db");
+                              "LruStorageTest_test.db");
   }
 
  private:
-  DISALLOW_COPY_AND_ASSIGN(LRUStorageTest);
+  DISALLOW_COPY_AND_ASSIGN(LruStorageTest);
 };
 
-TEST_F(LRUStorageTest, LRUStorageTest) {
-  const int kSize[] = {10, 100, 1000, 10000};
+TEST_F(LruStorageTest, LruStorageTest) {
+  constexpr int kSize[] = {10, 100, 1000, 10000};
   const std::string file = GetTemporaryFilePath();
-  for (int i = 0; i < arraysize(kSize); ++i) {
-    LRUStorage::CreateStorageFile(file.c_str(), 4, kSize[i], kSeed);
-    LRUStorage storage;
+  for (int i = 0; i < std::size(kSize); ++i) {
+    LruStorage::CreateStorageFile(file.c_str(), 4, kSize[i], kSeed);
+    LruStorage storage;
     EXPECT_TRUE(storage.Open(file.c_str()));
     EXPECT_EQ(file, storage.filename());
     EXPECT_EQ(kSize[i], storage.size());
@@ -161,17 +161,17 @@ TEST_F(LRUStorageTest, LRUStorageTest) {
 }
 
 struct Entry {
-  uint64 key;
-  uint32 last_access_time;
+  uint64_t key;
+  uint32_t last_access_time;
   std::string value;
 };
 
-TEST_F(LRUStorageTest, ReadWriteTest) {
-  const int kSize[] = {10, 100, 1000, 10000};
+TEST_F(LruStorageTest, ReadWriteTest) {
+  constexpr int kSize[] = {10, 100, 1000, 10000};
   const std::string file = GetTemporaryFilePath();
-  for (int i = 0; i < arraysize(kSize); ++i) {
-    LRUStorage::CreateStorageFile(file.c_str(), 4, kSize[i], kSeed);
-    LRUStorage storage;
+  for (int i = 0; i < std::size(kSize); ++i) {
+    LruStorage::CreateStorageFile(file.c_str(), 4, kSize[i], kSeed);
+    LruStorage storage;
     EXPECT_TRUE(storage.Open(file.c_str()));
     EXPECT_EQ(file, storage.filename());
     EXPECT_EQ(kSize[i], storage.size());
@@ -192,9 +192,9 @@ TEST_F(LRUStorageTest, ReadWriteTest) {
     }
 
     for (int j = 0; j < size; ++j) {
-      uint64 key;
+      uint64_t key;
       std::string value;
-      uint32 last_access_time;
+      uint32_t last_access_time;
       storage.Read(j, &key, &value, &last_access_time);
       EXPECT_EQ(entries[j].key, key);
       EXPECT_EQ(entries[j].value, value);
@@ -203,42 +203,42 @@ TEST_F(LRUStorageTest, ReadWriteTest) {
   }
 }
 
-TEST_F(LRUStorageTest, Merge) {
+TEST_F(LruStorageTest, Merge) {
   const std::string file1 = GetTemporaryFilePath() + ".tmp1";
   const std::string file2 = GetTemporaryFilePath() + ".tmp2";
 
   // Can merge
   {
-    LRUStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
-    LRUStorage::CreateStorageFile(file2.c_str(), 4, 100, kSeed);
-    LRUStorage storage;
+    LruStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
+    LruStorage::CreateStorageFile(file2.c_str(), 4, 100, kSeed);
+    LruStorage storage;
     EXPECT_TRUE(storage.Open(file1.c_str()));
     EXPECT_TRUE(storage.Merge(file2.c_str()));
   }
 
   // different entry size
   {
-    LRUStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
-    LRUStorage::CreateStorageFile(file2.c_str(), 4, 200, kSeed);
-    LRUStorage storage;
+    LruStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
+    LruStorage::CreateStorageFile(file2.c_str(), 4, 200, kSeed);
+    LruStorage storage;
     EXPECT_TRUE(storage.Open(file1.c_str()));
     EXPECT_TRUE(storage.Merge(file2.c_str()));
   }
 
   // seed is different
   {
-    LRUStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
-    LRUStorage::CreateStorageFile(file2.c_str(), 4, 200, 0x76fee);
-    LRUStorage storage;
+    LruStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
+    LruStorage::CreateStorageFile(file2.c_str(), 4, 200, 0x76fee);
+    LruStorage storage;
     EXPECT_TRUE(storage.Open(file1.c_str()));
     EXPECT_FALSE(storage.Merge(file2.c_str()));
   }
 
   // value size is different
   {
-    LRUStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
-    LRUStorage::CreateStorageFile(file2.c_str(), 8, 200, kSeed);
-    LRUStorage storage;
+    LruStorage::CreateStorageFile(file1.c_str(), 4, 100, kSeed);
+    LruStorage::CreateStorageFile(file2.c_str(), 8, 200, kSeed);
+    LruStorage storage;
     EXPECT_TRUE(storage.Open(file1.c_str()));
     EXPECT_FALSE(storage.Merge(file2.c_str()));
   }
@@ -248,25 +248,25 @@ TEST_F(LRUStorageTest, Merge) {
     // timestamp set below is 50, so set the current time to 100.
     ScopedClockMock clock(100, 0);
 
-    LRUStorage::CreateStorageFile(file1.c_str(), 4, 8, kSeed);
-    LRUStorage::CreateStorageFile(file2.c_str(), 4, 4, kSeed);
-    LRUStorage storage1;
+    LruStorage::CreateStorageFile(file1.c_str(), 4, 8, kSeed);
+    LruStorage::CreateStorageFile(file2.c_str(), 4, 4, kSeed);
+    LruStorage storage1;
     EXPECT_TRUE(storage1.Open(file1.c_str()));
     storage1.Write(0, 0, "test", 1);
     storage1.Write(1, 1, "test", 10);
     storage1.Write(2, 2, "test", 20);
     storage1.Write(3, 3, "test", 30);
 
-    LRUStorage storage2;
+    LruStorage storage2;
     EXPECT_TRUE(storage2.Open(file2.c_str()));
     storage2.Write(0, 4, "test", 2);
     storage2.Write(1, 5, "test", 50);
 
     EXPECT_TRUE(storage1.Merge(storage2));
 
-    uint64 fp;
+    uint64_t fp;
     std::string value;
-    uint32 last_access_time;
+    uint32_t last_access_time;
 
     storage1.Read(0, &fp, &value, &last_access_time);
     EXPECT_EQ(5, fp);
@@ -291,25 +291,25 @@ TEST_F(LRUStorageTest, Merge) {
     // timestamp set below is 50, so set the current time to 100.
     ScopedClockMock clock(100, 0);
 
-    LRUStorage::CreateStorageFile(file1.c_str(), 4, 8, kSeed);
-    LRUStorage::CreateStorageFile(file2.c_str(), 4, 4, kSeed);
-    LRUStorage storage1;
+    LruStorage::CreateStorageFile(file1.c_str(), 4, 8, kSeed);
+    LruStorage::CreateStorageFile(file2.c_str(), 4, 4, kSeed);
+    LruStorage storage1;
     EXPECT_TRUE(storage1.Open(file1.c_str()));
     storage1.Write(0, 0, "test", 0);
     storage1.Write(1, 1, "test", 10);
     storage1.Write(2, 2, "test", 20);
     storage1.Write(3, 3, "test", 30);
 
-    LRUStorage storage2;
+    LruStorage storage2;
     EXPECT_TRUE(storage2.Open(file2.c_str()));
     storage2.Write(0, 2, "new1", 0);
     storage2.Write(1, 3, "new2", 50);
 
     EXPECT_TRUE(storage1.Merge(storage2));
 
-    uint64 fp;
+    uint64_t fp;
     std::string value;
-    uint32 last_access_time;
+    uint32_t last_access_time;
 
     storage1.Read(0, &fp, &value, &last_access_time);
     EXPECT_EQ(3, fp);
@@ -330,54 +330,51 @@ TEST_F(LRUStorageTest, Merge) {
     EXPECT_EQ(0, last_access_time);
   }
 
-  FileUtil::Unlink(file1);
-  FileUtil::Unlink(file2);
+  EXPECT_OK(FileUtil::Unlink(file1));
+  EXPECT_OK(FileUtil::Unlink(file2));
 }
 
-TEST_F(LRUStorageTest, InvalidFileOpenTest) {
-  LRUStorage storage;
+TEST_F(LruStorageTest, InvalidFileOpenTest) {
+  LruStorage storage;
   EXPECT_FALSE(storage.Insert("test", nullptr));
 
   const std::string filename = GetTemporaryFilePath();
-  FileUtil::Unlink(filename);
+  ASSERT_OK(FileUtil::UnlinkIfExists(filename));
 
   // cannot open
   EXPECT_FALSE(storage.Open(filename.c_str()));
   EXPECT_FALSE(storage.Insert("test", nullptr));
 }
 
-TEST_F(LRUStorageTest, OpenOrCreateTest) {
+TEST_F(LruStorageTest, OpenOrCreateTest) {
   const std::string file = GetTemporaryFilePath();
-  {
-    OutputFileStream ofs(file.c_str());
-    ofs << "test";
-  }
+  ASSERT_OK(FileUtil::SetContents(file, "test"));
 
   {
-    LRUStorage storage;
+    LruStorage storage;
     EXPECT_FALSE(storage.Open(file.c_str()))
         << "Corrupted file should be detected as an error.";
   }
 
   {
-    LRUStorage storage;
+    LruStorage storage;
     EXPECT_TRUE(storage.OpenOrCreate(file.c_str(), 4, 10, kSeed))
         << "Corrupted file should be replaced with new one.";
-    uint32 v = 823;
+    uint32_t v = 823;
     storage.Insert("test", reinterpret_cast<const char *>(&v));
-    const uint32 *result =
-        reinterpret_cast<const uint32 *>(storage.Lookup("test"));
+    const uint32_t *result =
+        reinterpret_cast<const uint32_t *>(storage.Lookup("test"));
     CHECK_EQ(v, *result);
   }
 }
 
-TEST_F(LRUStorageTest, Delete) {
+TEST_F(LruStorageTest, Delete) {
   ScopedClockMock clock(1, 0);
   clock->SetAutoPutClockForward(1, 0);
 
-  const size_t kValueSize = 4;
-  const size_t kNumElements = 4;
-  LRUStorage storage;
+  constexpr size_t kValueSize = 4;
+  constexpr size_t kNumElements = 4;
+  LruStorage storage;
   ASSERT_TRUE(storage.OpenOrCreate(GetTemporaryFilePath().c_str(), kValueSize,
                                    kNumElements, kSeed));
 
@@ -460,12 +457,12 @@ TEST_F(LRUStorageTest, Delete) {
   EXPECT_TRUE(storage.Lookup("4444") == nullptr);
 }
 
-TEST_F(LRUStorageTest, DeleteElementsBefore) {
+TEST_F(LruStorageTest, DeleteElementsBefore) {
   ScopedClockMock clock(1, 0);
 
-  const size_t kValueSize = 4;
-  const size_t kNumElements = 4;
-  LRUStorage storage;
+  constexpr size_t kValueSize = 4;
+  constexpr size_t kNumElements = 4;
+  LruStorage storage;
   ASSERT_TRUE(storage.OpenOrCreate(GetTemporaryFilePath().c_str(), kValueSize,
                                    kNumElements, kSeed));
 
@@ -510,12 +507,12 @@ TEST_F(LRUStorageTest, DeleteElementsBefore) {
   EXPECT_EQ(kExpectedAfterDelete, values);
 }
 
-TEST_F(LRUStorageTest, DeleteElementsUntouchedFor62Days) {
+TEST_F(LruStorageTest, DeleteElementsUntouchedFor62Days) {
   ScopedClockMock clock(1, 0);
 
-  const size_t kValueSize = 4;
-  const size_t kNumElements = 4;
-  LRUStorage storage;
+  constexpr size_t kValueSize = 4;
+  constexpr size_t kNumElements = 4;
+  LruStorage storage;
   ASSERT_TRUE(storage.OpenOrCreate(GetTemporaryFilePath().c_str(), kValueSize,
                                    kNumElements, kSeed));
 
@@ -544,12 +541,12 @@ TEST_F(LRUStorageTest, DeleteElementsUntouchedFor62Days) {
   EXPECT_EQ(kExpectedAfterDelete, values);
 }
 
-TEST_F(LRUStorageTest, OldDataAreNotLookedUp) {
+TEST_F(LruStorageTest, OldDataAreNotLookedUp) {
   ScopedClockMock clock(1, 0);
 
-  const size_t kValueSize = 4;
-  const size_t kNumElements = 4;
-  LRUStorage storage;
+  constexpr size_t kValueSize = 4;
+  constexpr size_t kNumElements = 4;
+  LruStorage storage;
   ASSERT_TRUE(storage.OpenOrCreate(GetTemporaryFilePath().c_str(), kValueSize,
                                    kNumElements, kSeed));
 
