@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,8 +39,10 @@
 #include "base/file_util.h"
 #include "base/port.h"
 #include "storage/storage_interface.h"
+#include "testing/base/public/gmock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/flags/flag.h"
 #include "absl/strings/str_format.h"
 
 namespace mozc {
@@ -64,22 +66,21 @@ class TinyStorageTest : public testing::Test {
  protected:
   TinyStorageTest() {}
 
-  virtual void SetUp() { UnlinkDBFileIfExists(); }
+  void SetUp() override { UnlinkDBFileIfExists(); }
 
-  virtual void TearDown() { UnlinkDBFileIfExists(); }
+  void TearDown() override { UnlinkDBFileIfExists(); }
 
   static void UnlinkDBFileIfExists() {
     const std::string path = GetTemporaryFilePath();
-    if (FileUtil::FileExists(path)) {
-      FileUtil::Unlink(path);
-    }
+    EXPECT_OK(FileUtil::UnlinkIfExists(path));
   }
 
   static StorageInterface *CreateStorage() { return TinyStorage::New(); }
 
   static std::string GetTemporaryFilePath() {
     // This name should be unique to each test.
-    return FileUtil::JoinPath(FLAGS_test_tmpdir, "TinyStorageTest_test.db");
+    return FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir),
+                              "TinyStorageTest_test.db");
   }
 
  private:
@@ -89,10 +90,10 @@ class TinyStorageTest : public testing::Test {
 TEST_F(TinyStorageTest, TinyStorageTest) {
   const std::string filename = GetTemporaryFilePath();
 
-  static const int kSize[] = {10, 100, 1000};
+  static constexpr int kSize[] = {10, 100, 1000};
 
-  for (int i = 0; i < arraysize(kSize); ++i) {
-    FileUtil::Unlink(filename);
+  for (int i = 0; i < std::size(kSize); ++i) {
+    EXPECT_OK(FileUtil::UnlinkIfExists(filename));
     std::unique_ptr<StorageInterface> storage(CreateStorage());
 
     // Insert
