@@ -29,12 +29,18 @@
 
 #include "testing/base/public/mozctest.h"
 
+#include <string>
+#include <utility>
+
 #include "base/file_util.h"
 #include "base/logging.h"
+#include "base/status.h"
 #include "base/system_util.h"
-#include "base/util.h"
 #include "testing/base/public/googletest.h"
 #include "absl/flags/flag.h"
+#include "absl/status/status.h"
+#include "absl/status/statusor.h"
+#include "absl/strings/match.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -42,7 +48,7 @@ namespace testing {
 
 std::string GetSourcePath(const std::vector<absl::string_view> &components) {
   const std::string test_srcdir = absl::GetFlag(FLAGS_test_srcdir);
-  std::vector<absl::string_view> abs_components = { test_srcdir };
+  std::vector<absl::string_view> abs_components = {test_srcdir};
 
   const char *workspace = std::getenv("TEST_WORKSPACE");
   if (workspace && workspace[0]) {
@@ -54,17 +60,27 @@ std::string GetSourcePath(const std::vector<absl::string_view> &components) {
   return FileUtil::JoinPath(abs_components);
 }
 
+absl::StatusOr<std::string> GetSourceFile(
+    const std::vector<absl::string_view> &components) {
+  std::string path = GetSourcePath(components);
+  if (absl::Status s = FileUtil::FileExists(path); !s.ok()) {
+    return s;
+  }
+  return path;
+}
+
 std::string GetSourceFileOrDie(
     const std::vector<absl::string_view> &components) {
-  const std::string path = GetSourcePath(components);
-  CHECK(FileUtil::FileExists(path)) << "File doesn't exist: " << path;
-  return path;
+  absl::StatusOr<std::string> abs_path = GetSourceFile(components);
+  CHECK_OK(abs_path);
+  return *std::move(abs_path);
 }
 
 std::string GetSourceDirOrDie(
     const std::vector<absl::string_view> &components) {
   const std::string path = GetSourcePath(components);
-  CHECK(FileUtil::DirectoryExists(path)) << "Directory doesn't exist: " << path;
+  CHECK_OK(FileUtil::DirectoryExists(path))
+      << ": Directory doesn't exist: " << path;
   return path;
 }
 
@@ -75,8 +91,8 @@ std::vector<std::string> GetSourceFilesInDirOrDie(
   std::vector<std::string> paths;
   for (size_t i = 0; i < filenames.size(); ++i) {
     paths.push_back(FileUtil::JoinPath({dir, filenames[i]}));
-    CHECK(FileUtil::FileExists(paths.back()))
-        << "File doesn't exist: " << paths.back();
+    CHECK_OK(FileUtil::FileExists(paths.back()))
+        << ": File doesn't exist: " << paths.back();
   }
   return paths;
 }
