@@ -30,19 +30,23 @@
 #include "unix/emacs/mozc_emacs_helper_lib.h"
 
 #include <algorithm>
+#include <cstdint>
+#include <string>
 
 #include "base/protobuf/message.h"
 #include "base/util.h"
+#include "protocol/candidates.pb.h"
 #include "protocol/commands.pb.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/strings/str_join.h"
 
 class MozcEmacsHelperLibTest : public testing::Test {
  protected:
-  void ParseAndTestInputLine(const std::string &input_line, uint32 event_id,
-                             uint32 session_id, const std::string &protobuf) {
-    uint32 actual_event_id = 0xDEADBEEFU;
-    uint32 actual_session_id = 0xDEADBEEFU;
+  void ParseAndTestInputLine(const std::string &input_line, uint32_t event_id,
+                             uint32_t session_id, const std::string &protobuf) {
+    uint32_t actual_event_id = 0xDEADBEEFU;
+    uint32_t actual_session_id = 0xDEADBEEFU;
     mozc::commands::Input input;
     mozc::emacs::ParseInputLine(input_line, &actual_event_id,
                                 &actual_session_id, &input);
@@ -55,8 +59,7 @@ class MozcEmacsHelperLibTest : public testing::Test {
                          const std::string &sexpr) {
     std::vector<std::string> buffer;
     mozc::emacs::PrintMessage(message, &buffer);
-    std::string output;
-    mozc::Util::JoinStrings(buffer, "", &output);
+    const std::string output = absl::StrJoin(buffer, "");
     EXPECT_EQ(sexpr, output);
   }
 
@@ -196,9 +199,9 @@ TEST_F(MozcEmacsHelperLibTest, PrintMessage) {
   output.set_id(1234);
   output.set_mode(mozc::commands::HIRAGANA);
   output.set_consumed(true);
-  output.mutable_result()->CopyFrom(result);
-  output.mutable_preedit()->CopyFrom(preedit);
-  output.mutable_key()->CopyFrom(key_event);
+  *output.mutable_result() = result;
+  *output.mutable_preedit() = preedit;
+  *output.mutable_key() = key_event;
   PrintAndTestSexpr(output,
                     "((id . \"1234\")"
                     "(mode . hiragana)"
@@ -258,8 +261,8 @@ TEST_F(MozcEmacsHelperLibTest, TokenizeSExpr) {
                           "-x0", "\"い\"", "p",   ")"};
 
   EXPECT_TRUE(result);
-  EXPECT_EQ(arraysize(golden), output.size());
-  int len = std::min(arraysize(golden), output.size());
+  EXPECT_EQ(std::size(golden), output.size());
+  int len = std::min(std::size(golden), output.size());
   for (int i = 0; i < len; ++i) {
     EXPECT_EQ(golden[i], output[i]);
   }
