@@ -29,12 +29,15 @@
 
 #include "unix/ibus/ibus_config.h"
 
-#include "base/file_stream.h"
+#include <string>
+#include <utility>
+
 #include "base/file_util.h"
 #include "base/logging.h"
 #include "base/protobuf/text_format.h"
 #include "base/system_util.h"
 #include "unix/ibus/main.h"
+#include "absl/status/status.h"
 #include "absl/strings/ascii.h"
 #include "absl/strings/match.h"
 #include "absl/strings/str_cat.h"
@@ -49,16 +52,22 @@ namespace {
 std::string UpdateConfigFile() {
   const std::string engines_file = FileUtil::JoinPath(
       SystemUtil::GetUserProfileDirectory(), kIbusConfigFile);
-  if (FileUtil::FileExists(engines_file)) {
-    InputFileStream ifs(engines_file.c_str());
-    return ifs.Read();
-  } else {
-    OutputFileStream ofs(engines_file.c_str());
-    ofs << kIbusConfigTextProto;
-    ofs.close();
-    if (ofs.fail()) {
-      LOG(ERROR) << "Failed to write " << engines_file;
+  if (absl::Status s = FileUtil::FileExists(engines_file); s.ok()) {
+    absl::StatusOr<std::string> config = FileUtil::GetContents(engines_file);
+    if (!config.ok()) {
+      LOG(ERROR) << config.status();
+      return kIbusConfigTextProto;
     }
+    return *std::move(config);
+  } else if (absl::IsNotFound(s)) {
+    if (absl::Status s =
+            FileUtil::SetContents(engines_file, kIbusConfigTextProto);
+        !s.ok()) {
+      LOG(ERROR) << "Failed to write " << engines_file << ": " << s;
+    }
+    return kIbusConfigTextProto;
+  } else {
+    LOG(ERROR) << "Cannot check if " << engines_file << "exists: " << s;
     return kIbusConfigTextProto;
   }
 }
@@ -83,6 +92,7 @@ std::string EscapeXmlValue(const std::string &value) {
 std::string CreateEnginesXml(const ibus::Config &config) {
   std::string output = "<engines>\n";
   for (const ibus::Engine &engine : config.engines()) {
+    // clang-format off
     absl::StrAppend(
         &output,
         "<engine>\n",
@@ -101,28 +111,32 @@ std::string CreateEnginesXml(const ibus::Config &config) {
         "  <layout_option>", EscapeXmlValue(engine.layout_option()),
         "</layout_option>\n",
         "</engine>\n");
+    // clang-format on
   }
   absl::StrAppend(&output, "</engines>\n");
   return output;
 }
 }  // namespace
 
-const std::string &IbusConfig::InitEnginesXml() {
+bool IbusConfig::Initialize() {
   const std::string config_data = UpdateConfigFile();
   const bool valid_user_config = ParseConfig(config_data, config_);
+
   engine_xml_ = CreateEnginesXml(config_);
   if (!valid_user_config) {
-    engine_xml_ += ("<!-- Failed to parse the user config. -->\n"
-                    "<!-- Used the default setting instead. -->\n");
+    engine_xml_ +=
+        ("<!-- Failed to parse the user config. -->\n"
+         "<!-- Used the default setting instead. -->\n");
   }
-  return engine_xml_;
+
+  return valid_user_config;
 }
 
-const ibus::Config &IbusConfig::GetConfig() const {
-  return config_;
-}
+const std::string &IbusConfig::GetEnginesXml() const { return engine_xml_; }
 
-const std::string &IbusConfig::GetLayout(const std::string& name) const {
+const ibus::Config &IbusConfig::GetConfig() const { return config_; }
+
+const std::string &IbusConfig::GetLayout(const std::string &name) const {
   for (const ibus::Engine &engine : config_.engines()) {
     if (engine.name() == name) {
       return engine.layout();
@@ -130,4 +144,14 @@ const std::string &IbusConfig::GetLayout(const std::string& name) const {
   }
   return default_layout_;
 }
+
+bool IbusConfig::IsActiveOnLaunch() const {
+  if (config_.has_active_on_launch()) {
+    return config_.active_on_launch();
+  }
+
+  // The default value is off as IBus team's recommentation.
+  // https://github.com/google/mozc/issues/201
+  return false;
+}
 }  // namespace mozc
