@@ -39,8 +39,7 @@
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
 #include "testing/base/public/gunit.h"
-
-using std::unique_ptr;
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 namespace ibus {
@@ -135,7 +134,7 @@ class KeyEventHandlerTest : public testing::Test {
     }
   }
 
-  unique_ptr<KeyEventHandler> handler_;
+  std::unique_ptr<KeyEventHandler> handler_;
   std::map<guint, commands::KeyEvent::ModifierKey> keyval_to_modifier_;
 };
 
@@ -145,7 +144,7 @@ class KeyEventHandlerTest : public testing::Test {
 #define EXPECT_NO_MODIFIERS_PRESSED() EXPECT_TRUE(CheckModifiersPressed(false))
 
 namespace {
-const uint32 kNoModifiers = 0;
+constexpr uint32 kNoModifiers = 0;
 const guint kDummyKeycode = 0;
 }  // namespace
 
@@ -417,17 +416,17 @@ TEST_F(KeyEventHandlerTest, ProcessModifiersRandomTest) {
       IBUS_Alt_L,   IBUS_Alt_R,   IBUS_Control_L, IBUS_Control_R,
       IBUS_Shift_L, IBUS_Shift_R, IBUS_Caps_Lock, IBUS_a,
   };
-  const size_t kKeySetSize = arraysize(kKeySet);
+  constexpr size_t kKeySetSize = std::size(kKeySet);
   Util::SetRandomSeed(static_cast<uint32>(Clock::GetTime()));
 
-  const int kTrialNum = 1000;
+  constexpr int kTrialNum = 1000;
   for (int trial = 0; trial < kTrialNum; ++trial) {
     handler_->Clear();
 
     std::set<guint> pressed_keys;
     std::string key_sequence;
 
-    const int kSequenceLength = 100;
+    constexpr int kSequenceLength = 100;
     for (int i = 0; i < kSequenceLength; ++i) {
       const int key_index = Util::Random(kKeySetSize);
       const guint key_value = kKeySet[key_index];
@@ -441,8 +440,8 @@ TEST_F(KeyEventHandlerTest, ProcessModifiersRandomTest) {
         is_key_up = true;
       }
 
-      key_sequence += Util::StringPrintf("is_key_up: %d, key_index = %d\n",
-                                         is_key_up, key_index);
+      key_sequence += absl::StrFormat("is_key_up: %d, key_index = %d\n",
+                                      is_key_up, key_index);
 
       commands::KeyEvent key;
       for (std::set<guint>::const_iterator it = pressed_keys.begin();
@@ -468,7 +467,7 @@ TEST_F(KeyEventHandlerTest, ProcessModifiersRandomTest) {
 
     {
       const bool is_key_up = static_cast<bool>(Util::Random(2));
-      SCOPED_TRACE(Util::StringPrintf(
+      SCOPED_TRACE(absl::StrFormat(
           "Should be reset by non_modifier_key %s. key_sequence:\n%s",
           (is_key_up ? "up" : "down"), key_sequence.c_str()));
       EXPECT_FALSE(is_non_modifier_key_pressed());
