@@ -34,6 +34,7 @@
 #include <cstdlib>
 #include <limits>
 #include <map>
+#include <memory>
 #include <sstream>
 #include <string>
 
@@ -56,6 +57,7 @@
 #include "unix/ibus/path_util.h"
 #include "unix/ibus/preedit_handler.h"
 #include "unix/ibus/property_handler.h"
+#include "unix/ibus/selection_monitor.h"
 #include "unix/ibus/surrounding_text_util.h"
 #include "absl/flags/flag.h"
 
@@ -64,9 +66,6 @@
 #include "unix/ibus/gtk_candidate_window_handler.h"
 #endif  // ENABLE_GTK_RENDERER
 
-#ifdef MOZC_ENABLE_X11_SELECTION_MONITOR
-#include "unix/ibus/selection_monitor.h"
-#endif  // MOZC_ENABLE_X11_SELECTION_MONITOR
 
 #ifdef ENABLE_GTK_RENDERER
 ABSL_FLAG(bool, use_mozc_renderer, true,
@@ -79,7 +78,7 @@ namespace {
 const int32 kBadCandidateId = -1;
 
 // Default UI locale
-const char kMozcDefaultUILocale[] = "en_US.UTF-8";
+constexpr char kMozcDefaultUILocale[] = "en_US.UTF-8";
 
 // for every 5 minutes, call SyncData
 const uint64 kSyncDataInterval = 5 * 60;
@@ -90,13 +89,13 @@ const char *kUILocaleEnvNames[] = {
     "LANG",
 };
 
-string GetEnv(const char *envname) {
+std::string GetEnv(const char *envname) {
   const char *result = ::getenv(envname);
   return result != nullptr ? std::string(result) : "";
 }
 
-string GetMessageLocale() {
-  for (size_t i = 0; i < arraysize(kUILocaleEnvNames); ++i) {
+std::string GetMessageLocale() {
+  for (size_t i = 0; i < std::size(kUILocaleEnvNames); ++i) {
     const std::string result = GetEnv(kUILocaleEnvNames[i]);
     if (!result.empty()) {
       return result;
@@ -163,9 +162,7 @@ struct SurroundingTextInfo {
 };
 
 bool GetSurroundingText(IBusEngine *engine,
-#ifdef MOZC_ENABLE_X11_SELECTION_MONITOR
                         SelectionMonitorInterface *selection_monitor,
-#endif  // MOZC_ENABLE_X11_SELECTION_MONITOR
                         SurroundingTextInfo *info) {
   if (!(engine->client_capabilities & IBUS_CAP_SURROUNDING_TEXT)) {
     VLOG(1) << "Give up CONVERT_REVERSE due to client_capabilities: "
@@ -198,13 +195,34 @@ bool GetSurroundingText(IBusEngine *engine,
     return false;
   }
 
-  const size_t selection_start = std::min(cursor_pos, anchor_pos);
+  // あい[うえ]お
+  //     ^1   ^2
+  //
+  // [, ]: selection boundary (not actual characters).
+  // 1: pos1 (cursor_pos or anchor_pos)
+  // 2: pos2 (pos1 + selection_length)
+  //
+  // surrounding_text = "あいうえお"
+  // preceding_text = "あい"
+  // selection_text = "うえ"
+  // following_text = "お"
+
+  const size_t pos1 = std::min(cursor_pos, anchor_pos);
   const size_t selection_length = abs(info->relative_selected_length);
-  const auto &selection_start_it = surrounding_text.begin() + selection_start;
-  const auto &selection_end_it = selection_start_it + selection_length;
-  info->preceding_text.assign(surrounding_text.begin(), selection_start_it);
-  info->selection_text.assign(selection_start_it, selection_end_it);
-  info->following_text.assign(selection_end_it, surrounding_text.end());
+  const size_t pos2 = pos1 + selection_length;
+  const size_t text_length = Util::CharsLen(surrounding_text);
+
+  if (text_length < pos2) {
+    LOG(ERROR) << "selection is out of surrounding_text: ('" << surrounding_text
+               << "', " << pos2 << ").";
+    return false;
+  }
+
+  Util::Utf8SubString(surrounding_text, 0, pos1, &(info->preceding_text));
+  Util::Utf8SubString(surrounding_text, pos1, selection_length,
+                      &(info->selection_text));
+  Util::Utf8SubString(surrounding_text, pos2, text_length - pos2,
+                      &(info->following_text));
   return true;
 }
 
@@ -218,21 +236,25 @@ std::unique_ptr<client::ClientInterface> CreateAndConfigureClient() {
   return client;
 }
 
-#ifdef ENABLE_GTK_RENDERER
+#if defined(ENABLE_GTK_RENDERER) || defined(ENABLE_QT_RENDERER)
 CandidateWindowHandlerInterface *createGtkCandidateWindowHandler(
     ::mozc::renderer::RendererClient *renderer_client) {
   if (!absl::GetFlag(FLAGS_use_mozc_renderer)) {
     return nullptr;
   }
+
+#ifndef ENABLE_QT_RENDERER
   if (GetEnv("XDG_SESSION_TYPE") == "wayland") {
     // mozc_renderer is not supported on wayland session.
     return nullptr;
   }
+#endif  // !ENABLE_QT_RENDERER
+
   auto *handler = new GtkCandidateWindowHandler(renderer_client);
   handler->RegisterGSettingsObserver();
   return handler;
 }
-#endif  // !ENABLE_GTK_RENDERER
+#endif  // ENABLE_GTK_RENDERER || ENABLE_QT_RENDERER
 
 }  // namespace
 
@@ -243,22 +265,21 @@ MozcEngine::MozcEngine()
 #ifdef MOZC_ENABLE_X11_SELECTION_MONITOR
       selection_monitor_(SelectionMonitorFactory::Create(1024)),
 #endif  // MOZC_ENABLE_X11_SELECTION_MONITOR
-      property_handler_(new PropertyHandler(
-          new LocaleBasedMessageTranslator(GetMessageLocale()), client_.get())),
       preedit_handler_(new PreeditHandler()),
-#ifdef ENABLE_GTK_RENDERER
+#if defined(ENABLE_GTK_RENDERER) || defined(ENABLE_QT_RENDERER)
       gtk_candidate_window_handler_(
           createGtkCandidateWindowHandler(new renderer::RendererClient())),
-#endif  // ENABLE_GTK_RENDERER
+#endif  // ENABLE_GTK_RENDERER || ENABLE_QT_RENDERER
       ibus_candidate_window_handler_(new IBusCandidateWindowHandler()),
       preedit_method_(config::Config::ROMAN) {
-#ifdef MOZC_ENABLE_X11_SELECTION_MONITOR
   if (selection_monitor_ != nullptr) {
     selection_monitor_->StartMonitoring();
   }
-#endif  // MOZC_ENABLE_X11_SELECTION_MONITOR
 
-  ibus_config_.InitEnginesXml();
+  ibus_config_.Initialize();
+  property_handler_ = std::make_unique<PropertyHandler>(
+      std::make_unique<LocaleBasedMessageTranslator>(GetMessageLocale()),
+      ibus_config_.IsActiveOnLaunch(), client_.get());
 
   // TODO(yusukes): write a unit test to check if the capability is set
   // as expected.
@@ -375,9 +396,7 @@ gboolean MozcEngine::ProcessKeyEvent(IBusEngine *engine, guint keyval,
   commands::Context context;
   SurroundingTextInfo surrounding_text_info;
   if (GetSurroundingText(engine,
-#ifdef MOZC_ENABLE_X11_SELECTION_MONITOR
                          selection_monitor_.get(),
-#endif  // MOZC_ENABLE_X11_SELECTION_MONITOR
                          &surrounding_text_info)) {
     context.set_preceding_text(surrounding_text_info.preceding_text);
     context.set_following_text(surrounding_text_info.following_text);
@@ -605,9 +624,7 @@ bool MozcEngine::ExecuteCallback(IBusEngine *engine,
       break;
     case commands::SessionCommand::CONVERT_REVERSE: {
       if (!GetSurroundingText(engine,
-#ifdef MOZC_ENABLE_X11_SELECTION_MONITOR
                               selection_monitor_.get(),
-#endif  // MOZC_ENABLE_X11_SELECTION_MONITOR
                               &surrounding_text_info)) {
         return false;
       }
@@ -651,7 +668,7 @@ CandidateWindowHandlerInterface *MozcEngine::GetCandidateWindowHandler(
     IBusEngine *engine) {
 #ifndef ENABLE_GTK_RENDERER
   return ibus_candidate_window_handler_.get();
-#else
+#else   // ENABLE_GTK_RENDERER
   if (!gtk_candidate_window_handler_) {
     return ibus_candidate_window_handler_.get();
   }
@@ -663,7 +680,8 @@ CandidateWindowHandlerInterface *MozcEngine::GetCandidateWindowHandler(
   // TODO(nona): integrate with renderer/renderer_client.cc
   const std::string renderer_path =
       FileUtil::JoinPath(SystemUtil::GetServerDirectory(), "mozc_renderer");
-  if (!FileUtil::FileExists(renderer_path)) {
+  if (absl::Status s = FileUtil::FileExists(renderer_path); !s.ok()) {
+    LOG(ERROR) << s;
     return ibus_candidate_window_handler_.get();
   }
 
