@@ -116,7 +116,8 @@ const MozcEngineProperty *kMozcEngineProperties =
 
 const MozcEngineProperty *kMozcEnginePropertyIMEOffState =
     &kMozcEngineProperties[0];
-const size_t kMozcEnginePropertiesSize = arraysize(kMozcEnginePropertiesArray);
+constexpr size_t kMozcEnginePropertiesSize =
+    std::size(kMozcEnginePropertiesArray);
 static_assert(commands::NUM_OF_COMPOSITIONS == kMozcEnginePropertiesSize,
               "commands::NUM_OF_COMPOSITIONS must be the property size.");
 const commands::CompositionMode kMozcEngineInitialCompositionMode =
@@ -124,8 +125,8 @@ const commands::CompositionMode kMozcEngineInitialCompositionMode =
 
 const MozcEngineToolProperty *kMozcEngineToolProperties =
     &kMozcEngineToolPropertiesArray[0];
-const size_t kMozcEngineToolPropertiesSize =
-    arraysize(kMozcEngineToolPropertiesArray);
+constexpr size_t kMozcEngineToolPropertiesSize =
+    std::size(kMozcEngineToolPropertiesArray);
 
 const unsigned int kPageSize = 9;
 }  // namespace ibus
