@@ -53,14 +53,19 @@ namespace ibus {
 namespace {
 
 // A key which associates an IBusProperty object with MozcEngineProperty.
-const char kGObjectDataKey[] = "ibus-mozc-aux-data";
+constexpr char kGObjectDataKey[] = "ibus-mozc-aux-data";
 
 // Icon path for MozcTool
-const char kMozcToolIconPath[] = "tool.png";
+constexpr char kMozcToolIconPath[] = "tool.png";
 
 // Returns true if mozc_tool is installed.
 bool IsMozcToolAvailable() {
-  return FileUtil::FileExists(SystemUtil::GetToolPath());
+  if (absl::Status s = FileUtil::FileExists(SystemUtil::GetToolPath());
+      !s.ok()) {
+    LOG(ERROR) << s;
+    return false;
+  }
+  return true;
 }
 
 bool GetDisabled(IBusEngine *engine) {
@@ -75,27 +80,18 @@ bool GetDisabled(IBusEngine *engine) {
   return disabled;
 }
 
-// Some users expect that Mozc is turned off by default on IBus 1.5.0 and later.
-// https://github.com/google/mozc/issues/201
-// On IBus 1.4.x, IBus expects that an IME should always be turned on and
-// IME on/off keys are handled by IBus itself rather than each IME.
-#if IBUS_CHECK_VERSION(1, 5, 0)
-const bool kActivatedOnLaunch = false;
-#else
-const bool kActivatedOnLaunch = true;
-#endif  // IBus>=1.5.0
-
 }  // namespace
 
-PropertyHandler::PropertyHandler(MessageTranslatorInterface *translator,
-                                 client::ClientInterface *client)
+PropertyHandler::PropertyHandler(
+    std::unique_ptr<MessageTranslatorInterface> translator,
+    bool is_active_on_launch, client::ClientInterface *client)
     : prop_root_(ibus_prop_list_new()),
       prop_composition_mode_(nullptr),
       prop_mozc_tool_(nullptr),
       client_(client),
-      translator_(translator),
+      translator_(std::move(translator)),
       original_composition_mode_(kMozcEngineInitialCompositionMode),
-      is_activated_(kActivatedOnLaunch),
+      is_activated_(is_active_on_launch),
       is_disabled_(false) {
   commands::SessionCommand command;
   if (is_activated_) {
@@ -169,10 +165,10 @@ void PropertyHandler::AppendCompositionPropertyToPanel() {
       icon_path_for_panel = GetIconPath(entry.icon);
       mode_symbol = entry.label_for_panel;
     }
-    IBusProperty *item = ibus_property_new(
-        entry.key, PROP_TYPE_RADIO, label, nullptr /* icon */,
-        nullptr /* tooltip */, TRUE /* sensitive */, TRUE /* visible */, state,
-        nullptr /* sub props */);
+    IBusProperty *item =
+        ibus_property_new(entry.key, PROP_TYPE_RADIO, label, nullptr /* icon */,
+                          nullptr /* tooltip */, TRUE /* sensitive */,
+                          TRUE /* visible */, state, nullptr /* sub props */);
     g_object_set_data(G_OBJECT(item), kGObjectDataKey, (gpointer)&entry);
     ibus_prop_list_append(sub_prop_list, item);
     // |sub_prop_list| owns |item| by calling g_object_ref_sink for the |item|.
@@ -233,8 +229,7 @@ void PropertyHandler::UpdateContentType(IBusEngine *engine) {
 // TODO(nona): do not use kMozcEngine*** directory.
 void PropertyHandler::AppendToolPropertyToPanel() {
   if (kMozcEngineToolProperties == nullptr ||
-      kMozcEngineToolPropertiesSize == 0 ||
-      !IsMozcToolAvailable()) {
+      kMozcEngineToolPropertiesSize == 0 || !IsMozcToolAvailable()) {
     return;
   }
 
