@@ -37,18 +37,15 @@
 #include <string>
 
 #include "base/logging.h"
-#include "base/mutex.h"
 #include "base/port.h"
 #include "base/thread.h"
 #include "base/util.h"
+#include "absl/synchronization/mutex.h"
 
 namespace mozc {
 namespace ibus {
-
 namespace {
 
-using std::unique_ptr;
-
 class ScopedXcbGenericError {
  public:
   ScopedXcbGenericError() : error_(nullptr) {}
@@ -69,17 +66,17 @@ struct FreeDeleter {
 };
 
 // TODO(yukawa): Use template aliases when GCC 4.6 is retired.
-typedef unique_ptr<xcb_get_property_reply_t,
-                   FreeDeleter<xcb_get_property_reply_t>>
+typedef std::unique_ptr<xcb_get_property_reply_t,
+                        FreeDeleter<xcb_get_property_reply_t>>
     ScopedXcbGetPropertyReply;
-typedef unique_ptr<xcb_get_atom_name_reply_t,
-                   FreeDeleter<xcb_get_atom_name_reply_t>>
+typedef std::unique_ptr<xcb_get_atom_name_reply_t,
+                        FreeDeleter<xcb_get_atom_name_reply_t>>
     ScopedXcbGetAtomNameReply;
-typedef unique_ptr<xcb_intern_atom_reply_t,
-                   FreeDeleter<xcb_intern_atom_reply_t>>
+typedef std::unique_ptr<xcb_intern_atom_reply_t,
+                        FreeDeleter<xcb_intern_atom_reply_t>>
     ScopedXcbInternAtomReply;
-typedef unique_ptr<xcb_xfixes_query_version_reply_t,
-                   FreeDeleter<xcb_xfixes_query_version_reply_t>>
+typedef std::unique_ptr<xcb_xfixes_query_version_reply_t,
+                        FreeDeleter<xcb_xfixes_query_version_reply_t>>
     ScopedXcbXFixesQueqyVersionReply;
 
 struct XcbAtoms {
@@ -163,7 +160,7 @@ class SelectionMonitorServer {
     }
 
     ::xcb_flush(connection_);
-    unique_ptr<xcb_generic_event_t, void (*)(void *)> event(
+    std::unique_ptr<xcb_generic_event_t, void (*)(void *)> event(
         ::xcb_wait_for_event(connection_), &std::free);
 
     if (event.get() == nullptr) {
@@ -213,7 +210,7 @@ class SelectionMonitorServer {
     }
   }
 
-  bool CreateAtom(const std::string name, xcb_atom_t *atom) const {
+  bool CreateAtom(const std::string &name, xcb_atom_t *atom) const {
     DCHECK(atom);
     *atom = XCB_NONE;
     xcb_intern_atom_cookie_t cookie =
@@ -488,7 +485,10 @@ class SelectionMonitorImpl : public SelectionMonitorInterface, public Thread {
   SelectionMonitorImpl(SelectionMonitorServer *server, size_t max_text_bytes)
       : server_(server), max_text_bytes_(max_text_bytes), quit_(false) {}
 
-  virtual ~SelectionMonitorImpl() {
+  SelectionMonitorImpl(const SelectionMonitorImpl &) = delete;
+  SelectionMonitorImpl &operator=(const SelectionMonitorImpl &) = delete;
+
+  ~SelectionMonitorImpl() override {
     // Currently mozc::Thread cannot safely detach the attached thread since
     // the detached thread continues running on a heap allocated to this
     // object.
@@ -501,10 +501,10 @@ class SelectionMonitorImpl : public SelectionMonitorInterface, public Thread {
   }
 
   // Implements SelectionMonitorInterface::StartMonitoring.
-  virtual void StartMonitoring() { Thread::Start("SelectionMonitor"); }
+  void StartMonitoring() override { Thread::Start("SelectionMonitor"); }
 
   // Implements SelectionMonitorInterface::QueryQuit.
-  virtual void QueryQuit() {
+  void QueryQuit() override {
     if (Thread::IsRunning()) {
       quit_ = true;
       // Awake the message pump thread so that it can see the updated
@@ -514,20 +514,20 @@ class SelectionMonitorImpl : public SelectionMonitorInterface, public Thread {
   }
 
   // Implements SelectionMonitorInterface::GetSelectionInfo.
-  virtual SelectionInfo GetSelectionInfo() {
+  SelectionInfo GetSelectionInfo() override {
     SelectionInfo info;
     {
-      scoped_lock l(&mutex_);
+      absl::MutexLock l(&mutex_);
       info = last_selection_info_;
     }
     return info;
   }
 
   // Implements Thread::Run.
-  virtual void Run() {
+  void Run() override {
     while (!quit_) {
       if (!server_->checkConnection()) {
-        scoped_lock l(&mutex_);
+        absl::MutexLock l(&mutex_);
         last_selection_info_ = SelectionInfo();
         quit_ = true;
         break;
@@ -538,20 +538,18 @@ class SelectionMonitorImpl : public SelectionMonitorInterface, public Thread {
       // X11 message is received. In order to interrupt, you can call
       // SendNoopEventMessage() method from other threads.
       if (server_->WaitForNextSelectionEvent(max_text_bytes_, &next_info)) {
-        scoped_lock l(&mutex_);
+        absl::MutexLock l(&mutex_);
         last_selection_info_ = next_info;
       }
     }
   }
 
  private:
-  unique_ptr<SelectionMonitorServer> server_;
+  std::unique_ptr<SelectionMonitorServer> server_;
   const size_t max_text_bytes_;
   volatile bool quit_;
-  Mutex mutex_;
+  absl::Mutex mutex_;
   SelectionInfo last_selection_info_;
-
-  DISALLOW_COPY_AND_ASSIGN(SelectionMonitorImpl);
 };
 
 }  // namespace
@@ -562,7 +560,7 @@ SelectionInfo::SelectionInfo() : timestamp(0), process_id(0) {}
 
 SelectionMonitorInterface *SelectionMonitorFactory::Create(
     size_t max_text_bytes) {
-  unique_ptr<SelectionMonitorServer> server(new SelectionMonitorServer());
+  std::unique_ptr<SelectionMonitorServer> server(new SelectionMonitorServer());
   if (!server->Init()) {
     return nullptr;
   }
