@@ -51,45 +51,43 @@ using ::ATL::CComPtr;
 using ::ATL::CComQIPtr;
 using ::ATL::CComVariant;
 
-using ::std::unique_ptr;
-
-const size_t kMaxHierarchyLevel = 50;
+constexpr size_t kMaxHierarchyLevel = 50;
 
 DWORD g_tls_index = TLS_OUT_OF_INDEXES;
 HMODULE g_module_handle = nullptr;
 
-string UTF16ToUTF8(const std::wstring &str) {
-  string utf8;
-  Util::WideToUTF8(str, &utf8);
+std::string Utf16ToUtf8(const std::wstring &str) {
+  std::string utf8;
+  Util::WideToUtf8(str, &utf8);
   return utf8;
 }
 
-string GetWindowTestAsUTF8(HWND window_handle) {
+std::string GetWindowTestAsUTF8(HWND window_handle) {
   const int text_len = ::GetWindowTextLengthW(window_handle);
   if (text_len <= 0) {
     return "";
   }
   const int buffer_len = text_len + 1;
-  unique_ptr<wchar_t[]> buffer(new wchar_t[buffer_len]);
+  std::unique_ptr<wchar_t[]> buffer(new wchar_t[buffer_len]);
   const int copied_len_without_null =
       ::GetWindowText(window_handle, buffer.get(), buffer_len);
   if (copied_len_without_null <= 0 ||
       copied_len_without_null + 1 > buffer_len) {
     return "";
   }
-  return UTF16ToUTF8(std::wstring(buffer.get(), copied_len_without_null));
+  return Utf16ToUtf8(std::wstring(buffer.get(), copied_len_without_null));
 }
 
-string GetWindowClassNameAsUTF8(HWND window_handle) {
-  const int kBufferLen = 256 + 1;
-  unique_ptr<wchar_t[]> buffer(new wchar_t[kBufferLen]);
+std::string GetWindowClassNameAsUTF8(HWND window_handle) {
+  constexpr int kBufferLen = 256 + 1;
+  std::unique_ptr<wchar_t[]> buffer(new wchar_t[kBufferLen]);
   const int copied_len_without_null =
       ::GetClassNameW(window_handle, buffer.get(), kBufferLen);
   if (copied_len_without_null <= 0 ||
       copied_len_without_null + 1 > kBufferLen) {
     return "";
   }
-  return UTF16ToUTF8(std::wstring(buffer.get(), copied_len_without_null));
+  return Utf16ToUtf8(std::wstring(buffer.get(), copied_len_without_null));
 }
 
 DWORD GetProcessIdFromWindow(HWND window_handle) {
@@ -172,7 +170,7 @@ class ThreadLocalInfo {
   std::vector<FocusHierarchyObserver::WindowInfo> window_hierarchy() const {
     return window_hierarchy_;
   }
-  string root_window_name() const { return root_window_name_; }
+  std::string root_window_name() const { return root_window_name_; }
 
   void SyncFocusHierarchy() {
     const HWND focused_window = ::GetFocus();
@@ -317,7 +315,7 @@ class ThreadLocalInfo {
   HWINEVENTHOOK hook_handle_;
   std::vector<AccessibleObjectInfo> ui_hierarchy_;
   std::vector<FocusHierarchyObserver::WindowInfo> window_hierarchy_;
-  string root_window_name_;
+  std::string root_window_name_;
 };
 
 bool TlsAvailable() { return g_tls_index != TLS_OUT_OF_INDEXES; }
@@ -368,7 +366,7 @@ class FocusHierarchyObserverImpl : public FocusHierarchyObserver {
     }
     return self->window_hierarchy();
   }
-  virtual string GetRootWindowName() const {
+  virtual std::string GetRootWindowName() const {
     auto *self = ThreadLocalInfo::Self();
     if (self == nullptr) {
       return "";
@@ -395,7 +393,7 @@ class FocusHierarchyObserverNullImpl : public FocusHierarchyObserver {
   virtual std::vector<WindowInfo> GetWindowHierarchy() const {
     return std::vector<WindowInfo>();
   }
-  virtual string GetRootWindowName() const { return ""; }
+  virtual std::string GetRootWindowName() const { return ""; }
 
  private:
   DISALLOW_COPY_AND_ASSIGN(FocusHierarchyObserverNullImpl);
