@@ -56,8 +56,6 @@ namespace win32 {
 
 namespace {
 
-using std::unique_ptr;
-
 const wchar_t kRegKeyboardLayouts[] =
     L"SYSTEM\\CurrentControlSet\\Control\\Keyboard Layouts";
 const wchar_t kLayoutDisplayNameKey[] = L"Layout Display Name";
@@ -105,7 +103,7 @@ HRESULT SetLayoutDisplayName(
   }
 
   wchar_t layout_name[MAX_PATH];
-  HRESULT hr = StringCchPrintf(layout_name, arraysize(layout_name),
+  HRESULT hr = StringCchPrintf(layout_name, std::size(layout_name),
                                kLayoutDisplayNamePattern,
                                layout_display_name_resource_path.c_str(),
                                layout_display_name_resource_id);
@@ -130,16 +128,16 @@ HRESULT SetLayoutDisplayName(
 // folder as a system folder, so it will refuse to install our IME. The
 // solution here is to combine the 64-bit System32 folder and our filename
 // to make ImmInstallIME happy.
-std::wstring GetFullPathForSystem(const string &basename) {
-  string system_dir;
-  if (Util::WideToUTF8(SystemUtil::GetSystemDir(), &system_dir) <= 0) {
+std::wstring GetFullPathForSystem(const std::string &basename) {
+  std::string system_dir;
+  if (Util::WideToUtf8(SystemUtil::GetSystemDir(), &system_dir) <= 0) {
     return L"";
   }
 
-  const string fullpath = FileUtil::JoinPath(system_dir, basename);
+  const std::string fullpath = FileUtil::JoinPath(system_dir, basename);
 
   std::wstring wfullpath;
-  if (Util::UTF8ToWide(fullpath, &wfullpath) <= 0) {
+  if (Util::Utf8ToWide(fullpath, &wfullpath) <= 0) {
     return L"";
   }
 
@@ -155,9 +153,9 @@ LONG RetrievePreloadValues(HKEY preload_key, PreloadValueMap *keys) {
 
   // Registry element size limits are described in the link below.
   // http://msdn.microsoft.com/en-us/library/ms724872(VS.85).aspx
-  const DWORD kMaxValueNameLength = 16383;
+  constexpr DWORD kMaxValueNameLength = 16383;
   wchar_t value_name[kMaxValueNameLength];
-  const DWORD kMaxValueLength = 256;
+  constexpr DWORD kMaxValueLength = 256;
   BYTE value[kMaxValueLength];
   for (DWORD i = 0;; ++i) {
     DWORD value_name_length = kMaxValueNameLength;
@@ -199,9 +197,9 @@ unsigned int GetPreloadIndex(const KeyboardLayoutID &klid,
   return index;
 }
 
-std::wstring ToWideString(const string &str) {
+std::wstring ToWideString(const std::string &str) {
   std::wstring wide;
-  if (Util::UTF8ToWide(str, &wide) <= 0) {
+  if (Util::Utf8ToWide(str, &wide) <= 0) {
     return L"";
   }
   return wide;
@@ -264,13 +262,13 @@ HRESULT ImmRegistrar::Register(
                                L"\\" + ime_filename);
 
   // The path name of IME has hard limit. (http://b/2072809)
-  if (fullpath.size() + 1 > arraysize(dummy_ime_property.szName)) {
+  if (fullpath.size() + 1 > std::size(dummy_ime_property.szName)) {
     // Path name is too long. It will be truncated.
     return E_FAIL;
   }
 
   // The description of IME has hard limit. (http://b/2072809)
-  if (layout_name.size() + 1 > arraysize(dummy_ime_property.szDescription)) {
+  if (layout_name.size() + 1 > std::size(dummy_ime_property.szDescription)) {
     // Description is too long. It will be truncated.
     return E_FAIL;
   }
@@ -321,7 +319,7 @@ HRESULT ImmRegistrar::Unregister(const std::wstring &ime_filename) {
   // Ensure the target IME is unloaded.
   {
     const int num_keyboard_layout = ::GetKeyboardLayoutList(0, nullptr);
-    unique_ptr<HKL[]> keyboard_layouts(new HKL[num_keyboard_layout]);
+    std::unique_ptr<HKL[]> keyboard_layouts(new HKL[num_keyboard_layout]);
     const size_t num_copied =
         ::GetKeyboardLayoutList(num_keyboard_layout, keyboard_layouts.get());
     for (size_t i = 0; i < num_copied; ++i) {
@@ -389,7 +387,7 @@ KeyboardLayoutID ImmRegistrar::GetKLIDFromFileName(
 
   // Registry element size limits are described in the link below.
   // http://msdn.microsoft.com/en-us/library/ms724872(VS.85).aspx
-  const DWORD kMaxValueNameLength = 16383;
+  constexpr DWORD kMaxValueNameLength = 16383;
   wchar_t value_name[kMaxValueNameLength];
   for (DWORD enum_reg_index = 0;; ++enum_reg_index) {
     DWORD value_name_length = kMaxValueNameLength;
@@ -445,7 +443,7 @@ std::wstring ImmRegistrar::GetFullPathForIME() {
 std::wstring ImmRegistrar::GetLayoutName() {
   std::wstring layout_name;
   // We use English name here as culture-invariant layout name.
-  if (Util::UTF8ToWide(kProductNameInEnglish, &layout_name) <= 0) {
+  if (Util::Utf8ToWide(kProductNameInEnglish, &layout_name) <= 0) {
     return L"";
   }
   return layout_name;
