@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,8 +38,6 @@ namespace win32 {
 
 namespace {
 
-using std::unique_ptr;
-
 BYTE ParseVirtualKey(UINT combined_virtual_key) {
   const uint16 loword = LOWORD(combined_virtual_key);
   if (loword <= 0xff) {
@@ -187,7 +185,7 @@ class DefaultKeyboardInterface : public Win32KeyboardInterface {
 
     // Unfortunately, SendInput API requires LPINPUT (NOT const INPUT *).
     // This is why we make a temporary array with the same data here.
-    unique_ptr<INPUT[]> input_array(new INPUT[inputs.size()]);
+    std::unique_ptr<INPUT[]> input_array(new INPUT[inputs.size()]);
     for (size_t i = 0; i < inputs.size(); ++i) {
       input_array[i] = inputs[i];
     }
@@ -200,18 +198,18 @@ Win32KeyboardInterface *Win32KeyboardInterface::CreateDefault() {
   return new DefaultKeyboardInterface();
 }
 
-KeyboardStatus::KeyboardStatus() { memset(&status_[0], 0, arraysize(status_)); }
+KeyboardStatus::KeyboardStatus() { memset(&status_[0], 0, std::size(status_)); }
 
 KeyboardStatus::KeyboardStatus(const BYTE key_status[256]) {
   const errno_t error =
-      memcpy_s(&status_[0], arraysize(status_), key_status, arraysize(status_));
+      memcpy_s(&status_[0], std::size(status_), key_status, std::size(status_));
   if (error != NO_ERROR) {
-    memset(&status_[0], 0, arraysize(status_));
+    memset(&status_[0], 0, std::size(status_));
   }
 }
 
 BYTE KeyboardStatus::GetState(int virtual_key) const {
-  if (virtual_key < 0 || arraysize(status_) <= virtual_key) {
+  if (virtual_key < 0 || std::size(status_) <= virtual_key) {
     DLOG(ERROR) << "index out of range. index = " << virtual_key;
     return 0;
   }
@@ -219,7 +217,7 @@ BYTE KeyboardStatus::GetState(int virtual_key) const {
 }
 
 void KeyboardStatus::SetState(int virtual_key, BYTE value) {
-  if (virtual_key < 0 || arraysize(status_) <= virtual_key) {
+  if (virtual_key < 0 || std::size(status_) <= virtual_key) {
     DLOG(ERROR) << "index out of range. index = " << virtual_key;
     return;
   }
@@ -238,7 +236,7 @@ const BYTE *KeyboardStatus::status() const { return status_; }
 
 BYTE *KeyboardStatus::mutable_status() { return status_; }
 
-size_t KeyboardStatus::status_size() const { return arraysize(status_); }
+size_t KeyboardStatus::status_size() const { return std::size(status_); }
 
 namespace {
 enum KeyModifierFlags {
@@ -910,11 +908,11 @@ const wchar_t *kCharTable[] = {
     kNoCharGenKey,  // VK_PAUSE
     kNoCharGenKey,  // VK_CAPITAL
     kNoCharGenKey,  // VK_HANGUL, VK_KANA
-    kNoCharGenKey,
+    kNoCharGenKey,  // VK_IME_ON
     kNoCharGenKey,  // VK_JUNJA
     kNoCharGenKey,  // VK_FINAL
     kNoCharGenKey,  // VK_HANJA, VK_KANJI
-    kNoCharGenKey,
+    kNoCharGenKey,  // VK_IME_OFF
     kCharForVK_1B,  // VK_ESCAPE
     kNoCharGenKey,  // VK_CONVERT
     kNoCharGenKey,  // VK_NONCONVERT
@@ -1123,11 +1121,11 @@ const wchar_t *kCharTableMenuActive[] = {
     kNoCharGenKey,  // VK_PAUSE
     kNoCharGenKey,  // VK_CAPITAL
     kNoCharGenKey,  // VK_HANGUL, VK_KANA
-    kNoCharGenKey,
+    kNoCharGenKey,  // VK_IME_ON
     kNoCharGenKey,  // VK_JUNJA
     kNoCharGenKey,  // VK_FINAL
     kNoCharGenKey,  // VK_HANJA, VK_KANJI
-    kNoCharGenKey,
+    kNoCharGenKey,  // VK_IME_OFF
     kCharForVK_1B,  // VK_ESCAPE
     kNoCharGenKey,  // VK_CONVERT
     kNoCharGenKey,  // VK_NONCONVERT
@@ -1396,14 +1394,14 @@ wchar_t JapaneseKeyboardLayoutEmulator::GetCharacterForKeyDown(
   // - VK_LCONTROL/VK_RCONTROL
   // - VK_LMENU/VK_RMENU
 
-  DCHECK(virtual_key < arraysize(kCharTable));
+  DCHECK(virtual_key < std::size(kCharTable));
   if (is_menu_active) {
     DCHECK_LE(0, index);
-    DCHECK(index < arraysize(kNoCharGenKey));
+    DCHECK(index < std::size(kNoCharGenKey));
     return kCharTableMenuActive[virtual_key][index];
   } else {
     DCHECK_LE(0, index);
-    DCHECK(index < arraysize(kNoCharGenKey));
+    DCHECK(index < std::size(kNoCharGenKey));
     return kCharTable[virtual_key][index];
   }
 }
