@@ -40,8 +40,8 @@
 
 namespace {
 // A valid KLID consists of 8 character of hexadecimal digit in text form.
-const size_t kTextLength = (KL_NAMELENGTH - 1);
-const DWORD kDefaultKLID = 0;
+constexpr size_t kTextLength = (KL_NAMELENGTH - 1);
+constexpr DWORD kDefaultKLID = 0;
 
 bool IsHexadecimalDigit(wchar_t c) {
   if (L'0' <= c && c <= L'9') {
@@ -92,7 +92,7 @@ std::wstring KeyboardLayoutID::ToString() const {
   CHECK(has_id()) << "ID is not set.";
   wchar_t buffer[KL_NAMELENGTH];
   const HRESULT result =
-      ::StringCchPrintf(buffer, arraysize(buffer), L"%08X", id_);
+      ::StringCchPrintf(buffer, std::size(buffer), L"%08X", id_);
   if (FAILED(result)) {
     return L"";
   }
