@@ -35,6 +35,7 @@
 
 #include <set>
 
+#include "base/japanese_util.h"
 #include "base/logging.h"
 #include "base/util.h"
 #include "client/client_interface.h"
@@ -79,7 +80,7 @@ const KeyEvent::SpecialKey kSpecialKeyMap[] = {
     KeyEvent::NO_SPECIALKEY,  // 0x13: VK_PAUSE
     KeyEvent::CAPS_LOCK,      // 0x14: VK_CAPITAL
     KeyEvent::NO_SPECIALKEY,  // 0x15: VK_HANGUL, VK_KANA
-    KeyEvent::NO_SPECIALKEY,  // 0x16:
+    KeyEvent::ON,             // 0x16: VK_IME_ON
     KeyEvent::NO_SPECIALKEY,  // 0x17: VK_JUNJA
     KeyEvent::NO_SPECIALKEY,  // 0x18: VK_FINAL
     // VK_KANJI is very special in IMM32 mode. It activates IME in OS-side
@@ -89,7 +90,7 @@ const KeyEvent::SpecialKey kSpecialKeyMap[] = {
     // KeyEvent::KANJI in IMM32 mode and map VK_KANJI to KeyEvent::HANKAKU
     // via VK_DBE_DBCSCHAR in TSF mode. See b/7970379 for the background.
     KeyEvent::NO_SPECIALKEY,  // 0x19: VK_HANJA, VK_KANJI
-    KeyEvent::NO_SPECIALKEY,  // 0x1A:
+    KeyEvent::OFF,            // 0x1A: VK_IME_OFF
     KeyEvent::ESCAPE,         // 0x1B: VK_ESCAPE
     KeyEvent::HENKAN,         // 0x1C: VK_CONVERT
     KeyEvent::MUHENKAN,       // 0x1D: VK_NONCONVERT
@@ -406,8 +407,8 @@ bool ConvertToKeyEventMain(const VirtualKey &virtual_key, BYTE scan_code,
   // Support VK_PACKET.
   if (virtual_key.virtual_key() == VK_PACKET) {
     const char32 character = virtual_key.unicode_char();
-    string utf8_characters;
-    Util::UCS4ToUTF8(character, &utf8_characters);
+    std::string utf8_characters;
+    Util::Ucs4ToUtf8(character, &utf8_characters);
     if (utf8_characters.empty()) {
       return false;
     }
@@ -496,7 +497,7 @@ bool ConvertToKeyEventMain(const VirtualKey &virtual_key, BYTE scan_code,
     const int kana_locked_length = keyboard->ToUnicode(
         virtual_key.virtual_key(), to_unicode_scancode,
         keyboard_status_w_kana_lock.status(), &kana_codes[0],
-        arraysize(kana_codes), to_unicode_flag);
+        std::size(kana_codes), to_unicode_flag);
     if (kana_locked_length != 1) {
       return false;
     }
@@ -505,11 +506,12 @@ bool ConvertToKeyEventMain(const VirtualKey &virtual_key, BYTE scan_code,
     // TODO(yukawa): Move the following character conversion logic into
     //   mozc::Util as HalfWidthKatakanaToHiragana.
     const wchar_t whalf_katakana[] = {static_cast<wchar_t>(kana_code), L'\0'};
-    string half_katakana, full_katakana, full_hiragana;
-    mozc::Util::WideToUTF8(whalf_katakana, &half_katakana);
-    mozc::Util::HalfWidthKatakanaToFullWidthKatakana(half_katakana.c_str(),
-                                                     &full_katakana);
-    mozc::Util::KatakanaToHiragana(full_katakana.c_str(), &full_hiragana);
+    std::string half_katakana, full_katakana, full_hiragana;
+    mozc::Util::WideToUtf8(whalf_katakana, &half_katakana);
+    mozc::japanese_util::HalfWidthKatakanaToFullWidthKatakana(
+        half_katakana.c_str(), &full_katakana);
+    mozc::japanese_util::KatakanaToHiragana(full_katakana.c_str(),
+                                            &full_hiragana);
     key->set_key_string(full_hiragana);
     has_valid_key_string = true;
   }
@@ -591,7 +593,7 @@ bool ConvertToKeyEventMain(const VirtualKey &virtual_key, BYTE scan_code,
   int kana_unlocked_length =
       keyboard->ToUnicode(virtual_key.virtual_key(), to_unicode_scancode,
                           keyboard_status_wo_kana_lock.status(), &codes[0],
-                          arraysize(codes), to_unicode_flag);
+                          std::size(codes), to_unicode_flag);
 
   // A workaround for b/3029665.
   // Keyboard drivers of the JIS keyboard do not produce a key code for
@@ -610,7 +612,7 @@ bool ConvertToKeyEventMain(const VirtualKey &virtual_key, BYTE scan_code,
     kana_unlocked_length =
         keyboard->ToUnicode(virtual_key.virtual_key(), to_unicode_scancode,
                             keyboard_status_wo_kana_lock.status(), &codes[0],
-                            arraysize(codes), to_unicode_flag);
+                            std::size(codes), to_unicode_flag);
   }
 
   if (kana_unlocked_length != 1) {
@@ -973,7 +975,7 @@ void KeyEventHandler::MaybeSpawnTool(mozc::client::ClientInterface *client,
   // by client with specified mode.
   // TODO(team):  move it to better place.
   if (output->has_launch_tool_mode()) {
-    string mode;
+    std::string mode;
     switch (output->launch_tool_mode()) {
       case commands::Output::CONFIG_DIALOG:
         mode = "config_dialog";
