@@ -58,9 +58,8 @@ namespace win32 {
 namespace {
 
 using ATL::CStringA;
-using std::unique_ptr;
 
-bool SpawnBroker(const string &arg) {
+bool SpawnBroker(const std::string &arg) {
   // To workaround a bug around WoW version of LoadKeyboardLayout, 64-bit
   // version of mozc_broker should be launched on Windows x64.
   // See b/2958563 for details.
@@ -115,7 +114,7 @@ bool MigrationUtil::LaunchBrokerForSetDefault(bool do_not_ask_me_again) {
     }
   }
 
-  string arg = "--mode=set_default";
+  std::string arg = "--mode=set_default";
   if (do_not_ask_me_again) {
     arg += " --set_default_do_not_ask_again=true";
   }
@@ -137,7 +136,8 @@ bool MigrationUtil::DisableLegacyMozcForCurrentUserOnWin8() {
   const UINT num_element =
       ::EnumEnabledLayoutOrTip(nullptr, nullptr, nullptr, nullptr, 0);
 
-  unique_ptr<LAYOUTORTIPPROFILE[]> buffer(new LAYOUTORTIPPROFILE[num_element]);
+  std::unique_ptr<LAYOUTORTIPPROFILE[]> buffer(
+      new LAYOUTORTIPPROFILE[num_element]);
 
   const UINT num_copied = ::EnumEnabledLayoutOrTip(nullptr, nullptr, nullptr,
                                                    buffer.get(), num_element);
@@ -186,12 +186,12 @@ bool MigrationUtil::DisableLegacyMozcForCurrentUserOnWin8() {
     if ((profile.dwFlags & LOT_DEFAULT) == LOT_DEFAULT) {
       wchar_t clsid[64] = {};
       if (!::StringFromGUID2(TsfProfile::GetTextServiceGuid(), clsid,
-                             arraysize(clsid))) {
+                             std::size(clsid))) {
         return false;
       }
       wchar_t profile_id[64] = {};
       if (!::StringFromGUID2(TsfProfile::GetProfileGuid(), profile_id,
-                             arraysize(profile_id))) {
+                             std::size(profile_id))) {
         return false;
       }
 
@@ -206,7 +206,7 @@ bool MigrationUtil::DisableLegacyMozcForCurrentUserOnWin8() {
     // Disable IMM32 Mozc.
     {
       wchar_t profile_str[32] = {};
-      if (FAILED(::StringCchPrintf(profile_str, arraysize(profile_str),
+      if (FAILED(::StringCchPrintf(profile_str, std::size(profile_str),
                                    L"%04x:%s", profile.langid,
                                    klid.ToString().c_str()))) {
         return false;
