@@ -31,6 +31,7 @@
 
 #include <memory>
 
+#include "base/japanese_util.h"
 #include "base/util.h"
 #include "protocol/commands.pb.h"
 #include "absl/strings/string_view.h"
@@ -39,17 +40,17 @@ namespace mozc {
 namespace win32 {
 namespace {
 
-const size_t kMaxReadingChars = 512;
+constexpr size_t kMaxReadingChars = 512;
 
-void UTF8ToSJIS(absl::string_view input, string *output) {
+void Utf8ToSjis(absl::string_view input, std::string *output) {
   std::wstring utf16;
-  Util::UTF8ToWide(input, &utf16);
+  Util::Utf8ToWide(input, &utf16);
   if (utf16.empty()) {
     output->clear();
     return;
   }
 
-  const int kCodePageShiftJIS = 932;
+  constexpr int kCodePageShiftJIS = 932;
 
   const int output_length_without_null =
       ::WideCharToMultiByte(kCodePageShiftJIS, 0, utf16.data(), utf16.size(),
@@ -74,17 +75,17 @@ void UTF8ToSJIS(absl::string_view input, string *output) {
 }  // namespace
 
 std::wstring StringUtil::KeyToReading(absl::string_view key) {
-  string katakana;
-  Util::HiraganaToKatakana(key, &katakana);
+  std::string katakana;
+  japanese_util::HiraganaToKatakana(key, &katakana);
 
   DWORD lcid =
       MAKELCID(MAKELANGID(LANG_JAPANESE, SUBLANG_DEFAULT), SORT_JAPANESE_XJIS);
-  string sjis;
-  UTF8ToSJIS(katakana, &sjis);
+  std::string sjis;
+  Utf8ToSjis(katakana, &sjis);
 
   // Convert "\x81\x65" (backquote in SJIFT-JIS) to ` by myself since
   // LCMapStringA converts it to ' for some reason.
-  string sjis2;
+  std::string sjis2;
   mozc::Util::StringReplace(sjis, "\x81\x65", "`", true, &sjis2);
 
   const size_t halfwidth_len_without_null = ::LCMapStringA(
@@ -123,9 +124,9 @@ std::wstring StringUtil::KeyToReading(absl::string_view key) {
   return std::wstring(wide_output.get(), actual_output_length_without_null);
 }
 
-string StringUtil::KeyToReadingA(absl::string_view key) {
-  string ret;
-  mozc::Util::WideToUTF8(KeyToReading(key), &ret);
+std::string StringUtil::KeyToReadingA(absl::string_view key) {
+  std::string ret;
+  mozc::Util::WideToUtf8(KeyToReading(key), &ret);
   return ret;
 }
 
@@ -133,7 +134,7 @@ std::wstring StringUtil::ComposePreeditText(const commands::Preedit &preedit) {
   std::wstring value;
   for (int i = 0; i < preedit.segment_size(); ++i) {
     std::wstring segment_value;
-    mozc::Util::UTF8ToWide(preedit.segment(i).value(), &segment_value);
+    mozc::Util::Utf8ToWide(preedit.segment(i).value(), &segment_value);
     value.append(segment_value);
   }
   return value;
