@@ -39,7 +39,7 @@ namespace win32 {
 TEST(StringUtilTest, InvalidCases) {
   EXPECT_EQ("", StringUtil::KeyToReadingA(""));
   // KeyToReadingA fails if the resultant string is longer than 512 characters.
-  string longa(10000, 'a');
+  std::string longa(10000, 'a');
   EXPECT_EQ("", StringUtil::KeyToReadingA(longa));
 }
 
