@@ -37,7 +37,7 @@ namespace win32 {
 namespace {
 
 // TODO(yukawa): Move this to util.cc.
-char32 SurrogatePairToUCS4(wchar_t high, wchar_t low) {
+char32 SurrogatePairToUcs4(wchar_t high, wchar_t low) {
   return (((high - 0xD800) & 0x3FF) << 10) + ((low - 0xDC00) & 0x3FF) + 0x10000;
 }
 
@@ -105,7 +105,7 @@ SurrogatePairObserver::ClientAction SurrogatePairObserver::OnKeyEvent(
       }
       if (IS_LOW_SURROGATE(ucs2)) {
         if (is_keydown) {
-          const char32 ucs4 = SurrogatePairToUCS4(surrogate_high_, ucs2);
+          const char32 ucs4 = SurrogatePairToUcs4(surrogate_high_, ucs2);
           if (!is_test_key) {
             surrogate_low_ = ucs2;
             state_ = WAIT_FOR_SURROGATE_LOW_UP;
@@ -135,7 +135,7 @@ SurrogatePairObserver::ClientAction SurrogatePairObserver::OnKeyEvent(
       }
       if (IS_LOW_SURROGATE(ucs2)) {
         if (is_keydown) {
-          const char32 ucs4 = SurrogatePairToUCS4(surrogate_high_, ucs2);
+          const char32 ucs4 = SurrogatePairToUcs4(surrogate_high_, ucs2);
           if (!is_test_key) {
             surrogate_low_ = ucs2;
             state_ = WAIT_FOR_SURROGATE_LOW_UP;
@@ -178,7 +178,7 @@ SurrogatePairObserver::ClientAction SurrogatePairObserver::OnKeyEvent(
           return ClientAction(CONSUME_KEY_BUT_NEVER_SEND_TO_SERVER, 0);
         }
         const char32 ucs4 =
-            SurrogatePairToUCS4(surrogate_high_, surrogate_low_);
+            SurrogatePairToUcs4(surrogate_high_, surrogate_low_);
         if (!is_test_key) {
           state_ = INITIAL_STATE;
           surrogate_high_ = L'\0';
