@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,6 @@ namespace mozc {
 namespace win32 {
 using ATL::CComPtr;
 using ATL::CRegKey;
-using std::unique_ptr;
 
 namespace {
 
@@ -79,12 +78,12 @@ const wchar_t kPreloadKeyName[] = L"Keyboard Layout\\Preload";
 
 // Registry element size limits are described in the link below.
 // http://msdn.microsoft.com/en-us/library/ms724872(VS.85).aspx
-const DWORD kMaxValueNameLength = 16383;
+constexpr DWORD kMaxValueNameLength = 16383;
 
 // Timeout value used by a work around against b/5765783.
 // Note that the following timeout threshold is not well tested.
 // TODO(yukawa): Investigate the best timeout threshold. b/6165722
-const uint32 kWaitForAsmCacheReadyEventTimeout = 10000;  // 10 sec.
+constexpr uint32 kWaitForAsmCacheReadyEventTimeout = 10000;  // 10 sec.
 
 // Converts an unsigned integer to a wide string.
 std::wstring utow(unsigned int i) {
@@ -180,7 +179,7 @@ bool GenerateKeyboardLayoutMap(
 std::wstring GetIMEFileName(HKL hkl) {
   const UINT num_chars_without_null = ::ImmGetIMEFileName(hkl, nullptr, 0);
   const size_t num_chars_with_null = num_chars_without_null + 1;
-  unique_ptr<wchar_t[]> buffer(new wchar_t[num_chars_with_null]);
+  std::unique_ptr<wchar_t[]> buffer(new wchar_t[num_chars_with_null]);
   const UINT num_copied =
       ::ImmGetIMEFileName(hkl, buffer.get(), num_chars_with_null);
 
@@ -280,7 +279,7 @@ bool GetPreloadLayoutsMain(PreloadOrderToKLIDMap *preload_map) {
   }
 
   wchar_t value_name[kMaxValueNameLength];
-  const DWORD kMaxValueLength = 256;
+  constexpr DWORD kMaxValueLength = 256;
   BYTE value[kMaxValueLength];
   for (DWORD i = 0;; ++i) {
     DWORD value_name_length = kMaxValueNameLength;
@@ -311,7 +310,7 @@ bool GetPreloadLayoutsMain(PreloadOrderToKLIDMap *preload_map) {
 std::wstring GUIDToString(const GUID &guid) {
   wchar_t buffer[256];
   const int character_length_with_null =
-      ::StringFromGUID2(guid, buffer, arraysize(buffer));
+      ::StringFromGUID2(guid, buffer, std::size(buffer));
   if (character_length_with_null <= 0) {
     return L"";
   }
@@ -322,7 +321,7 @@ std::wstring GUIDToString(const GUID &guid) {
 
 std::wstring LANGIDToString(LANGID langid) {
   wchar_t buffer[5];
-  HRESULT hr = ::StringCchPrintf(buffer, arraysize(buffer), L"%04x", langid);
+  HRESULT hr = ::StringCchPrintf(buffer, std::size(buffer), L"%04x", langid);
   if (FAILED(hr)) {
     return L"";
   }
@@ -454,7 +453,7 @@ bool GetActiveKeyboardLayouts(std::vector<HKL> *keyboard_layouts) {
   keyboard_layouts->clear();
 
   const int num_keyboard_layout = ::GetKeyboardLayoutList(0, nullptr);
-  unique_ptr<HKL[]> buffer(new HKL[num_keyboard_layout]);
+  std::unique_ptr<HKL[]> buffer(new HKL[num_keyboard_layout]);
   const int num_copied =
       ::GetKeyboardLayoutList(num_keyboard_layout, buffer.get());
   keyboard_layouts->assign(buffer.get(), buffer.get() + num_copied);
@@ -816,7 +815,7 @@ bool UninstallHelper::GetCurrentProfilesForVista(
   {
     const UINT num_element =
         ::EnumEnabledLayoutOrTip(nullptr, nullptr, nullptr, nullptr, 0);
-    unique_ptr<LAYOUTORTIPPROFILE[]> buffer(
+    std::unique_ptr<LAYOUTORTIPPROFILE[]> buffer(
         new LAYOUTORTIPPROFILE[num_element]);
     const UINT num_copied = ::EnumEnabledLayoutOrTip(nullptr, nullptr, nullptr,
                                                      buffer.get(), num_element);
@@ -992,7 +991,7 @@ bool UninstallHelper::RestoreUserIMEEnvironmentMain() {
   // update entries under HKCU.  Assuming the desktop is available,
   // broadcast messages into existing processes so that these processes
   // start to use the new default IME.
-  const bool kBroadcastNewIME = true;
+  constexpr bool kBroadcastNewIME = true;
 
   return RestoreUserIMEEnvironmentForVista(kBroadcastNewIME);
 }
@@ -1015,7 +1014,7 @@ bool UninstallHelper::EnsureIMEIsRemovedForCurrentUser(
   // Since this function is targeting for the service account, IME change
   // notification will not be sent in case it causes unwilling side-effects
   // against other important processes running in the service session.
-  const bool kBroadcastNewIME = false;
+  constexpr bool kBroadcastNewIME = false;
   return RestoreUserIMEEnvironmentForVista(kBroadcastNewIME);
 }
 
