@@ -50,7 +50,6 @@ namespace {
 
 using ATL::CStringW;
 using ATL::CWindow;
-using std::unique_ptr;
 
 std::wstring SafeGetWindowText(HWND window_handle) {
   if (!::IsWindow(window_handle)) {
@@ -63,7 +62,7 @@ std::wstring SafeGetWindowText(HWND window_handle) {
   }
 
   const size_t buffer_len = text_len_without_null + 1;
-  unique_ptr<wchar_t[]> buffer(new wchar_t[buffer_len]);
+  std::unique_ptr<wchar_t[]> buffer(new wchar_t[buffer_len]);
 
   const int copied_len_without_null =
       GetWindowText(window_handle, buffer.get(), buffer_len);
@@ -82,8 +81,8 @@ std::wstring WindowUtil::GetWindowClassName(HWND window_handle) {
   // http://msdn.microsoft.com/en-us/library/ms633576.aspx
   wchar_t buffer[256 + 1] = {};
   const size_t num_copied_without_null =
-      ::GetClassNameW(window_handle, buffer, arraysize(buffer));
-  if (num_copied_without_null + 1 >= arraysize(buffer)) {
+      ::GetClassNameW(window_handle, buffer, std::size(buffer));
+  if (num_copied_without_null + 1 >= std::size(buffer)) {
     return L"";
   }
   return std::wstring(buffer, num_copied_without_null);
@@ -96,7 +95,7 @@ bool WindowUtil::ChangeMessageFilter(HWND window_handle, UINT message) {
 
   // The following constant is not available unless we change the WINVER
   // higher enough.
-  const int kMessageFilterAllow = 1;  // MSGFLT_ALLOW  (WINVER >=0x0601)
+  constexpr int kMessageFilterAllow = 1;  // MSGFLT_ALLOW  (WINVER >=0x0601)
 
   const HMODULE lib = WinUtil::GetSystemModuleHandle(L"user32.dll");
   if (lib == nullptr) {
