@@ -71,24 +71,24 @@
   if (::IsDebuggerPresent()) {                                          \
     __debugbreak();                                                     \
   }
-#else
+#else   // _DEBUG
 #define DEBUG_BREAK_FOR_DEBUGGER()
 #endif  // _DEBUG
 
 namespace {
 
 using mozc::win32::OmahaUtil;
-using std::unique_ptr;
 
-const char kIEFrameDll[] = "ieframe.dll";
+constexpr char kIEFrameDll[] = "ieframe.dll";
 const wchar_t kSystemSharedKey[] = L"Software\\Microsoft\\CTF\\SystemShared";
 
 HMODULE g_module = nullptr;
 
-std::wstring GetMozcComponentPath(const string &filename) {
-  const string path = mozc::SystemUtil::GetServerDirectory() + "\\" + filename;
+std::wstring GetMozcComponentPath(const std::string &filename) {
+  const std::string path =
+      mozc::SystemUtil::GetServerDirectory() + "\\" + filename;
   std::wstring wpath;
-  mozc::Util::UTF8ToWide(path, &wpath);
+  mozc::Util::Utf8ToWide(path, &wpath);
   return wpath;
 }
 
@@ -107,7 +107,7 @@ std::wstring GetProperty(MSIHANDLE msi, const std::wstring &name) {
 
   // add 1 for null termination
   ++num_buf;
-  unique_ptr<wchar_t[]> buf(new wchar_t[num_buf]);
+  std::unique_ptr<wchar_t[]> buf(new wchar_t[num_buf]);
   result = MsiGetProperty(msi, name.c_str(), buf.get(), &num_buf);
   if (ERROR_SUCCESS != result) {
     return L"";
@@ -141,14 +141,14 @@ bool DisableErrorReportingInternal(const wchar_t *key_name,
   }
   return true;
 }
-#endif
+#endif  // MOZC_NO_LOGGING
 
 std::wstring FormatMessageByResourceId(int resourceID, ...) {
   wchar_t format_message[4096];
   {
     const int length = ::LoadString(g_module, resourceID, format_message,
-                                    arraysize(format_message));
-    if (length <= 0 || arraysize(format_message) <= length) {
+                                    std::size(format_message));
+    if (length <= 0 || std::size(format_message) <= length) {
       return L"";
     }
   }
@@ -160,10 +160,10 @@ std::wstring FormatMessageByResourceId(int resourceID, ...) {
   {
     const DWORD num_chars =
         ::FormatMessage(FORMAT_MESSAGE_FROM_STRING, format_message, 0, 0,
-                        &buffer[0], arraysize(buffer), &va_args);
+                        &buffer[0], std::size(buffer), &va_args);
     va_end(va_args);
 
-    if (num_chars == 0 || num_chars >= arraysize(buffer)) {
+    if (num_chars == 0 || num_chars >= std::size(buffer)) {
       return L"";
     }
   }
@@ -179,8 +179,8 @@ std::wstring GetVersionHeader() {
 bool WriteOmahaErrorById(int resource_id) {
   wchar_t buffer[4096];
   const int length =
-      ::LoadString(g_module, resource_id, buffer, arraysize(buffer));
-  if (length <= 0 || arraysize(buffer) <= length) {
+      ::LoadString(g_module, resource_id, buffer, std::size(buffer));
+  if (length <= 0 || std::size(buffer) <= length) {
     return false;
   }
 
@@ -194,7 +194,7 @@ bool WriteOmahaError(const wchar_t (&function)[num_elements], int line) {
   log.Format(L"%s: %s; %s(%d)", L"WriteOmahaError: ",
              mozc::Version::GetMozcVersionW().c_str(), function, line);
   ::OutputDebugStringW(log);
-#endif
+#endif  // !defined(MOZC_NO_LOGGING)
   const std::wstring &message =
       FormatMessageByResourceId(IDS_FORMAT_FUNCTION_AND_LINE, function, line);
   return OmahaUtil::WriteOmahaError(message, GetVersionHeader());
@@ -273,15 +273,15 @@ UINT __stdcall CallIERefreshElevationPolicy(MSIHANDLE msi_handle) {
 // [Return='ignore']
 UINT __stdcall OpenUninstallSurveyPage(MSIHANDLE msi_handle) {
   DEBUG_BREAK_FOR_DEBUGGER();
-  string url;
-  mozc::URL::GetUninstallationSurveyURL(mozc::Version::GetMozcVersion(), &url);
+  std::string url;
+  mozc::Url::GetUninstallationSurveyUrl(mozc::Version::GetMozcVersion(), &url);
   mozc::Process::OpenBrowser(url);
   return ERROR_SUCCESS;
 }
 
 UINT __stdcall ShutdownServer(MSIHANDLE msi_handle) {
   DEBUG_BREAK_FOR_DEBUGGER();
-  unique_ptr<mozc::client::ClientInterface> server_client(
+  std::unique_ptr<mozc::client::ClientInterface> server_client(
       mozc::client::ClientFactory::NewClient());
   bool server_result = true;
   if (server_client->PingServer()) {
@@ -517,7 +517,7 @@ UINT __stdcall RegisterTIP(MSIHANDLE msi_handle) {
   const std::wstring &path = GetMozcComponentPath(mozc::kMozcTIP64);
 #elif defined(_M_IX86)
   const std::wstring &path = GetMozcComponentPath(mozc::kMozcTIP32);
-#else
+#else  // _M_X64, _M_IX86
 #error "Unsupported CPU architecture"
 #endif  // _M_X64, _M_IX86, and others
   HRESULT result =
