@@ -92,7 +92,7 @@ namespace {
     EXPECT_EQ((page_start), (info)->dwPageStart);                       \
   } while (false)
 
-const size_t kNumCandidates = 13;
+constexpr size_t kNumCandidates = 13;
 const char *kValueList[kNumCandidates] = {
     "Beta", "ベータ", "BETA",   "beta",  "β",          "Β",    "㌼",
     "Beta", "べーた", "ベータ", "be-ta", "ｂｅ－ｔａ", "ﾍﾞｰﾀ",
@@ -438,9 +438,9 @@ void FillOutputForConversion(commands::Output *output, int focused_index,
   }
 }
 
-string ToUTF8(const std::wstring &wstr) {
-  string result;
-  Util::WideToUTF8(wstr, &result);
+std::string ToUTF8(const std::wstring &wstr) {
+  std::string result;
+  Util::WideToUtf8(wstr, &result);
   return result;
 }
 }  // namespace
