@@ -60,11 +60,10 @@ namespace win32 {
 using commands::KeyEvent;
 using commands::Output;
 using commands::SessionCommand;
-using std::unique_ptr;
 
 namespace {
 
-const size_t kReconvertStringSizeLimit = 1024 * 64;
+constexpr size_t kReconvertStringSizeLimit = 1024 * 64;
 // An embedded object in the RichEdit will be replaced with this character.
 // See b/3406434 for details.
 const wchar_t kObjectReplacementCharacter = L'\uFFFC';
@@ -175,7 +174,7 @@ bool UpdateCompositionStringAndPushMessages(HIMC himc,
 }
 
 bool GetReconvertString(const RECONVERTSTRING *reconvert_string,
-                        string *total_composition_in_utf8) {
+                        std::string *total_composition_in_utf8) {
   DCHECK(total_composition_in_utf8);
   total_composition_in_utf8->clear();
 
@@ -206,7 +205,7 @@ bool GetReconvertString(const RECONVERTSTRING *reconvert_string,
     return false;
   }
 
-  if ((Util::WideToUTF8(total_composition, total_composition_in_utf8) == 0) ||
+  if ((Util::WideToUtf8(total_composition, total_composition_in_utf8) == 0) ||
       total_composition_in_utf8->empty()) {
     DLOG(INFO) << "Composition string is empty.";
     return false;
@@ -228,7 +227,7 @@ bool QueryDocumentFeed(HIMC himc, std::wstring *preceding_text,
     return false;
   }
 
-  unique_ptr<BYTE[]> buffer(new BYTE[buffer_size]);
+  std::unique_ptr<BYTE[]> buffer(new BYTE[buffer_size]);
 
   RECONVERTSTRING *reconvert_string =
       reinterpret_cast<RECONVERTSTRING *>(buffer.get());
@@ -260,8 +259,8 @@ void ImeCore::UpdateContextWithSurroundingText(HIMC himc,
   if (!QueryDocumentFeed(himc, &preceding_text, &following_text)) {
     return;
   }
-  Util::WideToUTF8(preceding_text, context->mutable_preceding_text());
-  Util::WideToUTF8(following_text, context->mutable_following_text());
+  Util::WideToUtf8(preceding_text, context->mutable_preceding_text());
+  Util::WideToUtf8(following_text, context->mutable_following_text());
 }
 
 KeyEventHandlerResult ImeCore::ImeProcessKey(
@@ -270,7 +269,7 @@ KeyEventHandlerResult ImeCore::ImeProcessKey(
     const InputBehavior &behavior, const InputState &initial_state,
     const mozc::commands::Context &context, InputState *next_state,
     commands::Output *output) {
-  unique_ptr<Win32KeyboardInterface> keyboard(
+  std::unique_ptr<Win32KeyboardInterface> keyboard(
       Win32KeyboardInterface::CreateDefault());
   return KeyEventHandler::ImeProcessKey(
       virtual_key, lparam.GetScanCode(), lparam.IsKeyDownInImeProcessKey(),
@@ -284,7 +283,7 @@ KeyEventHandlerResult ImeCore::ImeToAsciiEx(
     const InputBehavior &behavior, const InputState &initial_state,
     const commands::Context &context, InputState *next_state,
     commands::Output *output) {
-  unique_ptr<Win32KeyboardInterface> keyboard(
+  std::unique_ptr<Win32KeyboardInterface> keyboard(
       Win32KeyboardInterface::CreateDefault());
   return KeyEventHandler::ImeToAsciiEx(
       virtual_key, scan_code, is_key_down, keyboard_status, behavior,
@@ -377,12 +376,12 @@ DWORD ImeCore::GetSupportableConversionMode(DWORD raw_conversion_mode) {
   // If the initial |fdwConversion| is not a supported combination of flags,
   // we have to update it and then send the IMN_SETCONVERSIONMODE message.
   // See b/2914115 for details.
-  const DWORD kHiragana = IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE;
-  const DWORD kFullKatakana =
+  constexpr DWORD kHiragana = IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE;
+  constexpr DWORD kFullKatakana =
       IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE | IME_CMODE_KATAKANA;
-  const DWORD kHalfKatakana = IME_CMODE_NATIVE | IME_CMODE_KATAKANA;
-  const DWORD kFullAlpha = IME_CMODE_ALPHANUMERIC | IME_CMODE_FULLSHAPE;
-  const DWORD kHalfAlpha = IME_CMODE_ALPHANUMERIC;
+  constexpr DWORD kHalfKatakana = IME_CMODE_NATIVE | IME_CMODE_KATAKANA;
+  constexpr DWORD kFullAlpha = IME_CMODE_ALPHANUMERIC | IME_CMODE_FULLSHAPE;
+  constexpr DWORD kHalfAlpha = IME_CMODE_ALPHANUMERIC;
 
   // Separate Roman flag
   DWORD roman_flag = (raw_conversion_mode & IME_CMODE_ROMAN);
@@ -591,8 +590,7 @@ bool ImeCore::UpdateContextMain(HIMC himc, const InputState &next_state,
 
     // Make sure the pending output does not have |deletion_range|.
     // Otherwise, an infinite loop will be created.
-    commands::Output output;
-    output.CopyFrom(new_output);
+    commands::Output output = new_output;
     output.clear_deletion_range();
     private_context->deleter->BeginDeletion(
         new_output.deletion_range().length(), output, next_state);
@@ -600,7 +598,7 @@ bool ImeCore::UpdateContextMain(HIMC himc, const InputState &next_state,
   }
 
   if (new_output.has_consumed()) {
-    private_context->last_output->CopyFrom(new_output);
+    *private_context->last_output = new_output;
   }
 
   *private_context->ime_state = next_state;
@@ -821,7 +819,7 @@ bool ImeCore::TurnOnIMEAndTryToReconvertFromIME(HIMC himc) {
     return false;
   }
 
-  const string &text_utf8 = GetTextForReconversionFromIME(himc);
+  const std::string &text_utf8 = GetTextForReconversionFromIME(himc);
   if (text_utf8.empty()) {
     if (context.GetOpenStatus()) {
       return true;
@@ -846,7 +844,7 @@ bool ImeCore::TurnOnIMEAndTryToReconvertFromIME(HIMC himc) {
   return UpdateInputContext(himc, output, true);
 }
 
-string ImeCore::GetTextForReconversionFromIME(HIMC himc) {
+std::string ImeCore::GetTextForReconversionFromIME(HIMC himc) {
   // Implementation Note:
   // In order to implement IMM32 reconversion, IME is responsible to update
   // the following fields in RECONVERTSTRING.
@@ -871,7 +869,7 @@ string ImeCore::GetTextForReconversionFromIME(HIMC himc) {
     return "";
   }
 
-  unique_ptr<BYTE[]> buffer(new BYTE[buffer_size]);
+  std::unique_ptr<BYTE[]> buffer(new BYTE[buffer_size]);
 
   RECONVERTSTRING *reconvert_string =
       reinterpret_cast<RECONVERTSTRING *>(buffer.get());
@@ -885,7 +883,7 @@ string ImeCore::GetTextForReconversionFromIME(HIMC himc) {
     return "";
   }
 
-  unique_ptr<BYTE[]> copied_buffer(new BYTE[buffer_size]);
+  std::unique_ptr<BYTE[]> copied_buffer(new BYTE[buffer_size]);
   for (size_t i = 0; i < buffer_size; ++i) {
     copied_buffer[i] = buffer[i];
   }
@@ -905,7 +903,7 @@ string ImeCore::GetTextForReconversionFromIME(HIMC himc) {
     reconvert_string = expanded_reconvert_string;
   }
 
-  string total_composition_utf8;
+  std::string total_composition_utf8;
   if (!GetReconvertString(reconvert_string, &total_composition_utf8)) {
     return "";
   }
@@ -923,7 +921,7 @@ bool ImeCore::QueryReconversionFromApplication(
     return false;
   }
 
-  string total_composition_utf8;
+  std::string total_composition_utf8;
   if (!GetReconvertString(composition_info, &total_composition_utf8)) {
     return false;
   }
@@ -957,7 +955,7 @@ bool ImeCore::ReconversionFromApplication(
     return false;
   }
 
-  string total_composition_utf8;
+  std::string total_composition_utf8;
   if (!GetReconvertString(composition_info, &total_composition_utf8)) {
     return false;
   }
