@@ -79,7 +79,7 @@ bool g_in_safe_mode = true;
 bool g_fundamental_data_is_not_available = false;
 
 // TLS index for context update count. See b/3282221 for details.
-const DWORD kInvalidTlsIndex = 0xffffffff;
+constexpr DWORD kInvalidTlsIndex = 0xffffffff;
 DWORD g_context_revision_tls_index = kInvalidTlsIndex;
 
 // Breakpad never be enabled except for official builds.
@@ -93,7 +93,7 @@ DWORD g_context_revision_tls_index = kInvalidTlsIndex;
 CRITICAL_SECTION g_critical_section_for_breakpad;
 // 4,000 is a typical value of per-heap critical sections.
 // See http://msdn.microsoft.com/en-us/library/ms683476.aspx
-const int kSpinCountForCriticalSection = 4000;
+constexpr int kSpinCountForCriticalSection = 4000;
 #endif  // USE_BREAKPAD
 
 // True if the DLL received DLL_PROCESS_DETACH notification as a result of
@@ -116,13 +116,13 @@ bool g_process_is_shutting_down = false;
     }                                        \
   } while (false)
 
-static_assert(arraysize(mozc::kIMEUIWndClassName) <=
+static_assert(std::size(mozc::kIMEUIWndClassName) <=
                   mozc::kIMEUIwndClassNameLimitInTchars,
               "Window Class Name has length limit.");
 
 // Maximum number of characters for |REGISTERWORD::lpWord| and
 // |REGISTERWORD::lpReading|.
-const size_t kMaxCharsForRegisterWord = 64;
+constexpr size_t kMaxCharsForRegisterWord = 64;
 
 // If given string is too long, returns an empty string instead.
 std::wstring GetStringIfWithinLimit(const wchar_t *src, size_t size_limit) {
@@ -141,9 +141,9 @@ void SetEnveronmentVariablesForWordRegisterDialog(
     const std::wstring &word_value, const std::wstring &word_reading) {
   std::wstring word_value_env_name;
   std::wstring word_reading_env_name;
-  mozc::Util::UTF8ToWide(mozc::kWordRegisterEnvironmentName,
+  mozc::Util::Utf8ToWide(mozc::kWordRegisterEnvironmentName,
                          &word_value_env_name);
-  mozc::Util::UTF8ToWide(mozc::kWordRegisterEnvironmentReadingName,
+  mozc::Util::Utf8ToWide(mozc::kWordRegisterEnvironmentReadingName,
                          &word_reading_env_name);
 
   if (word_value.empty()) {
@@ -398,7 +398,7 @@ LRESULT WINAPI ImeEscape(HIMC himc, UINT sub_func, LPVOID data) {
       // than or equal to 64 characters in Windows NT.
       // http://msdn.microsoft.com/en-us/library/dd318166.aspx
       std::wstring name;
-      mozc::Util::UTF8ToWide(mozc::kProductNameInEnglish, &name);
+      mozc::Util::Utf8ToWide(mozc::kProductNameInEnglish, &name);
       wchar_t *dest = static_cast<wchar_t *>(data);
       const HRESULT result =
           ::StringCchCopyN(dest, mozc::kSafeIMENameLengthForNTInTchars,
@@ -565,7 +565,7 @@ BOOL WINAPI ImeProcessKey(HIMC himc, UINT virtual_key, LPARAM lParam,
   *private_context->ime_state = next_state;
 
   if (result.should_be_sent_to_server && temporal_output.has_consumed()) {
-    private_context->last_output->CopyFrom(temporal_output);
+    *private_context->last_output = temporal_output;
   }
 
   const mozc::win32::IndicatorVisibilityTracker::Action indicator_action =
@@ -966,7 +966,7 @@ UINT WINAPI ImeToAsciiEx(UINT virtual_key, UINT scan_code,
   bool should_be_sent_to_server = false;
   if (use_pending_status) {
     next_state = private_context->deleter->pending_ime_state();
-    temporal_output.CopyFrom(private_context->deleter->pending_output());
+    temporal_output = private_context->deleter->pending_output();
     should_be_sent_to_server = true;
   } else {
     mozc::win32::InputBehavior behavior = *private_context->ime_behavior;
