@@ -62,17 +62,17 @@ using ::WTL::CSize;
 using ::mozc::WinUtil;
 using ::mozc::win32::TextIcon;
 
-const int kDefaultDPI = 96;
+constexpr int kDefaultDPI = 96;
 
 // Represents the cookie for the sink to an ImeLangBarItem object.
-const int kImeLangBarMenuCookie =
+constexpr int kImeLangBarMenuCookie =
     (('M' << 24) | ('o' << 16) | ('z' << 8) | ('c' << 0));
 
-const char kTextIconFont[] = "ＭＳ ゴシック";
+constexpr char kTextIconFont[] = "ＭＳ ゴシック";
 
 // TODO(yukawa): Refactor LangBar code so that we can configure following
 // settings as a part of initialization.
-string GetIconStringIfNecessary(UINT icon_id) {
+std::string GetIconStringIfNecessary(UINT icon_id) {
   switch (icon_id) {
     case IDI_DIRECT_NT:
       return "A";
@@ -87,7 +87,7 @@ string GetIconStringIfNecessary(UINT icon_id) {
     case IDI_HALF_KATAKANA_NT:
       return "_ｱ";
   }
-  return string();
+  return "";
 }
 
 // Loads an icon which is appropriate for the current theme.
@@ -192,7 +192,7 @@ HRESULT ImeLangBarMenuDataArray::Init(HINSTANCE instance,
     if ((menu[i].flags_ & TF_LBMENUF_SEPARATOR) == 0) {
       // Retrieve the menu text and button icon.
       length = ::LoadString(instance, menu[i].text_id_, &data.text_[0],
-                            arraysize(data.text_));
+                            std::size(data.text_));
     }
     data.flags_ = menu[i].flags_;
     data.menu_id_ = menu[i].menu_id_;
@@ -350,7 +350,7 @@ HRESULT ImeLangBarMenu::Init(HINSTANCE instance, int string_id,
   // Retrieve the text label from the resource.
   // This string is also used as a tool-tip text.
   ::LoadString(instance, string_id, &item_info_.szDescription[0],
-               arraysize(item_info_.szDescription));
+               std::size(item_info_.szDescription));
 
   // Create a new ImeLangBarMenuItem object.
   menu_data_.Init(instance, menu, count);
