@@ -68,6 +68,7 @@
 #include "win32/ime/ime_types.h"
 #include "win32/ime/ime_ui_context.h"
 #include "win32/ime/ime_ui_visibility_tracker.h"
+#include "absl/base/call_once.h"
 
 namespace mozc {
 namespace win32 {
@@ -80,7 +81,6 @@ using WTL::CPoint;
 using WTL::CRect;
 
 using ::mozc::renderer::win32::Win32RendererClient;
-using ::std::unique_ptr;
 
 // True if the DLL received DLL_PROCESS_DETACH notification.
 volatile bool g_module_unloaded = false;
@@ -95,8 +95,8 @@ volatile bool g_module_unloaded = false;
     }                                        \
   } while (false)
 
-// A global variable of mozc::once_t, which is POD, has no bad side effect.
-static once_t g_launch_set_default_dialog = MOZC_ONCE_INIT;
+// absl::once_flag can be allocated as a global variable.
+absl::once_flag g_launch_set_default_dialog;
 
 void LaunchSetDefaultDialog() {
   config::Config config;
@@ -344,7 +344,7 @@ class LangBarCallbackImpl : public LangBarCallback {
 
   virtual ULONG AddRef() {
     const LONG count = ::InterlockedIncrement(&reference_count_);
-    return static_cast<ULONG>(std::max(count, static_cast<LONG>(0)));
+    return static_cast<ULONG>(std::max<LONG>(count, 0));
   }
 
   virtual ULONG Release() {
@@ -446,13 +446,15 @@ class LangBarCallbackImpl : public LangBarCallback {
       }
       case LangBarCallback::kHelp: {
         // Open the about dialog.
-        const char kHelpUrl[] = "http://www.google.com/support/ime/japanese";
+        constexpr char kHelpUrl[] =
+            "http://www.google.com/support/ime/japanese";
         if (!mozc::Process::OpenBrowser(kHelpUrl)) {
           result = E_FAIL;
         }
         break;
       }
-      default: { break; }
+      default:
+        break;
     }
     return result;
   }
@@ -651,7 +653,7 @@ class DefaultUIWindow {
     // SetDefaultDialog.
     if (context.ui_visibility_tracker()->IsSuggestWindowVisible()) {
       if (!IsProcessSandboxed() && RunLevel::IsValidClientRunLevel()) {
-        CallOnce(&g_launch_set_default_dialog, &LaunchSetDefaultDialog);
+        absl::call_once(g_launch_set_default_dialog, &LaunchSetDefaultDialog);
       }
     }
   }
@@ -691,7 +693,7 @@ class DefaultUIWindow {
         }
       }  // release |context|.
 
-      const int kCandidateWindowIndex = 0;
+      constexpr int kCandidateWindowIndex = 0;
       if (::ImmNotifyIME(himc, NI_SELECTCANDIDATESTR, kCandidateWindowIndex,
                          candidate_index) == FALSE) {
         return 0;
@@ -790,7 +792,7 @@ class DefaultUIWindow {
  private:
   // Timer for the langbar update.
   static const UINT_PTR kDeferredLangBarUpdateTimerId = 2;
-  static const DWORD kLangBarUpdateDelayMilliSec = 50;
+  static constexpr DWORD kLangBarUpdateDelayMilliSec = 50;
 
   enum LangBarUpdateMode {
     kDeferred = 0,
@@ -950,7 +952,7 @@ class DefaultUIWindow {
   HWND hwnd_;
   // TODO(yukawa): Make a wrapper class to encapsulate LangBar implementation
   // including cache mechanism to reduce API calls.
-  unique_ptr<LanguageBar> language_bar_;
+  std::unique_ptr<LanguageBar> language_bar_;
   LangBarCallbackImpl *langbar_callback_;
   // Represents the LangBarInfo that should be set to the LangBar when deferred
   // timer is fired.
@@ -959,7 +961,7 @@ class DefaultUIWindow {
   bool has_pending_langbar_update_;
   // Represents the last LangBarInfo that is set to the LangBar. nullpter if
   // no cached data is available.
-  unique_ptr<LangBarInfo> langbar_info_cache_;
+  std::unique_ptr<LangBarInfo> langbar_info_cache_;
 
   DISALLOW_COPY_AND_ASSIGN(DefaultUIWindow);
 };
