@@ -39,7 +39,6 @@ __author__ = "yukawa"
 
 import optparse
 import os
-import re
 import subprocess
 import sys
 
@@ -60,6 +59,30 @@ def ParseOption():
   return opts
 
 
+def PostProcessOnWindows(opts):
+  """Apply post-processes for Windows binaries.
+
+  Update the specified executable to be 'release quality' by
+  - bind import functions by bind.exe
+  - Set 'freeze' bit in the PE header.
+  - Code signing.
+  See the following issues for details.
+    http://b/1504561, http://b/1507272, http://b/2289857, http://b/1893852
+
+  Args:
+    opts: build options to be used to update the executable.
+  """
+  abs_target_path = os.path.abspath(opts.targetpath)
+  abs_touch_file_path = abs_target_path + '.postbuild'
+
+  # If the target looks like a PE image, update it.
+  (_, extension) = os.path.splitext(opts.targetpath)
+  if extension.lower() in ['.exe', '.dll', '.ime']:
+    # Protect it against further binding, which invalidates code signing.
+    RunOrDie(['editbin.exe', '/ALLOWBIND:NO', '/RELEASE', abs_target_path])
+
+  Codesign(abs_target_path)
+
   # Touch the timestamp file.
   if os.path.exists(abs_touch_file_path):
     os.utime(abs_touch_file_path, None)
@@ -67,6 +90,13 @@ def ParseOption():
     open(abs_touch_file_path, 'w').close()
 
 
+def Codesign(abs_target_path):
+  """Codesign the target path."""
+  signtool = (
+      r'C:\Program Files (x86)\Microsoft SDKs\ClickOnce\SignTool\signtool.exe')
+  # Do nothing for OSS build.
+
+
 class RunOrDieError(Exception):
   """The exception class for RunOrDie."""
 
@@ -90,8 +120,8 @@ def RunOrDie(argv):
     raise RunOrDieError('\n'.join(['',
                                    '==========',
                                    ' ERROR: %s' % ' '.join(argv),
-                                   ' Stdout', out,
-                                   ' Stderr', err,
+                                   ' Stdout', out.decode('utf-8'),
+                                   ' Stderr', err.decode('utf-8'),
                                    '==========']))
 
 
