@@ -75,7 +75,7 @@ typedef ::mozc::commands::Preedit::Segment::Annotation Annotation;
 namespace {
 
 HRESULT SetReadingProperties(ITfContext *context, ITfRange *range,
-                             const string &reading_string_utf8,
+                             const std::string &reading_string_utf8,
                              TfEditCookie write_cookie) {
   HRESULT result = S_OK;
 
@@ -177,7 +177,7 @@ CComPtr<ITfComposition> CommitText(TipTextService *text_service,
   }
 
   std::wstring result_text;
-  Util::UTF8ToWide(output.result().value(), &result_text);
+  Util::Utf8ToWide(output.result().value(), &result_text);
 
   std::wstring composition_text;
   TipRangeUtil::GetText(composition_range, write_cookie, &composition_text);
@@ -366,7 +366,7 @@ HRESULT UpdateComposition(TipTextService *text_service, ITfContext *context,
 
   // Update cursor.
   {
-    string preedit_text;
+    std::string preedit_text;
     for (int i = 0; i < preedit.segment_size(); ++i) {
       preedit_text += preedit.segment(i).value();
     }
@@ -408,7 +408,7 @@ HRESULT UpdatePrivateContext(TipTextService *text_service, ITfContext *context,
   if (private_context == nullptr) {
     return S_FALSE;
   }
-  private_context->mutable_last_output()->CopyFrom(output);
+  *private_context->mutable_last_output() = output;
   if (!output.has_status()) {
     return S_FALSE;
   }
