@@ -69,7 +69,6 @@ namespace tsf {
 using ATL::CComPtr;
 using mozc::commands::Context;
 using mozc::commands::Output;
-using std::unique_ptr;
 typedef mozc::commands::CompositionMode CompositionMode;
 typedef mozc::commands::SessionCommand SessionCommand;
 
@@ -93,7 +92,7 @@ VirtualKey GetVK(WPARAM wparam, const KeyboardStatus &keyboad_status) {
   const UINT scan_code = ::MapVirtualKey(wparam, MAPVK_VK_TO_VSC);
   wchar_t buffer[4] = {};
   if (::ToUnicode(wparam, scan_code, keyboad_status.status(), buffer,
-                  arraysize(buffer), 0) != 1) {
+                  std::size(buffer), 0) != 1) {
     return VirtualKey::FromVirtualKey(wparam);
   }
   const uint32 ucs2 = buffer[0];
@@ -268,7 +267,7 @@ HRESULT OnTestKey(TipTextService *text_service, ITfContext *context,
 
   InputState next_state;
   commands::Output temporal_output;
-  unique_ptr<Win32KeyboardInterface> keyboard(
+  std::unique_ptr<Win32KeyboardInterface> keyboard(
       Win32KeyboardInterface::CreateDefault());
 
   const KeyEventHandlerResult result = KeyEventHandler::ImeProcessKey(
@@ -283,7 +282,7 @@ HRESULT OnTestKey(TipTextService *text_service, ITfContext *context,
   *private_context->mutable_last_down_key() = next_state.last_down_key;
 
   if (result.should_be_sent_to_server && temporal_output.has_consumed()) {
-    private_context->mutable_last_output()->CopyFrom(temporal_output);
+    *private_context->mutable_last_output() = temporal_output;
   }
   const TipInputModeManager::Action action =
       text_service->GetThreadContext()->GetInputModeManager()->OnTestKey(
@@ -308,13 +307,13 @@ void FillMozcContextForOnKey(TipTextService *text_service, ITfContext *context,
     return;
   }
   if (info.has_preceding_text) {
-    string utf8_preceding_text;
-    Util::WideToUTF8(info.preceding_text, &utf8_preceding_text);
+    std::string utf8_preceding_text;
+    Util::WideToUtf8(info.preceding_text, &utf8_preceding_text);
     mozc_context->set_preceding_text(utf8_preceding_text);
   }
   if (info.has_following_text) {
-    string utf8_following_text;
-    Util::WideToUTF8(info.following_text, &utf8_following_text);
+    std::string utf8_following_text;
+    Util::WideToUtf8(info.following_text, &utf8_following_text);
     mozc_context->set_following_text(utf8_following_text);
   }
 }
@@ -449,7 +448,7 @@ HRESULT OnKey(TipTextService *text_service, ITfContext *context,
     KeyEventHandler::UpdateBehaviorInImeProcessKey(
         vk, is_key_down, ime_state, private_context->mutable_input_behavior());
 
-    unique_ptr<Win32KeyboardInterface> keyboard(
+    std::unique_ptr<Win32KeyboardInterface> keyboard(
         Win32KeyboardInterface::CreateDefault());
 
     Context mozc_context;
@@ -491,8 +490,8 @@ HRESULT OnKey(TipTextService *text_service, ITfContext *context,
   return S_OK;
 }
 
-const bool kKeyDown = true;
-const bool kKeyUp = false;
+constexpr bool kKeyDown = true;
+constexpr bool kKeyUp = false;
 
 }  // namespace
 
