@@ -107,7 +107,7 @@ const GUID kTipLangBarItem_HelpMenu = {
 
 #endif
 
-const bool kShowInTaskbar = true;
+constexpr bool kShowInTaskbar = true;
 
 CComPtr<ITfLangBarItemMgr> GetLangBarItemMgr() {
   // "msctf.dll" is not always available.  For example, Windows XP can disable
@@ -217,7 +217,7 @@ HRESULT TipLangBar::InitLangBar(TipLangBarCallback *text_service) {
          0},
     };
 
-    const bool kMenuButton = true;
+    constexpr bool kMenuButton = true;
     CComPtr<TipLangBarToggleButton> input_button_menu(
         new TipLangBarToggleButton(text_service, kTipLangBarItem_Button,
                                    kMenuButton, kShowInTaskbar));
@@ -227,7 +227,7 @@ HRESULT TipLangBar::InitLangBar(TipLangBarCallback *text_service) {
 
     result = input_button_menu->Init(TipDllModule::module_handle(),
                                      IDS_INPUTMODE, &kInputMenu[0],
-                                     arraysize(kInputMenu), kInputMenuDisabled);
+                                     std::size(kInputMenu), kInputMenuDisabled);
     if (result != S_OK) {
       return result;
     }
@@ -265,7 +265,7 @@ HRESULT TipLangBar::InitLangBar(TipLangBarCallback *text_service) {
         {kTipLangBarItemTypeDefault, TipLangBarCallback::kHelp, IDS_HELP, 0, 0},
     };
 
-    const bool kNonMenuButton = false;
+    constexpr bool kNonMenuButton = false;
     CComPtr<TipLangBarToggleButton> input_mode_menu(new TipLangBarToggleButton(
         text_service, kSystemInputMode, kNonMenuButton, kShowInTaskbar));
     if (input_mode_menu == nullptr) {
@@ -274,7 +274,7 @@ HRESULT TipLangBar::InitLangBar(TipLangBarCallback *text_service) {
 
     result = input_mode_menu->Init(TipDllModule::module_handle(),
                                    IDS_WIN8_TRAY_ITEM, kInputMenu,
-                                   arraysize(kInputMenu), kInputMenuDisabled);
+                                   std::size(kInputMenu), kInputMenuDisabled);
     if (FAILED(result)) {
       return result;
     }
@@ -308,7 +308,7 @@ HRESULT TipLangBar::InitLangBar(TipLangBarCallback *text_service) {
     }
 
     result = tool_button->Init(TipDllModule::module_handle(), IDS_TOOL,
-                               &kToolMenu[0], arraysize(kToolMenu), IDI_TOOL_NT,
+                               &kToolMenu[0], std::size(kToolMenu), IDI_TOOL_NT,
                                IDI_TOOL);
     if (result != S_OK) {
       return result;
@@ -331,7 +331,7 @@ HRESULT TipLangBar::InitLangBar(TipLangBarCallback *text_service) {
     }
 
     result = help_menu->Init(TipDllModule::module_handle(), &kHelpMenu[0],
-                             arraysize(kHelpMenu));
+                             std::size(kHelpMenu));
     if (result != S_OK) {
       return result;
     }
