@@ -63,17 +63,17 @@ using WTL::CMenu;
 using WTL::CMenuItemInfo;
 using WTL::CSize;
 
-const int kDefaultDPI = 96;
+constexpr int kDefaultDPI = 96;
 
 // Represents the cookie for the sink to an TipLangBarButton object.
-const int kTipLangBarMenuCookie =
+constexpr int kTipLangBarMenuCookie =
     (('M' << 24) | ('o' << 16) | ('z' << 8) | ('c' << 0));
 
-const char kTextIconFont[] = "ＭＳ ゴシック";
+constexpr char kTextIconFont[] = "ＭＳ ゴシック";
 
 // TODO(yukawa): Refactor LangBar code so that we can configure following
 // settings as a part of initialization.
-string GetIconStringIfNecessary(UINT icon_id) {
+std::string GetIconStringIfNecessary(UINT icon_id) {
   switch (icon_id) {
     case IDI_DIRECT_NT:
       return "A";
@@ -88,7 +88,7 @@ string GetIconStringIfNecessary(UINT icon_id) {
     case IDI_HALF_KATAKANA_NT:
       return "_ｱ";
   }
-  return string();
+  return "";
 }
 
 // Loads an icon which is appropriate for the current theme.
@@ -191,7 +191,7 @@ HRESULT TipLangBarMenuDataArray::Init(HINSTANCE instance,
     if ((menu[i].flags_ & TF_LBMENUF_SEPARATOR) == 0) {
       // Retrieve the menu text and button icon.
       length = ::LoadString(instance, menu[i].text_id_, &data.text_[0],
-                            arraysize(data.text_));
+                            std::size(data.text_));
     }
     data.flags_ = menu[i].flags_;
     data.item_id_ = menu[i].item_id_;
@@ -359,8 +359,8 @@ STDMETHODIMP TipLangBarButton::OnClick(TfLBIClick click, POINT point,
   // Caveats: TPM_NONOTIFY is important because the attached window may
   // change the menu state unless this flag is specified. We actually suffered
   // from this issue with Internet Explorer 10 on Windows 8. b/10217103.
-  const DWORD kMenuFlags = TPM_NONOTIFY | TPM_RETURNCMD | TPM_LEFTALIGN |
-                           TPM_TOPALIGN | TPM_LEFTBUTTON;
+  constexpr DWORD kMenuFlags = TPM_NONOTIFY | TPM_RETURNCMD | TPM_LEFTALIGN |
+                               TPM_TOPALIGN | TPM_LEFTBUTTON;
   const BOOL result =
       menu.TrackPopupMenu(kMenuFlags, point.x, point.y, ::GetFocus());
   if (!result) {
@@ -426,7 +426,7 @@ HRESULT TipLangBarButton::Init(HINSTANCE instance, int string_id,
   // Retrieve the text label from the resource.
   // This string is also used as a tool-tip text.
   ::LoadString(instance, string_id, &item_info_.szDescription[0],
-               arraysize(item_info_.szDescription));
+               std::size(item_info_.szDescription));
 
   // Create a new TipLangBarMenuItem object.
   menu_data_.Init(instance, menu, count);
@@ -534,7 +534,7 @@ STDMETHODIMP TipLangBarButton::QueryInterfaceBase(REFIID interface_id,
 }
 
 void TipLangBarButton::SetDescription(const std::wstring &description) {
-  ::StringCchCopy(item_info_.szDescription, arraysize(item_info_.szDescription),
+  ::StringCchCopy(item_info_.szDescription, std::size(item_info_.szDescription),
                   description.c_str());
 }
 
@@ -817,8 +817,8 @@ HRESULT TipLangBarToggleButton::Init(
   if (SUCCEEDED(array.Init(instance, &menu_for_disabled, 1))) {
     menu_data_for_disabled_ = *array.data(0);
   }
-  wchar_t buffer[arraysize(menu_data_for_disabled_.text_)];
-  ::LoadString(instance, string_id, buffer, arraysize(buffer));
+  wchar_t buffer[ABSL_ARRAYSIZE(menu_data_for_disabled_.text_)];
+  ::LoadString(instance, string_id, buffer, std::size(buffer));
   description_for_enabled_ = buffer;
   return TipLangBarButton::Init(instance, string_id, menu, count);
 }
