@@ -43,7 +43,6 @@ using ::mozc::commands::Input;
 using ::mozc::commands::KeyEvent;
 using ::mozc::commands::Output;
 using ::mozc::commands::SessionCommand;
-using ::std::unique_ptr;
 
 namespace mozc {
 namespace win32 {
@@ -69,8 +68,8 @@ class TipQueryProviderImpl : public TipQueryProvider {
                    std::vector<std::wstring> *result) {
     {
       KeyEvent key_event;
-      string utf8_query;
-      Util::WideToUTF8(query, &utf8_query);
+      std::string utf8_query;
+      Util::WideToUtf8(query, &utf8_query);
       key_event.set_key_string(utf8_query);
       key_event.set_activated(true);
       Output output;
@@ -87,7 +86,7 @@ class TipQueryProviderImpl : public TipQueryProvider {
       for (size_t i = 0; i < candidates.candidates_size(); ++i) {
         const auto &utf8 = candidates.candidates(i).value();
         std::wstring wide;
-        Util::UTF8ToWide(utf8, &wide);
+        Util::Utf8ToWide(utf8, &wide);
         result->push_back(wide);
       }
     }
@@ -103,8 +102,8 @@ class TipQueryProviderImpl : public TipQueryProvider {
   bool ReconvertQuery(const std::wstring &query,
                       std::vector<std::wstring> *result) {
     {
-      string utf8_query;
-      Util::WideToUTF8(query, &utf8_query);
+      std::string utf8_query;
+      Util::WideToUtf8(query, &utf8_query);
       SessionCommand command;
       command.set_type(SessionCommand::CONVERT_REVERSE);
 
@@ -117,7 +116,7 @@ class TipQueryProviderImpl : public TipQueryProvider {
       for (size_t i = 0; i < candidates.candidates_size(); ++i) {
         const auto &utf8 = candidates.candidates(i).value();
         std::wstring wide;
-        Util::UTF8ToWide(utf8, &wide);
+        Util::Utf8ToWide(utf8, &wide);
         result->push_back(wide);
       }
     }
@@ -131,7 +130,7 @@ class TipQueryProviderImpl : public TipQueryProvider {
   }
 
   TipRefCount ref_count_;
-  unique_ptr<client::ClientInterface> client_;
+  std::unique_ptr<client::ClientInterface> client_;
 
   DISALLOW_COPY_AND_ASSIGN(TipQueryProviderImpl);
 };
@@ -142,7 +141,7 @@ TipQueryProvider::~TipQueryProvider() {}
 
 // static
 TipQueryProvider *TipQueryProvider::Create() {
-  unique_ptr<ClientInterface> client(ClientFactory::NewClient());
+  std::unique_ptr<ClientInterface> client(ClientFactory::NewClient());
   if (!client->EnsureSession()) {
     return nullptr;
   }
