@@ -100,8 +100,8 @@ const UINT kUpdateUIMessage = WM_USER;
 
 #ifdef GOOGLE_JAPANESE_INPUT_BUILD
 
-const char kHelpUrl[] = "http://www.google.com/support/ime/japanese";
-const char kLogFileName[] = "GoogleJapaneseInput_tsf_ui.log";
+constexpr char kHelpUrl[] = "http://www.google.com/support/ime/japanese";
+constexpr char kLogFileName[] = "GoogleJapaneseInput_tsf_ui.log";
 const wchar_t kTaskWindowClassName[] =
     L"Google Japanese Input Task Message Window";
 
@@ -135,8 +135,8 @@ const GUID kTipFunctionProvider = {
 
 #else
 
-const char kHelpUrl[] = "https://github.com/google/mozc";
-const char kLogFileName[] = "Mozc_tsf_ui.log";
+constexpr char kHelpUrl[] = "https://github.com/google/mozc";
+constexpr char kLogFileName[] = "Mozc_tsf_ui.log";
 const wchar_t kTaskWindowClassName[] = L"Mozc Immersive Task Message Window";
 
 // {F16B7D92-84B0-4AC6-A35B-06EA77180A18}
@@ -169,7 +169,7 @@ const GUID kTipFunctionProvider = {
 
 #endif
 
-HRESULT SpawnTool(const string &command) {
+HRESULT SpawnTool(const std::string &command) {
   if (!Process::SpawnMozcProcess(kMozcTool, "--mode=" + command)) {
     return E_FAIL;
   }
@@ -196,7 +196,7 @@ commands::CompositionMode GetMozcMode(TipLangBarCallback::ItemId menu_id) {
   }
 }
 
-string GetMozcToolCommand(TipLangBarCallback::ItemId menu_id) {
+std::string GetMozcToolCommand(TipLangBarCallback::ItemId menu_id) {
   switch (menu_id) {
     case TipLangBarCallback::kProperty:
       // Open the config dialog.
@@ -251,9 +251,9 @@ struct CComPtrHash {
     // Caveats: On x86 environment, both _M_X64 and _M_IX86 are defined. So we
     //     need to check _M_X64 first.
 #if defined(_M_X64)
-    const size_t kUnusedBits = 3;  // assuming 8-byte aligned
+    constexpr size_t kUnusedBits = 3;  // assuming 8-byte aligned
 #elif defined(_M_IX86)
-    const size_t kUnusedBits = 2;  // assuming 4-byte aligned
+    constexpr size_t kUnusedBits = 2;  // assuming 4-byte aligned
 #else
 #error "unsupported platform"
 #endif
@@ -360,7 +360,7 @@ const PreserveKeyItem kPreservedKeyItems[] = {
      {VK_OEM_3, TF_MOD_ALT},
      VK_OEM_3,
      &kTipKeyTilde[0],
-     arraysize(kTipKeyTilde) - 1},
+     std::size(kTipKeyTilde) - 1},
     {kTipPreservedKey_Kanji,
      {VK_KANJI, TF_MOD_IGNORE_ALL_MODIFIER},
      // KeyEventHandler maps VK_KANJI to KeyEvent::NO_SPECIALKEY instead of
@@ -369,22 +369,22 @@ const PreserveKeyItem kPreservedKeyItems[] = {
      // b/7970379 about what happened.
      VK_DBE_DBCSCHAR,
      &kTipKeyKanji[0],
-     arraysize(kTipKeyKanji) - 1},
+     std::size(kTipKeyKanji) - 1},
     {kTipPreservedKey_Romaji,
      {VK_DBE_ROMAN, TF_MOD_IGNORE_ALL_MODIFIER},
      VK_DBE_ROMAN,
      &kTipKeyRoman[0],
-     arraysize(kTipKeyRoman) - 1},
+     std::size(kTipKeyRoman) - 1},
     {kTipPreservedKey_Romaji,
      {VK_DBE_NOROMAN, TF_MOD_IGNORE_ALL_MODIFIER},
      VK_DBE_NOROMAN,
      &kTipKeyNoRoman[0],
-     arraysize(kTipKeyNoRoman) - 1},
+     std::size(kTipKeyNoRoman) - 1},
     {kTipPreservedKey_F10,
      {VK_F10, 0},
      VK_F10,
      &kTipKeyF10[0],
-     arraysize(kTipKeyF10) - 1},
+     std::size(kTipKeyF10) - 1},
 };
 
 class UpdateUiEditSessionImpl : public ITfEditSession {
@@ -1451,7 +1451,7 @@ class TipTextServiceImpl : public ITfTextInputProcessorEx,
     if (FAILED(result)) {
       return result;
     }
-    for (size_t i = 0; i < arraysize(kPreservedKeyItems); ++i) {
+    for (size_t i = 0; i < std::size(kPreservedKeyItems); ++i) {
       const PreserveKeyItem &item = kPreservedKeyItems[i];
       // Register a hot key to the keystroke manager.
       result = keystroke->PreserveKey(client_id_, item.guid, &item.key,
@@ -1475,7 +1475,7 @@ class TipTextServiceImpl : public ITfTextInputProcessorEx,
       return result;
     }
 
-    for (size_t i = 0; i < arraysize(kPreservedKeyItems); ++i) {
+    for (size_t i = 0; i < std::size(kPreservedKeyItems); ++i) {
       result = keystroke->UnpreserveKey(kPreservedKeyItems[i].guid,
                                         &kPreservedKeyItems[i].key);
     }
