@@ -67,7 +67,7 @@ using ::mozc::commands::Output;
 using ::mozc::commands::Status;
 typedef mozc::commands::RendererCommand_IndicatorInfo IndicatorInfo;
 
-const size_t kPageSize = 9;
+constexpr size_t kPageSize = 9;
 
 // This GUID is used in Windows Vista/7/8 by MS-IME to represents if the
 // candidate window is visible or not.
@@ -109,7 +109,7 @@ const GUID KGuidIndicatorWindow = {
     0x4ff9,
     {0x9d, 0xea, 0x43, 0x2d, 0x8, 0xdc, 0xb0, 0xff}};
 
-#else
+#else  // GOOGLE_JAPANESE_INPUT_BUILD
 
 // {AD2489FB-D4C4-4632-85A9-7F9F917AB0FD}
 const GUID KGuidNonobservableSuggestWindow = {
@@ -141,8 +141,8 @@ CComBSTR GetResourceString(UINT resource_id) {
   return CComBSTR(str.GetLength(), str.GetBuffer());
 }
 
-const bool kIsIndicator = true;
-const bool kIsNotIndicator = false;
+constexpr bool kIsIndicator = true;
+constexpr bool kIsNotIndicator = false;
 
 class TipUiElementDelegateImpl : public TipUiElementDelegate {
  public:
@@ -346,7 +346,7 @@ class TipUiElementDelegateImpl : public TipUiElementDelegate {
       return E_FAIL;
     }
     std::wstring wide_text;
-    Util::UTF8ToWide(list.candidates(visible_index).value(), &wide_text);
+    Util::Utf8ToWide(list.candidates(visible_index).value(), &wide_text);
     *text = CComBSTR(wide_text.size(), wide_text.data()).Detach();
     return S_OK;
   }
@@ -525,13 +525,13 @@ class TipUiElementDelegateImpl : public TipUiElementDelegate {
     }
     const CandidateList &list = output.all_candidate_words();
     if (last_candidate_list_.candidates_size() != list.candidates_size()) {
-      last_candidate_list_.CopyFrom(list);
+      last_candidate_list_ = list;
       return true;
     }
     for (int i = 0; i < list.candidates_size(); ++i) {
       if (last_candidate_list_.candidates(i).value() !=
           list.candidates(i).value()) {
-        last_candidate_list_.CopyFrom(list);
+        last_candidate_list_ = list;
         return true;
       }
     }
