@@ -74,7 +74,8 @@ typedef ::mozc::commands::RendererCommand_IndicatorInfo IndicatorInfo;
 typedef ::mozc::commands::RendererCommand RendererCommand;
 typedef ::mozc::commands::RendererCommand::ApplicationInfo ApplicationInfo;
 
-const size_t kSizeOfGUIThreadInfoV1 = CCSIZEOF_STRUCT(GUITHREADINFO, rcCaret);
+constexpr size_t kSizeOfGUIThreadInfoV1 =
+    CCSIZEOF_STRUCT(GUITHREADINFO, rcCaret);
 
 size_t GetTargetPos(const commands::Output &output) {
   if (!output.has_candidates() || !output.candidates().has_category()) {
@@ -331,7 +332,7 @@ void UpdateCommand(TipTextService *text_service, ITfContext *context,
 
   TipPrivateContext *private_context = text_service->GetPrivateContext(context);
   if (private_context != nullptr) {
-    command->mutable_output()->CopyFrom(private_context->last_output());
+    *command->mutable_output() = private_context->last_output();
     private_context->GetUiElementManager()->OnUpdate(text_service, context);
   }
 
