@@ -50,7 +50,6 @@ namespace tsf {
 
 namespace {
 
-using std::unique_ptr;
 using WTL::CBitmap;
 using WTL::CBitmapHandle;
 using WTL::CDC;
@@ -66,9 +65,9 @@ typedef ::mozc::commands::Preedit_Segment::Annotation Annotation;
 typedef ::mozc::commands::Candidates_Candidate Candidate;
 
 // DPI-invariant layout size constants in pixel unit.
-const int kWindowBorder = 2;
-const int kRowRectPadding = 4;
-const int kIndicatorWidth = 4;
+constexpr int kWindowBorder = 2;
+constexpr int kRowRectPadding = 4;
+constexpr int kIndicatorWidth = 4;
 
 // Color scheme
 const COLORREF kFrameColor = RGB(0x00, 0x00, 0x00);
@@ -111,10 +110,10 @@ int GetCandidateArrayIndexByCandidateIndex(const Candidates &candidates,
 // This function returns the size of the given candidate list when there
 // aren't any candidates satisfying the above condition.
 int GetFocusedArrayIndex(const Candidates &candidates) {
-  const int kInvalidIndex = candidates.candidate_size();
+  const int invalid_index = candidates.candidate_size();
 
   if (!candidates.has_focused_index()) {
-    return kInvalidIndex;
+    return invalid_index;
   }
 
   const int focused_index = candidates.focused_index();
@@ -147,18 +146,18 @@ void CalcLayout(const Candidates &candidates, const TextRenderer &text_renderer,
     std::wstring candidate_string;
     const Candidate &candidate = candidates.candidate(i);
     if (candidate.has_value()) {
-      mozc::Util::UTF8ToWide(candidate.value(), &candidate_string);
+      mozc::Util::Utf8ToWide(candidate.value(), &candidate_string);
     }
     if (candidate.has_annotation()) {
       const commands::Annotation &annotation = candidate.annotation();
       if (annotation.has_prefix()) {
         std::wstring annotation_prefix;
-        mozc::Util::UTF8ToWide(annotation.prefix(), &annotation_prefix);
+        mozc::Util::Utf8ToWide(annotation.prefix(), &annotation_prefix);
         candidate_string = annotation_prefix + candidate_string;
       }
       if (annotation.has_suffix()) {
         std::wstring annotation_suffix;
-        mozc::Util::UTF8ToWide(annotation.suffix(), &annotation_suffix);
+        mozc::Util::Utf8ToWide(annotation.suffix(), &annotation_suffix);
         candidate_string += annotation_suffix;
       }
     }
